# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2
import dota2.protobufs.dota_gcmessages_common_pb2 as dota__gcmessages__common__pb2
import dota2.protobufs.gcsdk_gcmessages_pb2 as gcsdk__gcmessages__pb2
import dota2.protobufs.dota_gcmessages_common_match_management_pb2 as dota__gcmessages__common__match__management__pb2
import dota2.protobufs.base_gcmessages_pb2 as base__gcmessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client.proto',
  package='dota',
  syntax='proto2',
  serialized_options=_b('H\001\220\001\000'),
  serialized_pb=_b('\n\x1c\x64ota_gcmessages_client.proto\x12\x04\x64ota\x1a\x13steammessages.proto\x1a\x17\x64ota_shared_enums.proto\x1a\x1c\x64ota_gcmessages_common.proto\x1a\x16gcsdk_gcmessages.proto\x1a-dota_gcmessages_common_match_management.proto\x1a\x15\x62\x61se_gcmessages.proto\"\'\n\x13\x43MsgClientSuspended\x12\x10\n\x08time_end\x18\x01 \x01(\r\"\x1a\n\x18\x43MsgBalancedShuffleLobby\"9\n CMsgInitialQuestionnaireResponse\x12\x15\n\rinitial_skill\x18\x01 \x01(\r\"/\n\x1a\x43MsgDOTAPlayerMatchHistory\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\"o\n\x1a\x43MsgDOTAMatchHistoryFilter\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\x12%\n\x1dnewest_match_id_at_last_query\x18\x02 \x01(\x04\x12\x17\n\x0ftime_last_query\x18\x03 \x01(\r\"\x87\x03\n\x16\x43MsgDOTARequestMatches\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x11\n\tgame_mode\x18\x03 \x01(\r\x12\x10\n\x08\x64\x61te_min\x18\x06 \x01(\x07\x12\x10\n\x08\x64\x61te_max\x18\x07 \x01(\x07\x12\x19\n\x11matches_requested\x18\n \x01(\r\x12\x19\n\x11start_at_match_id\x18\x0b \x01(\x04\x12\x13\n\x0bmin_players\x18\x0c \x01(\x07\x12\x12\n\nrequest_id\x18\r \x01(\r\x12\x12\n\naccount_id\x18\x0f \x01(\r\x12\x11\n\tleague_id\x18\x10 \x01(\r\x12;\n\x05skill\x18\x11 \x01(\x0e\x32\'.dota.CMsgDOTARequestMatches.SkillLevel:\x03\x41ny\x12\x0f\n\x07team_id\x18\x12 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x14 \x01(\x04\"9\n\nSkillLevel\x12\x07\n\x03\x41ny\x10\x00\x12\n\n\x06Normal\x10\x01\x12\x08\n\x04High\x10\x02\x12\x0c\n\x08VeryHigh\x10\x03\"\xa1\x02\n\x1e\x43MsgDOTARequestMatchesResponse\x12$\n\x07matches\x18\x01 \x03(\x0b\x32\x13.dota.CMsgDOTAMatch\x12;\n\x06series\x18\x02 \x03(\x0b\x32+.dota.CMsgDOTARequestMatchesResponse.Series\x12\x12\n\nrequest_id\x18\x03 \x01(\r\x12\x15\n\rtotal_results\x18\x04 \x01(\r\x12\x19\n\x11results_remaining\x18\x05 \x01(\r\x1aV\n\x06Series\x12$\n\x07matches\x18\x01 \x03(\x0b\x32\x13.dota.CMsgDOTAMatch\x12\x11\n\tseries_id\x18\x02 \x01(\r\x12\x13\n\x0bseries_type\x18\x03 \x01(\r\"\xbe\x02\n\x1f\x43MsgDOTAGetDPCStandingsResponse\x12\x41\n\tstandings\x18\x01 \x03(\x0b\x32..dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo\x1a\xa1\x01\n\x08TeamInfo\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x11\n\tteam_name\x18\x02 \x01(\t\x12\x12\n\ndpc_points\x18\x03 \x01(\r\x12\x15\n\rteam_logo_url\x18\x04 \x01(\t\x12\x46\n\x06status\x18\x05 \x01(\x0e\x32-.dota.CMsgDOTAGetDPCStandingsResponse.EStatus:\x07\x44\x45\x46\x41ULT\"4\n\x07\x45Status\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x43LINCHED\x10\x01\x12\x0e\n\nELIMINATED\x10\x02\"\x9d\x0f\n\rCMsgDOTAPopup\x12-\n\x02id\x18\x01 \x01(\x0e\x32\x1b.dota.CMsgDOTAPopup.PopupID:\x04NONE\x12\x13\n\x0b\x63ustom_text\x18\x02 \x01(\t\x12\x10\n\x08int_data\x18\x03 \x01(\x11\x12\x12\n\npopup_data\x18\x04 \x01(\x0c\x12\x18\n\x10loc_token_header\x18\x05 \x01(\t\x12\x15\n\rloc_token_msg\x18\x06 \x01(\t\x12\x11\n\tvar_names\x18\x07 \x03(\t\x12\x12\n\nvar_values\x18\x08 \x03(\t\x12\x12\n\ndebug_text\x18\t \x01(\t\"\xb5\r\n\x07PopupID\x12\x11\n\x04NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x11KICKED_FROM_LOBBY\x10\x00\x12\x15\n\x11KICKED_FROM_PARTY\x10\x01\x12\x14\n\x10KICKED_FROM_TEAM\x10\x02\x12\x16\n\x12TEAM_WAS_DISBANDED\x10\x03\x12 \n\x1cTEAM_MATCHMAKE_ALREADY_MATCH\x10\x04\x12\"\n\x1eTEAM_MATCHMAKE_ALREADY_FINDING\x10\x05\x12\x17\n\x13TEAM_MATCHMAKE_FULL\x10\x06\x12\x1b\n\x17TEAM_MATCHMAKE_FAIL_ADD\x10\x07\x12#\n\x1fTEAM_MATCHMAKE_FAIL_ADD_CURRENT\x10\x08\x12%\n!TEAM_MATCHMAKE_FAILED_TEAM_MEMBER\x10\t\x12\x1f\n\x1bTEAM_MATCHMAKE_ALREADY_GAME\x10\n\x12!\n\x1dTEAM_MATCHMAKE_FAIL_GET_PARTY\x10\x0b\x12\x18\n\x14MATCHMAKING_DISABLED\x10\x0c\x12\x11\n\rINVITE_DENIED\x10\r\x12\x0e\n\nPARTY_FULL\x10\x0e\x12\x0e\n\nMADE_ADMIN\x10\x0f\x12\x14\n\x10NEED_TO_PURCHASE\x10\x10\x12\x12\n\x0eSIGNON_MESSAGE\x10\x11\x12\x10\n\x0cGUILD_KICKED\x10\x12\x12\x1e\n\x1aMATCHMAKING_REGION_OFFLINE\x10\x13\x12\x1d\n\x19TOURNAMENT_GAME_NOT_FOUND\x10\x15\x12 \n\x1cTOURNAMENT_GAME_HAS_LOBBY_ID\x10\x16\x12 \n\x1cTOURNAMENT_GAME_HAS_MATCH_ID\x10\x17\x12\'\n#TOURNAMENT_GAME_HAS_NO_RADIANT_TEAM\x10\x18\x12$\n TOURNAMENT_GAME_HAS_NO_DIRE_TEAM\x10\x19\x12%\n!TOURNAMENT_GAME_SQL_UPDATE_FAILED\x10\x1a\x12\x14\n\x10NOT_LEAGUE_ADMIN\x10\x1b\x12\x13\n\x0fIN_ANOTHER_GAME\x10\x1d\x12 \n\x1cPARTY_MEMBER_IN_ANOTHER_GAME\x10\x1e\x12 \n\x1cPARTY_MEMBER_IN_LOW_PRIORITY\x10\x1f\x12\x16\n\x12\x43LIENT_OUT_OF_DATE\x10 \x12\x15\n\x11SAVE_GAME_CORRUPT\x10&\x12\x17\n\x13INSUFFICIENT_INGOTS\x10\'\x12\x38\n4COMPETITIVE_MM_NOT_ENOUGH_PLAY_TIME_PLAY_MORE_CASUAL\x10*\x12\x1d\n\x19PARTY_LEADER_JOINED_LOBBY\x10,\x12\x1d\n\x19WEEKEND_TOURNEY_UNMATCHED\x10\x30\x12\x15\n\x11POST_MATCH_SURVEY\x10\x31\x12\x12\n\x0eTROPHY_AWARDED\x10\x32\x12\x13\n\x0fTROPHY_LEVEL_UP\x10\x33\x12\x1f\n\x1b\x41LL_HERO_CHALLENGE_PROGRESS\x10\x34\x12\x16\n\x12NEED_INITIAL_SKILL\x10\x35\x12\x1f\n\x1bNEED_INITIAL_SKILL_IN_PARTY\x10\x36\x12\x1a\n\x16TARGET_ENGINE_MISMATCH\x10\x37\x12\x14\n\x10VAC_NOT_VERIFIED\x10\x38\x12$\n KICKED_FROM_QUEUE_EVENT_STARTING\x10\x39\x12\"\n\x1eKICKED_FROM_QUEUE_EVENT_ENDING\x10:\x12\x0e\n\nLOBBY_FULL\x10>\x12\x17\n\x13\x45VENT_POINTS_EARNED\x10?\x12!\n\x1d\x43USTOM_GAME_INCORRECT_VERSION\x10@\x12\x15\n\x11LIMITED_USER_CHAT\x10\x42\x12\x1f\n\x1b\x45VENT_PREMIUM_POINTS_EARNED\x10\x43\x12\x15\n\x11LOBBY_MVP_AWARDED\x10\x44\x12\x18\n\x14LOW_BADGE_LEVEL_CHAT\x10G\x12\x11\n\rLOW_WINS_CHAT\x10H\x12\x18\n\x14UNVERIFIED_USER_CHAT\x10I\x12%\n!PARTY_STARTED_FINDING_EVENT_MATCH\x10J\x12\x10\n\x0cGENERIC_INFO\x10\x45\x12\x11\n\rGENERIC_ERROR\x10\x46\x12\x15\n\x11RANK_TIER_UPDATED\x10K\x12#\n\x1f\x43USTOM_GAME_COOLDOWN_RESTRICTED\x10L\"!\n\x1f\x43MsgDOTAReportsRemainingRequest\"\xba\x01\n CMsgDOTAReportsRemainingResponse\x12&\n\x1enum_positive_reports_remaining\x18\x01 \x01(\r\x12&\n\x1enum_negative_reports_remaining\x18\x02 \x01(\r\x12\"\n\x1anum_positive_reports_total\x18\x03 \x01(\r\x12\"\n\x1anum_negative_reports_total\x18\x04 \x01(\r\"p\n\x1a\x43MsgDOTASubmitPlayerReport\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x14\n\x0creport_flags\x18\x02 \x01(\r\x12\x10\n\x08lobby_id\x18\x04 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\"|\n\"CMsgDOTASubmitPlayerReportResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x14\n\x0creport_flags\x18\x02 \x01(\r\x12\x0e\n\x06result\x18\x03 \x01(\r\x12\x15\n\rdebug_message\x18\x04 \x01(\t\"8\n\x1b\x43MsgDOTAReportCountsRequest\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\"\x9c\x01\n\x1c\x43MsgDOTAReportCountsResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x18\n\x10leadership_count\x18\x02 \x01(\r\x12\x16\n\x0eteaching_count\x18\x03 \x01(\r\x12\x16\n\x0e\x66riendly_count\x18\x04 \x01(\r\x12\x17\n\x0f\x66orgiving_count\x18\x05 \x01(\r\"7\n\x1a\x43MsgDOTASubmitLobbyMVPVote\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\"P\n\"CMsgDOTASubmitLobbyMVPVoteResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"l\n\x1f\x43MsgDOTALobbyMVPNotifyRecipient\x12\x18\n\x10voter_account_id\x18\x01 \x01(\r\x12\x1c\n\x14recipient_account_id\x18\x02 \x01(\r\x12\x11\n\tnum_votes\x18\x03 \x01(\r\"C\n\x17\x43MsgDOTALobbyMVPAwarded\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x16\n\x0emvp_account_id\x18\x02 \x03(\r\"\\\n\"CMsgDOTAKickedFromMatchmakingQueue\x12\x36\n\nmatch_type\x18\x01 \x01(\x0e\x32\x0f.dota.MatchType:\x11MATCH_TYPE_CASUAL\"1\n\x18\x43MsgDOTARequestSaveGames\x12\x15\n\rserver_region\x18\x01 \x01(\r\"]\n CMsgDOTARequestSaveGamesResponse\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\'\n\nsave_games\x18\x02 \x03(\x0b\x32\x13.dota.CDOTASaveGame\"-\n\x19\x43MsgGCMatchDetailsRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"\x8a\x01\n\x1a\x43MsgGCMatchDetailsResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\"\n\x05match\x18\x02 \x01(\x0b\x32\x13.dota.CMsgDOTAMatch\x12\x38\n\x04vote\x18\x03 \x01(\x0e\x32\x13.dota.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\"6\n!CMsgServerToGCMatchDetailsRequest\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\"J\n\"CMsgGCToServerMatchDetailsResponse\x12$\n\x07matches\x18\x01 \x03(\x0b\x32\x13.dota.CMsgDOTAMatch\"\xaf\x01\n\x16\x43MsgDOTAProfileTickets\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12>\n\rleague_passes\x18\x03 \x03(\x0b\x32\'.dota.CMsgDOTAProfileTickets.LeaguePass\x1a\x31\n\nLeaguePass\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x10\n\x08item_def\x18\x02 \x01(\r\"5\n\x1f\x43MsgClientToGCGetProfileTickets\x12\x12\n\naccount_id\x18\x01 \x01(\r\"%\n#CMsgDOTAClearNotifySuccessfulReport\"Z\n CMsgGCToClientPartySearchInvites\x12\x36\n\x07invites\x18\x01 \x03(\x0b\x32%.dota.CMsgGCToClientPartySearchInvite\"\xee\x06\n\x0f\x43MsgDOTAWelcome\x12\x17\n\x0fstore_item_hash\x18\x05 \x01(\r\x12\x1f\n\x17timeplayedconsecutively\x18\x06 \x01(\r\x12%\n\x1d\x61llow_3rd_party_match_history\x18\x07 \x01(\x08\x12\x44\n\x14partner_account_type\x18\x08 \x01(\x0e\x32\x18.dota.PartnerAccountType:\x0cPARTNER_NONE\x12\x1d\n\x15partner_account_state\x18\x0b \x01(\r\x12\x18\n\x10last_time_played\x18\x0c \x01(\r\x12\x17\n\x0flast_ip_address\x18\r \x01(\r\x12#\n\x1bshutdownlawterminateminutes\x18\x0f \x01(\r\x12 \n\x18\x62\x61nned_word_list_version\x18\x10 \x01(\r\x12\x17\n\x0fprofile_private\x18\x11 \x01(\x08\x12\x10\n\x08\x63urrency\x18\x12 \x01(\r\x12\x1a\n\x12pwrd_cyber_cafe_id\x18\x13 \x01(\r\x12$\n\x1cshould_request_player_origin\x18\x14 \x01(\x08\x12\x1a\n\x12\x63ompendium_unlocks\x18\x15 \x01(\x04\x12\x1f\n\x17gc_socache_file_version\x18\x16 \x01(\r\x12%\n\x1dis_perfect_world_test_account\x18\x18 \x01(\x08\x12\x37\n\x0e\x65xtra_messages\x18\x1a \x03(\x0b\x32\x1f.dota.CMsgDOTAWelcome.CExtraMsg\x12\x1e\n\x16minimum_recent_item_id\x18\x1b \x01(\x04\x12\x31\n\x0c\x61\x63tive_event\x18\x1c \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x1f\n\x17\x61\x64\x64itional_user_message\x18\x1d \x01(\r\x12%\n\x1d\x63ustom_game_whitelist_version\x18\x1e \x01(\r\x12K\n\x1bparty_search_friend_invites\x18\x1f \x01(\x0b\x32&.dota.CMsgGCToClientPartySearchInvites\x1a)\n\tCExtraMsg\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x63ontents\x18\x02 \x01(\x0c\"K\n\x18\x43SODOTAGameHeroFavorites\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x15\n\x07hero_id\x18\x02 \x01(\rB\x04\x80\x97\"\x01\"+\n\x18\x43MsgDOTAHeroFavoritesAdd\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\".\n\x1b\x43MsgDOTAHeroFavoritesRemove\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"Z\n\x15\x43MsgDOTAFeaturedItems\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10\x66\x65\x61tured_item_id\x18\x02 \x03(\x04\x12\x13\n\x0bobject_data\x18\x03 \x03(\x0c\"\x8a\x01\n\x12\x43MsgDOTAMatchVotes\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x32\n\x05votes\x18\x02 \x03(\x0b\x32#.dota.CMsgDOTAMatchVotes.PlayerVote\x1a.\n\nPlayerVote\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04vote\x18\x02 \x01(\r\"_\n\x11\x43MsgCastMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x38\n\x04vote\x18\x02 \x01(\x0e\x32\x13.dota.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\">\n\x15\x43MsgRetrieveMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x13\n\x0bincremental\x18\x02 \x01(\r\"\x95\x01\n\x15\x43MsgMatchVoteResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x38\n\x04vote\x18\x02 \x01(\x0e\x32\x13.dota.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\x12\x16\n\x0epositive_votes\x18\x03 \x01(\r\x12\x16\n\x0enegative_votes\x18\x04 \x01(\r\"\xef\x02\n\x12\x43MsgDOTAHallOfFame\x12\x0c\n\x04week\x18\x01 \x01(\r\x12\x41\n\x10\x66\x65\x61tured_players\x18\x02 \x03(\x0b\x32\'.dota.CMsgDOTAHallOfFame.FeaturedPlayer\x12@\n\x0f\x66\x65\x61tured_farmer\x18\x03 \x01(\x0b\x32\'.dota.CMsgDOTAHallOfFame.FeaturedFarmer\x1ag\n\x0e\x46\x65\x61turedPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x1d\n\x15\x61verage_scaled_metric\x18\x03 \x01(\x02\x12\x11\n\tnum_games\x18\x04 \x01(\r\x1a]\n\x0e\x46\x65\x61turedFarmer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x14\n\x0cgold_per_min\x18\x03 \x01(\r\x12\x10\n\x08match_id\x18\x04 \x01(\x04\")\n\x19\x43MsgDOTAHallOfFameRequest\x12\x0c\n\x04week\x18\x01 \x01(\r\"`\n\x1a\x43MsgDOTAHallOfFameResponse\x12.\n\x0chall_of_fame\x18\x01 \x01(\x0b\x32\x18.dota.CMsgDOTAHallOfFame\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"6\n!CMsgDOTAHalloweenHighScoreRequest\x12\x11\n\x05round\x18\x01 \x01(\x05:\x02-1\"w\n\"CMsgDOTAHalloweenHighScoreResponse\x12\r\n\x05score\x18\x01 \x01(\r\x12\"\n\x05match\x18\x02 \x01(\x0b\x32\x13.dota.CMsgDOTAMatch\x12\x0f\n\x07\x65result\x18\x03 \x01(\r\x12\r\n\x05round\x18\x04 \x01(\x05\"6\n\x1e\x43MsgDOTAStorePromoPagesRequest\x12\x14\n\x0cversion_seen\x18\x01 \x01(\r\"\x9c\x01\n\x1f\x43MsgDOTAStorePromoPagesResponse\x12>\n\x05pages\x18\x01 \x03(\x0b\x32/.dota.CMsgDOTAStorePromoPagesResponse.PromoPage\x1a\x39\n\tPromoPage\x12\x10\n\x08promo_id\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"\xe0\x01\n\x1d\x43MsgMatchmakingMatchGroupInfo\x12\x19\n\x11players_searching\x18\x01 \x01(\r\x12\'\n\x1f\x61uto_region_select_ping_penalty\x18\x02 \x01(\x11\x12.\n&auto_region_select_ping_penalty_custom\x18\x04 \x01(\x11\x12K\n\x06status\x18\x03 \x01(\x0e\x32\x1d.dota.EMatchGroupServerStatus:\x1ck_EMatchGroupServerStatus_OK\"!\n\x1f\x43MsgDOTAMatchmakingStatsRequest\"\xad\x01\n CMsgDOTAMatchmakingStatsResponse\x12\x1b\n\x13matchgroups_version\x18\x01 \x01(\r\x12\x31\n)legacy_searching_players_by_group_source2\x18\x07 \x03(\r\x12\x39\n\x0cmatch_groups\x18\x08 \x03(\x0b\x32#.dota.CMsgMatchmakingMatchGroupInfo\"W\n\x1e\x43MsgDOTAUpdateMatchmakingStats\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32&.dota.CMsgDOTAMatchmakingStatsResponse\"[\n\"CMsgDOTAUpdateMatchManagementStats\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32&.dota.CMsgDOTAMatchmakingStatsResponse\"F\n\x1d\x43MsgDOTASetMatchHistoryAccess\x12%\n\x1d\x61llow_3rd_party_match_history\x18\x01 \x01(\x08\";\n%CMsgDOTASetMatchHistoryAccessResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"L\n CMsgDOTANotifyAccountFlagsChange\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x15\n\raccount_flags\x18\x02 \x01(\r\"4\n\x19\x43MsgDOTASetProfilePrivacy\x12\x17\n\x0fprofile_private\x18\x01 \x01(\x08\"4\n!CMsgDOTASetProfilePrivacyResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"<\n\x15\x43MsgUpgradeLeagueItem\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x11\n\tleague_id\x18\x02 \x01(\r\"\x1f\n\x1d\x43MsgUpgradeLeagueItemResponse\"y\n\x1b\x43MsgGCWatchDownloadedReplay\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12H\n\nwatch_type\x18\x02 \x01(\x0e\x32\x1a.dota.DOTA_WatchReplayType:\x18\x44OTA_WATCH_REPLAY_NORMAL\"A\n\x17\x43MsgSetMapLocationState\x12\x13\n\x0blocation_id\x18\x01 \x01(\x05\x12\x11\n\tcompleted\x18\x02 \x01(\x08\"5\n\x1f\x43MsgSetMapLocationStateResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"\x17\n\x15\x43MsgResetMapLocations\"3\n\x1d\x43MsgResetMapLocationsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"5\n\x1d\x43MsgRefreshPartnerAccountLink\x12\x14\n\x0cpartner_type\x18\x01 \x01(\x05\"\x1f\n\x1d\x43MsgClientsRejoinChatChannels\".\n\x1a\x43MsgDOTASendFriendRecruits\x12\x10\n\x08recruits\x18\x01 \x03(\r\"4\n\x1d\x43MsgDOTAFriendRecruitsRequest\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\r\"\x91\x03\n\x1e\x43MsgDOTAFriendRecruitsResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.dota.CMsgDOTAFriendRecruitsResponse.EResult:\x07SUCCESS\x12J\n\x08recruits\x18\x02 \x03(\x0b\x32\x38.dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus\x12L\n\nrecruiters\x18\x03 \x03(\x0b\x32\x38.dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus\x1a_\n\x13\x46riendRecruitStatus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x15\n\rlevels_earned\x18\x03 \x01(\r\x12\r\n\x05\x62onus\x18\x04 \x01(\x08\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"P\n(CMsgDOTAFriendRecruitInviteAcceptDecline\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x12\n\naccount_id\x18\x02 \x01(\r\"/\n\x1a\x43MsgRequestLeaguePrizePool\x12\x11\n\tleague_id\x18\x01 \x01(\r\"K\n\"CMsgRequestLeaguePrizePoolResponse\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x12\n\nprize_pool\x18\x02 \x01(\r\"\x18\n\x16\x43MsgGCGetHeroStandings\"\xa0\x05\n\x1e\x43MsgGCGetHeroStandingsResponse\x12<\n\tstandings\x18\x01 \x03(\x0b\x32).dota.CMsgGCGetHeroStandingsResponse.Hero\x1a\xbf\x04\n\x04Hero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x0c\n\x04wins\x18\x02 \x01(\r\x12\x0e\n\x06losses\x18\x03 \x01(\r\x12\x12\n\nwin_streak\x18\x04 \x01(\r\x12\x17\n\x0f\x62\x65st_win_streak\x18\x05 \x01(\r\x12\x11\n\tavg_kills\x18\x06 \x01(\x02\x12\x12\n\navg_deaths\x18\x07 \x01(\x02\x12\x13\n\x0b\x61vg_assists\x18\x08 \x01(\x02\x12\x0f\n\x07\x61vg_gpm\x18\t \x01(\x02\x12\x0f\n\x07\x61vg_xpm\x18\n \x01(\x02\x12\x12\n\nbest_kills\x18\x0b \x01(\r\x12\x14\n\x0c\x62\x65st_assists\x18\x0c \x01(\r\x12\x10\n\x08\x62\x65st_gpm\x18\r \x01(\r\x12\x10\n\x08\x62\x65st_xpm\x18\x0e \x01(\r\x12\x13\n\x0bperformance\x18\x0f \x01(\x02\x12\x16\n\x0ewins_with_ally\x18\x10 \x01(\r\x12\x18\n\x10losses_with_ally\x18\x11 \x01(\r\x12\x1a\n\x12wins_against_enemy\x18\x12 \x01(\r\x12\x1c\n\x14losses_against_enemy\x18\x13 \x01(\r\x12\x15\n\rnetworth_peak\x18\x14 \x01(\r\x12\x14\n\x0clasthit_peak\x18\x15 \x01(\r\x12\x11\n\tdeny_peak\x18\x16 \x01(\r\x12\x13\n\x0b\x64\x61mage_peak\x18\x17 \x01(\r\x12\x19\n\x11longest_game_peak\x18\x18 \x01(\r\x12\x14\n\x0chealing_peak\x18\x19 \x01(\r\x12\x14\n\x0c\x61vg_lasthits\x18\x1a \x01(\x02\x12\x12\n\navg_denies\x18\x1b \x01(\x02\"*\n\x17\x43MsgGCGetHeroTimedStats\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\"\x85\x01\n\x1d\x43MatchPlayerTimedStatAverages\x12\r\n\x05kills\x18\x02 \x01(\x02\x12\x0e\n\x06\x64\x65\x61ths\x18\x03 \x01(\x02\x12\x0f\n\x07\x61ssists\x18\x04 \x01(\x02\x12\x11\n\tnet_worth\x18\x05 \x01(\x02\x12\x11\n\tlast_hits\x18\x06 \x01(\x02\x12\x0e\n\x06\x64\x65nies\x18\x07 \x01(\x02\"\xd3\x03\n\x1f\x43MsgGCGetHeroTimedStatsResponse\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12R\n\x12rank_chunked_stats\x18\x02 \x03(\x0b\x32\x36.dota.CMsgGCGetHeroTimedStatsResponse.RankChunkedStats\x1a\xd2\x01\n\x13TimedStatsContainer\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x36\n\tall_stats\x18\x02 \x01(\x0b\x32#.dota.CMatchPlayerTimedStatAverages\x12:\n\rwinning_stats\x18\x03 \x01(\x0b\x32#.dota.CMatchPlayerTimedStatAverages\x12\x39\n\x0closing_stats\x18\x04 \x01(\x0b\x32#.dota.CMatchPlayerTimedStatAverages\x1av\n\x10RankChunkedStats\x12\x12\n\nrank_chunk\x18\x01 \x01(\r\x12N\n\x0btimed_stats\x18\x02 \x03(\x0b\x32\x39.dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer\"%\n#CMsgGCItemEditorReservationsRequest\">\n\x1b\x43MsgGCItemEditorReservation\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"_\n$CMsgGCItemEditorReservationsResponse\x12\x37\n\x0creservations\x18\x01 \x03(\x0b\x32!.dota.CMsgGCItemEditorReservation\"E\n\x1e\x43MsgGCItemEditorReserveItemDef\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\"]\n&CMsgGCItemEditorReserveItemDefResponse\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\r\"I\n\"CMsgGCItemEditorReleaseReservation\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\"Q\n*CMsgGCItemEditorReleaseReservationResponse\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08released\x18\x02 \x01(\x08\"J\n\x1c\x43MsgDOTARewardTutorialPrizes\x12\x13\n\x0blocation_id\x18\x01 \x01(\r\x12\x15\n\rtracking_only\x18\x02 \x01(\x08\"L\n%CMsgDOTALastHitChallengeHighScorePost\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x12\n\nhigh_score\x18\x02 \x01(\r\";\n(CMsgDOTALastHitChallengeHighScoreRequest\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"K\n)CMsgDOTALastHitChallengeHighScoreResponse\x12\r\n\x05score\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"\x14\n\x12\x43MsgFlipLobbyTeams\"!\n\x1f\x43MsgPresentedClientTerminateDlg\"}\n%CMsgGCLobbyUpdateBroadcastChannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\"\xb9\x01\n\x1c\x43MsgDOTAClaimEventActionData\x12R\n\x14grant_item_gift_data\x18\x04 \x01(\x0b\x32\x34.dota.CMsgDOTAClaimEventActionData.GrantItemGiftData\x1a\x45\n\x11GrantItemGiftData\x12\x1a\n\x12give_to_account_id\x18\x01 \x01(\r\x12\x14\n\x0cgift_message\x18\x02 \x01(\t\"\x83\x01\n\x18\x43MsgDOTAClaimEventAction\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x11\n\taction_id\x18\x02 \x01(\r\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x30\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\".dota.CMsgDOTAClaimEventActionData\"\xc5\x05\n CMsgDOTAClaimEventActionResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.dota.CMsgDOTAClaimEventActionResponse.ResultCode:\x07Success\x12P\n\x0ereward_results\x18\x02 \x03(\x0b\x32\x38.dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData\x1a@\n\x15MysteryItemRewardData\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x15\n\ritem_category\x18\x02 \x01(\r\x1a&\n\x12LootListRewardData\x12\x10\n\x08item_def\x18\x01 \x03(\r\x1ah\n\x11GrantedRewardData\x12\x13\n\x0bgrant_index\x18\x01 \x01(\r\x12\x13\n\x0bscore_index\x18\x02 \x01(\r\x12\x14\n\x0creward_index\x18\x03 \x01(\r\x12\x13\n\x0breward_data\x18\x04 \x01(\x0c\"\xae\x02\n\nResultCode\x12\x0b\n\x07Success\x10\x00\x12\x10\n\x0cInvalidEvent\x10\x01\x12\x12\n\x0e\x45ventNotActive\x10\x02\x12\x11\n\rInvalidAction\x10\x03\x12\x0f\n\x0bServerError\x10\x04\x12\x16\n\x12InsufficientPoints\x10\x05\x12\x14\n\x10InsufficentLevel\x10\x06\x12\x12\n\x0e\x41lreadyClaimed\x10\x07\x12\x12\n\x0eSDOLockFailure\x10\x08\x12\x12\n\x0eSDOLoadFailure\x10\t\x12\x11\n\rEventNotOwned\x10\n\x12\x0b\n\x07Timeout\x10\x0b\x12\x1c\n\x18RequiresPlusSubscription\x10\x0c\x12\x0f\n\x0bInvalidItem\x10\r\x12\x10\n\x0c\x41syncRewards\x10\x0e\"q\n\'CMsgClientToGCClaimEventActionUsingItem\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x11\n\taction_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\x12\x10\n\x08quantity\x18\x04 \x01(\r\"q\n/CMsgClientToGCClaimEventActionUsingItemResponse\x12>\n\x0e\x61\x63tion_results\x18\x01 \x01(\x0b\x32&.dota.CMsgDOTAClaimEventActionResponse\"\x83\x01\n0CMsgGCToClientClaimEventActionUsingItemCompleted\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12>\n\x0e\x61\x63tion_results\x18\x02 \x01(\x0b\x32&.dota.CMsgDOTAClaimEventActionResponse\">\n\x16\x43MsgDOTAGetEventPoints\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xc8\x02\n\x1e\x43MsgDOTAGetEventPointsResponse\x12\x14\n\x0ctotal_points\x18\x01 \x01(\r\x12\x1c\n\x14total_premium_points\x18\x02 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x03 \x01(\r\x12\x0e\n\x06points\x18\x04 \x01(\r\x12\x16\n\x0epremium_points\x18\x05 \x01(\r\x12\x46\n\x11\x63ompleted_actions\x18\x06 \x03(\x0b\x32+.dota.CMsgDOTAGetEventPointsResponse.Action\x12\x12\n\naccount_id\x18\x07 \x01(\r\x12\r\n\x05owned\x18\x08 \x01(\x08\x12\x14\n\x0c\x61udit_action\x18\t \x01(\r\x1a\x37\n\x06\x41\x63tion\x12\x11\n\taction_id\x18\x01 \x01(\r\x12\x1a\n\x0ftimes_completed\x18\x02 \x01(\r:\x01\x31\"b\n\x1b\x43MsgDOTAGetPeriodicResource\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1c\n\x14periodic_resource_id\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"d\n#CMsgDOTAGetPeriodicResourceResponse\x12\x1d\n\x15periodic_resource_max\x18\x01 \x01(\r\x12\x1e\n\x16periodic_resource_used\x18\x02 \x01(\r\"\xaf\x01\n\x1f\x43MsgDOTAPeriodicResourceUpdated\x12@\n\x15periodic_resource_key\x18\x01 \x01(\x0b\x32!.dota.CMsgDOTAGetPeriodicResource\x12J\n\x17periodic_resource_value\x18\x02 \x01(\x0b\x32).dota.CMsgDOTAGetPeriodicResourceResponse\"9\n\x1c\x43MsgDOTALiveLeagueGameUpdate\x12\x19\n\x11live_league_games\x18\x01 \x01(\r\"[\n\x1b\x43MsgDOTACompendiumSelection\x12\x17\n\x0fselection_index\x18\x01 \x01(\r\x12\x11\n\tselection\x18\x02 \x01(\r\x12\x10\n\x08leagueid\x18\x03 \x01(\r\"9\n#CMsgDOTACompendiumSelectionResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"O\n\x16\x43MsgDOTACompendiumData\x12\x35\n\nselections\x18\x01 \x03(\x0b\x32!.dota.CMsgDOTACompendiumSelection\"E\n\x1d\x43MsgDOTACompendiumDataRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08leagueid\x18\x02 \x01(\r\"\x90\x01\n\x1e\x43MsgDOTACompendiumDataResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08leagueid\x18\x02 \x01(\r\x12\x11\n\x06result\x18\x03 \x01(\r:\x01\x32\x12\x35\n\x0f\x63ompendium_data\x18\x04 \x01(\x0b\x32\x1c.dota.CMsgDOTACompendiumData\"\xeb\x01\n\x1d\x43MsgDOTAGetPlayerMatchHistory\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x19\n\x11start_at_match_id\x18\x02 \x01(\x04\x12\x19\n\x11matches_requested\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x12\n\nrequest_id\x18\x05 \x01(\r\x12 \n\x18include_practice_matches\x18\x07 \x01(\x08\x12\x1c\n\x14include_custom_games\x18\x08 \x01(\x08\x12\x1b\n\x13include_event_games\x18\t \x01(\x08\"\xbb\x04\n%CMsgDOTAGetPlayerMatchHistoryResponse\x12\x42\n\x07matches\x18\x01 \x03(\x0b\x32\x31.dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match\x12\x12\n\nrequest_id\x18\x02 \x01(\r\x1a\xb9\x03\n\x05Match\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x0e\n\x06winner\x18\x04 \x01(\x08\x12\x11\n\tgame_mode\x18\x05 \x01(\r\x12\x13\n\x0brank_change\x18\x06 \x01(\x05\x12\x15\n\rprevious_rank\x18\x07 \x01(\r\x12\x12\n\nlobby_type\x18\x08 \x01(\r\x12\x11\n\tsolo_rank\x18\t \x01(\x08\x12\x0f\n\x07\x61\x62\x61ndon\x18\n \x01(\x08\x12\x10\n\x08\x64uration\x18\x0b \x01(\r\x12\x0e\n\x06\x65ngine\x18\x0c \x01(\r\x12 \n\x18\x61\x63tive_plus_subscription\x18\r \x01(\x08\x12\x15\n\rseasonal_rank\x18\x0e \x01(\x08\x12\x12\n\ntourney_id\x18\x0f \x01(\r\x12\x15\n\rtourney_round\x18\x10 \x01(\r\x12\x14\n\x0ctourney_tier\x18\x11 \x01(\r\x12\x18\n\x10tourney_division\x18\x12 \x01(\r\x12\x0f\n\x07team_id\x18\x13 \x01(\r\x12\x11\n\tteam_name\x18\x14 \x01(\t\x12\x18\n\x10ugc_team_ui_logo\x18\x15 \x01(\x04\"!\n\x1f\x43MsgDOTAStartDailyHeroChallenge\"\x1c\n\x1a\x43MsgGCNotificationsRequest\"\xf5\x02\n\x1b\x43MsgGCNotificationsResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32).dota.CMsgGCNotificationsResponse.EResult:\x07SUCCESS\x12\x45\n\rnotifications\x18\x02 \x03(\x0b\x32..dota.CMsgGCNotificationsResponse.Notification\x1a\x9b\x01\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x13\n\x0breference_a\x18\x04 \x01(\r\x12\x13\n\x0breference_b\x18\x05 \x01(\r\x12\x13\n\x0breference_c\x18\x06 \x01(\r\x12\x0f\n\x07message\x18\x07 \x01(\t\x12\x0e\n\x06unread\x18\x08 \x01(\x08\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"$\n\"CMsgGCNotificationsMarkReadRequest\"B\n&CMsgClientToGCMarkNotificationListRead\x12\x18\n\x10notification_ids\x18\x01 \x03(\x04\"\x8e\x01\n\x17\x43MsgGCPlayerInfoRequest\x12>\n\x0cplayer_infos\x18\x01 \x03(\x0b\x32(.dota.CMsgGCPlayerInfoRequest.PlayerInfo\x1a\x33\n\nPlayerInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\"t\n\x16\x43MsgGCPlayerInfoSubmit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x14\n\x0c\x66\x61ntasy_role\x18\x03 \x01(\r\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x0f\n\x07sponsor\x18\x05 \x01(\t\"\xad\x01\n\x1e\x43MsgGCPlayerInfoSubmitResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.dota.CMsgGCPlayerInfoSubmitResponse.EResult:\x07SUCCESS\"D\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x15\n\x11\x45RROR_INFO_LOCKED\x10\x02\"\xab\x01\n\x1d\x43MsgClientProvideSurveyResult\x12?\n\tresponses\x18\x01 \x03(\x0b\x32,.dota.CMsgClientProvideSurveyResult.Response\x12\x12\n\nsurvey_key\x18\x02 \x01(\x04\x1a\x35\n\x08Response\x12\x13\n\x0bquestion_id\x18\x01 \x01(\r\x12\x14\n\x0csurvey_value\x18\x02 \x01(\r\"K\n\x19\x43MsgDOTAEmoticonAccessSDO\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1a\n\x12unlocked_emoticons\x18\x02 \x01(\x0c\"#\n!CMsgClientToGCEmoticonDataRequest\"V\n\x1a\x43MsgGCToClientEmoticonData\x12\x38\n\x0f\x65moticon_access\x18\x01 \x01(\x0b\x32\x1f.dota.CMsgDOTAEmoticonAccessSDO\"C\n\x1f\x43MsgClientToGCTrackDialogResult\x12\x11\n\tdialog_id\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\"H\n CMsgGCToClientTournamentItemDrop\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x12\n\nevent_type\x18\x02 \x01(\r\"O\n!CMsgClientToGCSetAdditionalEquips\x12*\n\x06\x65quips\x18\x01 \x03(\x0b\x32\x1a.dota.CAdditionalEquipSlot\"+\n)CMsgClientToGCSetAdditionalEquipsResponse\"#\n!CMsgClientToGCGetAdditionalEquips\"W\n)CMsgClientToGCGetAdditionalEquipsResponse\x12*\n\x06\x65quips\x18\x01 \x03(\x0b\x32\x1a.dota.CAdditionalEquipSlot\"\x1f\n\x1d\x43MsgClientToGCGetAllHeroOrder\"9\n%CMsgClientToGCGetAllHeroOrderResponse\x12\x10\n\x08hero_ids\x18\x01 \x03(\r\"6\n CMsgClientToGCGetAllHeroProgress\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\x99\x04\n(CMsgClientToGCGetAllHeroProgressResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63urr_hero_id\x18\x02 \x01(\r\x12\x16\n\x0elaps_completed\x18\x03 \x01(\r\x12\x17\n\x0f\x63urr_hero_games\x18\x04 \x01(\r\x12\x1d\n\x15\x63urr_lap_time_started\x18\x05 \x01(\r\x12\x16\n\x0e\x63urr_lap_games\x18\x06 \x01(\r\x12\x16\n\x0e\x62\x65st_lap_games\x18\x07 \x01(\r\x12\x15\n\rbest_lap_time\x18\x08 \x01(\r\x12\x1c\n\x14lap_heroes_completed\x18\t \x01(\r\x12\x1c\n\x14lap_heroes_remaining\x18\n \x01(\r\x12\x14\n\x0cnext_hero_id\x18\x0b \x01(\r\x12\x14\n\x0cprev_hero_id\x18\x0c \x01(\r\x12\x17\n\x0fprev_hero_games\x18\r \x01(\r\x12\x16\n\x0eprev_avg_tries\x18\x0e \x01(\x02\x12\x16\n\x0e\x63urr_avg_tries\x18\x0f \x01(\x02\x12\x16\n\x0enext_avg_tries\x18\x10 \x01(\x02\x12\x1a\n\x12\x66ull_lap_avg_tries\x18\x11 \x01(\x02\x12\x1a\n\x12\x63urr_lap_avg_tries\x18\x12 \x01(\x02\x12\x14\n\x0cprofile_name\x18\x13 \x01(\t\x12\x15\n\rstart_hero_id\x18\x14 \x01(\r\"1\n\x1b\x43MsgClientToGCGetTrophyList\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xdc\x01\n#CMsgClientToGCGetTrophyListResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x42\n\x08trophies\x18\x02 \x03(\x0b\x32\x30.dota.CMsgClientToGCGetTrophyListResponse.Trophy\x12\x14\n\x0cprofile_name\x18\x03 \x01(\t\x1aG\n\x06Trophy\x12\x11\n\ttrophy_id\x18\x01 \x01(\r\x12\x14\n\x0ctrophy_score\x18\x02 \x01(\r\x12\x14\n\x0clast_updated\x18\x03 \x01(\r\"v\n\x1b\x43MsgGCToClientTrophyAwarded\x12\x11\n\ttrophy_id\x18\x01 \x01(\r\x12\x14\n\x0ctrophy_score\x18\x02 \x01(\r\x12\x18\n\x10trophy_old_score\x18\x03 \x01(\r\x12\x14\n\x0clast_updated\x18\x04 \x01(\r\"2\n\x1c\x43MsgClientToGCGetProfileCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xe2\x01\n!CMsgClientToGCSetProfileCardSlots\x12?\n\x05slots\x18\x01 \x03(\x0b\x32\x30.dota.CMsgClientToGCSetProfileCardSlots.CardSlot\x1a|\n\x08\x43\x61rdSlot\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12K\n\tslot_type\x18\x02 \x01(\x0e\x32\x1a.dota.EProfileCardSlotType:\x1ck_EProfileCardSlotType_Empty\x12\x12\n\nslot_value\x18\x03 \x01(\x04\"#\n!CMsgClientToGCGetProfileCardStats\"\xd4\x01\n\x1e\x43MsgClientToGCCreateHeroStatue\x12\x13\n\x0bsource_item\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x15\n\rsequence_name\x18\x04 \x01(\t\x12\r\n\x05\x63ycle\x18\x05 \x01(\x02\x12\x11\n\twearables\x18\x06 \x03(\r\x12\x13\n\x0binscription\x18\x07 \x01(\t\x12\x0e\n\x06styles\x18\x08 \x03(\r\x12\x15\n\rreforger_item\x18\t \x01(\x04\x12\x17\n\x0ftournament_drop\x18\n \x01(\x08\">\n$CMsgGCToClientHeroStatueCreateResult\x12\x16\n\x0eresulting_item\x18\x01 \x01(\x04\"U\n CMsgGCToClientEventStatusChanged\x12\x31\n\x0c\x61\x63tive_event\x18\x02 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\"6\n CMsgClientToGCPlayerStatsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xaa\x04\n!CMsgGCToClientPlayerStatsResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0cplayer_stats\x18\x02 \x03(\x02\x12\x13\n\x0bmatch_count\x18\x03 \x01(\r\x12\x10\n\x08mean_gpm\x18\x04 \x01(\x02\x12\x11\n\tmean_xppm\x18\x05 \x01(\x02\x12\x15\n\rmean_lasthits\x18\x06 \x01(\x02\x12\x10\n\x08rampages\x18\x07 \x01(\r\x12\x14\n\x0ctriple_kills\x18\x08 \x01(\r\x12\x1b\n\x13\x66irst_blood_claimed\x18\t \x01(\r\x12\x19\n\x11\x66irst_blood_given\x18\n \x01(\r\x12\x17\n\x0f\x63ouriers_killed\x18\x0b \x01(\r\x12\x18\n\x10\x61\x65gises_snatched\x18\x0c \x01(\r\x12\x15\n\rcheeses_eaten\x18\r \x01(\r\x12\x16\n\x0e\x63reeps_stacked\x18\x0e \x01(\r\x12\x13\n\x0b\x66ight_score\x18\x0f \x01(\x02\x12\x12\n\nfarm_score\x18\x10 \x01(\x02\x12\x15\n\rsupport_score\x18\x11 \x01(\x02\x12\x12\n\npush_score\x18\x12 \x01(\x02\x12\x19\n\x11versatility_score\x18\x13 \x01(\x02\x12\x15\n\rmean_networth\x18\x14 \x01(\x02\x12\x13\n\x0bmean_damage\x18\x15 \x01(\x02\x12\x12\n\nmean_heals\x18\x16 \x01(\x02\x12\x19\n\x11rapiers_purchased\x18\x17 \x01(\r\"D\n*CMsgClientToGCCustomGamePlayerCountRequest\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\"t\n+CMsgGCToClientCustomGamePlayerCountResponse\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x14\n\x0cplayer_count\x18\x02 \x01(\x04\x12\x17\n\x0fspectator_count\x18\x03 \x01(\x04\"/\n-CMsgClientToGCCustomGamesFriendsPlayedRequest\"\xcf\x01\n.CMsgGCToClientCustomGamesFriendsPlayedResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12N\n\x05games\x18\x02 \x03(\x0b\x32?.dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame\x1a\x39\n\nCustomGame\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\"O\n*CMsgClientToGCSocialFeedPostCommentRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\">\n+CMsgGCToClientSocialFeedPostCommentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"h\n*CMsgClientToGCSocialFeedPostMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x17\n\x0fmatch_timestamp\x18\x03 \x01(\r\">\n+CMsgGCToClientSocialFeedPostMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"F\n,CMsgClientToGCFriendsPlayedCustomGameRequest\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\"\\\n-CMsgGCToClientFriendsPlayedCustomGameResponse\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\"P\n+CMsgClientToGCSocialMatchPostCommentRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"?\n,CMsgGCToClientSocialMatchPostCommentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"Y\n\'CMsgClientToGCSocialMatchDetailsRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x1c\n\x14pagination_timestamp\x18\x02 \x01(\r\"\xde\x01\n(CMsgGCToClientSocialMatchDetailsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12H\n\x08\x63omments\x18\x02 \x03(\x0b\x32\x36.dota.CMsgGCToClientSocialMatchDetailsResponse.Comment\x1aW\n\x07\x43omment\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"\xdb\x04\n\x19\x43MsgDOTAPartyRichPresence\x12\x10\n\x08party_id\x18\x01 \x01(\x06\x12\x31\n\x0bparty_state\x18\x02 \x01(\x0e\x32\x18.dota.CSODOTAParty.State:\x02UI\x12\x0c\n\x04open\x18\x03 \x01(\x08\x12\x14\n\x0clow_priority\x18\x05 \x01(\x08\x12\x0f\n\x07team_id\x18\x07 \x01(\r\x12\x11\n\tteam_name\x18\x08 \x01(\t\x12\x18\n\x10ugc_team_ui_logo\x18\t \x01(\x04\x12\x37\n\x07members\x18\x04 \x03(\x0b\x32&.dota.CMsgDOTAPartyRichPresence.Member\x12G\n\x0fweekend_tourney\x18\x06 \x01(\x0b\x32..dota.CMsgDOTAPartyRichPresence.WeekendTourney\x1a)\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\r\n\x05\x63oach\x18\x02 \x01(\x08\x1a\xe9\x01\n\x0eWeekendTourney\x12\x10\n\x08\x64ivision\x18\x01 \x01(\r\x12\x13\n\x0bskill_level\x18\x02 \x01(\r\x12\r\n\x05round\x18\x03 \x01(\r\x12\x15\n\rtournament_id\x18\x04 \x01(\r\x12\x15\n\rstate_seq_num\x18\x05 \x01(\r\x12^\n\x05\x65vent\x18\x06 \x01(\x0e\x32&.dota.EWeekendTourneyRichPresenceEvent:\'k_EWeekendTourneyRichPresenceEvent_None\x12\x13\n\x0b\x65vent_round\x18\x07 \x01(\r\"\x98\x02\n\x19\x43MsgDOTALobbyRichPresence\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x31\n\x0blobby_state\x18\x02 \x01(\x0e\x32\x18.dota.CSODOTALobby.State:\x02UI\x12\x10\n\x08password\x18\x03 \x01(\x08\x12:\n\tgame_mode\x18\x04 \x01(\x0e\x32\x13.dota.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\x12\x14\n\x0cmember_count\x18\x05 \x01(\r\x12\x18\n\x10max_member_count\x18\x06 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x07 \x01(\x06\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x12\n\nlobby_type\x18\t \x01(\r\"\x83\x01\n,CMsgDOTACustomGameListenServerStartedLoading\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63ustom_game_id\x18\x02 \x01(\x04\x12\x15\n\rlobby_members\x18\x03 \x03(\r\x12\x12\n\nstart_time\x18\x04 \x01(\r\"\xa9\x01\n\'CMsgDOTACustomGameClientFinishedLoading\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x18\n\x10loading_duration\x18\x02 \x01(\r\x12\x13\n\x0bresult_code\x18\x03 \x01(\x11\x12\x15\n\rresult_string\x18\x04 \x01(\t\x12\x15\n\rsignon_states\x18\x05 \x01(\r\x12\x0f\n\x07\x63omment\x18\x06 \x01(\t\"F\n\x1e\x43MsgClientToGCApplyGemCombiner\x12\x11\n\titem_id_1\x18\x01 \x01(\x04\x12\x11\n\titem_id_2\x18\x02 \x01(\x04\"\x1f\n\x1d\x43MsgClientToGCH264Unsupported\"\"\n CMsgClientToGCRequestH264Support\"3\n\x1e\x43MsgClientToGCGetQuestProgress\x12\x11\n\tquest_ids\x18\x01 \x03(\r\"\xf6\x02\n&CMsgClientToGCGetQuestProgressResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x42\n\x06quests\x18\x02 \x03(\x0b\x32\x32.dota.CMsgClientToGCGetQuestProgressResponse.Quest\x1a\x85\x01\n\tChallenge\x12\x14\n\x0c\x63hallenge_id\x18\x01 \x01(\r\x12\x16\n\x0etime_completed\x18\x02 \x01(\r\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x13\n\x0btemplate_id\x18\x05 \x01(\r\x12\x12\n\nquest_rank\x18\x06 \x01(\r\x1ao\n\x05Quest\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12T\n\x14\x63ompleted_challenges\x18\x02 \x03(\x0b\x32\x36.dota.CMsgClientToGCGetQuestProgressResponse.Challenge\"0\n\x1c\x43MsgGCToClientMatchSignedOut\x12\x10\n\x08match_id\x18\x01 \x01(\x04\",\n\x19\x43MsgGCGetHeroStatsHistory\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"h\n!CMsgGCGetHeroStatsHistoryResponse\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x32\n\x07records\x18\x02 \x03(\x0b\x32!.dota.CMsgDOTASDOHeroStatsHistory\"#\n!CMsgPlayerConductScorecardRequest\"\x90\x03\n\x1a\x43MsgPlayerConductScorecard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x0f\n\x07seq_num\x18\x03 \x01(\r\x12\x0f\n\x07reasons\x18\x04 \x01(\r\x12\x19\n\x11matches_in_report\x18\x05 \x01(\r\x12\x15\n\rmatches_clean\x18\x06 \x01(\r\x12\x18\n\x10matches_reported\x18\x07 \x01(\r\x12\x19\n\x11matches_abandoned\x18\x08 \x01(\r\x12\x15\n\rreports_count\x18\t \x01(\r\x12\x17\n\x0freports_parties\x18\n \x01(\r\x12\x15\n\rcommend_count\x18\x0b \x01(\r\x12\x0c\n\x04\x64\x61te\x18\x0e \x01(\r\x12\x16\n\x0e\x62\x65havior_grade\x18\x0f \x01(\r\x12\x1a\n\x12old_behavior_grade\x18\x10 \x01(\r\x12\x1a\n\x12raw_behavior_score\x18\x11 \x01(\r\x12\x1e\n\x16old_raw_behavior_score\x18\x12 \x01(\r\"1\n\x1d\x43MsgClientToGCWageringRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\xd0\x02\n\x1e\x43MsgGCToClientWageringResponse\x12\x17\n\x0f\x63oins_remaining\x18\x01 \x01(\r\x12\x18\n\x10total_points_won\x18\x02 \x01(\r\x12\x1c\n\x14total_points_wagered\x18\x03 \x01(\r\x12\x1b\n\x13total_points_tipped\x18\x04 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x05 \x01(\r\x12\x1b\n\x13total_games_wagered\x18\x06 \x01(\r\x12\x11\n\tcoins_max\x18\x07 \x01(\r\x12\x1d\n\x15rank_wagers_remaining\x18\x08 \x01(\r\x12\x17\n\x0frank_wagers_max\x18\t \x01(\r\x12#\n\x1bprediction_tokens_remaining\x18\n \x01(\r\x12\x1d\n\x15prediction_tokens_max\x18\x0b \x01(\r\"m\n\x1c\x43MsgGCToClientWageringUpdate\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12;\n\rwagering_info\x18\x02 \x01(\x0b\x32$.dota.CMsgGCToClientWageringResponse\"\x82\x01\n\x1f\x43MsgGCToClientArcanaVotesUpdate\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12M\n\x0c\x61rcana_votes\x18\x02 \x01(\x0b\x32\x37.dota.CMsgClientToGCRequestArcanaVotesRemainingResponse\">\n\x1b\x43MsgClientToGCGetEventGoals\x12\x1f\n\tevent_ids\x18\x01 \x03(\x0e\x32\x0c.dota.EEvent\"\xa1\x01\n\x0e\x43MsgEventGoals\x12\x33\n\x0b\x65vent_goals\x18\x01 \x03(\x0b\x32\x1e.dota.CMsgEventGoals.EventGoal\x1aZ\n\tEventGoal\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x0f\n\x07goal_id\x18\x02 \x01(\r\x12\r\n\x05value\x18\x03 \x01(\x04\"0\n\x1b\x43MsgGCToGCLeaguePredictions\x12\x11\n\tleague_id\x18\x01 \x01(\r\"\xa6\x02\n\x16\x43MsgPredictionRankings\x12<\n\x0bpredictions\x18\x01 \x03(\x0b\x32\'.dota.CMsgPredictionRankings.Prediction\x1a\x63\n\x0ePredictionLine\x12\x11\n\tanswer_id\x18\x01 \x01(\r\x12\x13\n\x0b\x61nswer_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61nswer_logo\x18\x03 \x01(\x04\x12\x14\n\x0c\x61nswer_value\x18\x04 \x01(\x02\x1ai\n\nPrediction\x12\x14\n\x0cselection_id\x18\x01 \x01(\r\x12\x45\n\x10prediction_lines\x18\x02 \x03(\x0b\x32+.dota.CMsgPredictionRankings.PredictionLine\"\xf6\x01\n\x15\x43MsgPredictionResults\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".dota.CMsgPredictionResults.Result\x1a\x41\n\x0fResultBreakdown\x12\x18\n\x10\x61nswer_selection\x18\x02 \x01(\r\x12\x14\n\x0c\x61nswer_value\x18\x03 \x01(\x02\x1a\x65\n\x06Result\x12\x14\n\x0cselection_id\x18\x01 \x01(\r\x12\x45\n\x10result_breakdown\x18\x02 \x03(\x0b\x32+.dota.CMsgPredictionResults.ResultBreakdown\"4\n CMsgClientToGCSuspiciousActivity\x12\x10\n\x08\x61pp_data\x18\x01 \x01(\x04\"6\n\"CMsgClientToGCHasPlayerVotedForMVP\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"<\n*CMsgClientToGCHasPlayerVotedForMVPResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"J\n\"CMsgClientToGCVoteForLeagueGameMVP\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x03 \x01(\r\"@\n\x18\x43MsgClientToGCVoteForMVP\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x03 \x01(\r\"2\n CMsgClientToGCVoteForMVPResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"0\n\x1c\x43MsgClientToGCMVPVoteTimeout\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"6\n$CMsgClientToGCMVPVoteTimeoutResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"|\n\x14\x43MsgMVPVotesForMatch\x12\x32\n\x07players\x18\x01 \x03(\x0b\x32!.dota.CMsgMVPVotesForMatch.Player\x1a\x30\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x12\n\nvote_count\x18\x02 \x01(\r\"$\n\"CMsgClientToGCTeammateStatsRequest\"\xa4\x02\n#CMsgClientToGCTeammateStatsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12N\n\x0eteammate_stats\x18\x02 \x03(\x0b\x32\x36.dota.CMsgClientToGCTeammateStatsResponse.TeammateStat\x1a\x9b\x01\n\x0cTeammateStat\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\r\n\x05games\x18\x02 \x01(\r\x12\x0c\n\x04wins\x18\x03 \x01(\r\x12\"\n\x1amost_recent_game_timestamp\x18\x04 \x01(\r\x12!\n\x19most_recent_game_match_id\x18\x05 \x01(\x04\x12\x13\n\x0bperformance\x18\x64 \x01(\x02\"\x9f\x01\n\x1b\x43MsgClientToGCVoteForArcana\x12<\n\x07matches\x18\x01 \x03(\x0b\x32+.dota.CMsgClientToGCVoteForArcana.MatchVote\x1a\x42\n\tMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x12\n\nvote_count\x18\x03 \x01(\r\"\xc2\x01\n#CMsgClientToGCVoteForArcanaResponse\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x30.dota.CMsgClientToGCVoteForArcanaResponse.Result:\tSUCCEEDED\"N\n\x06Result\x12\r\n\tSUCCEEDED\x10\x00\x12 \n\x1cVOTING_NOT_ENABLED_FOR_ROUND\x10\x01\x12\x13\n\x0fUNKNOWN_FAILURE\x10\x02\"\xc1\x04\n\x0f\x43MsgArcanaVotes\x12,\n\x07matches\x18\x01 \x03(\x0b\x32\x1b.dota.CMsgArcanaVotes.Match\x12\x1c\n\x14round_time_remaining\x18\x02 \x01(\r\x12\x14\n\x0cround_number\x18\x03 \x01(\r\x12\x14\n\x0cvoting_state\x18\x04 \x01(\r\x12$\n\x1cis_current_round_calibrating\x18\x05 \x01(\x08\x12\x1f\n\x17\x63losest_active_match_id\x18\x06 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x07 \x01(\r\x12\x19\n\x11voting_start_time\x18\x08 \x01(\r\x1a\x84\x02\n\x05Match\x12\x10\n\x08match_id\x18\x01 \x01(\r\x12\x11\n\thero_id_0\x18\x02 \x01(\r\x12\x11\n\thero_id_1\x18\x03 \x01(\r\x12\x16\n\x0ehero_seeding_0\x18\x04 \x01(\r\x12\x16\n\x0ehero_seeding_1\x18\x05 \x01(\r\x12\x14\n\x0cvote_count_0\x18\x06 \x01(\r\x12\x14\n\x0cvote_count_1\x18\x07 \x01(\r\x12\x14\n\x0cvoting_state\x18\x08 \x01(\r\x12\x14\n\x0cround_number\x18\t \x01(\r\x12\x17\n\x0fis_votes_hidden\x18\n \x01(\x08\x12\"\n\x1a\x63\x61libration_time_remaining\x18\x0b \x01(\r\";\n\x0bVotingState\x12\x0c\n\x08\x46INISHED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\r\n\tIN_FUTURE\x10\x02\"+\n)CMsgClientToGCRequestArcanaVotesRemaining\"\x9e\x02\n1CMsgClientToGCRequestArcanaVotesRemainingResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x17\n\x0fvotes_remaining\x18\x02 \x01(\r\x12\x13\n\x0bvotes_total\x18\x03 \x01(\r\x12g\n\x1cmatches_previously_voted_for\x18\x04 \x03(\x0b\x32\x41.dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote\x1a\x42\n\tMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x12\n\nvote_count\x18\x03 \x01(\r\"8\n$CMsgClientToGCRequestEventPointLogV2\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\x9e\x02\n,CMsgClientToGCRequestEventPointLogResponseV2\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12-\n\x08\x65vent_id\x18\x02 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12P\n\x0blog_entries\x18\x03 \x03(\x0b\x32;.dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry\x1a]\n\x08LogEntry\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x14\n\x0c\x61udit_action\x18\x02 \x01(\r\x12\x14\n\x0c\x65vent_points\x18\x03 \x01(\x05\x12\x12\n\naudit_data\x18\x04 \x01(\x04\"Q\n\x1d\x43MsgClientToGCPublishUserStat\x12\x18\n\x10user_stats_event\x18\x01 \x01(\r\x12\x16\n\x0ereference_data\x18\x02 \x01(\x04\"1\n CMsgClientToGCAddTI6TreeProgress\x12\r\n\x05trees\x18\x01 \x01(\r\"X\n\'CMsgClientToGCRequestLinaPlaysRemaining\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\"_\n/CMsgClientToGCRequestLinaPlaysRemainingResponse\x12\x17\n\x0fplays_remaining\x18\x01 \x01(\r\x12\x13\n\x0bplays_total\x18\x02 \x01(\r\"i\n#CMsgClientToGCRequestLinaGameResult\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x13\n\x0bslot_chosen\x18\x02 \x01(\r\"=\n+CMsgClientToGCRequestLinaGameResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"x\n$CMsgClientToGCRequestSlarkGameResult\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x13\n\x0bslot_chosen\x18\x02 \x01(\r\x12\x0c\n\x04week\x18\x03 \x01(\r\"T\n,CMsgClientToGCRequestSlarkGameResultResponse\x12\x12\n\npoints_won\x18\x01 \x01(\r\x12\x10\n\x08\x61ura_won\x18\x02 \x01(\x08\"\xa8\x02\n\"CMsgGCToClientQuestProgressUpdated\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12P\n\x14\x63ompleted_challenges\x18\x02 \x03(\x0b\x32\x32.dota.CMsgGCToClientQuestProgressUpdated.Challenge\x1a\x9d\x01\n\tChallenge\x12\x14\n\x0c\x63hallenge_id\x18\x01 \x01(\r\x12\x16\n\x0etime_completed\x18\x02 \x01(\r\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x13\n\x0btemplate_id\x18\x05 \x01(\r\x12\x12\n\nquest_rank\x18\x06 \x01(\r\x12\x16\n\x0emax_quest_rank\x18\x07 \x01(\r\"?\n\x12\x43MsgDOTARedeemItem\x12\x13\n\x0b\x63urrency_id\x18\x01 \x01(\x04\x12\x14\n\x0cpurchase_def\x18\x02 \x01(\r\"\x97\x01\n\x1a\x43MsgDOTARedeemItemResponse\x12K\n\x08response\x18\x01 \x01(\x0e\x32,.dota.CMsgDOTARedeemItemResponse.EResultCode:\x0bk_Succeeded\",\n\x0b\x45ResultCode\x12\x0f\n\x0bk_Succeeded\x10\x00\x12\x0c\n\x08k_Failed\x10\x01\"6\n!CMsgPerfectWorldUserLookupRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\"\xcd\x02\n\"CMsgPerfectWorldUserLookupResponse\x12`\n\x0bresult_code\x18\x01 \x01(\x0e\x32\x34.dota.CMsgPerfectWorldUserLookupResponse.EResultCode:\x15SUCCESS_ACCOUNT_FOUND\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xb0\x01\n\x0b\x45ResultCode\x12\x19\n\x15SUCCESS_ACCOUNT_FOUND\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12 \n\x1c\x45RROR_USER_NAME_WRONG_FORMAT\x10\x02\x12(\n$ERROR_NO_PERFECT_WORLD_ACCOUNT_FOUND\x10\x03\x12\'\n#ERROR_NO_LINKED_STEAM_ACCOUNT_FOUND\x10\x04\"#\n\x10\x43MsgMakeOffering\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\x16\n\x14\x43MsgRequestOfferings\"\xb1\x01\n\x1c\x43MsgRequestOfferingsResponse\x12\x46\n\tofferings\x18\x01 \x03(\x0b\x32\x33.dota.CMsgRequestOfferingsResponse.NewYearsOffering\x12\x11\n\tcompleted\x18\x02 \x01(\x08\x1a\x36\n\x10NewYearsOffering\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"Q\n\x19\x43MsgDOTAPCBangTimedReward\x12\x0f\n\x07persona\x18\x01 \x01(\t\x12\x0f\n\x07itemdef\x18\x02 \x01(\r\x12\x12\n\npcbangname\x18\x03 \x01(\t\"\xf2\x01\n)CMsgDOTACompendiumInGamePredictionResults\x12Q\n\x07results\x18\x01 \x03(\x0b\x32@.dota.CMsgDOTACompendiumInGamePredictionResults.PredictionResult\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x1a\n\x12predictions_closed\x18\x03 \x01(\x08\x1a\x43\n\x10PredictionResult\x12\x15\n\rprediction_id\x18\x01 \x01(\r\x12\x18\n\x10prediction_value\x18\x02 \x01(\r\"\xea\x01\n.CMsgClientToGCSelectCompendiumInGamePrediction\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12T\n\x0bpredictions\x18\x02 \x03(\x0b\x32?.dota.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction\x12\x11\n\tleague_id\x18\x03 \x01(\r\x1a=\n\nPrediction\x12\x15\n\rprediction_id\x18\x01 \x01(\r\x12\x18\n\x10prediction_value\x18\x02 \x01(\r\"\xef\x01\n6CMsgClientToGCSelectCompendiumInGamePredictionResponse\x12]\n\x06result\x18\x01 \x01(\x0e\x32\x44.dota.CMsgClientToGCSelectCompendiumInGamePredictionResponse.EResult:\x07SUCCESS\"V\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rINVALID_MATCH\x10\x01\x12\x1a\n\x16PREDICTIONS_ARE_CLOSED\x10\x02\x12\x0f\n\x0bOTHER_ERROR\x10\x03\"D\n CMsgClientToGCOpenPlayerCardPack\x12 \n\x18player_card_pack_item_id\x18\x01 \x01(\x04\"\x9f\x02\n(CMsgClientToGCOpenPlayerCardPackResponse\x12N\n\x06result\x18\x01 \x01(\x0e\x32\x35.dota.CMsgClientToGCOpenPlayerCardPackResponse.Result:\x07SUCCESS\x12\x1c\n\x14player_card_item_ids\x18\x02 \x03(\x04\"\x84\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1d\n\x19\x45RROR_FAILED_TO_FIND_PACK\x10\x03\x12\x1c\n\x18\x45RROR_ITEM_NOT_CARD_PACK\x10\x04\x12\x1c\n\x18\x45RROR_FAILED_CARD_CREATE\x10\x05\"Q\n\x1f\x43MsgClientToGCRecyclePlayerCard\x12\x1c\n\x14player_card_item_ids\x18\x03 \x03(\x04\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\"\xb9\x02\n\'CMsgClientToGCRecyclePlayerCardResponse\x12M\n\x06result\x18\x01 \x01(\x0e\x32\x34.dota.CMsgClientToGCRecyclePlayerCardResponse.Result:\x07SUCCESS\x12\x13\n\x0b\x64ust_amount\x18\x02 \x01(\r\"\xa9\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12$\n ERROR_FAILED_TO_FIND_PLAYER_CARD\x10\x03\x12\x1e\n\x1a\x45RROR_ITEM_NOT_PLAYER_CARD\x10\x04\x12!\n\x1d\x45RROR_FAILED_DUST_CARD_CREATE\x10\x05\x12\x15\n\x11\x45RROR_CARD_LOCKED\x10\x06\"g\n\"CMsgClientToGCCreatePlayerCardPack\x12\x19\n\x11\x63\x61rd_dust_item_id\x18\x01 \x01(\x04\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x14\n\x0cpremium_pack\x18\x03 \x01(\x08\"\x88\x02\n*CMsgClientToGCCreatePlayerCardPackResponse\x12P\n\x06result\x18\x01 \x01(\x0e\x32\x37.dota.CMsgClientToGCCreatePlayerCardPackResponse.Result:\x07SUCCESS\"\x87\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1b\n\x17\x45RROR_INSUFFICIENT_DUST\x10\x03\x12\x1c\n\x18\x45RROR_ITEM_NOT_DUST_ITEM\x10\x04\x12!\n\x1d\x45RROR_FAILED_CARD_PACK_CREATE\x10\x05\"\xab\n\n0CMsgGCToClientBattlePassRollup_International2016\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12U\n\nquestlines\x18\x02 \x03(\x0b\x32\x41.dota.CMsgGCToClientBattlePassRollup_International2016.Questlines\x12Q\n\x08wagering\x18\x03 \x01(\x0b\x32?.dota.CMsgGCToClientBattlePassRollup_International2016.Wagering\x12Y\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32\x43.dota.CMsgGCToClientBattlePassRollup_International2016.Achievements\x12T\n\nbattle_cup\x18\x05 \x01(\x0b\x32@.dota.CMsgGCToClientBattlePassRollup_International2016.BattleCup\x12W\n\x0bpredictions\x18\x06 \x01(\x0b\x32\x42.dota.CMsgGCToClientBattlePassRollup_International2016.Predictions\x12O\n\x07\x62racket\x18\x07 \x01(\x0b\x32>.dota.CMsgGCToClientBattlePassRollup_International2016.Bracket\x12W\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32\x41.dota.CMsgGCToClientBattlePassRollup_International2016.PlayerCard\x12\x62\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32G.dota.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge\x1a^\n\nQuestlines\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07onestar\x18\x02 \x01(\r\x12\x0f\n\x07twostar\x18\x03 \x01(\r\x12\x11\n\tthreestar\x18\x04 \x01(\r\x12\r\n\x05total\x18\x05 \x01(\r\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a(\n\tBattleCup\x12\x0c\n\x04wins\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"\xda\t\n\'CMsgGCToClientBattlePassRollup_Fall2016\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12L\n\nquestlines\x18\x02 \x03(\x0b\x32\x38.dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines\x12H\n\x08wagering\x18\x03 \x01(\x0b\x32\x36.dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering\x12P\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32:.dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements\x12K\n\nbattle_cup\x18\x05 \x01(\x0b\x32\x37.dota.CMsgGCToClientBattlePassRollup_Fall2016.BattleCup\x12N\n\x0bpredictions\x18\x06 \x01(\x0b\x32\x39.dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions\x12\x46\n\x07\x62racket\x18\x07 \x01(\x0b\x32\x35.dota.CMsgGCToClientBattlePassRollup_Fall2016.Bracket\x12N\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32\x38.dota.CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard\x12Y\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32>.dota.CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge\x1a^\n\nQuestlines\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07onestar\x18\x02 \x01(\r\x12\x0f\n\x07twostar\x18\x03 \x01(\r\x12\x11\n\tthreestar\x18\x04 \x01(\r\x12\r\n\x05total\x18\x05 \x01(\r\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a(\n\tBattleCup\x12\x0c\n\x04wins\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"\xec\t\n)CMsgGCToClientBattlePassRollup_Winter2017\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12N\n\nquestlines\x18\x02 \x03(\x0b\x32:.dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines\x12J\n\x08wagering\x18\x03 \x01(\x0b\x32\x38.dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering\x12R\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32<.dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements\x12M\n\nbattle_cup\x18\x05 \x01(\x0b\x32\x39.dota.CMsgGCToClientBattlePassRollup_Winter2017.BattleCup\x12P\n\x0bpredictions\x18\x06 \x01(\x0b\x32;.dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions\x12H\n\x07\x62racket\x18\x07 \x01(\x0b\x32\x37.dota.CMsgGCToClientBattlePassRollup_Winter2017.Bracket\x12P\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32:.dota.CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard\x12[\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32@.dota.CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge\x1a^\n\nQuestlines\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07onestar\x18\x02 \x01(\r\x12\x0f\n\x07twostar\x18\x03 \x01(\r\x12\x11\n\tthreestar\x18\x04 \x01(\r\x12\r\n\x05total\x18\x05 \x01(\r\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a(\n\tBattleCup\x12\x0c\n\x04wins\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"\xad\t\n\"CMsgGCToClientBattlePassRollup_TI7\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12G\n\nquestlines\x18\x02 \x03(\x0b\x32\x33.dota.CMsgGCToClientBattlePassRollup_TI7.Questlines\x12\x43\n\x08wagering\x18\x03 \x01(\x0b\x32\x31.dota.CMsgGCToClientBattlePassRollup_TI7.Wagering\x12K\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32\x35.dota.CMsgGCToClientBattlePassRollup_TI7.Achievements\x12\x46\n\nbattle_cup\x18\x05 \x01(\x0b\x32\x32.dota.CMsgGCToClientBattlePassRollup_TI7.BattleCup\x12I\n\x0bpredictions\x18\x06 \x01(\x0b\x32\x34.dota.CMsgGCToClientBattlePassRollup_TI7.Predictions\x12\x41\n\x07\x62racket\x18\x07 \x01(\x0b\x32\x30.dota.CMsgGCToClientBattlePassRollup_TI7.Bracket\x12I\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32\x33.dota.CMsgGCToClientBattlePassRollup_TI7.PlayerCard\x12T\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32\x39.dota.CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge\x1a^\n\nQuestlines\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07onestar\x18\x02 \x01(\r\x12\x0f\n\x07twostar\x18\x03 \x01(\r\x12\x11\n\tthreestar\x18\x04 \x01(\r\x12\r\n\x05total\x18\x05 \x01(\r\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a(\n\tBattleCup\x12\x0c\n\x04wins\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"\xd3\x08\n\"CMsgGCToClientBattlePassRollup_TI8\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12J\n\x0c\x63\x61vern_crawl\x18\x02 \x01(\x0b\x32\x34.dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl\x12\x43\n\x08wagering\x18\x03 \x01(\x0b\x32\x31.dota.CMsgGCToClientBattlePassRollup_TI8.Wagering\x12K\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32\x35.dota.CMsgGCToClientBattlePassRollup_TI8.Achievements\x12I\n\x0bpredictions\x18\x06 \x01(\x0b\x32\x34.dota.CMsgGCToClientBattlePassRollup_TI8.Predictions\x12\x41\n\x07\x62racket\x18\x07 \x01(\x0b\x32\x30.dota.CMsgGCToClientBattlePassRollup_TI8.Bracket\x12I\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32\x33.dota.CMsgGCToClientBattlePassRollup_TI8.PlayerCard\x12T\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32\x39.dota.CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge\x1as\n\x0b\x43\x61vernCrawl\x12\x15\n\rrooms_cleared\x18\x01 \x01(\r\x12\x17\n\x0f\x63\x61rry_completed\x18\x02 \x01(\x08\x12\x19\n\x11support_completed\x18\x03 \x01(\x08\x12\x19\n\x11utility_completed\x18\x04 \x01(\x08\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"M\n%CMsgGCToClientBattlePassRollupRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xff\x02\n&CMsgGCToClientBattlePassRollupResponse\x12I\n\tevent_ti6\x18\x01 \x01(\x0b\x32\x36.dota.CMsgGCToClientBattlePassRollup_International2016\x12\x45\n\x0e\x65vent_fall2016\x18\x02 \x01(\x0b\x32-.dota.CMsgGCToClientBattlePassRollup_Fall2016\x12I\n\x10\x65vent_winter2017\x18\x03 \x01(\x0b\x32/.dota.CMsgGCToClientBattlePassRollup_Winter2017\x12;\n\tevent_ti7\x18\x04 \x01(\x0b\x32(.dota.CMsgGCToClientBattlePassRollup_TI7\x12;\n\tevent_ti8\x18\x05 \x01(\x0b\x32(.dota.CMsgGCToClientBattlePassRollup_TI8\"?\n)CMsgGCToClientBattlePassRollupListRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xaa\x01\n*CMsgGCToClientBattlePassRollupListResponse\x12N\n\nevent_info\x18\x01 \x03(\x0b\x32:.dota.CMsgGCToClientBattlePassRollupListResponse.EventInfo\x1a,\n\tEventInfo\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\r\n\x05level\x18\x02 \x01(\r\"<\n(CMsgClientToGCTransferSeasonalMMRRequest\x12\x10\n\x08is_party\x18\x01 \x01(\x08\"<\n)CMsgClientToGCTransferSeasonalMMRResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\".\n\x1c\x43MsgGCToClientPlaytestStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\"4\n\x1a\x43MsgClientToGCJoinPlaytest\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\"3\n\"CMsgClientToGCJoinPlaytestResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"<\n\x17\x43MsgDOTASetFavoriteTeam\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\"\xed\x01\n\x16\x43MsgDOTATriviaQuestion\x12\x13\n\x0bquestion_id\x18\x01 \x01(\r\x12^\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32!.dota.EDOTATriviaQuestionCategory:)k_EDOTATriviaQuestionCategory_AbilityIcon\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x16\n\x0equestion_value\x18\x04 \x01(\t\x12\x15\n\ranswer_values\x18\x05 \x03(\t\x12\x1c\n\x14\x63orrect_answer_index\x18\x06 \x01(\r\"i\n\x1e\x43MsgDOTATriviaCurrentQuestions\x12/\n\tquestions\x18\x01 \x03(\x0b\x32\x1c.dota.CMsgDOTATriviaQuestion\x12\x16\n\x0etrivia_enabled\x18\x02 \x01(\x08\"W\n$CMsgDOTATriviaQuestionAnswersSummary\x12\x19\n\x11summary_available\x18\x01 \x01(\x08\x12\x14\n\x0cpicked_count\x18\x02 \x03(\r\"O\n\"CMsgDOTASubmitTriviaQuestionAnswer\x12\x13\n\x0bquestion_id\x18\x01 \x01(\r\x12\x14\n\x0c\x61nswer_index\x18\x02 \x01(\r\"~\n*CMsgDOTASubmitTriviaQuestionAnswerResponse\x12P\n\x06result\x18\x01 \x01(\x0e\x32\x1d.dota.EDOTATriviaAnswerResult:!k_EDOTATriviaAnswerResult_Success\"\x1c\n\x1a\x43MsgDOTAStartTriviaSession\"W\n\"CMsgDOTAStartTriviaSessionResponse\x12\x16\n\x0etrivia_enabled\x18\x01 \x01(\x08\x12\x19\n\x11\x63urrent_timestamp\x18\x02 \x01(\r\"Y\n\x15\x43MsgClientToGCGiveTip\x12\x1c\n\x14recipient_account_id\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x10\n\x08\x65vent_id\x18\x03 \x01(\r\"\xcc\x02\n\x1d\x43MsgClientToGCGiveTipResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.dota.CMsgClientToGCGiveTipResponse.Result:\x07SUCCESS\"\xe5\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x18\n\x14\x45RROR_ALREADY_TIPPED\x10\x01\x12\x1a\n\x16\x45RROR_INVALID_MATCH_ID\x10\x02\x12\x1a\n\x16\x45RROR_INVALID_EVENT_ID\x10\x03\x12\x1c\n\x18\x45RROR_INVALID_MATCH_TIME\x10\x04\x12\x14\n\x10\x45RROR_NOT_WINNER\x10\x05\x12\x17\n\x13\x45RROR_UNOWNED_EVENT\x10\x06\x12\x1c\n\x18\x45RROR_INVALID_LOBBY_TYPE\x10\x07\x12\x11\n\rERROR_UNKNOWN\x10\x08\"\"\n CMsgDOTAAnchorPhoneNumberRequest\"\xe5\x01\n!CMsgDOTAAnchorPhoneNumberResponse\x12G\n\x06result\x18\x01 \x01(\x0e\x32..dota.CMsgDOTAAnchorPhoneNumberResponse.Result:\x07SUCCESS\"w\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x18\n\x14\x45RROR_NO_STEAM_PHONE\x10\x02\x12\x18\n\x14\x45RROR_ALREADY_IN_USE\x10\x03\x12\x19\n\x15\x45RROR_COOLDOWN_ACTIVE\x10\x04\"$\n\"CMsgDOTAUnanchorPhoneNumberRequest\"\x9a\x01\n#CMsgDOTAUnanchorPhoneNumberResponse\x12I\n\x06result\x18\x01 \x01(\x0e\x32\x30.dota.CMsgDOTAUnanchorPhoneNumberResponse.Result:\x07SUCCESS\"(\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\"\x97\x01\n\x1d\x43MsgGCToClientTipNotification\x12\x19\n\x11tipper_account_id\x18\x01 \x01(\r\x12\x13\n\x0btipper_name\x18\x02 \x01(\t\x12\x1c\n\x14recipient_account_id\x18\x03 \x01(\r\x12\x16\n\x0erecipient_name\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\r\"h\n!CMsgGCToClientCommendNotification\x12\x1c\n\x14\x63ommender_account_id\x18\x01 \x01(\r\x12\x16\n\x0e\x63ommender_name\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\r\"5\n!CMsgGCToClientAllStarVotesRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"=\n\x1f\x43MsgGCToClientAllStarVotesReply\x12\x1a\n\x12player_account_ids\x18\x01 \x03(\r\"P\n CMsgGCToClientAllStarVotesSubmit\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x1a\n\x12player_account_ids\x18\x02 \x03(\r\"\xf7\x01\n%CMsgGCToClientAllStarVotesSubmitReply\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x32.dota.CMsgGCToClientAllStarVotesSubmitReply.Result:\x07SUCCESS\"\x80\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1a\n\x16\x45RROR_INVALID_EVENT_ID\x10\x03\x12\x1c\n\x18\x45RROR_INVALID_ACCOUNT_ID\x10\x04\x12\x1b\n\x17\x45RROR_SELECTIONS_LOCKED\x10\x05\"u\n#CMsgDOTAClientToGCQuickStatsRequest\x12\x19\n\x11player_account_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\r\x12\x11\n\tleague_id\x18\x04 \x01(\r\"\xab\x05\n$CMsgDOTAClientToGCQuickStatsResponse\x12\x43\n\x10original_request\x18\x01 \x01(\x0b\x32).dota.CMsgDOTAClientToGCQuickStatsRequest\x12J\n\nhero_stats\x18\x02 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x12J\n\nitem_stats\x18\x03 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x12O\n\x0fitem_hero_stats\x18\x04 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x12Q\n\x11item_player_stats\x18\x05 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x12Q\n\x11hero_player_stats\x18\x06 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x12N\n\x0e\x66ull_set_stats\x18\x07 \x01(\x0b\x32\x36.dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats\x1a_\n\x0bSimpleStats\x12\x13\n\x0bwin_percent\x18\x01 \x01(\x02\x12\x14\n\x0cpick_percent\x18\x02 \x01(\x02\x12\x11\n\twin_count\x18\x03 \x01(\r\x12\x12\n\npick_count\x18\x04 \x01(\r\"\x82\x01\n&CMsgDOTASelectionPriorityChoiceRequest\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.dota.DOTASelectionPriorityChoice:%k_DOTASelectionPriorityChoice_Invalid\"\xa2\x01\n\'CMsgDOTASelectionPriorityChoiceResponse\x12M\n\x06result\x18\x01 \x01(\x0e\x32\x34.dota.CMsgDOTASelectionPriorityChoiceResponse.Result:\x07SUCCESS\"(\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\"/\n\x1b\x43MsgDOTAGameAutographReward\x12\x10\n\x08\x62\x61\x64ge_id\x18\x01 \x01(\t\"\x9a\x01\n#CMsgDOTAGameAutographRewardResponse\x12I\n\x06result\x18\x01 \x01(\x0e\x32\x30.dota.CMsgDOTAGameAutographRewardResponse.Result:\x07SUCCESS\"(\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\"\x1d\n\x1b\x43MsgDOTADestroyLobbyRequest\"\x8c\x01\n\x1c\x43MsgDOTADestroyLobbyResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32).dota.CMsgDOTADestroyLobbyResponse.Result:\x07SUCCESS\"(\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\")\n\'CMsgDOTAGetRecentPlayTimeFriendsRequest\"?\n(CMsgDOTAGetRecentPlayTimeFriendsResponse\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\x07\"\x90\x01\n\x1f\x43MsgPurchaseItemWithEventPoints\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\x12-\n\x08\x65vent_id\x18\x03 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x1a\n\x12use_premium_points\x18\x04 \x01(\x08\"\xf0\x02\n\'CMsgPurchaseItemWithEventPointsResponse\x12M\n\x06result\x18\x01 \x01(\x0e\x32\x34.dota.CMsgPurchaseItemWithEventPointsResponse.Result:\x07SUCCESS\"\xf5\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rUNKNOWN_EVENT\x10\x01\x12\x10\n\x0cUNKNOWN_ITEM\x10\x02\x12\x10\n\x0c\x42\x41\x44_QUANTITY\x10\x03\x12\x14\n\x10NOT_PURCHASEABLE\x10\x04\x12\x13\n\x0fSDO_LOAD_FAILED\x10\x05\x12\x15\n\x11NOT_ENOUGH_POINTS\x10\x06\x12\r\n\tSQL_ERROR\x10\x07\x12\x12\n\x0e\x46\x41ILED_TO_SEND\x10\x08\x12\x10\n\x0cSERVER_ERROR\x10\t\x12\x0f\n\x0bNOT_ALLOWED\x10\n\x12\r\n\tCANCELLED\x10\x0b\x12\x10\n\x0c\x43LIENT_ERROR\x10\x0c\"\xbe\x01\n CMsgGCRequestItemRecommendations\x12\x0b\n\x03mmr\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x17\n\x0f\x61llied_hero_ids\x18\x03 \x03(\r\x12\x16\n\x0e\x65nemy_hero_ids\x18\x04 \x03(\r\x12\x17\n\x0finventory_items\x18\x05 \x03(\r\x12\x11\n\tgame_time\x18\x06 \x01(\x05\x12\x0c\n\x04gold\x18\x07 \x01(\r\x12\x11\n\tnet_worth\x18\x08 \x01(\r\"H\n(CMsgGCRequestItemRecommendationsResponse\x12\x1c\n\x14recommended_item_ids\x18\x01 \x03(\r\"\x89\x01\n#CMsgGCRequestSkillUpRecommendations\x12\x0b\n\x03mmr\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x17\n\x0f\x61llied_hero_ids\x18\x03 \x03(\r\x12\x16\n\x0e\x65nemy_hero_ids\x18\x04 \x03(\r\x12\x13\n\x0b\x61\x62ility_ids\x18\x05 \x03(\r\"\xbc\x01\n+CMsgGCRequestSkillUpRecommendationsResponse\x12U\n\tabilities\x18\x01 \x03(\x0b\x32\x42.dota.CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection\x1a\x36\n\x10\x41\x62ilitySelection\x12\x12\n\nability_id\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\x02\"2\n\x1e\x43MsgClientToGCRecycleHeroRelic\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\"\x9d\x02\n&CMsgClientToGCRecycleHeroRelicResponse\x12L\n\x06result\x18\x01 \x01(\x0e\x32\x33.dota.CMsgClientToGCRecycleHeroRelicResponse.Result:\x07SUCCESS\x12\x13\n\x0b\x64ust_amount\x18\x02 \x01(\r\"\x8f\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12#\n\x1f\x45RROR_FAILED_TO_FIND_HERO_RELIC\x10\x03\x12\x1d\n\x19\x45RROR_ITEM_NOT_HERO_RELIC\x10\x04\x12 \n\x1c\x45RROR_FAILED_EVENT_NOT_OWNED\x10\x05\"A\n\x15\x43MsgPurchaseHeroRelic\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x17\n\x0fkill_eater_type\x18\x02 \x01(\r\"s\n\x1d\x43MsgPurchaseHeroRelicResponse\x12R\n\x06result\x18\x01 \x01(\x0e\x32\x1e.dota.EPurchaseHeroRelicResult:\"k_EPurchaseHeroRelicResult_Success\".\n\x1b\x43MsgPurchaseHeroRandomRelic\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"\x92\x01\n#CMsgPurchaseHeroRandomRelicResponse\x12R\n\x06result\x18\x01 \x01(\x0e\x32\x1e.dota.EPurchaseHeroRelicResult:\"k_EPurchaseHeroRelicResult_Success\x12\x17\n\x0fkill_eater_type\x18\x02 \x01(\r\"m\n.CMsgClientToGCRequestPlusWeeklyChallengeResult\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x0c\n\x04week\x18\x02 \x01(\r\"8\n6CMsgClientToGCRequestPlusWeeklyChallengeResultResponse\"(\n\x12\x43MsgProfileRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xf0\x05\n\x13\x43MsgProfileResponse\x12*\n\x0f\x62\x61\x63kground_item\x18\x01 \x01(\x0b\x32\x11.dota.CSOEconItem\x12?\n\x0f\x66\x65\x61tured_heroes\x18\x02 \x03(\x0b\x32&.dota.CMsgProfileResponse.FeaturedHero\x12;\n\x0erecent_matches\x18\x03 \x03(\x0b\x32#.dota.CMsgProfileResponse.MatchInfo\x12\x33\n\x11successful_heroes\x18\x04 \x03(\x0b\x32\x18.dota.CMsgSuccessfulHero\x12\x37\n\x14recent_match_details\x18\x05 \x01(\x0b\x32\x19.dota.CMsgRecentMatchInfo\x12\x45\n\x06result\x18\x06 \x01(\x0e\x32#.dota.CMsgProfileResponse.EResponse:\x10k_eInternalError\x1a\xad\x01\n\x0c\x46\x65\x61turedHero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12.\n\x13\x65quipped_econ_items\x18\x02 \x03(\x0b\x32\x11.dota.CSOEconItem\x12\x14\n\x0cmanually_set\x18\x03 \x01(\x08\x12\x14\n\x0cplus_hero_xp\x18\x04 \x01(\r\x12\x30\n\x15plus_hero_relics_item\x18\x05 \x01(\x0b\x32\x11.dota.CSOEconItem\x1av\n\tMatchInfo\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x17\n\x0fmatch_timestamp\x18\x02 \x01(\r\x12\x1a\n\x12performance_rating\x18\x03 \x01(\x11\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x11\n\twon_match\x18\x05 \x01(\x08\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"J\n\x11\x43MsgProfileUpdate\x12\x1a\n\x12\x62\x61\x63kground_item_id\x18\x01 \x01(\x04\x12\x19\n\x11\x66\x65\x61tured_hero_ids\x18\x02 \x03(\r\"\x80\x01\n\x19\x43MsgProfileUpdateResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32&.dota.CMsgProfileUpdateResponse.Result:\x07SUCCESS\"\"\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\"a\n\x12\x43MsgTalentWinRates\x12\x10\n\x08last_run\x18\x01 \x01(\r\x12\x12\n\nability_id\x18\x02 \x01(\r\x12\x12\n\ngame_count\x18\x03 \x01(\r\x12\x11\n\twin_count\x18\x04 \x01(\r\"\xda\x01\n\x16\x43MsgGlobalHeroAverages\x12\x10\n\x08last_run\x18\x01 \x01(\r\x12\x18\n\x10\x61vg_gold_per_min\x18\x03 \x01(\r\x12\x16\n\x0e\x61vg_xp_per_min\x18\x04 \x01(\r\x12\x11\n\tavg_kills\x18\x05 \x01(\r\x12\x12\n\navg_deaths\x18\x06 \x01(\r\x12\x13\n\x0b\x61vg_assists\x18\x07 \x01(\r\x12\x15\n\ravg_last_hits\x18\x08 \x01(\r\x12\x12\n\navg_denies\x18\t \x01(\r\x12\x15\n\ravg_net_worth\x18\n \x01(\r\",\n\x19\x43MsgHeroGlobalDataRequest\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"\xc9\x04\n\x1a\x43MsgHeroGlobalDataResponse\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12R\n\x13hero_data_per_chunk\x18\x02 \x03(\x0b\x32\x35.dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk\x1aX\n\tGraphData\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\r\x12\x13\n\x0bwin_percent\x18\x02 \x01(\x02\x12\x14\n\x0cpick_percent\x18\x03 \x01(\x02\x12\x13\n\x0b\x62\x61n_percent\x18\x04 \x01(\x02\x1aX\n\x08WeekData\x12\x0c\n\x04week\x18\x01 \x01(\r\x12\x13\n\x0bwin_percent\x18\x02 \x01(\x02\x12\x14\n\x0cpick_percent\x18\x03 \x01(\x02\x12\x13\n\x0b\x62\x61n_percent\x18\x04 \x01(\x02\x1a\x91\x02\n\x14HeroDataPerRankChunk\x12\x12\n\nrank_chunk\x18\x01 \x01(\r\x12\x32\n\x10talent_win_rates\x18\x02 \x03(\x0b\x32\x18.dota.CMsgTalentWinRates\x12\x33\n\rhero_averages\x18\x03 \x01(\x0b\x32\x1c.dota.CMsgGlobalHeroAverages\x12>\n\ngraph_data\x18\x04 \x03(\x0b\x32*.dota.CMsgHeroGlobalDataResponse.GraphData\x12<\n\tweek_data\x18\x05 \x03(\x0b\x32).dota.CMsgHeroGlobalDataResponse.WeekData\"O\n\x1b\x43MsgHeroGlobalDataAllHeroes\x12\x30\n\x06heroes\x18\x01 \x03(\x0b\x32 .dota.CMsgHeroGlobalDataResponse\"\xea\x02\n(CMsgHeroGlobalDataHeroesAlliesAndEnemies\x12W\n\x10ranked_hero_data\x18\x01 \x03(\x0b\x32=.dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData\x1ay\n\x08HeroData\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x10\n\x08win_rate\x18\x02 \x01(\r\x12\x1b\n\x13\x66irst_other_hero_id\x18\x03 \x01(\r\x12\x15\n\rally_win_rate\x18\x05 \x03(\r\x12\x16\n\x0e\x65nemy_win_rate\x18\x06 \x03(\r\x1aj\n\x0eRankedHeroData\x12\x0c\n\x04rank\x18\x01 \x01(\r\x12J\n\thero_data\x18\x02 \x03(\x0b\x32\x37.dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData\"1\n\x1d\x43MsgPrivateMetadataKeyRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"5\n\x1e\x43MsgPrivateMetadataKeyResponse\x12\x13\n\x0bprivate_key\x18\x01 \x01(\r\"\"\n CMsgActivatePlusFreeTrialRequest\"\xf6\x01\n!CMsgActivatePlusFreeTrialResponse\x12G\n\x06result\x18\x01 \x01(\x0e\x32..dota.CMsgActivatePlusFreeTrialResponse.Result:\x07SUCCESS\"\x87\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_GENERIC\x10\x01\x12\x1f\n\x1b\x45RROR_ALREADY_IN_FREE_TRIAL\x10\x02\x12!\n\x1d\x45RROR_ALREADY_USED_FREE_TRIAL\x10\x03\x12\x19\n\x15\x45RROR_OFFER_NOT_VALID\x10\x04\"\xa0\x02\n)CMsgGCToClientCavernCrawlMapPathCompleted\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x19\n\x11hero_id_completed\x18\x02 \x01(\r\x12Z\n\x0f\x63ompleted_paths\x18\x03 \x03(\x0b\x32\x41.dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo\x1aj\n\x11\x43ompletedPathInfo\x12\x19\n\x11path_id_completed\x18\x01 \x01(\r\x12\"\n\x1areceived_ultra_rare_reward\x18\x02 \x01(\x08\x12\x16\n\x0ehalf_completed\x18\x03 \x01(\x08\"7\n#CMsgGCToClientCavernCrawlMapUpdated\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"G\n\"CMsgClientToGCCavernCrawlClaimRoom\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x0f\n\x07room_id\x18\x02 \x01(\r\"\xc8\x01\n*CMsgClientToGCCavernCrawlClaimRoomResponse\x12P\n\x06result\x18\x01 \x01(\x0e\x32\x37.dota.CMsgClientToGCCavernCrawlClaimRoomResponse.Result:\x07SUCCESS\"H\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x1e\n\x1aRECEIVED_ULTRA_RARE_REWARD\x10\x02\"^\n&CMsgClientToGCCavernCrawlUseItemOnRoom\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x0f\n\x07room_id\x18\x02 \x01(\r\x12\x11\n\titem_type\x18\x03 \x01(\r\"\xd0\x01\n.CMsgClientToGCCavernCrawlUseItemOnRoomResponse\x12T\n\x06result\x18\x01 \x01(\x0e\x32;.dota.CMsgClientToGCCavernCrawlUseItemOnRoomResponse.Result:\x07SUCCESS\"H\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x1e\n\x1aRECEIVED_ULTRA_RARE_REWARD\x10\x02\"^\n&CMsgClientToGCCavernCrawlUseItemOnPath\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x0f\n\x07path_id\x18\x02 \x01(\r\x12\x11\n\titem_type\x18\x03 \x01(\r\"\xd0\x01\n.CMsgClientToGCCavernCrawlUseItemOnPathResponse\x12T\n\x06result\x18\x01 \x01(\x0e\x32;.dota.CMsgClientToGCCavernCrawlUseItemOnPathResponse.Result:\x07SUCCESS\"H\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x1e\n\x1aRECEIVED_ULTRA_RARE_REWARD\x10\x02\"<\n(CMsgClientToGCCavernCrawlRequestMapState\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\x89\x08\n0CMsgClientToGCCavernCrawlRequestMapStateResponse\x12V\n\x06result\x18\x01 \x01(\x0e\x32=.dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.Result:\x07SUCCESS\x12\x17\n\x0f\x63laimed_rooms_1\x18\x02 \x01(\x06\x12\x17\n\x0f\x63laimed_rooms_2\x18\x03 \x01(\x06\x12\x18\n\x10revealed_rooms_1\x18\x04 \x01(\x06\x12\x18\n\x10revealed_rooms_2\x18\x05 \x01(\x06\x12\x19\n\x11\x63ompleted_paths_1\x18\x06 \x01(\x06\x12\x19\n\x11\x63ompleted_paths_2\x18\x07 \x01(\x06\x12\x19\n\x11\x63ompleted_paths_3\x18\x08 \x01(\x06\x12\x19\n\x11\x63ompleted_paths_4\x18\x0c \x01(\x06\x12\x1e\n\x16half_completed_paths_1\x18\r \x01(\x06\x12\x1e\n\x16half_completed_paths_2\x18\x0e \x01(\x06\x12\x1e\n\x16half_completed_paths_3\x18\x0f \x01(\x06\x12\x1e\n\x16half_completed_paths_4\x18\x10 \x01(\x06\x12\x62\n\x11swapped_challenge\x18\t \x03(\x0b\x32G.dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge\x12\\\n\x0einventory_item\x18\n \x03(\x0b\x32\x44.dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem\x12%\n\x1dultra_rare_reward_room_number\x18\x0b \x01(\r\x12X\n\x0ctreasure_map\x18\x11 \x03(\x0b\x32\x42.dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap\x1a\x38\n\x10SwappedChallenge\x12\x11\n\tpath_id_1\x18\x01 \x01(\r\x12\x11\n\tpath_id_2\x18\x02 \x01(\r\x1a\x31\n\rInventoryItem\x12\x11\n\titem_type\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a<\n\x0bTreasureMap\x12\x13\n\x0bmap_room_id\x18\x01 \x01(\r\x12\x18\n\x10revealed_room_id\x18\x02 \x01(\r\"=\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x13\n\x0f\x45VENT_NOT_OWNED\x10\x02\"@\n,CMsgClientToGCCavernCrawlGetClaimedRoomCount\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\xe0\x01\n4CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse\x12Z\n\x06result\x18\x01 \x01(\x0e\x32\x41.dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse.Result:\x07SUCCESS\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"=\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12\x13\n\x0f\x45VENT_NOT_OWNED\x10\x02\"\x89\x01\n\x14\x43MsgDOTAMutationList\x12\x36\n\tmutations\x18\x01 \x03(\x0b\x32#.dota.CMsgDOTAMutationList.Mutation\x1a\x39\n\x08Mutation\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"`\n\x1b\x43MsgEventTipsSummaryRequest\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xab\x01\n\x1c\x43MsgEventTipsSummaryResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12@\n\rtips_received\x18\x02 \x03(\x0b\x32).dota.CMsgEventTipsSummaryResponse.Tipper\x1a\x39\n\x06Tipper\x12\x19\n\x11tipper_account_id\x18\x01 \x01(\r\x12\x14\n\ttip_count\x18\x02 \x01(\r:\x01\x31\">\n\x15\x43MsgSocialFeedRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tself_only\x18\x02 \x01(\x08\"\xbc\x04\n\x16\x43MsgSocialFeedResponse\x12<\n\x06result\x18\x01 \x01(\x0e\x32#.dota.CMsgSocialFeedResponse.Result:\x07SUCCESS\x12;\n\x0b\x66\x65\x65\x64_events\x18\x02 \x03(\x0b\x32&.dota.CMsgSocialFeedResponse.FeedEvent\x1a\xfa\x01\n\tFeedEvent\x12\x15\n\rfeed_event_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x15\n\rcomment_count\x18\x04 \x01(\r\x12\x12\n\nevent_type\x18\x05 \x01(\r\x12\x16\n\x0e\x65vent_sub_type\x18\x06 \x01(\r\x12\x17\n\x0fparam_big_int_1\x18\x07 \x01(\x04\x12\x13\n\x0bparam_int_1\x18\x08 \x01(\r\x12\x13\n\x0bparam_int_2\x18\t \x01(\r\x12\x13\n\x0bparam_int_3\x18\n \x01(\r\x12\x14\n\x0cparam_string\x18\x0b \x01(\t\"\xa9\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x1a\n\x16\x46\x41ILED_TO_LOAD_FRIENDS\x10\x01\x12\x1c\n\x18\x46\x41ILED_TO_LOAD_FEED_DATA\x10\x02\x12\x1d\n\x19\x46\x41ILED_TO_LOAD_FEED_ENTRY\x10\x03\x12\x1b\n\x17\x46\x41ILED_TO_LOAD_COMMENTS\x10\x04\x12\x1c\n\x18\x46\x41ILED_TOO_MANY_REQUESTS\x10\x05\"6\n\x1d\x43MsgSocialFeedCommentsRequest\x12\x15\n\rfeed_event_id\x18\x01 \x01(\x04\"\xd7\x02\n\x1e\x43MsgSocialFeedCommentsResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.dota.CMsgSocialFeedCommentsResponse.Result:\x07SUCCESS\x12G\n\rfeed_comments\x18\x03 \x03(\x0b\x32\x30.dota.CMsgSocialFeedCommentsResponse.FeedComment\x1aT\n\x0b\x46\x65\x65\x64\x43omment\x12\x1c\n\x14\x63ommenter_account_id\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x14\n\x0c\x63omment_text\x18\x03 \x01(\t\"P\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x1c\n\x18\x46\x41ILED_TOO_MANY_REQUESTS\x10\x01\x12\x1b\n\x17\x46\x41ILED_TO_LOAD_COMMENTS\x10\x02\"y\n/CMsgClientToGCPlayerCardSpecificPurchaseRequest\x12\x19\n\x11player_account_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x19\n\x11\x63\x61rd_dust_item_id\x18\x03 \x01(\x04\"\xa5\x02\n0CMsgClientToGCPlayerCardSpecificPurchaseResponse\x12V\n\x06result\x18\x01 \x01(\x0e\x32=.dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse.Result:\x07SUCCESS\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"\x87\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1b\n\x17\x45RROR_INSUFFICIENT_DUST\x10\x03\x12\x1c\n\x18\x45RROR_ITEM_NOT_DUST_ITEM\x10\x04\x12!\n\x1d\x45RROR_FAILED_CARD_PACK_CREATE\x10\x05\"7\n!CMsgClientToGCRequestContestVotes\x12\x12\n\ncontest_id\x18\x01 \x01(\r\"\xd8\x02\n)CMsgClientToGCRequestContestVotesResponse\x12[\n\x06result\x18\x01 \x01(\x0e\x32\x39.dota.CMsgClientToGCRequestContestVotesResponse.EResponse:\x10k_eInternalError\x12G\n\x05votes\x18\x02 \x03(\x0b\x32\x38.dota.CMsgClientToGCRequestContestVotesResponse.ItemVote\x1a\x31\n\x08ItemVote\x12\x17\n\x0f\x63ontest_item_id\x18\x01 \x01(\x04\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"\\\n\x1f\x43MsgClientToGCRecordContestVote\x12\x12\n\ncontest_id\x18\x01 \x01(\r\x12\x17\n\x0f\x63ontest_item_id\x18\x02 \x01(\x04\x12\x0c\n\x04vote\x18\x03 \x01(\x05\"\x9c\x02\n\'CMsgGCToClientRecordContestVoteResponse\x12O\n\x07\x65result\x18\x01 \x01(\x0e\x32\x35.dota.CMsgGCToClientRecordContestVoteResponse.EResult:\x07SUCCESS\"\x9f\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x1a\n\x16\x46\x41ILED_EVENT_NOT_OWNED\x10\x01\x12\x1c\n\x18\x46\x41ILED_SQL_INSERT_FAILED\x10\x02\x12\x1a\n\x16\x46\x41ILED_INVALID_CONTEST\x10\x03\x12\x1d\n\x19\x46\x41ILED_CONTEST_NOT_ACTIVE\x10\x04\x12\x12\n\x0e\x46\x41ILED_TIMEOUT\x10\x05\"\x80\x06\n\x0f\x43MsgDOTADPCFeed\x12/\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1d.dota.CMsgDOTADPCFeed.Element\x1a\xad\x02\n\x07\x45lement\x12H\n\x04type\x18\x01 \x01(\x0e\x32&.dota.CMsgDOTADPCFeed.EFeedElementType:\x12\x46\x45\x45\x44_SERIES_RESULT\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x11\n\tseries_id\x18\x03 \x01(\r\x12\x10\n\x08match_id\x18\x04 \x01(\x04\x12\x0f\n\x07team_id\x18\x05 \x01(\r\x12\x12\n\naccount_id\x18\x06 \x01(\r\x12\x11\n\tleague_id\x18\x07 \x01(\r\x12\x0f\n\x07node_id\x18\x08 \x01(\r\x12\x17\n\x0fserver_steam_id\x18\r \x01(\x04\x12\x0e\n\x06\x64\x61ta_1\x18\t \x01(\r\x12\x0e\n\x06\x64\x61ta_2\x18\n \x01(\r\x12\x0e\n\x06\x64\x61ta_3\x18\x0b \x01(\r\x12\x0e\n\x06\x64\x61ta_4\x18\x0c \x01(\r\"\x8b\x03\n\x10\x45\x46\x65\x65\x64\x45lementType\x12\x16\n\x12\x46\x45\x45\x44_SERIES_RESULT\x10\x01\x12\x16\n\x12\x46\x45\x45\x44_MATCH_POPULAR\x10\x02\x12\x1c\n\x18\x46\x45\x45\x44_TEAM_UPCOMING_MATCH\x10\x03\x12\x1b\n\x17\x46\x45\x45\x44_TEAM_LEAGUE_RESULT\x10\x04\x12\x18\n\x14\x46\x45\x45\x44_TEAM_ADD_PLAYER\x10\x05\x12\x1b\n\x17\x46\x45\x45\x44_TEAM_REMOVE_PLAYER\x10\x06\x12\x15\n\x11\x46\x45\x45\x44_TEAM_DISBAND\x10\x07\x12\x18\n\x14\x46\x45\x45\x44_LEAGUE_UPCOMING\x10\x08\x12\x19\n\x15\x46\x45\x45\x44_LEAGUE_CONCLUDED\x10\t\x12\x16\n\x12\x46\x45\x45\x44_DPC_STANDINGS\x10\n\x12\x1a\n\x16\x46\x45\x45\x44_ALERT_PREDICTIONS\x10\x0b\x12\x16\n\x12\x46\x45\x45\x44_ALERT_FANTASY\x10\x0c\x12\x1a\n\x16\x46\x45\x45\x44_LEAGUE_LIVE_MATCH\x10\r\x12!\n\x1d\x46\x45\x45\x44_LEAGUE_INPROGRESS_SERIES\x10\x0e\"1\n\x13\x43MsgDOTADPCUserInfo\x12\x1a\n\x12is_plus_subscriber\x18\x01 \x01(\x08\"v\n\x17\x43MsgDevGrantEventPoints\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x14\n\x0c\x65vent_points\x18\x02 \x01(\r\x12\x16\n\x0epremium_points\x18\x03 \x01(\r\"q\n\x1f\x43MsgDevGrantEventPointsResponse\x12N\n\x06result\x18\x01 \x01(\x0e\x32\x1c.dota.EDevEventRequestResult: k_EDevEventRequestResult_Success\"q\n\x17\x43MsgDevGrantEventAction\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x11\n\taction_id\x18\x02 \x01(\r\x12\x14\n\x0c\x61\x63tion_score\x18\x03 \x01(\r\"q\n\x1f\x43MsgDevGrantEventActionResponse\x12N\n\x06result\x18\x01 \x01(\x0e\x32\x1c.dota.EDevEventRequestResult: k_EDevEventRequestResult_Success\"]\n\x16\x43MsgDevResetEventState\x12-\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x0c.dota.EEvent:\rEVENT_ID_NONE\x12\x14\n\x0cremove_audit\x18\x02 \x01(\x08\"p\n\x1e\x43MsgDevResetEventStateResponse\x12N\n\x06result\x18\x01 \x01(\x0e\x32\x1c.dota.EDevEventRequestResult: k_EDevEventRequestResult_Success\"3\n CMsgConsumeEventSupportGrantItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\x82\x01\n(CMsgConsumeEventSupportGrantItemResponse\x12V\n\x06result\x18\x01 \x01(\x0e\x32 .dota.ESupportEventRequestResult:$k_ESupportEventRequestResult_Success\"\"\n CMsgClientToGCGetFilteredPlayers\"\xc3\x02\n(CMsgGCToClientGetFilteredPlayersResponse\x12N\n\x06result\x18\x01 \x01(\x0e\x32\x35.dota.CMsgGCToClientGetFilteredPlayersResponse.Result:\x07SUCCESS\x12U\n\x10\x66iltered_players\x18\x02 \x03(\x0b\x32;.dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry\x1aL\n\x0c\x43\x46ilterEntry\x12\x12\n\naccount_id\x18\x01 \x01(\x07\x12\x12\n\ntime_added\x18\x02 \x01(\x07\x12\x14\n\x0ctime_expires\x18\x03 \x01(\x07\"\"\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\"B\n\"CMsgClientToGCRemoveFilteredPlayer\x12\x1c\n\x14\x61\x63\x63ount_id_to_remove\x18\x01 \x01(\x07\"\xa2\x01\n*CMsgGCToClientRemoveFilteredPlayerResponse\x12P\n\x06result\x18\x01 \x01(\x0e\x32\x37.dota.CMsgGCToClientRemoveFilteredPlayerResponse.Result:\x07SUCCESS\"\"\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\"T\n\x15\x43MsgPartySearchPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\x07\x12\x10\n\x08match_id\x18\x02 \x01(\x06\x12\x15\n\rcreation_time\x18\x03 \x01(\x07\"=\n\x1f\x43MsgGCToClientPlayerBeaconState\x12\x1a\n\x12num_active_beacons\x18\x01 \x03(\x05\"`\n\x1f\x43MsgGCToClientPartyBeaconUpdate\x12\x14\n\x0c\x62\x65\x61\x63on_added\x18\x01 \x01(\x08\x12\x13\n\x0b\x62\x65\x61\x63on_type\x18\x02 \x01(\x05\x12\x12\n\naccount_id\x18\x03 \x01(\x07\"~\n\x1f\x43MsgClientToGCUpdatePartyBeacon\x12@\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32,.dota.CMsgClientToGCUpdatePartyBeacon.Action:\x02ON\"\x19\n\x06\x41\x63tion\x12\x06\n\x02ON\x10\x00\x12\x07\n\x03OFF\x10\x01\"*\n(CMsgClientToGCRequestActiveBeaconParties\"\xf7\x01\n0CMsgGCToClientRequestActiveBeaconPartiesResponse\x12[\n\x08response\x18\x01 \x01(\x0e\x32@.dota.CMsgGCToClientRequestActiveBeaconPartiesResponse.EResponse:\x07SUCCESS\x12\x35\n\x0e\x61\x63tive_parties\x18\x02 \x03(\x0b\x32\x1d.dota.CPartySearchClientParty\"/\n\tEResponse\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x08\n\x04\x42USY\x10\x02\"^\n!CMsgClientToGCJoinPartyFromBeacon\x12\x10\n\x08party_id\x18\x01 \x01(\x06\x12\x12\n\naccount_id\x18\x02 \x01(\x07\x12\x13\n\x0b\x62\x65\x61\x63on_type\x18\x03 \x01(\x05\"\xc2\x01\n)CMsgGCToClientJoinPartyFromBeaconResponse\x12T\n\x08response\x18\x01 \x01(\x0e\x32\x39.dota.CMsgGCToClientJoinPartyFromBeaconResponse.EResponse:\x07SUCCESS\"?\n\tEResponse\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x08\n\x04\x42USY\x10\x02\x12\x0e\n\nNOT_LEADER\x10\x03\"\xee\x01\n\x1d\x43MsgClientToGCManageFavorites\x12?\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32*.dota.CMsgClientToGCManageFavorites.Action:\x03\x41\x44\x44\x12\x12\n\naccount_id\x18\x02 \x01(\x07\x12\x15\n\rfavorite_name\x18\x03 \x01(\t\x12\x17\n\x0finvite_response\x18\x04 \x01(\x08\x12\x17\n\x0f\x66rom_friendlist\x18\x05 \x01(\x08\x12\x10\n\x08lobby_id\x18\x06 \x01(\x06\"\x1d\n\x06\x41\x63tion\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06REMOVE\x10\x01\"\xa3\x02\n%CMsgGCToClientManageFavoritesResponse\x12P\n\x08response\x18\x01 \x01(\x0e\x32\x35.dota.CMsgGCToClientManageFavoritesResponse.EResponse:\x07SUCCESS\x12\x15\n\rdebug_message\x18\x02 \x01(\t\x12+\n\x06player\x18\x03 \x01(\x0b\x32\x1b.dota.CMsgPartySearchPlayer\"d\n\tEResponse\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x15\n\x11NO_INVITE_PRESENT\x10\x02\x12\x0f\n\x0bINVITE_SENT\x10\x03\x12\x0b\n\x07\x45XPIRED\x10\x04\x12\x08\n\x04\x42USY\x10\x05\"T\n CMsgClientToGCGetFavoritePlayers\x12\x16\n\x0epagination_key\x18\x01 \x01(\x04\x12\x18\n\x10pagination_count\x18\x02 \x01(\x05\"\xf1\x01\n(CMsgGCToClientGetFavoritePlayersResponse\x12S\n\x08response\x18\x01 \x01(\x0e\x32\x38.dota.CMsgGCToClientGetFavoritePlayersResponse.EResponse:\x07SUCCESS\x12,\n\x07players\x18\x02 \x03(\x0b\x32\x1b.dota.CMsgPartySearchPlayer\x12\x1b\n\x13next_pagination_key\x18\x03 \x01(\x04\"%\n\tEResponse\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\"5\n\x1f\x43MsgGCToClientPartySearchInvite\x12\x12\n\naccount_id\x18\x01 \x01(\x07\":\n#CMsgClientToGCVerifyFavoritePlayers\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\x07\"\xc4\x01\n+CMsgGCToClientVerifyFavoritePlayersResponse\x12I\n\x07results\x18\x01 \x03(\x0b\x32\x38.dota.CMsgGCToClientVerifyFavoritePlayersResponse.Result\x1aJ\n\x06Result\x12+\n\x06player\x18\x01 \x01(\x0b\x32\x1b.dota.CMsgPartySearchPlayer\x12\x13\n\x0bis_favorite\x18\x02 \x01(\x08\"F\n0CMsgClientToGCRequestPlayerRecentAccomplishments\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xc1\x02\n8CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse\x12j\n\x06result\x18\x01 \x01(\x0e\x32H.dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse.EResponse:\x10k_eInternalError\x12\x45\n\x16player_accomplishments\x18\x02 \x01(\x0b\x32%.dota.CMsgPlayerRecentAccomplishments\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"[\n4CMsgClientToGCRequestPlayerHeroRecentAccomplishments\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\"\xcb\x02\n<CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse\x12n\n\x06result\x18\x01 \x01(\x0e\x32L.dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse.EResponse:\x10k_eInternalError\x12G\n\x14hero_accomplishments\x18\x02 \x01(\x0b\x32).dota.CMsgPlayerHeroRecentAccomplishments\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"\xf4\x01\n\x14\x43MsgPlayerCoachMatch\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x43\n\rmatch_outcome\x18\x02 \x01(\x0e\x32\x13.dota.EMatchOutcome:\x17k_EMatchOutcome_Unknown\x12\x14\n\x0c\x63oached_team\x18\x03 \x01(\r\x12\x12\n\nstart_time\x18\x04 \x01(\x07\x12\x10\n\x08\x64uration\x18\x05 \x01(\r\x12\x34\n\x10teammate_ratings\x18\x06 \x03(\x0e\x32\x1a.dota.ECoachTeammateRating\x12\x13\n\x0b\x63oach_flags\x18\x07 \x01(\r\")\n\'CMsgClientToGCRequestPlayerCoachMatches\"\x9b\x02\n/CMsgClientToGCRequestPlayerCoachMatchesResponse\x12\x61\n\x06result\x18\x01 \x01(\x0e\x32?.dota.CMsgClientToGCRequestPlayerCoachMatchesResponse.EResponse:\x10k_eInternalError\x12\x31\n\rcoach_matches\x18\x02 \x03(\x0b\x32\x1a.dota.CMsgPlayerCoachMatch\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"9\n%CMsgClientToGCRequestPlayerCoachMatch\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"\x95\x02\n-CMsgClientToGCRequestPlayerCoachMatchResponse\x12_\n\x06result\x18\x01 \x01(\x0e\x32=.dota.CMsgClientToGCRequestPlayerCoachMatchResponse.EResponse:\x10k_eInternalError\x12/\n\x0b\x63oach_match\x18\x02 \x01(\x0b\x32\x1a.dota.CMsgPlayerCoachMatch\"R\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\"\xae\x01\n\'CMsgClientToGCSubmitCoachTeammateRating\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x18\n\x10\x63oach_account_id\x18\x02 \x01(\r\x12G\n\x06rating\x18\x03 \x01(\x0e\x32\x1a.dota.ECoachTeammateRating:\x1bk_ECoachTeammateRating_None\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\xb6\x03\n/CMsgClientToGCSubmitCoachTeammateRatingResponse\x12\x61\n\x06result\x18\x01 \x01(\x0e\x32?.dota.CMsgClientToGCSubmitCoachTeammateRatingResponse.EResponse:\x10k_eInternalError\"\x9f\x02\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\x12\x13\n\x0fk_eInvalidInput\x10\x04\x12\x17\n\x13k_eAlreadySubmitted\x10\x05\x12\x15\n\x11k_eVotingFinished\x10\x06\x12\x17\n\x13k_ePlayerNotInMatch\x10\x07\x12\x16\n\x12k_eCoachNotInMatch\x10\x08\x12\x1b\n\x17k_ePlayerNotOnCoachTeam\x10\t\x12\x1f\n\x1bk_ePlayerInSamePartyAsCoach\x10\n\x12\x17\n\x13k_eMatchNotEligible\x10\x0b\"\\\n)CMsgGCToClientCoachTeammateRatingsChanged\x12/\n\x0b\x63oach_match\x18\x01 \x01(\x0b\x32\x1a.dota.CMsgPlayerCoachMatch\">\n#CMsgClientToGCGetTicketCodesRequest\x12\x17\n\x0fticket_pool_ids\x18\x01 \x03(\r\"\xb0\x01\n$CMsgClientToGCGetTicketCodesResponse\x12>\n\x05\x63odes\x18\x01 \x03(\x0b\x32/.dota.CMsgClientToGCGetTicketCodesResponse.Code\x1aH\n\x04\x43ode\x12\x16\n\x0eticket_pool_id\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x63\x63ount_disallowed\x18\x03 \x01(\x08\")\n\'CMsgClientToGCGetUnderlordsCDKeyRequest\"\xc9\x01\n(CMsgClientToGCGetUnderlordsCDKeyResponse\x12Q\n\x06result\x18\x01 \x01(\x0e\x32\x38.dota.CMsgClientToGCGetUnderlordsCDKeyResponse.EResponse:\x07Success\x12\x0f\n\x07\x63\x64_keys\x18\x02 \x03(\t\"9\n\tEResponse\x12\x0b\n\x07Success\x10\x00\x12\x10\n\x0cUnknownError\x10\x01\x12\r\n\tOutOfKeys\x10\x02\"M\n&CMsgClientToGCSetFavoriteAllStarPlayer\x12\x11\n\tplayer_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\"\xd7\x02\n.CMsgClientToGCSetFavoriteAllStarPlayerResponse\x12`\n\x06result\x18\x01 \x01(\x0e\x32>.dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse.EResponse:\x10k_eInternalError\x12\x11\n\tplayer_id\x18\x02 \x01(\r\"\xaf\x01\n\tEResponse\x12\x14\n\x10k_eInternalError\x10\x00\x12\x0e\n\nk_eSuccess\x10\x01\x12\x0e\n\nk_eTooBusy\x10\x02\x12\x0f\n\x0bk_eDisabled\x10\x03\x12\x17\n\x13k_eAlreadySubmitted\x10\x04\x12\x15\n\x11k_ePlayerNotValid\x10\x05\x12\x15\n\x11k_eDoesntOwnEvent\x10\x06\x12\x14\n\x10k_eEventNotValid\x10\x07\"/\n-CMsgClientToGCGetFavoriteAllStarPlayerRequest\"\x9e\x02\n.CMsgClientToGCGetFavoriteAllStarPlayerResponse\x12Z\n\x06result\x18\x01 \x01(\x0e\x32>.dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.EResponse:\nk_eSuccess\x12\x11\n\tplayer_id\x18\x02 \x01(\r\x12\x1d\n\x15picking_allowed_until\x18\x03 \x01(\r\x12\x1c\n\x14\x65\x61rned_battle_points\x18\x04 \x01(\r\"@\n\tEResponse\x12\x0e\n\nk_eSuccess\x10\x00\x12\r\n\tk_eNoPick\x10\x01\x12\x14\n\x10k_eInternalError\x10\x02\"a\n\x1d\x43MsgClientToGCVerifyIntegrity\x12\x10\n\x08\x63urrency\x18\x01 \x01(\r\x12\x1f\n\x17\x61\x64\x64itional_user_message\x18\x02 \x01(\r\x12\r\n\x05\x61\x63ked\x18\x03 \x01(\x0c*V\n\x14\x44OTA_WatchReplayType\x12\x1c\n\x18\x44OTA_WATCH_REPLAY_NORMAL\x10\x00\x12 \n\x1c\x44OTA_WATCH_REPLAY_HIGHLIGHTS\x10\x01*\xd1\x01\n\x1c\x45ItemEditorReservationResult\x12%\n!k_EItemEditorReservationResult_OK\x10\x01\x12\x30\n,k_EItemEditorReservationResult_AlreadyExists\x10\x02\x12+\n\'k_EItemEditorReservationResult_Reserved\x10\x03\x12+\n\'k_EItemEditorReservationResult_TimedOut\x10\x04*\x92\x04\n\x16\x45\x46\x65\x61turedHeroTextField\x12$\n k_EFeaturedHeroTextField_NewHero\x10\x00\x12$\n k_EFeaturedHeroTextField_NewItem\x10\x01\x12/\n+k_EFeaturedHeroTextField_ItemSetDescription\x10\x02\x12,\n(k_EFeaturedHeroTextField_ItemDescription\x10\x03\x12!\n\x1dk_EFeaturedHeroTextField_Hype\x10\x04\x12(\n$k_EFeaturedHeroTextField_HeroWinLoss\x10\x05\x12\x31\n-k_EFeaturedHeroTextField_FrequentlyPlayedHero\x10\x06\x12)\n%k_EFeaturedHeroTextField_FeaturedItem\x10\x07\x12(\n$k_EFeaturedHeroTextField_PopularItem\x10\x08\x12%\n!k_EFeaturedHeroTextField_SaleItem\x10\t\x12)\n%k_EFeaturedHeroTextField_SaleDiscount\x10\n\x12&\n\"k_EFeaturedHeroTextField_Container\x10\x0b*\x87\x03\n\x15\x45\x46\x65\x61turedHeroDataType\x12\"\n\x1ek_EFeaturedHeroDataType_HeroID\x10\x00\x12#\n\x1fk_EFeaturedHeroDataType_ItemDef\x10\x01\x12&\n\"k_EFeaturedHeroDataType_HypeString\x10\x02\x12*\n&k_EFeaturedHeroDataType_StartTimestamp\x10\x03\x12+\n\'k_EFeaturedHeroDataType_ExpireTimestamp\x10\x04\x12$\n k_EFeaturedHeroDataType_HeroWins\x10\x05\x12&\n\"k_EFeaturedHeroDataType_HeroLosses\x10\x06\x12(\n$k_EFeaturedHeroDataType_SaleDiscount\x10\x07\x12,\n(k_EFeaturedHeroDataType_ContainerItemDef\x10\x08*\xe8\x01\n EWeekendTourneyRichPresenceEvent\x12+\n\'k_EWeekendTourneyRichPresenceEvent_None\x10\x00\x12\x33\n/k_EWeekendTourneyRichPresenceEvent_StartedMatch\x10\x01\x12/\n+k_EWeekendTourneyRichPresenceEvent_WonMatch\x10\x02\x12\x31\n-k_EWeekendTourneyRichPresenceEvent_Eliminated\x10\x03*\xf2\x05\n\x1b\x45\x44OTATriviaQuestionCategory\x12-\n)k_EDOTATriviaQuestionCategory_AbilityIcon\x10\x00\x12\x31\n-k_EDOTATriviaQuestionCategory_AbilityCooldown\x10\x01\x12\x30\n,k_EDOTATriviaQuestionCategory_HeroAttributes\x10\x02\x12\x33\n/k_EDOTATriviaQuestionCategory_HeroMovementSpeed\x10\x03\x12,\n(k_EDOTATriviaQuestionCategory_TalentTree\x10\x04\x12+\n\'k_EDOTATriviaQuestionCategory_HeroStats\x10\x05\x12+\n\'k_EDOTATriviaQuestionCategory_ItemPrice\x10\x06\x12.\n*k_EDOTATriviaQuestionCategory_AbilitySound\x10\x07\x12/\n+k_EDOTATriviaQuestionCategory_InvokerSpells\x10\x08\x12\x31\n-k_EDOTATriviaQuestionCategory_AbilityManaCost\x10\t\x12\x31\n-k_EDOTATriviaQuestionCategory_HeroAttackSound\x10\n\x12-\n)k_EDOTATriviaQuestionCategory_AbilityName\x10\x0b\x12\x30\n,k_EDOTATriviaQuestionCategory_ItemComponents\x10\x0c\x12*\n&k_EDOTATriviaQuestionCategory_ItemLore\x10\r\x12.\n*k_EDOTATriviaQuestionCategory_ItemPassives\x10\x0e*\xa7\x02\n\x17\x45\x44OTATriviaAnswerResult\x12%\n!k_EDOTATriviaAnswerResult_Success\x10\x00\x12-\n)k_EDOTATriviaAnswerResult_InvalidQuestion\x10\x01\x12+\n\'k_EDOTATriviaAnswerResult_InvalidAnswer\x10\x02\x12,\n(k_EDOTATriviaAnswerResult_QuestionLocked\x10\x03\x12-\n)k_EDOTATriviaAnswerResult_AlreadyAnswered\x10\x04\x12,\n(k_EDOTATriviaAnswerResult_TriviaDisabled\x10\x05*\xe0\x02\n\x18\x45PurchaseHeroRelicResult\x12&\n\"k_EPurchaseHeroRelicResult_Success\x10\x00\x12+\n\'k_EPurchaseHeroRelicResult_FailedToSend\x10\x01\x12.\n*k_EPurchaseHeroRelicResult_NotEnoughPoints\x10\x02\x12\x32\n.k_EPurchaseHeroRelicResult_InternalServerError\x10\x03\x12\x31\n-k_EPurchaseHeroRelicResult_PurchaseNotAllowed\x10\x04\x12+\n\'k_EPurchaseHeroRelicResult_InvalidRelic\x10\x05\x12+\n\'k_EPurchaseHeroRelicResult_AlreadyOwned\x10\x06*\xb8\x02\n\x16\x45\x44\x65vEventRequestResult\x12$\n k_EDevEventRequestResult_Success\x10\x00\x12\'\n#k_EDevEventRequestResult_NotAllowed\x10\x01\x12)\n%k_EDevEventRequestResult_InvalidEvent\x10\x02\x12\'\n#k_EDevEventRequestResult_SqlFailure\x10\x03\x12$\n k_EDevEventRequestResult_Timeout\x10\x04\x12(\n$k_EDevEventRequestResult_LockFailure\x10\x05\x12+\n\'k_EDevEventRequestResult_SDOLoadFailure\x10\x06*\xdd\x05\n\x1a\x45SupportEventRequestResult\x12(\n$k_ESupportEventRequestResult_Success\x10\x00\x12(\n$k_ESupportEventRequestResult_Timeout\x10\x01\x12\x30\n,k_ESupportEventRequestResult_CantLockSOCache\x10\x02\x12\x33\n/k_ESupportEventRequestResult_ItemNotInInventory\x10\x03\x12/\n+k_ESupportEventRequestResult_InvalidItemDef\x10\x04\x12-\n)k_ESupportEventRequestResult_InvalidEvent\x10\x05\x12-\n)k_ESupportEventRequestResult_EventExpired\x10\x06\x12\x36\n2k_ESupportEventRequestResult_InvalidSupportAccount\x10\x07\x12\x36\n2k_ESupportEventRequestResult_InvalidSupportMessage\x10\x08\x12\x33\n/k_ESupportEventRequestResult_InvalidEventPoints\x10\t\x12\x35\n1k_ESupportEventRequestResult_InvalidPremiumPoints\x10\n\x12\x30\n,k_ESupportEventRequestResult_InvalidActionID\x10\x0b\x12\x33\n/k_ESupportEventRequestResult_InvalidActionScore\x10\x0c\x12\x32\n.k_ESupportEventRequestResult_TransactionFailed\x10\r*\xa5\x01\n\x14\x45\x43oachTeammateRating\x12\x1f\n\x1bk_ECoachTeammateRating_None\x10\x00\x12#\n\x1fk_ECoachTeammateRating_Positive\x10\x01\x12#\n\x1fk_ECoachTeammateRating_Negative\x10\x02\x12\"\n\x1ek_ECoachTeammateRating_Abusive\x10\x03*G\n\x15\x45PlayerCoachMatchFlag\x12.\n*k_EPlayerCoachMatchFlag_EligibleForRewards\x10\x01\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,dota__shared__enums__pb2.DESCRIPTOR,dota__gcmessages__common__pb2.DESCRIPTOR,gcsdk__gcmessages__pb2.DESCRIPTOR,dota__gcmessages__common__match__management__pb2.DESCRIPTOR,base__gcmessages__pb2.DESCRIPTOR,])

_DOTA_WATCHREPLAYTYPE = _descriptor.EnumDescriptor(
  name='DOTA_WatchReplayType',
  full_name='dota.DOTA_WatchReplayType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_WATCH_REPLAY_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_WATCH_REPLAY_HIGHLIGHTS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=61066,
  serialized_end=61152,
)
_sym_db.RegisterEnumDescriptor(_DOTA_WATCHREPLAYTYPE)

DOTA_WatchReplayType = enum_type_wrapper.EnumTypeWrapper(_DOTA_WATCHREPLAYTYPE)
_EITEMEDITORRESERVATIONRESULT = _descriptor.EnumDescriptor(
  name='EItemEditorReservationResult',
  full_name='dota.EItemEditorReservationResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_OK', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_AlreadyExists', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_Reserved', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_TimedOut', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=61155,
  serialized_end=61364,
)
_sym_db.RegisterEnumDescriptor(_EITEMEDITORRESERVATIONRESULT)

EItemEditorReservationResult = enum_type_wrapper.EnumTypeWrapper(_EITEMEDITORRESERVATIONRESULT)
_EFEATUREDHEROTEXTFIELD = _descriptor.EnumDescriptor(
  name='EFeaturedHeroTextField',
  full_name='dota.EFeaturedHeroTextField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_NewHero', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_NewItem', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_ItemSetDescription', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_ItemDescription', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_Hype', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_HeroWinLoss', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_FrequentlyPlayedHero', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_FeaturedItem', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_PopularItem', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_SaleItem', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_SaleDiscount', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_Container', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=61367,
  serialized_end=61897,
)
_sym_db.RegisterEnumDescriptor(_EFEATUREDHEROTEXTFIELD)

EFeaturedHeroTextField = enum_type_wrapper.EnumTypeWrapper(_EFEATUREDHEROTEXTFIELD)
_EFEATUREDHERODATATYPE = _descriptor.EnumDescriptor(
  name='EFeaturedHeroDataType',
  full_name='dota.EFeaturedHeroDataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ItemDef', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HypeString', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_StartTimestamp', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ExpireTimestamp', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroWins', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroLosses', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_SaleDiscount', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ContainerItemDef', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=61900,
  serialized_end=62291,
)
_sym_db.RegisterEnumDescriptor(_EFEATUREDHERODATATYPE)

EFeaturedHeroDataType = enum_type_wrapper.EnumTypeWrapper(_EFEATUREDHERODATATYPE)
_EWEEKENDTOURNEYRICHPRESENCEEVENT = _descriptor.EnumDescriptor(
  name='EWeekendTourneyRichPresenceEvent',
  full_name='dota.EWeekendTourneyRichPresenceEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_StartedMatch', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_WonMatch', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_Eliminated', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=62294,
  serialized_end=62526,
)
_sym_db.RegisterEnumDescriptor(_EWEEKENDTOURNEYRICHPRESENCEEVENT)

EWeekendTourneyRichPresenceEvent = enum_type_wrapper.EnumTypeWrapper(_EWEEKENDTOURNEYRICHPRESENCEEVENT)
_EDOTATRIVIAQUESTIONCATEGORY = _descriptor.EnumDescriptor(
  name='EDOTATriviaQuestionCategory',
  full_name='dota.EDOTATriviaQuestionCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_AbilityIcon', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_AbilityCooldown', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_HeroAttributes', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_HeroMovementSpeed', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_TalentTree', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_HeroStats', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_ItemPrice', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_AbilitySound', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_InvokerSpells', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_AbilityManaCost', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_HeroAttackSound', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_AbilityName', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_ItemComponents', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_ItemLore', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaQuestionCategory_ItemPassives', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=62529,
  serialized_end=63283,
)
_sym_db.RegisterEnumDescriptor(_EDOTATRIVIAQUESTIONCATEGORY)

EDOTATriviaQuestionCategory = enum_type_wrapper.EnumTypeWrapper(_EDOTATRIVIAQUESTIONCATEGORY)
_EDOTATRIVIAANSWERRESULT = _descriptor.EnumDescriptor(
  name='EDOTATriviaAnswerResult',
  full_name='dota.EDOTATriviaAnswerResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_InvalidQuestion', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_InvalidAnswer', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_QuestionLocked', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_AlreadyAnswered', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTATriviaAnswerResult_TriviaDisabled', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=63286,
  serialized_end=63581,
)
_sym_db.RegisterEnumDescriptor(_EDOTATRIVIAANSWERRESULT)

EDOTATriviaAnswerResult = enum_type_wrapper.EnumTypeWrapper(_EDOTATRIVIAANSWERRESULT)
_EPURCHASEHERORELICRESULT = _descriptor.EnumDescriptor(
  name='EPurchaseHeroRelicResult',
  full_name='dota.EPurchaseHeroRelicResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_FailedToSend', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_NotEnoughPoints', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_InternalServerError', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_PurchaseNotAllowed', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_InvalidRelic', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPurchaseHeroRelicResult_AlreadyOwned', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=63584,
  serialized_end=63936,
)
_sym_db.RegisterEnumDescriptor(_EPURCHASEHERORELICRESULT)

EPurchaseHeroRelicResult = enum_type_wrapper.EnumTypeWrapper(_EPURCHASEHERORELICRESULT)
_EDEVEVENTREQUESTRESULT = _descriptor.EnumDescriptor(
  name='EDevEventRequestResult',
  full_name='dota.EDevEventRequestResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_NotAllowed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_InvalidEvent', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_SqlFailure', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_Timeout', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_LockFailure', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDevEventRequestResult_SDOLoadFailure', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=63939,
  serialized_end=64251,
)
_sym_db.RegisterEnumDescriptor(_EDEVEVENTREQUESTRESULT)

EDevEventRequestResult = enum_type_wrapper.EnumTypeWrapper(_EDEVEVENTREQUESTRESULT)
_ESUPPORTEVENTREQUESTRESULT = _descriptor.EnumDescriptor(
  name='ESupportEventRequestResult',
  full_name='dota.ESupportEventRequestResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_Timeout', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_CantLockSOCache', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_ItemNotInInventory', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidItemDef', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidEvent', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_EventExpired', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidSupportAccount', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidSupportMessage', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidEventPoints', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidPremiumPoints', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidActionID', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_InvalidActionScore', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESupportEventRequestResult_TransactionFailed', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=64254,
  serialized_end=64987,
)
_sym_db.RegisterEnumDescriptor(_ESUPPORTEVENTREQUESTRESULT)

ESupportEventRequestResult = enum_type_wrapper.EnumTypeWrapper(_ESUPPORTEVENTREQUESTRESULT)
_ECOACHTEAMMATERATING = _descriptor.EnumDescriptor(
  name='ECoachTeammateRating',
  full_name='dota.ECoachTeammateRating',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ECoachTeammateRating_None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECoachTeammateRating_Positive', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECoachTeammateRating_Negative', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECoachTeammateRating_Abusive', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=64990,
  serialized_end=65155,
)
_sym_db.RegisterEnumDescriptor(_ECOACHTEAMMATERATING)

ECoachTeammateRating = enum_type_wrapper.EnumTypeWrapper(_ECOACHTEAMMATERATING)
_EPLAYERCOACHMATCHFLAG = _descriptor.EnumDescriptor(
  name='EPlayerCoachMatchFlag',
  full_name='dota.EPlayerCoachMatchFlag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EPlayerCoachMatchFlag_EligibleForRewards', index=0, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=65157,
  serialized_end=65228,
)
_sym_db.RegisterEnumDescriptor(_EPLAYERCOACHMATCHFLAG)

EPlayerCoachMatchFlag = enum_type_wrapper.EnumTypeWrapper(_EPLAYERCOACHMATCHFLAG)
DOTA_WATCH_REPLAY_NORMAL = 0
DOTA_WATCH_REPLAY_HIGHLIGHTS = 1
k_EItemEditorReservationResult_OK = 1
k_EItemEditorReservationResult_AlreadyExists = 2
k_EItemEditorReservationResult_Reserved = 3
k_EItemEditorReservationResult_TimedOut = 4
k_EFeaturedHeroTextField_NewHero = 0
k_EFeaturedHeroTextField_NewItem = 1
k_EFeaturedHeroTextField_ItemSetDescription = 2
k_EFeaturedHeroTextField_ItemDescription = 3
k_EFeaturedHeroTextField_Hype = 4
k_EFeaturedHeroTextField_HeroWinLoss = 5
k_EFeaturedHeroTextField_FrequentlyPlayedHero = 6
k_EFeaturedHeroTextField_FeaturedItem = 7
k_EFeaturedHeroTextField_PopularItem = 8
k_EFeaturedHeroTextField_SaleItem = 9
k_EFeaturedHeroTextField_SaleDiscount = 10
k_EFeaturedHeroTextField_Container = 11
k_EFeaturedHeroDataType_HeroID = 0
k_EFeaturedHeroDataType_ItemDef = 1
k_EFeaturedHeroDataType_HypeString = 2
k_EFeaturedHeroDataType_StartTimestamp = 3
k_EFeaturedHeroDataType_ExpireTimestamp = 4
k_EFeaturedHeroDataType_HeroWins = 5
k_EFeaturedHeroDataType_HeroLosses = 6
k_EFeaturedHeroDataType_SaleDiscount = 7
k_EFeaturedHeroDataType_ContainerItemDef = 8
k_EWeekendTourneyRichPresenceEvent_None = 0
k_EWeekendTourneyRichPresenceEvent_StartedMatch = 1
k_EWeekendTourneyRichPresenceEvent_WonMatch = 2
k_EWeekendTourneyRichPresenceEvent_Eliminated = 3
k_EDOTATriviaQuestionCategory_AbilityIcon = 0
k_EDOTATriviaQuestionCategory_AbilityCooldown = 1
k_EDOTATriviaQuestionCategory_HeroAttributes = 2
k_EDOTATriviaQuestionCategory_HeroMovementSpeed = 3
k_EDOTATriviaQuestionCategory_TalentTree = 4
k_EDOTATriviaQuestionCategory_HeroStats = 5
k_EDOTATriviaQuestionCategory_ItemPrice = 6
k_EDOTATriviaQuestionCategory_AbilitySound = 7
k_EDOTATriviaQuestionCategory_InvokerSpells = 8
k_EDOTATriviaQuestionCategory_AbilityManaCost = 9
k_EDOTATriviaQuestionCategory_HeroAttackSound = 10
k_EDOTATriviaQuestionCategory_AbilityName = 11
k_EDOTATriviaQuestionCategory_ItemComponents = 12
k_EDOTATriviaQuestionCategory_ItemLore = 13
k_EDOTATriviaQuestionCategory_ItemPassives = 14
k_EDOTATriviaAnswerResult_Success = 0
k_EDOTATriviaAnswerResult_InvalidQuestion = 1
k_EDOTATriviaAnswerResult_InvalidAnswer = 2
k_EDOTATriviaAnswerResult_QuestionLocked = 3
k_EDOTATriviaAnswerResult_AlreadyAnswered = 4
k_EDOTATriviaAnswerResult_TriviaDisabled = 5
k_EPurchaseHeroRelicResult_Success = 0
k_EPurchaseHeroRelicResult_FailedToSend = 1
k_EPurchaseHeroRelicResult_NotEnoughPoints = 2
k_EPurchaseHeroRelicResult_InternalServerError = 3
k_EPurchaseHeroRelicResult_PurchaseNotAllowed = 4
k_EPurchaseHeroRelicResult_InvalidRelic = 5
k_EPurchaseHeroRelicResult_AlreadyOwned = 6
k_EDevEventRequestResult_Success = 0
k_EDevEventRequestResult_NotAllowed = 1
k_EDevEventRequestResult_InvalidEvent = 2
k_EDevEventRequestResult_SqlFailure = 3
k_EDevEventRequestResult_Timeout = 4
k_EDevEventRequestResult_LockFailure = 5
k_EDevEventRequestResult_SDOLoadFailure = 6
k_ESupportEventRequestResult_Success = 0
k_ESupportEventRequestResult_Timeout = 1
k_ESupportEventRequestResult_CantLockSOCache = 2
k_ESupportEventRequestResult_ItemNotInInventory = 3
k_ESupportEventRequestResult_InvalidItemDef = 4
k_ESupportEventRequestResult_InvalidEvent = 5
k_ESupportEventRequestResult_EventExpired = 6
k_ESupportEventRequestResult_InvalidSupportAccount = 7
k_ESupportEventRequestResult_InvalidSupportMessage = 8
k_ESupportEventRequestResult_InvalidEventPoints = 9
k_ESupportEventRequestResult_InvalidPremiumPoints = 10
k_ESupportEventRequestResult_InvalidActionID = 11
k_ESupportEventRequestResult_InvalidActionScore = 12
k_ESupportEventRequestResult_TransactionFailed = 13
k_ECoachTeammateRating_None = 0
k_ECoachTeammateRating_Positive = 1
k_ECoachTeammateRating_Negative = 2
k_ECoachTeammateRating_Abusive = 3
k_EPlayerCoachMatchFlag_EligibleForRewards = 1


_CMSGDOTAREQUESTMATCHES_SKILLLEVEL = _descriptor.EnumDescriptor(
  name='SkillLevel',
  full_name='dota.CMsgDOTARequestMatches.SkillLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Any', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Normal', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='High', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VeryHigh', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=833,
  serialized_end=890,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREQUESTMATCHES_SKILLLEVEL)

_CMSGDOTAGETDPCSTANDINGSRESPONSE_ESTATUS = _descriptor.EnumDescriptor(
  name='EStatus',
  full_name='dota.CMsgDOTAGetDPCStandingsResponse.EStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLINCHED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ELIMINATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1451,
  serialized_end=1503,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGETDPCSTANDINGSRESPONSE_ESTATUS)

_CMSGDOTAPOPUP_POPUPID = _descriptor.EnumDescriptor(
  name='PopupID',
  full_name='dota.CMsgDOTAPopup.PopupID',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_LOBBY', index=1, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_PARTY', index=2, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_TEAM', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_WAS_DISBANDED', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_MATCH', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_FINDING', index=6, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FULL', index=7, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_ADD', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_ADD_CURRENT', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAILED_TEAM_MEMBER', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_GAME', index=11, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_GET_PARTY', index=12, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHMAKING_DISABLED', index=13, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVITE_DENIED', index=14, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_FULL', index=15, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MADE_ADMIN', index=16, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_TO_PURCHASE', index=17, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNON_MESSAGE', index=18, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GUILD_KICKED', index=19, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHMAKING_REGION_OFFLINE', index=20, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_NOT_FOUND', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_LOBBY_ID', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_MATCH_ID', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_NO_RADIANT_TEAM', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_NO_DIRE_TEAM', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_SQL_UPDATE_FAILED', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_LEAGUE_ADMIN', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_ANOTHER_GAME', index=28, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_MEMBER_IN_ANOTHER_GAME', index=29, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_MEMBER_IN_LOW_PRIORITY', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_OUT_OF_DATE', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVE_GAME_CORRUPT', index=32, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_INGOTS', index=33, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPETITIVE_MM_NOT_ENOUGH_PLAY_TIME_PLAY_MORE_CASUAL', index=34, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_LEADER_JOINED_LOBBY', index=35, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKEND_TOURNEY_UNMATCHED', index=36, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POST_MATCH_SURVEY', index=37, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TROPHY_AWARDED', index=38, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TROPHY_LEVEL_UP', index=39, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_HERO_CHALLENGE_PROGRESS', index=40, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_INITIAL_SKILL', index=41, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_INITIAL_SKILL_IN_PARTY', index=42, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_ENGINE_MISMATCH', index=43, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAC_NOT_VERIFIED', index=44, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_QUEUE_EVENT_STARTING', index=45, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_QUEUE_EVENT_ENDING', index=46, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOBBY_FULL', index=47, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_POINTS_EARNED', index=48, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_GAME_INCORRECT_VERSION', index=49, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIMITED_USER_CHAT', index=50, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PREMIUM_POINTS_EARNED', index=51, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOBBY_MVP_AWARDED', index=52, number=68,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW_BADGE_LEVEL_CHAT', index=53, number=71,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW_WINS_CHAT', index=54, number=72,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNVERIFIED_USER_CHAT', index=55, number=73,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_STARTED_FINDING_EVENT_MATCH', index=56, number=74,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERIC_INFO', index=57, number=69,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERIC_ERROR', index=58, number=70,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANK_TIER_UPDATED', index=59, number=75,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_GAME_COOLDOWN_RESTRICTED', index=60, number=76,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1738,
  serialized_end=3455,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAPOPUP_POPUPID)

_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='dota.CMsgDOTAFriendRecruitsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9784,
  serialized_end=9829,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT)

_CMSGDOTACLAIMEVENTACTIONRESPONSE_RESULTCODE = _descriptor.EnumDescriptor(
  name='ResultCode',
  full_name='dota.CMsgDOTAClaimEventActionResponse.ResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidEvent', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EventNotActive', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidAction', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ServerError', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficientPoints', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficentLevel', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AlreadyClaimed', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SDOLockFailure', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SDOLoadFailure', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EventNotOwned', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Timeout', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RequiresPlusSubscription', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidItem', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AsyncRewards', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13120,
  serialized_end=13422,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTACLAIMEVENTACTIONRESPONSE_RESULTCODE)

_CMSGGCNOTIFICATIONSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='dota.CMsgGCNotificationsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9784,
  serialized_end=9829,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCNOTIFICATIONSRESPONSE_ERESULT)

_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='dota.CMsgGCPlayerInfoSubmitResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INFO_LOCKED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16801,
  serialized_end=16869,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT)

_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCVoteForArcanaResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOTING_NOT_ENABLED_FOR_ROUND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FAILURE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26488,
  serialized_end=26566,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT)

_CMSGARCANAVOTES_VOTINGSTATE = _descriptor.EnumDescriptor(
  name='VotingState',
  full_name='dota.CMsgArcanaVotes.VotingState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_FUTURE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=27087,
  serialized_end=27146,
)
_sym_db.RegisterEnumDescriptor(_CMSGARCANAVOTES_VOTINGSTATE)

_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE = _descriptor.EnumDescriptor(
  name='EResultCode',
  full_name='dota.CMsgDOTARedeemItemResponse.EResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_Succeeded', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29000,
  serialized_end=29044,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE)

_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE = _descriptor.EnumDescriptor(
  name='EResultCode',
  full_name='dota.CMsgPerfectWorldUserLookupResponse.EResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_ACCOUNT_FOUND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_USER_NAME_WRONG_FORMAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERFECT_WORLD_ACCOUNT_FOUND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_LINKED_STEAM_ACCOUNT_FOUND', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29260,
  serialized_end=29436,
)
_sym_db.RegisterEnumDescriptor(_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE)

_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='dota.CMsgClientToGCSelectCompendiumInGamePredictionResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MATCH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREDICTIONS_ARE_CLOSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=30398,
  serialized_end=30484,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT)

_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCOpenPlayerCardPackResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_TO_FIND_PACK', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_CARD_PACK', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_CREATE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=30712,
  serialized_end=30844,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT)

_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCRecyclePlayerCardResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_TO_FIND_PLAYER_CARD', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_PLAYER_CARD', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_DUST_CARD_CREATE', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CARD_LOCKED', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31074,
  serialized_end=31243,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT)

_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCreatePlayerCardPackResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INSUFFICIENT_DUST', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_DUST_ITEM', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_PACK_CREATE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31480,
  serialized_end=31615,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT)

_CMSGCLIENTTOGCGIVETIPRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCGiveTipResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_TIPPED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_MATCH_ID', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_EVENT_ID', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_MATCH_TIME', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_WINNER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNOWNED_EVENT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_LOBBY_TYPE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=39764,
  serialized_end=39993,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCGIVETIPRESPONSE_RESULT)

_CMSGDOTAANCHORPHONENUMBERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgDOTAAnchorPhoneNumberResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_STEAM_PHONE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_IN_USE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_COOLDOWN_ACTIVE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=40142,
  serialized_end=40261,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAANCHORPHONENUMBERRESPONSE_RESULT)

_CMSGDOTAUNANCHORPHONENUMBERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgDOTAUnanchorPhoneNumberResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=40142,
  serialized_end=40182,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAUNANCHORPHONENUMBERRESPONSE_RESULT)

_CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgGCToClientAllStarVotesSubmitReply.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_EVENT_ID', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_ACCOUNT_ID', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SELECTIONS_LOCKED', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=41038,
  serialized_end=41166,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY_RESULT)

_CMSGDOTASELECTIONPRIORITYCHOICERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgDOTASelectionPriorityChoiceResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=40142,
  serialized_end=40182,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASELECTIONPRIORITYCHOICERESPONSE_RESULT)

_CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgDOTAGameAutographRewardResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=40142,
  serialized_end=40182,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE_RESULT)

_CMSGDOTADESTROYLOBBYRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgDOTADestroyLobbyResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=40142,
  serialized_end=40182,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTADESTROYLOBBYRESPONSE_RESULT)

_CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgPurchaseItemWithEventPointsResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_EVENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ITEM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_QUANTITY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_PURCHASEABLE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SDO_LOAD_FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ENOUGH_POINTS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQL_ERROR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_SEND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ALLOWED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_ERROR', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=43030,
  serialized_end=43275,
)
_sym_db.RegisterEnumDescriptor(_CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE_RESULT)

_CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCRecycleHeroRelicResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_TO_FIND_HERO_RELIC', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_HERO_RELIC', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_EVENT_NOT_OWNED', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44070,
  serialized_end=44213,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE_RESULT)

_CMSGPROFILERESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgProfileResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGPROFILERESPONSE_ERESPONSE)

_CMSGPROFILEUPDATERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgProfileUpdateResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45733,
  serialized_end=45767,
)
_sym_db.RegisterEnumDescriptor(_CMSGPROFILEUPDATERESPONSE_RESULT)

_CMSGACTIVATEPLUSFREETRIALRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgActivatePlusFreeTrialResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_GENERIC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_IN_FREE_TRIAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_USED_FREE_TRIAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OFFER_NOT_VALID', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=47423,
  serialized_end=47558,
)
_sym_db.RegisterEnumDescriptor(_CMSGACTIVATEPLUSFREETRIALRESPONSE_RESULT)

_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCavernCrawlClaimRoomResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECEIVED_ULTRA_RARE_REWARD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48110,
  serialized_end=48182,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE_RESULT)

_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoomResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECEIVED_ULTRA_RARE_REWARD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48110,
  serialized_end=48182,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE_RESULT)

_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPathResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECEIVED_ULTRA_RARE_REWARD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=48110,
  serialized_end=48182,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE_RESULT)

_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_NOT_OWNED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49833,
  serialized_end=49894,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_RESULT)

_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_NOT_OWNED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49833,
  serialized_end=49894,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE_RESULT)

_CMSGSOCIALFEEDRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgSocialFeedResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_LOAD_FRIENDS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_LOAD_FEED_DATA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_LOAD_FEED_ENTRY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_LOAD_COMMENTS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TOO_MANY_REQUESTS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=51069,
  serialized_end=51238,
)
_sym_db.RegisterEnumDescriptor(_CMSGSOCIALFEEDRESPONSE_RESULT)

_CMSGSOCIALFEEDCOMMENTSRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgSocialFeedCommentsResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TOO_MANY_REQUESTS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_LOAD_COMMENTS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=51560,
  serialized_end=51640,
)
_sym_db.RegisterEnumDescriptor(_CMSGSOCIALFEEDCOMMENTSRESPONSE_RESULT)

_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INSUFFICIENT_DUST', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_DUST_ITEM', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_PACK_CREATE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31480,
  serialized_end=31615,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE_RESULT)

_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCRequestContestVotesResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ERESPONSE)

_CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='dota.CMsgGCToClientRecordContestVoteResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_EVENT_NOT_OWNED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_SQL_INSERT_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_INVALID_CONTEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_CONTEST_NOT_ACTIVE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=52685,
  serialized_end=52844,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE_ERESULT)

_CMSGDOTADPCFEED_EFEEDELEMENTTYPE = _descriptor.EnumDescriptor(
  name='EFeedElementType',
  full_name='dota.CMsgDOTADPCFeed.EFeedElementType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEED_SERIES_RESULT', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_MATCH_POPULAR', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_TEAM_UPCOMING_MATCH', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_TEAM_LEAGUE_RESULT', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_TEAM_ADD_PLAYER', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_TEAM_REMOVE_PLAYER', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_TEAM_DISBAND', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_LEAGUE_UPCOMING', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_LEAGUE_CONCLUDED', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_DPC_STANDINGS', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ALERT_PREDICTIONS', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ALERT_FANTASY', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_LEAGUE_LIVE_MATCH', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_LEAGUE_INPROGRESS_SERIES', index=13, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=53220,
  serialized_end=53615,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTADPCFEED_EFEEDELEMENTTYPE)

_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45733,
  serialized_end=45767,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_RESULT)

_CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='dota.CMsgGCToClientRemoveFilteredPlayerResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45733,
  serialized_end=45767,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE_RESULT)

_CMSGCLIENTTOGCUPDATEPARTYBEACON_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='dota.CMsgClientToGCUpdatePartyBeacon.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55471,
  serialized_end=55496,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCUPDATEPARTYBEACON_ACTION)

_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgGCToClientRequestActiveBeaconPartiesResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUSY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55743,
  serialized_end=55790,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE_ERESPONSE)

_CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgGCToClientJoinPartyFromBeaconResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUSY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_LEADER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=56020,
  serialized_end=56083,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCMANAGEFAVORITES_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='dota.CMsgClientToGCManageFavorites.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=56295,
  serialized_end=56324,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCMANAGEFAVORITES_ACTION)

_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgGCToClientManageFavoritesResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_INVITE_PRESENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVITE_SENT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUSY', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=56518,
  serialized_end=56618,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE_ERESPONSE)

_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgGCToClientGetFavoritePlayersResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55743,
  serialized_end=55780,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatchesResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatchResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45478,
  serialized_end=45560,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCSubmitCoachTeammateRatingResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eInvalidInput', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eAlreadySubmitted', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eVotingFinished', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ePlayerNotInMatch', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eCoachNotInMatch', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ePlayerNotOnCoachTeam', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ePlayerInSamePartyAsCoach', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eMatchNotEligible', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=59331,
  serialized_end=59618,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCGetUnderlordsCDKeyResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Success', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownError', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OutOfKeys', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=60145,
  serialized_end=60202,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eTooBusy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDisabled', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eAlreadySubmitted', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ePlayerNotValid', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eDoesntOwnEvent', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eEventNotValid', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=60452,
  serialized_end=60627,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE)

_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eSuccess', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eNoPick', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eInternalError', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=60901,
  serialized_end=60965,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE)


_CMSGCLIENTSUSPENDED = _descriptor.Descriptor(
  name='CMsgClientSuspended',
  full_name='dota.CMsgClientSuspended',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_end', full_name='dota.CMsgClientSuspended.time_end', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=247,
)


_CMSGBALANCEDSHUFFLELOBBY = _descriptor.Descriptor(
  name='CMsgBalancedShuffleLobby',
  full_name='dota.CMsgBalancedShuffleLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=275,
)


_CMSGINITIALQUESTIONNAIRERESPONSE = _descriptor.Descriptor(
  name='CMsgInitialQuestionnaireResponse',
  full_name='dota.CMsgInitialQuestionnaireResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initial_skill', full_name='dota.CMsgInitialQuestionnaireResponse.initial_skill', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=334,
)


_CMSGDOTAPLAYERMATCHHISTORY = _descriptor.Descriptor(
  name='CMsgDOTAPlayerMatchHistory',
  full_name='dota.CMsgDOTAPlayerMatchHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='dota.CMsgDOTAPlayerMatchHistory.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=383,
)


_CMSGDOTAMATCHHISTORYFILTER = _descriptor.Descriptor(
  name='CMsgDOTAMatchHistoryFilter',
  full_name='dota.CMsgDOTAMatchHistoryFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='dota.CMsgDOTAMatchHistoryFilter.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newest_match_id_at_last_query', full_name='dota.CMsgDOTAMatchHistoryFilter.newest_match_id_at_last_query', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_last_query', full_name='dota.CMsgDOTAMatchHistoryFilter.time_last_query', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=496,
)


_CMSGDOTAREQUESTMATCHES = _descriptor.Descriptor(
  name='CMsgDOTARequestMatches',
  full_name='dota.CMsgDOTARequestMatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTARequestMatches.hero_id', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='dota.CMsgDOTARequestMatches.game_mode', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_min', full_name='dota.CMsgDOTARequestMatches.date_min', index=2,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_max', full_name='dota.CMsgDOTARequestMatches.date_max', index=3,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_requested', full_name='dota.CMsgDOTARequestMatches.matches_requested', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_at_match_id', full_name='dota.CMsgDOTARequestMatches.start_at_match_id', index=5,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_players', full_name='dota.CMsgDOTARequestMatches.min_players', index=6,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dota.CMsgDOTARequestMatches.request_id', index=7,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTARequestMatches.account_id', index=8,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgDOTARequestMatches.league_id', index=9,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skill', full_name='dota.CMsgDOTARequestMatches.skill', index=10,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTARequestMatches.team_id', index=11,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgDOTARequestMatches.custom_game_id', index=12,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAREQUESTMATCHES_SKILLLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=890,
)


_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES = _descriptor.Descriptor(
  name='Series',
  full_name='dota.CMsgDOTARequestMatchesResponse.Series',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgDOTARequestMatchesResponse.Series.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='dota.CMsgDOTARequestMatchesResponse.Series.series_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='dota.CMsgDOTARequestMatchesResponse.Series.series_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1182,
)

_CMSGDOTAREQUESTMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARequestMatchesResponse',
  full_name='dota.CMsgDOTARequestMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgDOTARequestMatchesResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series', full_name='dota.CMsgDOTARequestMatchesResponse.series', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dota.CMsgDOTARequestMatchesResponse.request_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='dota.CMsgDOTARequestMatchesResponse.total_results', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results_remaining', full_name='dota.CMsgDOTARequestMatchesResponse.results_remaining', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=1182,
)


_CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO = _descriptor.Descriptor(
  name='TeamInfo',
  full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo.team_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dpc_points', full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo.dpc_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_logo_url', full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo.team_logo_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1449,
)

_CMSGDOTAGETDPCSTANDINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetDPCStandingsResponse',
  full_name='dota.CMsgDOTAGetDPCStandingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='standings', full_name='dota.CMsgDOTAGetDPCStandingsResponse.standings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO, ],
  enum_types=[
    _CMSGDOTAGETDPCSTANDINGSRESPONSE_ESTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1503,
)


_CMSGDOTAPOPUP = _descriptor.Descriptor(
  name='CMsgDOTAPopup',
  full_name='dota.CMsgDOTAPopup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgDOTAPopup.id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_text', full_name='dota.CMsgDOTAPopup.custom_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_data', full_name='dota.CMsgDOTAPopup.int_data', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='popup_data', full_name='dota.CMsgDOTAPopup.popup_data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loc_token_header', full_name='dota.CMsgDOTAPopup.loc_token_header', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loc_token_msg', full_name='dota.CMsgDOTAPopup.loc_token_msg', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_names', full_name='dota.CMsgDOTAPopup.var_names', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_values', full_name='dota.CMsgDOTAPopup.var_values', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_text', full_name='dota.CMsgDOTAPopup.debug_text', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAPOPUP_POPUPID,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1506,
  serialized_end=3455,
)


_CMSGDOTAREPORTSREMAININGREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAReportsRemainingRequest',
  full_name='dota.CMsgDOTAReportsRemainingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3457,
  serialized_end=3490,
)


_CMSGDOTAREPORTSREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAReportsRemainingResponse',
  full_name='dota.CMsgDOTAReportsRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_positive_reports_remaining', full_name='dota.CMsgDOTAReportsRemainingResponse.num_positive_reports_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_negative_reports_remaining', full_name='dota.CMsgDOTAReportsRemainingResponse.num_negative_reports_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_positive_reports_total', full_name='dota.CMsgDOTAReportsRemainingResponse.num_positive_reports_total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_negative_reports_total', full_name='dota.CMsgDOTAReportsRemainingResponse.num_negative_reports_total', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3493,
  serialized_end=3679,
)


_CMSGDOTASUBMITPLAYERREPORT = _descriptor.Descriptor(
  name='CMsgDOTASubmitPlayerReport',
  full_name='dota.CMsgDOTASubmitPlayerReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTASubmitPlayerReport.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_flags', full_name='dota.CMsgDOTASubmitPlayerReport.report_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgDOTASubmitPlayerReport.lobby_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='dota.CMsgDOTASubmitPlayerReport.comment', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3681,
  serialized_end=3793,
)


_CMSGDOTASUBMITPLAYERREPORTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASubmitPlayerReportResponse',
  full_name='dota.CMsgDOTASubmitPlayerReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTASubmitPlayerReportResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_flags', full_name='dota.CMsgDOTASubmitPlayerReportResponse.report_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTASubmitPlayerReportResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='dota.CMsgDOTASubmitPlayerReportResponse.debug_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3795,
  serialized_end=3919,
)


_CMSGDOTAREPORTCOUNTSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAReportCountsRequest',
  full_name='dota.CMsgDOTAReportCountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTAReportCountsRequest.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3921,
  serialized_end=3977,
)


_CMSGDOTAREPORTCOUNTSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAReportCountsResponse',
  full_name='dota.CMsgDOTAReportCountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTAReportCountsResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leadership_count', full_name='dota.CMsgDOTAReportCountsResponse.leadership_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teaching_count', full_name='dota.CMsgDOTAReportCountsResponse.teaching_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='friendly_count', full_name='dota.CMsgDOTAReportCountsResponse.friendly_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forgiving_count', full_name='dota.CMsgDOTAReportCountsResponse.forgiving_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3980,
  serialized_end=4136,
)


_CMSGDOTASUBMITLOBBYMVPVOTE = _descriptor.Descriptor(
  name='CMsgDOTASubmitLobbyMVPVote',
  full_name='dota.CMsgDOTASubmitLobbyMVPVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTASubmitLobbyMVPVote.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4138,
  serialized_end=4193,
)


_CMSGDOTASUBMITLOBBYMVPVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASubmitLobbyMVPVoteResponse',
  full_name='dota.CMsgDOTASubmitLobbyMVPVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='dota.CMsgDOTASubmitLobbyMVPVoteResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTASubmitLobbyMVPVoteResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4195,
  serialized_end=4275,
)


_CMSGDOTALOBBYMVPNOTIFYRECIPIENT = _descriptor.Descriptor(
  name='CMsgDOTALobbyMVPNotifyRecipient',
  full_name='dota.CMsgDOTALobbyMVPNotifyRecipient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voter_account_id', full_name='dota.CMsgDOTALobbyMVPNotifyRecipient.voter_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recipient_account_id', full_name='dota.CMsgDOTALobbyMVPNotifyRecipient.recipient_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_votes', full_name='dota.CMsgDOTALobbyMVPNotifyRecipient.num_votes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4277,
  serialized_end=4385,
)


_CMSGDOTALOBBYMVPAWARDED = _descriptor.Descriptor(
  name='CMsgDOTALobbyMVPAwarded',
  full_name='dota.CMsgDOTALobbyMVPAwarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgDOTALobbyMVPAwarded.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mvp_account_id', full_name='dota.CMsgDOTALobbyMVPAwarded.mvp_account_id', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4387,
  serialized_end=4454,
)


_CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE = _descriptor.Descriptor(
  name='CMsgDOTAKickedFromMatchmakingQueue',
  full_name='dota.CMsgDOTAKickedFromMatchmakingQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_type', full_name='dota.CMsgDOTAKickedFromMatchmakingQueue.match_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4456,
  serialized_end=4548,
)


_CMSGDOTAREQUESTSAVEGAMES = _descriptor.Descriptor(
  name='CMsgDOTARequestSaveGames',
  full_name='dota.CMsgDOTARequestSaveGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='dota.CMsgDOTARequestSaveGames.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4550,
  serialized_end=4599,
)


_CMSGDOTAREQUESTSAVEGAMESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARequestSaveGamesResponse',
  full_name='dota.CMsgDOTARequestSaveGamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgDOTARequestSaveGamesResponse.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_games', full_name='dota.CMsgDOTARequestSaveGamesResponse.save_games', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4601,
  serialized_end=4694,
)


_CMSGGCMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgGCMatchDetailsRequest',
  full_name='dota.CMsgGCMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgGCMatchDetailsRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4696,
  serialized_end=4741,
)


_CMSGGCMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCMatchDetailsResponse',
  full_name='dota.CMsgGCMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCMatchDetailsResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match', full_name='dota.CMsgGCMatchDetailsResponse.match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgGCMatchDetailsResponse.vote', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4744,
  serialized_end=4882,
)


_CMSGSERVERTOGCMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgServerToGCMatchDetailsRequest',
  full_name='dota.CMsgServerToGCMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='dota.CMsgServerToGCMatchDetailsRequest.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4884,
  serialized_end=4938,
)


_CMSGGCTOSERVERMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToServerMatchDetailsResponse',
  full_name='dota.CMsgGCToServerMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgGCToServerMatchDetailsResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4940,
  serialized_end=5014,
)


_CMSGDOTAPROFILETICKETS_LEAGUEPASS = _descriptor.Descriptor(
  name='LeaguePass',
  full_name='dota.CMsgDOTAProfileTickets.LeaguePass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgDOTAProfileTickets.LeaguePass.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgDOTAProfileTickets.LeaguePass.item_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5143,
  serialized_end=5192,
)

_CMSGDOTAPROFILETICKETS = _descriptor.Descriptor(
  name='CMsgDOTAProfileTickets',
  full_name='dota.CMsgDOTAProfileTickets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAProfileTickets.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAProfileTickets.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_passes', full_name='dota.CMsgDOTAProfileTickets.league_passes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROFILETICKETS_LEAGUEPASS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5017,
  serialized_end=5192,
)


_CMSGCLIENTTOGCGETPROFILETICKETS = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileTickets',
  full_name='dota.CMsgClientToGCGetProfileTickets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetProfileTickets.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5194,
  serialized_end=5247,
)


_CMSGDOTACLEARNOTIFYSUCCESSFULREPORT = _descriptor.Descriptor(
  name='CMsgDOTAClearNotifySuccessfulReport',
  full_name='dota.CMsgDOTAClearNotifySuccessfulReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5249,
  serialized_end=5286,
)


_CMSGGCTOCLIENTPARTYSEARCHINVITES = _descriptor.Descriptor(
  name='CMsgGCToClientPartySearchInvites',
  full_name='dota.CMsgGCToClientPartySearchInvites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invites', full_name='dota.CMsgGCToClientPartySearchInvites.invites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5288,
  serialized_end=5378,
)


_CMSGDOTAWELCOME_CEXTRAMSG = _descriptor.Descriptor(
  name='CExtraMsg',
  full_name='dota.CMsgDOTAWelcome.CExtraMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgDOTAWelcome.CExtraMsg.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents', full_name='dota.CMsgDOTAWelcome.CExtraMsg.contents', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6218,
  serialized_end=6259,
)

_CMSGDOTAWELCOME = _descriptor.Descriptor(
  name='CMsgDOTAWelcome',
  full_name='dota.CMsgDOTAWelcome',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_item_hash', full_name='dota.CMsgDOTAWelcome.store_item_hash', index=0,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeplayedconsecutively', full_name='dota.CMsgDOTAWelcome.timeplayedconsecutively', index=1,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_3rd_party_match_history', full_name='dota.CMsgDOTAWelcome.allow_3rd_party_match_history', index=2,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partner_account_type', full_name='dota.CMsgDOTAWelcome.partner_account_type', index=3,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partner_account_state', full_name='dota.CMsgDOTAWelcome.partner_account_state', index=4,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_time_played', full_name='dota.CMsgDOTAWelcome.last_time_played', index=5,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_ip_address', full_name='dota.CMsgDOTAWelcome.last_ip_address', index=6,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdownlawterminateminutes', full_name='dota.CMsgDOTAWelcome.shutdownlawterminateminutes', index=7,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banned_word_list_version', full_name='dota.CMsgDOTAWelcome.banned_word_list_version', index=8,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_private', full_name='dota.CMsgDOTAWelcome.profile_private', index=9,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='dota.CMsgDOTAWelcome.currency', index=10,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pwrd_cyber_cafe_id', full_name='dota.CMsgDOTAWelcome.pwrd_cyber_cafe_id', index=11,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_request_player_origin', full_name='dota.CMsgDOTAWelcome.should_request_player_origin', index=12,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compendium_unlocks', full_name='dota.CMsgDOTAWelcome.compendium_unlocks', index=13,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_socache_file_version', full_name='dota.CMsgDOTAWelcome.gc_socache_file_version', index=14,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_perfect_world_test_account', full_name='dota.CMsgDOTAWelcome.is_perfect_world_test_account', index=15,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_messages', full_name='dota.CMsgDOTAWelcome.extra_messages', index=16,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum_recent_item_id', full_name='dota.CMsgDOTAWelcome.minimum_recent_item_id', index=17,
      number=27, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_event', full_name='dota.CMsgDOTAWelcome.active_event', index=18,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_user_message', full_name='dota.CMsgDOTAWelcome.additional_user_message', index=19,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_whitelist_version', full_name='dota.CMsgDOTAWelcome.custom_game_whitelist_version', index=20,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='party_search_friend_invites', full_name='dota.CMsgDOTAWelcome.party_search_friend_invites', index=21,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAWELCOME_CEXTRAMSG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5381,
  serialized_end=6259,
)


_CSODOTAGAMEHEROFAVORITES = _descriptor.Descriptor(
  name='CSODOTAGameHeroFavorites',
  full_name='dota.CSODOTAGameHeroFavorites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSODOTAGameHeroFavorites.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CSODOTAGameHeroFavorites.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6261,
  serialized_end=6336,
)


_CMSGDOTAHEROFAVORITESADD = _descriptor.Descriptor(
  name='CMsgDOTAHeroFavoritesAdd',
  full_name='dota.CMsgDOTAHeroFavoritesAdd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAHeroFavoritesAdd.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6338,
  serialized_end=6381,
)


_CMSGDOTAHEROFAVORITESREMOVE = _descriptor.Descriptor(
  name='CMsgDOTAHeroFavoritesRemove',
  full_name='dota.CMsgDOTAHeroFavoritesRemove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAHeroFavoritesRemove.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6383,
  serialized_end=6429,
)


_CMSGDOTAFEATUREDITEMS = _descriptor.Descriptor(
  name='CMsgDOTAFeaturedItems',
  full_name='dota.CMsgDOTAFeaturedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAFeaturedItems.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featured_item_id', full_name='dota.CMsgDOTAFeaturedItems.featured_item_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='dota.CMsgDOTAFeaturedItems.object_data', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6431,
  serialized_end=6521,
)


_CMSGDOTAMATCHVOTES_PLAYERVOTE = _descriptor.Descriptor(
  name='PlayerVote',
  full_name='dota.CMsgDOTAMatchVotes.PlayerVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAMatchVotes.PlayerVote.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgDOTAMatchVotes.PlayerVote.vote', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6616,
  serialized_end=6662,
)

_CMSGDOTAMATCHVOTES = _descriptor.Descriptor(
  name='CMsgDOTAMatchVotes',
  full_name='dota.CMsgDOTAMatchVotes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgDOTAMatchVotes.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='votes', full_name='dota.CMsgDOTAMatchVotes.votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMATCHVOTES_PLAYERVOTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6524,
  serialized_end=6662,
)


_CMSGCASTMATCHVOTE = _descriptor.Descriptor(
  name='CMsgCastMatchVote',
  full_name='dota.CMsgCastMatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgCastMatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgCastMatchVote.vote', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6664,
  serialized_end=6759,
)


_CMSGRETRIEVEMATCHVOTE = _descriptor.Descriptor(
  name='CMsgRetrieveMatchVote',
  full_name='dota.CMsgRetrieveMatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgRetrieveMatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='dota.CMsgRetrieveMatchVote.incremental', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6761,
  serialized_end=6823,
)


_CMSGMATCHVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgMatchVoteResponse',
  full_name='dota.CMsgMatchVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgMatchVoteResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgMatchVoteResponse.vote', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='positive_votes', full_name='dota.CMsgMatchVoteResponse.positive_votes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_votes', full_name='dota.CMsgMatchVoteResponse.negative_votes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6826,
  serialized_end=6975,
)


_CMSGDOTAHALLOFFAME_FEATUREDPLAYER = _descriptor.Descriptor(
  name='FeaturedPlayer',
  full_name='dota.CMsgDOTAHallOfFame.FeaturedPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAHallOfFame.FeaturedPlayer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAHallOfFame.FeaturedPlayer.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_scaled_metric', full_name='dota.CMsgDOTAHallOfFame.FeaturedPlayer.average_scaled_metric', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_games', full_name='dota.CMsgDOTAHallOfFame.FeaturedPlayer.num_games', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7147,
  serialized_end=7250,
)

_CMSGDOTAHALLOFFAME_FEATUREDFARMER = _descriptor.Descriptor(
  name='FeaturedFarmer',
  full_name='dota.CMsgDOTAHallOfFame.FeaturedFarmer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAHallOfFame.FeaturedFarmer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAHallOfFame.FeaturedFarmer.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gold_per_min', full_name='dota.CMsgDOTAHallOfFame.FeaturedFarmer.gold_per_min', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgDOTAHallOfFame.FeaturedFarmer.match_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7252,
  serialized_end=7345,
)

_CMSGDOTAHALLOFFAME = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFame',
  full_name='dota.CMsgDOTAHallOfFame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='week', full_name='dota.CMsgDOTAHallOfFame.week', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featured_players', full_name='dota.CMsgDOTAHallOfFame.featured_players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featured_farmer', full_name='dota.CMsgDOTAHallOfFame.featured_farmer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAHALLOFFAME_FEATUREDPLAYER, _CMSGDOTAHALLOFFAME_FEATUREDFARMER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6978,
  serialized_end=7345,
)


_CMSGDOTAHALLOFFAMEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFameRequest',
  full_name='dota.CMsgDOTAHallOfFameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='week', full_name='dota.CMsgDOTAHallOfFameRequest.week', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7347,
  serialized_end=7388,
)


_CMSGDOTAHALLOFFAMERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFameResponse',
  full_name='dota.CMsgDOTAHallOfFameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hall_of_fame', full_name='dota.CMsgDOTAHallOfFameResponse.hall_of_fame', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTAHallOfFameResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7390,
  serialized_end=7486,
)


_CMSGDOTAHALLOWEENHIGHSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAHalloweenHighScoreRequest',
  full_name='dota.CMsgDOTAHalloweenHighScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='dota.CMsgDOTAHalloweenHighScoreRequest.round', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7488,
  serialized_end=7542,
)


_CMSGDOTAHALLOWEENHIGHSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHalloweenHighScoreResponse',
  full_name='dota.CMsgDOTAHalloweenHighScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgDOTAHalloweenHighScoreResponse.score', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match', full_name='dota.CMsgDOTAHalloweenHighScoreResponse.match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTAHalloweenHighScoreResponse.eresult', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='round', full_name='dota.CMsgDOTAHalloweenHighScoreResponse.round', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7544,
  serialized_end=7663,
)


_CMSGDOTASTOREPROMOPAGESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAStorePromoPagesRequest',
  full_name='dota.CMsgDOTAStorePromoPagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_seen', full_name='dota.CMsgDOTAStorePromoPagesRequest.version_seen', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7665,
  serialized_end=7719,
)


_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE = _descriptor.Descriptor(
  name='PromoPage',
  full_name='dota.CMsgDOTAStorePromoPagesResponse.PromoPage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='promo_id', full_name='dota.CMsgDOTAStorePromoPagesResponse.PromoPage.promo_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dota.CMsgDOTAStorePromoPagesResponse.PromoPage.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='dota.CMsgDOTAStorePromoPagesResponse.PromoPage.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7821,
  serialized_end=7878,
)

_CMSGDOTASTOREPROMOPAGESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAStorePromoPagesResponse',
  full_name='dota.CMsgDOTAStorePromoPagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pages', full_name='dota.CMsgDOTAStorePromoPagesResponse.pages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7722,
  serialized_end=7878,
)


_CMSGMATCHMAKINGMATCHGROUPINFO = _descriptor.Descriptor(
  name='CMsgMatchmakingMatchGroupInfo',
  full_name='dota.CMsgMatchmakingMatchGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players_searching', full_name='dota.CMsgMatchmakingMatchGroupInfo.players_searching', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_region_select_ping_penalty', full_name='dota.CMsgMatchmakingMatchGroupInfo.auto_region_select_ping_penalty', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_region_select_ping_penalty_custom', full_name='dota.CMsgMatchmakingMatchGroupInfo.auto_region_select_ping_penalty_custom', index=2,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='dota.CMsgMatchmakingMatchGroupInfo.status', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7881,
  serialized_end=8105,
)


_CMSGDOTAMATCHMAKINGSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAMatchmakingStatsRequest',
  full_name='dota.CMsgDOTAMatchmakingStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8107,
  serialized_end=8140,
)


_CMSGDOTAMATCHMAKINGSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAMatchmakingStatsResponse',
  full_name='dota.CMsgDOTAMatchmakingStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchgroups_version', full_name='dota.CMsgDOTAMatchmakingStatsResponse.matchgroups_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_searching_players_by_group_source2', full_name='dota.CMsgDOTAMatchmakingStatsResponse.legacy_searching_players_by_group_source2', index=1,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_groups', full_name='dota.CMsgDOTAMatchmakingStatsResponse.match_groups', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8143,
  serialized_end=8316,
)


_CMSGDOTAUPDATEMATCHMAKINGSTATS = _descriptor.Descriptor(
  name='CMsgDOTAUpdateMatchmakingStats',
  full_name='dota.CMsgDOTAUpdateMatchmakingStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='dota.CMsgDOTAUpdateMatchmakingStats.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8318,
  serialized_end=8405,
)


_CMSGDOTAUPDATEMATCHMANAGEMENTSTATS = _descriptor.Descriptor(
  name='CMsgDOTAUpdateMatchManagementStats',
  full_name='dota.CMsgDOTAUpdateMatchManagementStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='dota.CMsgDOTAUpdateMatchManagementStats.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8407,
  serialized_end=8498,
)


_CMSGDOTASETMATCHHISTORYACCESS = _descriptor.Descriptor(
  name='CMsgDOTASetMatchHistoryAccess',
  full_name='dota.CMsgDOTASetMatchHistoryAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_3rd_party_match_history', full_name='dota.CMsgDOTASetMatchHistoryAccess.allow_3rd_party_match_history', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8500,
  serialized_end=8570,
)


_CMSGDOTASETMATCHHISTORYACCESSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASetMatchHistoryAccessResponse',
  full_name='dota.CMsgDOTASetMatchHistoryAccessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTASetMatchHistoryAccessResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8572,
  serialized_end=8631,
)


_CMSGDOTANOTIFYACCOUNTFLAGSCHANGE = _descriptor.Descriptor(
  name='CMsgDOTANotifyAccountFlagsChange',
  full_name='dota.CMsgDOTANotifyAccountFlagsChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='dota.CMsgDOTANotifyAccountFlagsChange.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_flags', full_name='dota.CMsgDOTANotifyAccountFlagsChange.account_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8633,
  serialized_end=8709,
)


_CMSGDOTASETPROFILEPRIVACY = _descriptor.Descriptor(
  name='CMsgDOTASetProfilePrivacy',
  full_name='dota.CMsgDOTASetProfilePrivacy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_private', full_name='dota.CMsgDOTASetProfilePrivacy.profile_private', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8711,
  serialized_end=8763,
)


_CMSGDOTASETPROFILEPRIVACYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASetProfilePrivacyResponse',
  full_name='dota.CMsgDOTASetProfilePrivacyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTASetProfilePrivacyResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8765,
  serialized_end=8817,
)


_CMSGUPGRADELEAGUEITEM = _descriptor.Descriptor(
  name='CMsgUpgradeLeagueItem',
  full_name='dota.CMsgUpgradeLeagueItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgUpgradeLeagueItem.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgUpgradeLeagueItem.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8819,
  serialized_end=8879,
)


_CMSGUPGRADELEAGUEITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgUpgradeLeagueItemResponse',
  full_name='dota.CMsgUpgradeLeagueItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8881,
  serialized_end=8912,
)


_CMSGGCWATCHDOWNLOADEDREPLAY = _descriptor.Descriptor(
  name='CMsgGCWatchDownloadedReplay',
  full_name='dota.CMsgGCWatchDownloadedReplay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgGCWatchDownloadedReplay.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='watch_type', full_name='dota.CMsgGCWatchDownloadedReplay.watch_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8914,
  serialized_end=9035,
)


_CMSGSETMAPLOCATIONSTATE = _descriptor.Descriptor(
  name='CMsgSetMapLocationState',
  full_name='dota.CMsgSetMapLocationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_id', full_name='dota.CMsgSetMapLocationState.location_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgSetMapLocationState.completed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9037,
  serialized_end=9102,
)


_CMSGSETMAPLOCATIONSTATERESPONSE = _descriptor.Descriptor(
  name='CMsgSetMapLocationStateResponse',
  full_name='dota.CMsgSetMapLocationStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgSetMapLocationStateResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9104,
  serialized_end=9157,
)


_CMSGRESETMAPLOCATIONS = _descriptor.Descriptor(
  name='CMsgResetMapLocations',
  full_name='dota.CMsgResetMapLocations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9159,
  serialized_end=9182,
)


_CMSGRESETMAPLOCATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgResetMapLocationsResponse',
  full_name='dota.CMsgResetMapLocationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgResetMapLocationsResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9184,
  serialized_end=9235,
)


_CMSGREFRESHPARTNERACCOUNTLINK = _descriptor.Descriptor(
  name='CMsgRefreshPartnerAccountLink',
  full_name='dota.CMsgRefreshPartnerAccountLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partner_type', full_name='dota.CMsgRefreshPartnerAccountLink.partner_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9237,
  serialized_end=9290,
)


_CMSGCLIENTSREJOINCHATCHANNELS = _descriptor.Descriptor(
  name='CMsgClientsRejoinChatChannels',
  full_name='dota.CMsgClientsRejoinChatChannels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9292,
  serialized_end=9323,
)


_CMSGDOTASENDFRIENDRECRUITS = _descriptor.Descriptor(
  name='CMsgDOTASendFriendRecruits',
  full_name='dota.CMsgDOTASendFriendRecruits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recruits', full_name='dota.CMsgDOTASendFriendRecruits.recruits', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9325,
  serialized_end=9371,
)


_CMSGDOTAFRIENDRECRUITSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitsRequest',
  full_name='dota.CMsgDOTAFriendRecruitsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgDOTAFriendRecruitsRequest.account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9373,
  serialized_end=9425,
)


_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS = _descriptor.Descriptor(
  name='FriendRecruitStatus',
  full_name='dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels_earned', full_name='dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.levels_earned', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonus', full_name='dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.bonus', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9687,
  serialized_end=9782,
)

_CMSGDOTAFRIENDRECRUITSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitsResponse',
  full_name='dota.CMsgDOTAFriendRecruitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAFriendRecruitsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recruits', full_name='dota.CMsgDOTAFriendRecruitsResponse.recruits', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recruiters', full_name='dota.CMsgDOTAFriendRecruitsResponse.recruiters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS, ],
  enum_types=[
    _CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9428,
  serialized_end=9829,
)


_CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitInviteAcceptDecline',
  full_name='dota.CMsgDOTAFriendRecruitInviteAcceptDecline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accepted', full_name='dota.CMsgDOTAFriendRecruitInviteAcceptDecline.accepted', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAFriendRecruitInviteAcceptDecline.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9831,
  serialized_end=9911,
)


_CMSGREQUESTLEAGUEPRIZEPOOL = _descriptor.Descriptor(
  name='CMsgRequestLeaguePrizePool',
  full_name='dota.CMsgRequestLeaguePrizePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgRequestLeaguePrizePool.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9913,
  serialized_end=9960,
)


_CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE = _descriptor.Descriptor(
  name='CMsgRequestLeaguePrizePoolResponse',
  full_name='dota.CMsgRequestLeaguePrizePoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgRequestLeaguePrizePoolResponse.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prize_pool', full_name='dota.CMsgRequestLeaguePrizePoolResponse.prize_pool', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9962,
  serialized_end=10037,
)


_CMSGGCGETHEROSTANDINGS = _descriptor.Descriptor(
  name='CMsgGCGetHeroStandings',
  full_name='dota.CMsgGCGetHeroStandings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10039,
  serialized_end=10063,
)


_CMSGGCGETHEROSTANDINGSRESPONSE_HERO = _descriptor.Descriptor(
  name='Hero',
  full_name='dota.CMsgGCGetHeroStandingsResponse.Hero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.wins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='losses', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.losses', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_streak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.win_streak', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_win_streak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.best_win_streak', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_kills', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_kills', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_deaths', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_deaths', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_assists', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_assists', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_gpm', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_gpm', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_xpm', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_xpm', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_kills', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.best_kills', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_assists', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.best_assists', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_gpm', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.best_gpm', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_xpm', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.best_xpm', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.performance', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wins_with_ally', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.wins_with_ally', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='losses_with_ally', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.losses_with_ally', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wins_against_enemy', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.wins_against_enemy', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='losses_against_enemy', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.losses_against_enemy', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networth_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.networth_peak', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lasthit_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.lasthit_peak', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deny_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.deny_peak', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.damage_peak', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longest_game_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.longest_game_peak', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healing_peak', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.healing_peak', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_lasthits', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_lasthits', index=25,
      number=26, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_denies', full_name='dota.CMsgGCGetHeroStandingsResponse.Hero.avg_denies', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10163,
  serialized_end=10738,
)

_CMSGGCGETHEROSTANDINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetHeroStandingsResponse',
  full_name='dota.CMsgGCGetHeroStandingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='standings', full_name='dota.CMsgGCGetHeroStandingsResponse.standings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCGETHEROSTANDINGSRESPONSE_HERO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10066,
  serialized_end=10738,
)


_CMSGGCGETHEROTIMEDSTATS = _descriptor.Descriptor(
  name='CMsgGCGetHeroTimedStats',
  full_name='dota.CMsgGCGetHeroTimedStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCGetHeroTimedStats.hero_id', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10740,
  serialized_end=10782,
)


_CMATCHPLAYERTIMEDSTATAVERAGES = _descriptor.Descriptor(
  name='CMatchPlayerTimedStatAverages',
  full_name='dota.CMatchPlayerTimedStatAverages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kills', full_name='dota.CMatchPlayerTimedStatAverages.kills', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='dota.CMatchPlayerTimedStatAverages.deaths', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assists', full_name='dota.CMatchPlayerTimedStatAverages.assists', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_worth', full_name='dota.CMatchPlayerTimedStatAverages.net_worth', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='dota.CMatchPlayerTimedStatAverages.last_hits', index=4,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='denies', full_name='dota.CMatchPlayerTimedStatAverages.denies', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10785,
  serialized_end=10918,
)


_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER = _descriptor.Descriptor(
  name='TimedStatsContainer',
  full_name='dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer.time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_stats', full_name='dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer.all_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='winning_stats', full_name='dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer.winning_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='losing_stats', full_name='dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer.losing_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11058,
  serialized_end=11268,
)

_CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS = _descriptor.Descriptor(
  name='RankChunkedStats',
  full_name='dota.CMsgGCGetHeroTimedStatsResponse.RankChunkedStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank_chunk', full_name='dota.CMsgGCGetHeroTimedStatsResponse.RankChunkedStats.rank_chunk', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timed_stats', full_name='dota.CMsgGCGetHeroTimedStatsResponse.RankChunkedStats.timed_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11270,
  serialized_end=11388,
)

_CMSGGCGETHEROTIMEDSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetHeroTimedStatsResponse',
  full_name='dota.CMsgGCGetHeroTimedStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCGetHeroTimedStatsResponse.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rank_chunked_stats', full_name='dota.CMsgGCGetHeroTimedStatsResponse.rank_chunked_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER, _CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10921,
  serialized_end=11388,
)


_CMSGGCITEMEDITORRESERVATIONSREQUEST = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservationsRequest',
  full_name='dota.CMsgGCItemEditorReservationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11390,
  serialized_end=11427,
)


_CMSGGCITEMEDITORRESERVATION = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservation',
  full_name='dota.CMsgGCItemEditorReservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgGCItemEditorReservation.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCItemEditorReservation.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11429,
  serialized_end=11491,
)


_CMSGGCITEMEDITORRESERVATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservationsResponse',
  full_name='dota.CMsgGCItemEditorReservationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservations', full_name='dota.CMsgGCItemEditorReservationsResponse.reservations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11493,
  serialized_end=11588,
)


_CMSGGCITEMEDITORRESERVEITEMDEF = _descriptor.Descriptor(
  name='CMsgGCItemEditorReserveItemDef',
  full_name='dota.CMsgGCItemEditorReserveItemDef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgGCItemEditorReserveItemDef.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='dota.CMsgGCItemEditorReserveItemDef.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11590,
  serialized_end=11659,
)


_CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReserveItemDefResponse',
  full_name='dota.CMsgGCItemEditorReserveItemDefResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgGCItemEditorReserveItemDefResponse.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='dota.CMsgGCItemEditorReserveItemDefResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCItemEditorReserveItemDefResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11661,
  serialized_end=11754,
)


_CMSGGCITEMEDITORRELEASERESERVATION = _descriptor.Descriptor(
  name='CMsgGCItemEditorReleaseReservation',
  full_name='dota.CMsgGCItemEditorReleaseReservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgGCItemEditorReleaseReservation.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='dota.CMsgGCItemEditorReleaseReservation.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11756,
  serialized_end=11829,
)


_CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReleaseReservationResponse',
  full_name='dota.CMsgGCItemEditorReleaseReservationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgGCItemEditorReleaseReservationResponse.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='released', full_name='dota.CMsgGCItemEditorReleaseReservationResponse.released', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11831,
  serialized_end=11912,
)


_CMSGDOTAREWARDTUTORIALPRIZES = _descriptor.Descriptor(
  name='CMsgDOTARewardTutorialPrizes',
  full_name='dota.CMsgDOTARewardTutorialPrizes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_id', full_name='dota.CMsgDOTARewardTutorialPrizes.location_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_only', full_name='dota.CMsgDOTARewardTutorialPrizes.tracking_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11914,
  serialized_end=11988,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScorePost',
  full_name='dota.CMsgDOTALastHitChallengeHighScorePost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTALastHitChallengeHighScorePost.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_score', full_name='dota.CMsgDOTALastHitChallengeHighScorePost.high_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11990,
  serialized_end=12066,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScoreRequest',
  full_name='dota.CMsgDOTALastHitChallengeHighScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTALastHitChallengeHighScoreRequest.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12068,
  serialized_end=12127,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScoreResponse',
  full_name='dota.CMsgDOTALastHitChallengeHighScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgDOTALastHitChallengeHighScoreResponse.score', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTALastHitChallengeHighScoreResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12129,
  serialized_end=12204,
)


_CMSGFLIPLOBBYTEAMS = _descriptor.Descriptor(
  name='CMsgFlipLobbyTeams',
  full_name='dota.CMsgFlipLobbyTeams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12206,
  serialized_end=12226,
)


_CMSGPRESENTEDCLIENTTERMINATEDLG = _descriptor.Descriptor(
  name='CMsgPresentedClientTerminateDlg',
  full_name='dota.CMsgPresentedClientTerminateDlg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12228,
  serialized_end=12261,
)


_CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO = _descriptor.Descriptor(
  name='CMsgGCLobbyUpdateBroadcastChannelInfo',
  full_name='dota.CMsgGCLobbyUpdateBroadcastChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='dota.CMsgGCLobbyUpdateBroadcastChannelInfo.channel_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='dota.CMsgGCLobbyUpdateBroadcastChannelInfo.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='dota.CMsgGCLobbyUpdateBroadcastChannelInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='dota.CMsgGCLobbyUpdateBroadcastChannelInfo.language_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12263,
  serialized_end=12388,
)


_CMSGDOTACLAIMEVENTACTIONDATA_GRANTITEMGIFTDATA = _descriptor.Descriptor(
  name='GrantItemGiftData',
  full_name='dota.CMsgDOTAClaimEventActionData.GrantItemGiftData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='give_to_account_id', full_name='dota.CMsgDOTAClaimEventActionData.GrantItemGiftData.give_to_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gift_message', full_name='dota.CMsgDOTAClaimEventActionData.GrantItemGiftData.gift_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12507,
  serialized_end=12576,
)

_CMSGDOTACLAIMEVENTACTIONDATA = _descriptor.Descriptor(
  name='CMsgDOTAClaimEventActionData',
  full_name='dota.CMsgDOTAClaimEventActionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grant_item_gift_data', full_name='dota.CMsgDOTAClaimEventActionData.grant_item_gift_data', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACLAIMEVENTACTIONDATA_GRANTITEMGIFTDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12391,
  serialized_end=12576,
)


_CMSGDOTACLAIMEVENTACTION = _descriptor.Descriptor(
  name='CMsgDOTAClaimEventAction',
  full_name='dota.CMsgDOTAClaimEventAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDOTAClaimEventAction.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='dota.CMsgDOTAClaimEventAction.action_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CMsgDOTAClaimEventAction.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dota.CMsgDOTAClaimEventAction.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12579,
  serialized_end=12710,
)


_CMSGDOTACLAIMEVENTACTIONRESPONSE_MYSTERYITEMREWARDDATA = _descriptor.Descriptor(
  name='MysteryItemRewardData',
  full_name='dota.CMsgDOTAClaimEventActionResponse.MysteryItemRewardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgDOTAClaimEventActionResponse.MysteryItemRewardData.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_category', full_name='dota.CMsgDOTAClaimEventActionResponse.MysteryItemRewardData.item_category', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12907,
  serialized_end=12971,
)

_CMSGDOTACLAIMEVENTACTIONRESPONSE_LOOTLISTREWARDDATA = _descriptor.Descriptor(
  name='LootListRewardData',
  full_name='dota.CMsgDOTAClaimEventActionResponse.LootListRewardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgDOTAClaimEventActionResponse.LootListRewardData.item_def', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12973,
  serialized_end=13011,
)

_CMSGDOTACLAIMEVENTACTIONRESPONSE_GRANTEDREWARDDATA = _descriptor.Descriptor(
  name='GrantedRewardData',
  full_name='dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grant_index', full_name='dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData.grant_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score_index', full_name='dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData.score_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_index', full_name='dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData.reward_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_data', full_name='dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData.reward_data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13013,
  serialized_end=13117,
)

_CMSGDOTACLAIMEVENTACTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAClaimEventActionResponse',
  full_name='dota.CMsgDOTAClaimEventActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAClaimEventActionResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_results', full_name='dota.CMsgDOTAClaimEventActionResponse.reward_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACLAIMEVENTACTIONRESPONSE_MYSTERYITEMREWARDDATA, _CMSGDOTACLAIMEVENTACTIONRESPONSE_LOOTLISTREWARDDATA, _CMSGDOTACLAIMEVENTACTIONRESPONSE_GRANTEDREWARDDATA, ],
  enum_types=[
    _CMSGDOTACLAIMEVENTACTIONRESPONSE_RESULTCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12713,
  serialized_end=13422,
)


_CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEM = _descriptor.Descriptor(
  name='CMsgClientToGCClaimEventActionUsingItem',
  full_name='dota.CMsgClientToGCClaimEventActionUsingItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCClaimEventActionUsingItem.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='dota.CMsgClientToGCClaimEventActionUsingItem.action_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgClientToGCClaimEventActionUsingItem.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CMsgClientToGCClaimEventActionUsingItem.quantity', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13424,
  serialized_end=13537,
)


_CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCClaimEventActionUsingItemResponse',
  full_name='dota.CMsgClientToGCClaimEventActionUsingItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_results', full_name='dota.CMsgClientToGCClaimEventActionUsingItemResponse.action_results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13539,
  serialized_end=13652,
)


_CMSGGCTOCLIENTCLAIMEVENTACTIONUSINGITEMCOMPLETED = _descriptor.Descriptor(
  name='CMsgGCToClientClaimEventActionUsingItemCompleted',
  full_name='dota.CMsgGCToClientClaimEventActionUsingItemCompleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgGCToClientClaimEventActionUsingItemCompleted.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_results', full_name='dota.CMsgGCToClientClaimEventActionUsingItemCompleted.action_results', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13655,
  serialized_end=13786,
)


_CMSGDOTAGETEVENTPOINTS = _descriptor.Descriptor(
  name='CMsgDOTAGetEventPoints',
  full_name='dota.CMsgDOTAGetEventPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDOTAGetEventPoints.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAGetEventPoints.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13788,
  serialized_end=13850,
)


_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='dota.CMsgDOTAGetEventPointsResponse.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_id', full_name='dota.CMsgDOTAGetEventPointsResponse.Action.action_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='times_completed', full_name='dota.CMsgDOTAGetEventPointsResponse.Action.times_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14126,
  serialized_end=14181,
)

_CMSGDOTAGETEVENTPOINTSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetEventPointsResponse',
  full_name='dota.CMsgDOTAGetEventPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_points', full_name='dota.CMsgDOTAGetEventPointsResponse.total_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_premium_points', full_name='dota.CMsgDOTAGetEventPointsResponse.total_premium_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDOTAGetEventPointsResponse.event_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgDOTAGetEventPointsResponse.points', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='premium_points', full_name='dota.CMsgDOTAGetEventPointsResponse.premium_points', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_actions', full_name='dota.CMsgDOTAGetEventPointsResponse.completed_actions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAGetEventPointsResponse.account_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owned', full_name='dota.CMsgDOTAGetEventPointsResponse.owned', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audit_action', full_name='dota.CMsgDOTAGetEventPointsResponse.audit_action', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13853,
  serialized_end=14181,
)


_CMSGDOTAGETPERIODICRESOURCE = _descriptor.Descriptor(
  name='CMsgDOTAGetPeriodicResource',
  full_name='dota.CMsgDOTAGetPeriodicResource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAGetPeriodicResource.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='periodic_resource_id', full_name='dota.CMsgDOTAGetPeriodicResource.periodic_resource_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgDOTAGetPeriodicResource.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14183,
  serialized_end=14281,
)


_CMSGDOTAGETPERIODICRESOURCERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetPeriodicResourceResponse',
  full_name='dota.CMsgDOTAGetPeriodicResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='periodic_resource_max', full_name='dota.CMsgDOTAGetPeriodicResourceResponse.periodic_resource_max', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='periodic_resource_used', full_name='dota.CMsgDOTAGetPeriodicResourceResponse.periodic_resource_used', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14283,
  serialized_end=14383,
)


_CMSGDOTAPERIODICRESOURCEUPDATED = _descriptor.Descriptor(
  name='CMsgDOTAPeriodicResourceUpdated',
  full_name='dota.CMsgDOTAPeriodicResourceUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='periodic_resource_key', full_name='dota.CMsgDOTAPeriodicResourceUpdated.periodic_resource_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='periodic_resource_value', full_name='dota.CMsgDOTAPeriodicResourceUpdated.periodic_resource_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14386,
  serialized_end=14561,
)


_CMSGDOTALIVELEAGUEGAMEUPDATE = _descriptor.Descriptor(
  name='CMsgDOTALiveLeagueGameUpdate',
  full_name='dota.CMsgDOTALiveLeagueGameUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='live_league_games', full_name='dota.CMsgDOTALiveLeagueGameUpdate.live_league_games', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14563,
  serialized_end=14620,
)


_CMSGDOTACOMPENDIUMSELECTION = _descriptor.Descriptor(
  name='CMsgDOTACompendiumSelection',
  full_name='dota.CMsgDOTACompendiumSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_index', full_name='dota.CMsgDOTACompendiumSelection.selection_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection', full_name='dota.CMsgDOTACompendiumSelection.selection', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='dota.CMsgDOTACompendiumSelection.leagueid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14622,
  serialized_end=14713,
)


_CMSGDOTACOMPENDIUMSELECTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACompendiumSelectionResponse',
  full_name='dota.CMsgDOTACompendiumSelectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgDOTACompendiumSelectionResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14715,
  serialized_end=14772,
)


_CMSGDOTACOMPENDIUMDATA = _descriptor.Descriptor(
  name='CMsgDOTACompendiumData',
  full_name='dota.CMsgDOTACompendiumData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selections', full_name='dota.CMsgDOTACompendiumData.selections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14774,
  serialized_end=14853,
)


_CMSGDOTACOMPENDIUMDATAREQUEST = _descriptor.Descriptor(
  name='CMsgDOTACompendiumDataRequest',
  full_name='dota.CMsgDOTACompendiumDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTACompendiumDataRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='dota.CMsgDOTACompendiumDataRequest.leagueid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14855,
  serialized_end=14924,
)


_CMSGDOTACOMPENDIUMDATARESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACompendiumDataResponse',
  full_name='dota.CMsgDOTACompendiumDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTACompendiumDataResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='dota.CMsgDOTACompendiumDataResponse.leagueid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTACompendiumDataResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compendium_data', full_name='dota.CMsgDOTACompendiumDataResponse.compendium_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14927,
  serialized_end=15071,
)


_CMSGDOTAGETPLAYERMATCHHISTORY = _descriptor.Descriptor(
  name='CMsgDOTAGetPlayerMatchHistory',
  full_name='dota.CMsgDOTAGetPlayerMatchHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAGetPlayerMatchHistory.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_at_match_id', full_name='dota.CMsgDOTAGetPlayerMatchHistory.start_at_match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_requested', full_name='dota.CMsgDOTAGetPlayerMatchHistory.matches_requested', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAGetPlayerMatchHistory.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dota.CMsgDOTAGetPlayerMatchHistory.request_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_practice_matches', full_name='dota.CMsgDOTAGetPlayerMatchHistory.include_practice_matches', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_custom_games', full_name='dota.CMsgDOTAGetPlayerMatchHistory.include_custom_games', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_event_games', full_name='dota.CMsgDOTAGetPlayerMatchHistory.include_event_games', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15074,
  serialized_end=15309,
)


_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='winner', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.winner', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.game_mode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.rank_change', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_rank', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.previous_rank', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.lobby_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='solo_rank', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.solo_rank', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abandon', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.abandon', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.duration', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.engine', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_plus_subscription', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.active_plus_subscription', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seasonal_rank', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.seasonal_rank', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tourney_id', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_id', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tourney_round', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_round', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tourney_tier', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_tier', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tourney_division', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_division', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.team_id', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.team_name', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ugc_team_ui_logo', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match.ugc_team_ui_logo', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15442,
  serialized_end=15883,
)

_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetPlayerMatchHistoryResponse',
  full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dota.CMsgDOTAGetPlayerMatchHistoryResponse.request_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15312,
  serialized_end=15883,
)


_CMSGDOTASTARTDAILYHEROCHALLENGE = _descriptor.Descriptor(
  name='CMsgDOTAStartDailyHeroChallenge',
  full_name='dota.CMsgDOTAStartDailyHeroChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15885,
  serialized_end=15918,
)


_CMSGGCNOTIFICATIONSREQUEST = _descriptor.Descriptor(
  name='CMsgGCNotificationsRequest',
  full_name='dota.CMsgGCNotificationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15920,
  serialized_end=15948,
)


_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='dota.CMsgGCNotificationsResponse.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgGCNotificationsResponse.Notification.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgGCNotificationsResponse.Notification.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgGCNotificationsResponse.Notification.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_a', full_name='dota.CMsgGCNotificationsResponse.Notification.reference_a', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_b', full_name='dota.CMsgGCNotificationsResponse.Notification.reference_b', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_c', full_name='dota.CMsgGCNotificationsResponse.Notification.reference_c', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dota.CMsgGCNotificationsResponse.Notification.message', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unread', full_name='dota.CMsgGCNotificationsResponse.Notification.unread', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16122,
  serialized_end=16277,
)

_CMSGGCNOTIFICATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCNotificationsResponse',
  full_name='dota.CMsgGCNotificationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCNotificationsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='dota.CMsgGCNotificationsResponse.notifications', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION, ],
  enum_types=[
    _CMSGGCNOTIFICATIONSRESPONSE_ERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15951,
  serialized_end=16324,
)


_CMSGGCNOTIFICATIONSMARKREADREQUEST = _descriptor.Descriptor(
  name='CMsgGCNotificationsMarkReadRequest',
  full_name='dota.CMsgGCNotificationsMarkReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16326,
  serialized_end=16362,
)


_CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD = _descriptor.Descriptor(
  name='CMsgClientToGCMarkNotificationListRead',
  full_name='dota.CMsgClientToGCMarkNotificationListRead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_ids', full_name='dota.CMsgClientToGCMarkNotificationListRead.notification_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16364,
  serialized_end=16430,
)


_CMSGGCPLAYERINFOREQUEST_PLAYERINFO = _descriptor.Descriptor(
  name='PlayerInfo',
  full_name='dota.CMsgGCPlayerInfoRequest.PlayerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCPlayerInfoRequest.PlayerInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgGCPlayerInfoRequest.PlayerInfo.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16524,
  serialized_end=16575,
)

_CMSGGCPLAYERINFOREQUEST = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoRequest',
  full_name='dota.CMsgGCPlayerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_infos', full_name='dota.CMsgGCPlayerInfoRequest.player_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCPLAYERINFOREQUEST_PLAYERINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16433,
  serialized_end=16575,
)


_CMSGGCPLAYERINFOSUBMIT = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoSubmit',
  full_name='dota.CMsgGCPlayerInfoSubmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCPlayerInfoSubmit.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='dota.CMsgGCPlayerInfoSubmit.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_role', full_name='dota.CMsgGCPlayerInfoSubmit.fantasy_role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgGCPlayerInfoSubmit.team_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sponsor', full_name='dota.CMsgGCPlayerInfoSubmit.sponsor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16577,
  serialized_end=16693,
)


_CMSGGCPLAYERINFOSUBMITRESPONSE = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoSubmitResponse',
  full_name='dota.CMsgGCPlayerInfoSubmitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCPlayerInfoSubmitResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16696,
  serialized_end=16869,
)


_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='dota.CMsgClientProvideSurveyResult.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='question_id', full_name='dota.CMsgClientProvideSurveyResult.Response.question_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='survey_value', full_name='dota.CMsgClientProvideSurveyResult.Response.survey_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16990,
  serialized_end=17043,
)

_CMSGCLIENTPROVIDESURVEYRESULT = _descriptor.Descriptor(
  name='CMsgClientProvideSurveyResult',
  full_name='dota.CMsgClientProvideSurveyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='dota.CMsgClientProvideSurveyResult.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='survey_key', full_name='dota.CMsgClientProvideSurveyResult.survey_key', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16872,
  serialized_end=17043,
)


_CMSGDOTAEMOTICONACCESSSDO = _descriptor.Descriptor(
  name='CMsgDOTAEmoticonAccessSDO',
  full_name='dota.CMsgDOTAEmoticonAccessSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTAEmoticonAccessSDO.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlocked_emoticons', full_name='dota.CMsgDOTAEmoticonAccessSDO.unlocked_emoticons', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17045,
  serialized_end=17120,
)


_CMSGCLIENTTOGCEMOTICONDATAREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCEmoticonDataRequest',
  full_name='dota.CMsgClientToGCEmoticonDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17122,
  serialized_end=17157,
)


_CMSGGCTOCLIENTEMOTICONDATA = _descriptor.Descriptor(
  name='CMsgGCToClientEmoticonData',
  full_name='dota.CMsgGCToClientEmoticonData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emoticon_access', full_name='dota.CMsgGCToClientEmoticonData.emoticon_access', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17159,
  serialized_end=17245,
)


_CMSGCLIENTTOGCTRACKDIALOGRESULT = _descriptor.Descriptor(
  name='CMsgClientToGCTrackDialogResult',
  full_name='dota.CMsgClientToGCTrackDialogResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialog_id', full_name='dota.CMsgClientToGCTrackDialogResult.dialog_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CMsgClientToGCTrackDialogResult.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17247,
  serialized_end=17314,
)


_CMSGGCTOCLIENTTOURNAMENTITEMDROP = _descriptor.Descriptor(
  name='CMsgGCToClientTournamentItemDrop',
  full_name='dota.CMsgGCToClientTournamentItemDrop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgGCToClientTournamentItemDrop.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='dota.CMsgGCToClientTournamentItemDrop.event_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17316,
  serialized_end=17388,
)


_CMSGCLIENTTOGCSETADDITIONALEQUIPS = _descriptor.Descriptor(
  name='CMsgClientToGCSetAdditionalEquips',
  full_name='dota.CMsgClientToGCSetAdditionalEquips',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equips', full_name='dota.CMsgClientToGCSetAdditionalEquips.equips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17390,
  serialized_end=17469,
)


_CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSetAdditionalEquipsResponse',
  full_name='dota.CMsgClientToGCSetAdditionalEquipsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17471,
  serialized_end=17514,
)


_CMSGCLIENTTOGCGETADDITIONALEQUIPS = _descriptor.Descriptor(
  name='CMsgClientToGCGetAdditionalEquips',
  full_name='dota.CMsgClientToGCGetAdditionalEquips',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17516,
  serialized_end=17551,
)


_CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAdditionalEquipsResponse',
  full_name='dota.CMsgClientToGCGetAdditionalEquipsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equips', full_name='dota.CMsgClientToGCGetAdditionalEquipsResponse.equips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17553,
  serialized_end=17640,
)


_CMSGCLIENTTOGCGETALLHEROORDER = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroOrder',
  full_name='dota.CMsgClientToGCGetAllHeroOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17642,
  serialized_end=17673,
)


_CMSGCLIENTTOGCGETALLHEROORDERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroOrderResponse',
  full_name='dota.CMsgClientToGCGetAllHeroOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_ids', full_name='dota.CMsgClientToGCGetAllHeroOrderResponse.hero_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17675,
  serialized_end=17732,
)


_CMSGCLIENTTOGCGETALLHEROPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroProgress',
  full_name='dota.CMsgClientToGCGetAllHeroProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetAllHeroProgress.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17734,
  serialized_end=17788,
)


_CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroProgressResponse',
  full_name='dota.CMsgClientToGCGetAllHeroProgressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_hero_id', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='laps_completed', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.laps_completed', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_hero_games', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_hero_games', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_lap_time_started', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_lap_time_started', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_lap_games', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_lap_games', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_lap_games', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.best_lap_games', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_lap_time', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.best_lap_time', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lap_heroes_completed', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.lap_heroes_completed', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lap_heroes_remaining', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.lap_heroes_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_hero_id', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.next_hero_id', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_hero_id', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.prev_hero_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_hero_games', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.prev_hero_games', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_avg_tries', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.prev_avg_tries', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_avg_tries', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_avg_tries', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_avg_tries', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.next_avg_tries', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_lap_avg_tries', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.full_lap_avg_tries', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_lap_avg_tries', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.curr_lap_avg_tries', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_name', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.profile_name', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_hero_id', full_name='dota.CMsgClientToGCGetAllHeroProgressResponse.start_hero_id', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17791,
  serialized_end=18328,
)


_CMSGCLIENTTOGCGETTROPHYLIST = _descriptor.Descriptor(
  name='CMsgClientToGCGetTrophyList',
  full_name='dota.CMsgClientToGCGetTrophyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetTrophyList.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18330,
  serialized_end=18379,
)


_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY = _descriptor.Descriptor(
  name='Trophy',
  full_name='dota.CMsgClientToGCGetTrophyListResponse.Trophy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trophy_id', full_name='dota.CMsgClientToGCGetTrophyListResponse.Trophy.trophy_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trophy_score', full_name='dota.CMsgClientToGCGetTrophyListResponse.Trophy.trophy_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='dota.CMsgClientToGCGetTrophyListResponse.Trophy.last_updated', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18531,
  serialized_end=18602,
)

_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetTrophyListResponse',
  full_name='dota.CMsgClientToGCGetTrophyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetTrophyListResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trophies', full_name='dota.CMsgClientToGCGetTrophyListResponse.trophies', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_name', full_name='dota.CMsgClientToGCGetTrophyListResponse.profile_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18382,
  serialized_end=18602,
)


_CMSGGCTOCLIENTTROPHYAWARDED = _descriptor.Descriptor(
  name='CMsgGCToClientTrophyAwarded',
  full_name='dota.CMsgGCToClientTrophyAwarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trophy_id', full_name='dota.CMsgGCToClientTrophyAwarded.trophy_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trophy_score', full_name='dota.CMsgGCToClientTrophyAwarded.trophy_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trophy_old_score', full_name='dota.CMsgGCToClientTrophyAwarded.trophy_old_score', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='dota.CMsgGCToClientTrophyAwarded.last_updated', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18604,
  serialized_end=18722,
)


_CMSGCLIENTTOGCGETPROFILECARD = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileCard',
  full_name='dota.CMsgClientToGCGetProfileCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCGetProfileCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18724,
  serialized_end=18774,
)


_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT = _descriptor.Descriptor(
  name='CardSlot',
  full_name='dota.CMsgClientToGCSetProfileCardSlots.CardSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='dota.CMsgClientToGCSetProfileCardSlots.CardSlot.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot_type', full_name='dota.CMsgClientToGCSetProfileCardSlots.CardSlot.slot_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot_value', full_name='dota.CMsgClientToGCSetProfileCardSlots.CardSlot.slot_value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18879,
  serialized_end=19003,
)

_CMSGCLIENTTOGCSETPROFILECARDSLOTS = _descriptor.Descriptor(
  name='CMsgClientToGCSetProfileCardSlots',
  full_name='dota.CMsgClientToGCSetProfileCardSlots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slots', full_name='dota.CMsgClientToGCSetProfileCardSlots.slots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18777,
  serialized_end=19003,
)


_CMSGCLIENTTOGCGETPROFILECARDSTATS = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileCardStats',
  full_name='dota.CMsgClientToGCGetProfileCardStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19005,
  serialized_end=19040,
)


_CMSGCLIENTTOGCCREATEHEROSTATUE = _descriptor.Descriptor(
  name='CMsgClientToGCCreateHeroStatue',
  full_name='dota.CMsgClientToGCCreateHeroStatue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_item', full_name='dota.CMsgClientToGCCreateHeroStatue.source_item', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgClientToGCCreateHeroStatue.hero_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_name', full_name='dota.CMsgClientToGCCreateHeroStatue.sequence_name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='dota.CMsgClientToGCCreateHeroStatue.cycle', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wearables', full_name='dota.CMsgClientToGCCreateHeroStatue.wearables', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inscription', full_name='dota.CMsgClientToGCCreateHeroStatue.inscription', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles', full_name='dota.CMsgClientToGCCreateHeroStatue.styles', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reforger_item', full_name='dota.CMsgClientToGCCreateHeroStatue.reforger_item', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tournament_drop', full_name='dota.CMsgClientToGCCreateHeroStatue.tournament_drop', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19043,
  serialized_end=19255,
)


_CMSGGCTOCLIENTHEROSTATUECREATERESULT = _descriptor.Descriptor(
  name='CMsgGCToClientHeroStatueCreateResult',
  full_name='dota.CMsgGCToClientHeroStatueCreateResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resulting_item', full_name='dota.CMsgGCToClientHeroStatueCreateResult.resulting_item', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19257,
  serialized_end=19319,
)


_CMSGGCTOCLIENTEVENTSTATUSCHANGED = _descriptor.Descriptor(
  name='CMsgGCToClientEventStatusChanged',
  full_name='dota.CMsgGCToClientEventStatusChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_event', full_name='dota.CMsgGCToClientEventStatusChanged.active_event', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19321,
  serialized_end=19406,
)


_CMSGCLIENTTOGCPLAYERSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCPlayerStatsRequest',
  full_name='dota.CMsgClientToGCPlayerStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCPlayerStatsRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19408,
  serialized_end=19462,
)


_CMSGGCTOCLIENTPLAYERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPlayerStatsResponse',
  full_name='dota.CMsgGCToClientPlayerStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientPlayerStatsResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_stats', full_name='dota.CMsgGCToClientPlayerStatsResponse.player_stats', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_count', full_name='dota.CMsgGCToClientPlayerStatsResponse.match_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_gpm', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_gpm', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_xppm', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_xppm', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_lasthits', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_lasthits', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rampages', full_name='dota.CMsgGCToClientPlayerStatsResponse.rampages', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triple_kills', full_name='dota.CMsgGCToClientPlayerStatsResponse.triple_kills', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_blood_claimed', full_name='dota.CMsgGCToClientPlayerStatsResponse.first_blood_claimed', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_blood_given', full_name='dota.CMsgGCToClientPlayerStatsResponse.first_blood_given', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='couriers_killed', full_name='dota.CMsgGCToClientPlayerStatsResponse.couriers_killed', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aegises_snatched', full_name='dota.CMsgGCToClientPlayerStatsResponse.aegises_snatched', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cheeses_eaten', full_name='dota.CMsgGCToClientPlayerStatsResponse.cheeses_eaten', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creeps_stacked', full_name='dota.CMsgGCToClientPlayerStatsResponse.creeps_stacked', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fight_score', full_name='dota.CMsgGCToClientPlayerStatsResponse.fight_score', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='farm_score', full_name='dota.CMsgGCToClientPlayerStatsResponse.farm_score', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='support_score', full_name='dota.CMsgGCToClientPlayerStatsResponse.support_score', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push_score', full_name='dota.CMsgGCToClientPlayerStatsResponse.push_score', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versatility_score', full_name='dota.CMsgGCToClientPlayerStatsResponse.versatility_score', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_networth', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_networth', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_damage', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_damage', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_heals', full_name='dota.CMsgGCToClientPlayerStatsResponse.mean_heals', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rapiers_purchased', full_name='dota.CMsgGCToClientPlayerStatsResponse.rapiers_purchased', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19465,
  serialized_end=20019,
)


_CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCCustomGamePlayerCountRequest',
  full_name='dota.CMsgClientToGCCustomGamePlayerCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgClientToGCCustomGamePlayerCountRequest.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20021,
  serialized_end=20089,
)


_CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientCustomGamePlayerCountResponse',
  full_name='dota.CMsgGCToClientCustomGamePlayerCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgGCToClientCustomGamePlayerCountResponse.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_count', full_name='dota.CMsgGCToClientCustomGamePlayerCountResponse.player_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spectator_count', full_name='dota.CMsgGCToClientCustomGamePlayerCountResponse.spectator_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20091,
  serialized_end=20207,
)


_CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCCustomGamesFriendsPlayedRequest',
  full_name='dota.CMsgClientToGCCustomGamesFriendsPlayedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20209,
  serialized_end=20256,
)


_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME = _descriptor.Descriptor(
  name='CustomGame',
  full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20409,
  serialized_end=20466,
)

_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientCustomGamesFriendsPlayedResponse',
  full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='games', full_name='dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.games', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20259,
  serialized_end=20466,
)


_CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialFeedPostCommentRequest',
  full_name='dota.CMsgClientToGCSocialFeedPostCommentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCSocialFeedPostCommentRequest.event_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='dota.CMsgClientToGCSocialFeedPostCommentRequest.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20468,
  serialized_end=20547,
)


_CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialFeedPostCommentResponse',
  full_name='dota.CMsgGCToClientSocialFeedPostCommentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToClientSocialFeedPostCommentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20549,
  serialized_end=20611,
)


_CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialFeedPostMessageRequest',
  full_name='dota.CMsgClientToGCSocialFeedPostMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='dota.CMsgClientToGCSocialFeedPostMessageRequest.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCSocialFeedPostMessageRequest.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_timestamp', full_name='dota.CMsgClientToGCSocialFeedPostMessageRequest.match_timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20613,
  serialized_end=20717,
)


_CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialFeedPostMessageResponse',
  full_name='dota.CMsgGCToClientSocialFeedPostMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToClientSocialFeedPostMessageResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20719,
  serialized_end=20781,
)


_CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCFriendsPlayedCustomGameRequest',
  full_name='dota.CMsgClientToGCFriendsPlayedCustomGameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgClientToGCFriendsPlayedCustomGameRequest.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20783,
  serialized_end=20853,
)


_CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientFriendsPlayedCustomGameResponse',
  full_name='dota.CMsgGCToClientFriendsPlayedCustomGameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgGCToClientFriendsPlayedCustomGameResponse.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgGCToClientFriendsPlayedCustomGameResponse.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20855,
  serialized_end=20947,
)


_CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialMatchPostCommentRequest',
  full_name='dota.CMsgClientToGCSocialMatchPostCommentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCSocialMatchPostCommentRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='dota.CMsgClientToGCSocialMatchPostCommentRequest.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20949,
  serialized_end=21029,
)


_CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialMatchPostCommentResponse',
  full_name='dota.CMsgGCToClientSocialMatchPostCommentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToClientSocialMatchPostCommentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21031,
  serialized_end=21094,
)


_CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialMatchDetailsRequest',
  full_name='dota.CMsgClientToGCSocialMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCSocialMatchDetailsRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination_timestamp', full_name='dota.CMsgClientToGCSocialMatchDetailsRequest.pagination_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21096,
  serialized_end=21185,
)


_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT = _descriptor.Descriptor(
  name='Comment',
  full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.Comment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.Comment.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.Comment.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.Comment.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.Comment.comment', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21323,
  serialized_end=21410,
)

_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialMatchDetailsResponse',
  full_name='dota.CMsgGCToClientSocialMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comments', full_name='dota.CMsgGCToClientSocialMatchDetailsResponse.comments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21188,
  serialized_end=21410,
)


_CMSGDOTAPARTYRICHPRESENCE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='dota.CMsgDOTAPartyRichPresence.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgDOTAPartyRichPresence.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coach', full_name='dota.CMsgDOTAPartyRichPresence.Member.coach', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21739,
  serialized_end=21780,
)

_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY = _descriptor.Descriptor(
  name='WeekendTourney',
  full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='division', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.division', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.skill_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='round', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.round', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.tournament_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_seq_num', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.state_seq_num', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.event', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_round', full_name='dota.CMsgDOTAPartyRichPresence.WeekendTourney.event_round', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21783,
  serialized_end=22016,
)

_CMSGDOTAPARTYRICHPRESENCE = _descriptor.Descriptor(
  name='CMsgDOTAPartyRichPresence',
  full_name='dota.CMsgDOTAPartyRichPresence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='dota.CMsgDOTAPartyRichPresence.party_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='party_state', full_name='dota.CMsgDOTAPartyRichPresence.party_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='dota.CMsgDOTAPartyRichPresence.open', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='dota.CMsgDOTAPartyRichPresence.low_priority', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTAPartyRichPresence.team_id', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='dota.CMsgDOTAPartyRichPresence.team_name', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ugc_team_ui_logo', full_name='dota.CMsgDOTAPartyRichPresence.ugc_team_ui_logo', index=6,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='dota.CMsgDOTAPartyRichPresence.members', index=7,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekend_tourney', full_name='dota.CMsgDOTAPartyRichPresence.weekend_tourney', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPARTYRICHPRESENCE_MEMBER, _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21413,
  serialized_end=22016,
)


_CMSGDOTALOBBYRICHPRESENCE = _descriptor.Descriptor(
  name='CMsgDOTALobbyRichPresence',
  full_name='dota.CMsgDOTALobbyRichPresence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgDOTALobbyRichPresence.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_state', full_name='dota.CMsgDOTALobbyRichPresence.lobby_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='dota.CMsgDOTALobbyRichPresence.password', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='dota.CMsgDOTALobbyRichPresence.game_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='dota.CMsgDOTALobbyRichPresence.member_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_member_count', full_name='dota.CMsgDOTALobbyRichPresence.max_member_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgDOTALobbyRichPresence.custom_game_id', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgDOTALobbyRichPresence.name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='dota.CMsgDOTALobbyRichPresence.lobby_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22019,
  serialized_end=22299,
)


_CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING = _descriptor.Descriptor(
  name='CMsgDOTACustomGameListenServerStartedLoading',
  full_name='dota.CMsgDOTACustomGameListenServerStartedLoading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgDOTACustomGameListenServerStartedLoading.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='dota.CMsgDOTACustomGameListenServerStartedLoading.custom_game_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_members', full_name='dota.CMsgDOTACustomGameListenServerStartedLoading.lobby_members', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='dota.CMsgDOTACustomGameListenServerStartedLoading.start_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22302,
  serialized_end=22433,
)


_CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING = _descriptor.Descriptor(
  name='CMsgDOTACustomGameClientFinishedLoading',
  full_name='dota.CMsgDOTACustomGameClientFinishedLoading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loading_duration', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.loading_duration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_code', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.result_code', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_string', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.result_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signon_states', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.signon_states', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='dota.CMsgDOTACustomGameClientFinishedLoading.comment', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22436,
  serialized_end=22605,
)


_CMSGCLIENTTOGCAPPLYGEMCOMBINER = _descriptor.Descriptor(
  name='CMsgClientToGCApplyGemCombiner',
  full_name='dota.CMsgClientToGCApplyGemCombiner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id_1', full_name='dota.CMsgClientToGCApplyGemCombiner.item_id_1', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id_2', full_name='dota.CMsgClientToGCApplyGemCombiner.item_id_2', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22607,
  serialized_end=22677,
)


_CMSGCLIENTTOGCH264UNSUPPORTED = _descriptor.Descriptor(
  name='CMsgClientToGCH264Unsupported',
  full_name='dota.CMsgClientToGCH264Unsupported',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22679,
  serialized_end=22710,
)


_CMSGCLIENTTOGCREQUESTH264SUPPORT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestH264Support',
  full_name='dota.CMsgClientToGCRequestH264Support',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22712,
  serialized_end=22746,
)


_CMSGCLIENTTOGCGETQUESTPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCGetQuestProgress',
  full_name='dota.CMsgClientToGCGetQuestProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_ids', full_name='dota.CMsgClientToGCGetQuestProgress.quest_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22748,
  serialized_end=22799,
)


_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE = _descriptor.Descriptor(
  name='Challenge',
  full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.challenge_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_completed', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.time_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.attempts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template_id', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.template_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quest_rank', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Challenge.quest_rank', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22930,
  serialized_end=23063,
)

_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST = _descriptor.Descriptor(
  name='Quest',
  full_name='dota.CMsgClientToGCGetQuestProgressResponse.Quest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Quest.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_challenges', full_name='dota.CMsgClientToGCGetQuestProgressResponse.Quest.completed_challenges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23065,
  serialized_end=23176,
)

_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetQuestProgressResponse',
  full_name='dota.CMsgClientToGCGetQuestProgressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgClientToGCGetQuestProgressResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quests', full_name='dota.CMsgClientToGCGetQuestProgressResponse.quests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE, _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22802,
  serialized_end=23176,
)


_CMSGGCTOCLIENTMATCHSIGNEDOUT = _descriptor.Descriptor(
  name='CMsgGCToClientMatchSignedOut',
  full_name='dota.CMsgGCToClientMatchSignedOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgGCToClientMatchSignedOut.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23178,
  serialized_end=23226,
)


_CMSGGCGETHEROSTATSHISTORY = _descriptor.Descriptor(
  name='CMsgGCGetHeroStatsHistory',
  full_name='dota.CMsgGCGetHeroStatsHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCGetHeroStatsHistory.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23228,
  serialized_end=23272,
)


_CMSGGCGETHEROSTATSHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetHeroStatsHistoryResponse',
  full_name='dota.CMsgGCGetHeroStatsHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCGetHeroStatsHistoryResponse.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='records', full_name='dota.CMsgGCGetHeroStatsHistoryResponse.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23274,
  serialized_end=23378,
)


_CMSGPLAYERCONDUCTSCORECARDREQUEST = _descriptor.Descriptor(
  name='CMsgPlayerConductScorecardRequest',
  full_name='dota.CMsgPlayerConductScorecardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23380,
  serialized_end=23415,
)


_CMSGPLAYERCONDUCTSCORECARD = _descriptor.Descriptor(
  name='CMsgPlayerConductScorecard',
  full_name='dota.CMsgPlayerConductScorecard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgPlayerConductScorecard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgPlayerConductScorecard.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='dota.CMsgPlayerConductScorecard.seq_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='dota.CMsgPlayerConductScorecard.reasons', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_in_report', full_name='dota.CMsgPlayerConductScorecard.matches_in_report', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_clean', full_name='dota.CMsgPlayerConductScorecard.matches_clean', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_reported', full_name='dota.CMsgPlayerConductScorecard.matches_reported', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_abandoned', full_name='dota.CMsgPlayerConductScorecard.matches_abandoned', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reports_count', full_name='dota.CMsgPlayerConductScorecard.reports_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reports_parties', full_name='dota.CMsgPlayerConductScorecard.reports_parties', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commend_count', full_name='dota.CMsgPlayerConductScorecard.commend_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dota.CMsgPlayerConductScorecard.date', index=11,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='behavior_grade', full_name='dota.CMsgPlayerConductScorecard.behavior_grade', index=12,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_behavior_grade', full_name='dota.CMsgPlayerConductScorecard.old_behavior_grade', index=13,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_behavior_score', full_name='dota.CMsgPlayerConductScorecard.raw_behavior_score', index=14,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_raw_behavior_score', full_name='dota.CMsgPlayerConductScorecard.old_raw_behavior_score', index=15,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23418,
  serialized_end=23818,
)


_CMSGCLIENTTOGCWAGERINGREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCWageringRequest',
  full_name='dota.CMsgClientToGCWageringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCWageringRequest.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23820,
  serialized_end=23869,
)


_CMSGGCTOCLIENTWAGERINGRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientWageringResponse',
  full_name='dota.CMsgGCToClientWageringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coins_remaining', full_name='dota.CMsgGCToClientWageringResponse.coins_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_points_won', full_name='dota.CMsgGCToClientWageringResponse.total_points_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_points_wagered', full_name='dota.CMsgGCToClientWageringResponse.total_points_wagered', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_points_tipped', full_name='dota.CMsgGCToClientWageringResponse.total_points_tipped', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientWageringResponse.success_rate', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_games_wagered', full_name='dota.CMsgGCToClientWageringResponse.total_games_wagered', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coins_max', full_name='dota.CMsgGCToClientWageringResponse.coins_max', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rank_wagers_remaining', full_name='dota.CMsgGCToClientWageringResponse.rank_wagers_remaining', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rank_wagers_max', full_name='dota.CMsgGCToClientWageringResponse.rank_wagers_max', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_tokens_remaining', full_name='dota.CMsgGCToClientWageringResponse.prediction_tokens_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_tokens_max', full_name='dota.CMsgGCToClientWageringResponse.prediction_tokens_max', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23872,
  serialized_end=24208,
)


_CMSGGCTOCLIENTWAGERINGUPDATE = _descriptor.Descriptor(
  name='CMsgGCToClientWageringUpdate',
  full_name='dota.CMsgGCToClientWageringUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientWageringUpdate.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering_info', full_name='dota.CMsgGCToClientWageringUpdate.wagering_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24210,
  serialized_end=24319,
)


_CMSGGCTOCLIENTARCANAVOTESUPDATE = _descriptor.Descriptor(
  name='CMsgGCToClientArcanaVotesUpdate',
  full_name='dota.CMsgGCToClientArcanaVotesUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientArcanaVotesUpdate.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arcana_votes', full_name='dota.CMsgGCToClientArcanaVotesUpdate.arcana_votes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24322,
  serialized_end=24452,
)


_CMSGCLIENTTOGCGETEVENTGOALS = _descriptor.Descriptor(
  name='CMsgClientToGCGetEventGoals',
  full_name='dota.CMsgClientToGCGetEventGoals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_ids', full_name='dota.CMsgClientToGCGetEventGoals.event_ids', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24454,
  serialized_end=24516,
)


_CMSGEVENTGOALS_EVENTGOAL = _descriptor.Descriptor(
  name='EventGoal',
  full_name='dota.CMsgEventGoals.EventGoal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgEventGoals.EventGoal.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_id', full_name='dota.CMsgEventGoals.EventGoal.goal_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CMsgEventGoals.EventGoal.value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24590,
  serialized_end=24680,
)

_CMSGEVENTGOALS = _descriptor.Descriptor(
  name='CMsgEventGoals',
  full_name='dota.CMsgEventGoals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_goals', full_name='dota.CMsgEventGoals.event_goals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGEVENTGOALS_EVENTGOAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24519,
  serialized_end=24680,
)


_CMSGGCTOGCLEAGUEPREDICTIONS = _descriptor.Descriptor(
  name='CMsgGCToGCLeaguePredictions',
  full_name='dota.CMsgGCToGCLeaguePredictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgGCToGCLeaguePredictions.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24682,
  serialized_end=24730,
)


_CMSGPREDICTIONRANKINGS_PREDICTIONLINE = _descriptor.Descriptor(
  name='PredictionLine',
  full_name='dota.CMsgPredictionRankings.PredictionLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer_id', full_name='dota.CMsgPredictionRankings.PredictionLine.answer_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_name', full_name='dota.CMsgPredictionRankings.PredictionLine.answer_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_logo', full_name='dota.CMsgPredictionRankings.PredictionLine.answer_logo', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_value', full_name='dota.CMsgPredictionRankings.PredictionLine.answer_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24821,
  serialized_end=24920,
)

_CMSGPREDICTIONRANKINGS_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='dota.CMsgPredictionRankings.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_id', full_name='dota.CMsgPredictionRankings.Prediction.selection_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_lines', full_name='dota.CMsgPredictionRankings.Prediction.prediction_lines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24922,
  serialized_end=25027,
)

_CMSGPREDICTIONRANKINGS = _descriptor.Descriptor(
  name='CMsgPredictionRankings',
  full_name='dota.CMsgPredictionRankings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgPredictionRankings.predictions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPREDICTIONRANKINGS_PREDICTIONLINE, _CMSGPREDICTIONRANKINGS_PREDICTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24733,
  serialized_end=25027,
)


_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN = _descriptor.Descriptor(
  name='ResultBreakdown',
  full_name='dota.CMsgPredictionResults.ResultBreakdown',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer_selection', full_name='dota.CMsgPredictionResults.ResultBreakdown.answer_selection', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_value', full_name='dota.CMsgPredictionResults.ResultBreakdown.answer_value', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25108,
  serialized_end=25173,
)

_CMSGPREDICTIONRESULTS_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='dota.CMsgPredictionResults.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_id', full_name='dota.CMsgPredictionResults.Result.selection_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_breakdown', full_name='dota.CMsgPredictionResults.Result.result_breakdown', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25175,
  serialized_end=25276,
)

_CMSGPREDICTIONRESULTS = _descriptor.Descriptor(
  name='CMsgPredictionResults',
  full_name='dota.CMsgPredictionResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='dota.CMsgPredictionResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN, _CMSGPREDICTIONRESULTS_RESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25030,
  serialized_end=25276,
)


_CMSGCLIENTTOGCSUSPICIOUSACTIVITY = _descriptor.Descriptor(
  name='CMsgClientToGCSuspiciousActivity',
  full_name='dota.CMsgClientToGCSuspiciousActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_data', full_name='dota.CMsgClientToGCSuspiciousActivity.app_data', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25278,
  serialized_end=25330,
)


_CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP = _descriptor.Descriptor(
  name='CMsgClientToGCHasPlayerVotedForMVP',
  full_name='dota.CMsgClientToGCHasPlayerVotedForMVP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCHasPlayerVotedForMVP.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25332,
  serialized_end=25386,
)


_CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCHasPlayerVotedForMVPResponse',
  full_name='dota.CMsgClientToGCHasPlayerVotedForMVPResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCHasPlayerVotedForMVPResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25388,
  serialized_end=25448,
)


_CMSGCLIENTTOGCVOTEFORLEAGUEGAMEMVP = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForLeagueGameMVP',
  full_name='dota.CMsgClientToGCVoteForLeagueGameMVP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCVoteForLeagueGameMVP.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCVoteForLeagueGameMVP.account_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25450,
  serialized_end=25524,
)


_CMSGCLIENTTOGCVOTEFORMVP = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForMVP',
  full_name='dota.CMsgClientToGCVoteForMVP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCVoteForMVP.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCVoteForMVP.account_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25526,
  serialized_end=25590,
)


_CMSGCLIENTTOGCVOTEFORMVPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForMVPResponse',
  full_name='dota.CMsgClientToGCVoteForMVPResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCVoteForMVPResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25592,
  serialized_end=25642,
)


_CMSGCLIENTTOGCMVPVOTETIMEOUT = _descriptor.Descriptor(
  name='CMsgClientToGCMVPVoteTimeout',
  full_name='dota.CMsgClientToGCMVPVoteTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCMVPVoteTimeout.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25644,
  serialized_end=25692,
)


_CMSGCLIENTTOGCMVPVOTETIMEOUTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCMVPVoteTimeoutResponse',
  full_name='dota.CMsgClientToGCMVPVoteTimeoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCMVPVoteTimeoutResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25694,
  serialized_end=25748,
)


_CMSGMVPVOTESFORMATCH_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='dota.CMsgMVPVotesForMatch.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgMVPVotesForMatch.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='dota.CMsgMVPVotesForMatch.Player.vote_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25826,
  serialized_end=25874,
)

_CMSGMVPVOTESFORMATCH = _descriptor.Descriptor(
  name='CMsgMVPVotesForMatch',
  full_name='dota.CMsgMVPVotesForMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='dota.CMsgMVPVotesForMatch.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGMVPVOTESFORMATCH_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25750,
  serialized_end=25874,
)


_CMSGCLIENTTOGCTEAMMATESTATSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTeammateStatsRequest',
  full_name='dota.CMsgClientToGCTeammateStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25876,
  serialized_end=25912,
)


_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT = _descriptor.Descriptor(
  name='TeammateStat',
  full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='games', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.games', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.wins', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='most_recent_game_timestamp', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.most_recent_game_timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='most_recent_game_match_id', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.most_recent_game_match_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance', full_name='dota.CMsgClientToGCTeammateStatsResponse.TeammateStat.performance', index=5,
      number=100, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26052,
  serialized_end=26207,
)

_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCTeammateStatsResponse',
  full_name='dota.CMsgClientToGCTeammateStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgClientToGCTeammateStatsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teammate_stats', full_name='dota.CMsgClientToGCTeammateStatsResponse.teammate_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25915,
  serialized_end=26207,
)


_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE = _descriptor.Descriptor(
  name='MatchVote',
  full_name='dota.CMsgClientToGCVoteForArcana.MatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCVoteForArcana.MatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgClientToGCVoteForArcana.MatchVote.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='dota.CMsgClientToGCVoteForArcana.MatchVote.vote_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26303,
  serialized_end=26369,
)

_CMSGCLIENTTOGCVOTEFORARCANA = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForArcana',
  full_name='dota.CMsgClientToGCVoteForArcana',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgClientToGCVoteForArcana.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26210,
  serialized_end=26369,
)


_CMSGCLIENTTOGCVOTEFORARCANARESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForArcanaResponse',
  full_name='dota.CMsgClientToGCVoteForArcanaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCVoteForArcanaResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26372,
  serialized_end=26566,
)


_CMSGARCANAVOTES_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='dota.CMsgArcanaVotes.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgArcanaVotes.Match.match_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id_0', full_name='dota.CMsgArcanaVotes.Match.hero_id_0', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id_1', full_name='dota.CMsgArcanaVotes.Match.hero_id_1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_seeding_0', full_name='dota.CMsgArcanaVotes.Match.hero_seeding_0', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_seeding_1', full_name='dota.CMsgArcanaVotes.Match.hero_seeding_1', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_count_0', full_name='dota.CMsgArcanaVotes.Match.vote_count_0', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_count_1', full_name='dota.CMsgArcanaVotes.Match.vote_count_1', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voting_state', full_name='dota.CMsgArcanaVotes.Match.voting_state', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='round_number', full_name='dota.CMsgArcanaVotes.Match.round_number', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_votes_hidden', full_name='dota.CMsgArcanaVotes.Match.is_votes_hidden', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibration_time_remaining', full_name='dota.CMsgArcanaVotes.Match.calibration_time_remaining', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26825,
  serialized_end=27085,
)

_CMSGARCANAVOTES = _descriptor.Descriptor(
  name='CMsgArcanaVotes',
  full_name='dota.CMsgArcanaVotes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='dota.CMsgArcanaVotes.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='round_time_remaining', full_name='dota.CMsgArcanaVotes.round_time_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='round_number', full_name='dota.CMsgArcanaVotes.round_number', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voting_state', full_name='dota.CMsgArcanaVotes.voting_state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_current_round_calibrating', full_name='dota.CMsgArcanaVotes.is_current_round_calibrating', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closest_active_match_id', full_name='dota.CMsgArcanaVotes.closest_active_match_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgArcanaVotes.event_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voting_start_time', full_name='dota.CMsgArcanaVotes.voting_start_time', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGARCANAVOTES_MATCH, ],
  enum_types=[
    _CMSGARCANAVOTES_VOTINGSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26569,
  serialized_end=27146,
)


_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING = _descriptor.Descriptor(
  name='CMsgClientToGCRequestArcanaVotesRemaining',
  full_name='dota.CMsgClientToGCRequestArcanaVotesRemaining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27148,
  serialized_end=27191,
)


_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE = _descriptor.Descriptor(
  name='MatchVote',
  full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.vote_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26303,
  serialized_end=26369,
)

_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestArcanaVotesRemainingResponse',
  full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='votes_remaining', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.votes_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='votes_total', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.votes_total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matches_previously_voted_for', full_name='dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.matches_previously_voted_for', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27194,
  serialized_end=27480,
)


_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGV2 = _descriptor.Descriptor(
  name='CMsgClientToGCRequestEventPointLogV2',
  full_name='dota.CMsgClientToGCRequestEventPointLogV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestEventPointLogV2.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27482,
  serialized_end=27538,
)


_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audit_action', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry.audit_action', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry.event_points', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audit_data', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry.audit_data', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27734,
  serialized_end=27827,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2 = _descriptor.Descriptor(
  name='CMsgClientToGCRequestEventPointLogResponseV2',
  full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.event_id', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_entries', full_name='dota.CMsgClientToGCRequestEventPointLogResponseV2.log_entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2_LOGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27541,
  serialized_end=27827,
)


_CMSGCLIENTTOGCPUBLISHUSERSTAT = _descriptor.Descriptor(
  name='CMsgClientToGCPublishUserStat',
  full_name='dota.CMsgClientToGCPublishUserStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_stats_event', full_name='dota.CMsgClientToGCPublishUserStat.user_stats_event', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_data', full_name='dota.CMsgClientToGCPublishUserStat.reference_data', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27829,
  serialized_end=27910,
)


_CMSGCLIENTTOGCADDTI6TREEPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCAddTI6TreeProgress',
  full_name='dota.CMsgClientToGCAddTI6TreeProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trees', full_name='dota.CMsgClientToGCAddTI6TreeProgress.trees', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27912,
  serialized_end=27961,
)


_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaPlaysRemaining',
  full_name='dota.CMsgClientToGCRequestLinaPlaysRemaining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestLinaPlaysRemaining.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27963,
  serialized_end=28051,
)


_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaPlaysRemainingResponse',
  full_name='dota.CMsgClientToGCRequestLinaPlaysRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plays_remaining', full_name='dota.CMsgClientToGCRequestLinaPlaysRemainingResponse.plays_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plays_total', full_name='dota.CMsgClientToGCRequestLinaPlaysRemainingResponse.plays_total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28053,
  serialized_end=28148,
)


_CMSGCLIENTTOGCREQUESTLINAGAMERESULT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaGameResult',
  full_name='dota.CMsgClientToGCRequestLinaGameResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestLinaGameResult.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot_chosen', full_name='dota.CMsgClientToGCRequestLinaGameResult.slot_chosen', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28150,
  serialized_end=28255,
)


_CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaGameResultResponse',
  full_name='dota.CMsgClientToGCRequestLinaGameResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestLinaGameResultResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28257,
  serialized_end=28318,
)


_CMSGCLIENTTOGCREQUESTSLARKGAMERESULT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestSlarkGameResult',
  full_name='dota.CMsgClientToGCRequestSlarkGameResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestSlarkGameResult.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot_chosen', full_name='dota.CMsgClientToGCRequestSlarkGameResult.slot_chosen', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='week', full_name='dota.CMsgClientToGCRequestSlarkGameResult.week', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28320,
  serialized_end=28440,
)


_CMSGCLIENTTOGCREQUESTSLARKGAMERESULTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestSlarkGameResultResponse',
  full_name='dota.CMsgClientToGCRequestSlarkGameResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points_won', full_name='dota.CMsgClientToGCRequestSlarkGameResultResponse.points_won', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aura_won', full_name='dota.CMsgClientToGCRequestSlarkGameResultResponse.aura_won', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28442,
  serialized_end=28526,
)


_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE = _descriptor.Descriptor(
  name='Challenge',
  full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.challenge_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_completed', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.time_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.attempts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template_id', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.template_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quest_rank', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.quest_rank', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_quest_rank', full_name='dota.CMsgGCToClientQuestProgressUpdated.Challenge.max_quest_rank', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28668,
  serialized_end=28825,
)

_CMSGGCTOCLIENTQUESTPROGRESSUPDATED = _descriptor.Descriptor(
  name='CMsgGCToClientQuestProgressUpdated',
  full_name='dota.CMsgGCToClientQuestProgressUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='dota.CMsgGCToClientQuestProgressUpdated.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_challenges', full_name='dota.CMsgGCToClientQuestProgressUpdated.completed_challenges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28529,
  serialized_end=28825,
)


_CMSGDOTAREDEEMITEM = _descriptor.Descriptor(
  name='CMsgDOTARedeemItem',
  full_name='dota.CMsgDOTARedeemItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='dota.CMsgDOTARedeemItem.currency_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_def', full_name='dota.CMsgDOTARedeemItem.purchase_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28827,
  serialized_end=28890,
)


_CMSGDOTAREDEEMITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARedeemItemResponse',
  full_name='dota.CMsgDOTARedeemItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgDOTARedeemItemResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28893,
  serialized_end=29044,
)


_CMSGPERFECTWORLDUSERLOOKUPREQUEST = _descriptor.Descriptor(
  name='CMsgPerfectWorldUserLookupRequest',
  full_name='dota.CMsgPerfectWorldUserLookupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_name', full_name='dota.CMsgPerfectWorldUserLookupRequest.user_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29046,
  serialized_end=29100,
)


_CMSGPERFECTWORLDUSERLOOKUPRESPONSE = _descriptor.Descriptor(
  name='CMsgPerfectWorldUserLookupResponse',
  full_name='dota.CMsgPerfectWorldUserLookupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_code', full_name='dota.CMsgPerfectWorldUserLookupResponse.result_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgPerfectWorldUserLookupResponse.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29103,
  serialized_end=29436,
)


_CMSGMAKEOFFERING = _descriptor.Descriptor(
  name='CMsgMakeOffering',
  full_name='dota.CMsgMakeOffering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgMakeOffering.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29438,
  serialized_end=29473,
)


_CMSGREQUESTOFFERINGS = _descriptor.Descriptor(
  name='CMsgRequestOfferings',
  full_name='dota.CMsgRequestOfferings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29475,
  serialized_end=29497,
)


_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING = _descriptor.Descriptor(
  name='NewYearsOffering',
  full_name='dota.CMsgRequestOfferingsResponse.NewYearsOffering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgRequestOfferingsResponse.NewYearsOffering.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgRequestOfferingsResponse.NewYearsOffering.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29623,
  serialized_end=29677,
)

_CMSGREQUESTOFFERINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgRequestOfferingsResponse',
  full_name='dota.CMsgRequestOfferingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offerings', full_name='dota.CMsgRequestOfferingsResponse.offerings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgRequestOfferingsResponse.completed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29500,
  serialized_end=29677,
)


_CMSGDOTAPCBANGTIMEDREWARD = _descriptor.Descriptor(
  name='CMsgDOTAPCBangTimedReward',
  full_name='dota.CMsgDOTAPCBangTimedReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona', full_name='dota.CMsgDOTAPCBangTimedReward.persona', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='itemdef', full_name='dota.CMsgDOTAPCBangTimedReward.itemdef', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pcbangname', full_name='dota.CMsgDOTAPCBangTimedReward.pcbangname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29679,
  serialized_end=29760,
)


_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT = _descriptor.Descriptor(
  name='PredictionResult',
  full_name='dota.CMsgDOTACompendiumInGamePredictionResults.PredictionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_id', full_name='dota.CMsgDOTACompendiumInGamePredictionResults.PredictionResult.prediction_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_value', full_name='dota.CMsgDOTACompendiumInGamePredictionResults.PredictionResult.prediction_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29938,
  serialized_end=30005,
)

_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS = _descriptor.Descriptor(
  name='CMsgDOTACompendiumInGamePredictionResults',
  full_name='dota.CMsgDOTACompendiumInGamePredictionResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='dota.CMsgDOTACompendiumInGamePredictionResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgDOTACompendiumInGamePredictionResults.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions_closed', full_name='dota.CMsgDOTACompendiumInGamePredictionResults.predictions_closed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29763,
  serialized_end=30005,
)


_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_id', full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction.prediction_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_value', full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction.prediction_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30181,
  serialized_end=30242,
)

_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION = _descriptor.Descriptor(
  name='CMsgClientToGCSelectCompendiumInGamePrediction',
  full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.predictions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgClientToGCSelectCompendiumInGamePrediction.league_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30008,
  serialized_end=30242,
)


_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSelectCompendiumInGamePredictionResponse',
  full_name='dota.CMsgClientToGCSelectCompendiumInGamePredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCSelectCompendiumInGamePredictionResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30245,
  serialized_end=30484,
)


_CMSGCLIENTTOGCOPENPLAYERCARDPACK = _descriptor.Descriptor(
  name='CMsgClientToGCOpenPlayerCardPack',
  full_name='dota.CMsgClientToGCOpenPlayerCardPack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_pack_item_id', full_name='dota.CMsgClientToGCOpenPlayerCardPack.player_card_pack_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30486,
  serialized_end=30554,
)


_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCOpenPlayerCardPackResponse',
  full_name='dota.CMsgClientToGCOpenPlayerCardPackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCOpenPlayerCardPackResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_card_item_ids', full_name='dota.CMsgClientToGCOpenPlayerCardPackResponse.player_card_item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30557,
  serialized_end=30844,
)


_CMSGCLIENTTOGCRECYCLEPLAYERCARD = _descriptor.Descriptor(
  name='CMsgClientToGCRecyclePlayerCard',
  full_name='dota.CMsgClientToGCRecyclePlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_item_ids', full_name='dota.CMsgClientToGCRecyclePlayerCard.player_card_item_ids', index=0,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRecyclePlayerCard.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30846,
  serialized_end=30927,
)


_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRecyclePlayerCardResponse',
  full_name='dota.CMsgClientToGCRecyclePlayerCardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRecyclePlayerCardResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dust_amount', full_name='dota.CMsgClientToGCRecyclePlayerCardResponse.dust_amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30930,
  serialized_end=31243,
)


_CMSGCLIENTTOGCCREATEPLAYERCARDPACK = _descriptor.Descriptor(
  name='CMsgClientToGCCreatePlayerCardPack',
  full_name='dota.CMsgClientToGCCreatePlayerCardPack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='card_dust_item_id', full_name='dota.CMsgClientToGCCreatePlayerCardPack.card_dust_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCreatePlayerCardPack.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='premium_pack', full_name='dota.CMsgClientToGCCreatePlayerCardPack.premium_pack', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31245,
  serialized_end=31348,
)


_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCreatePlayerCardPackResponse',
  full_name='dota.CMsgClientToGCCreatePlayerCardPackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCreatePlayerCardPackResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31351,
  serialized_end=31615,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES = _descriptor.Descriptor(
  name='Questlines',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onestar', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines.onestar', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twostar', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines.twostar', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threestar', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines.threestar', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Questlines.total', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32403,
  serialized_end=32497,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32499,
  serialized_end=32614,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32616,
  serialized_end=32680,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP = _descriptor.Descriptor(
  name='BattleCup',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.BattleCup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.BattleCup.wins', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.BattleCup.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32682,
  serialized_end=32722,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32724,
  serialized_end=32785,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32787,
  serialized_end=32829,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32831,
  serialized_end=32880,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32882,
  serialized_end=32941,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_International2016',
  full_name='dota.CMsgGCToClientBattlePassRollup_International2016',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='questlines', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.questlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battle_cup', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.battle_cup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.predictions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.bracket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.player_cards', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='dota.CMsgGCToClientBattlePassRollup_International2016.fantasy_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31618,
  serialized_end=32941,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_QUESTLINES = _descriptor.Descriptor(
  name='Questlines',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onestar', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines.onestar', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twostar', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines.twostar', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threestar', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines.threestar', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines.total', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32403,
  serialized_end=32497,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32499,
  serialized_end=32614,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32616,
  serialized_end=32680,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BATTLECUP = _descriptor.Descriptor(
  name='BattleCup',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.BattleCup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.BattleCup.wins', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.BattleCup.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32682,
  serialized_end=32722,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32724,
  serialized_end=32785,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32787,
  serialized_end=32829,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32831,
  serialized_end=32880,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32882,
  serialized_end=32941,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_Fall2016',
  full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='questlines', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.questlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battle_cup', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.battle_cup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.predictions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.bracket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.player_cards', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='dota.CMsgGCToClientBattlePassRollup_Fall2016.fantasy_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_QUESTLINES, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BATTLECUP, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32944,
  serialized_end=34186,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_QUESTLINES = _descriptor.Descriptor(
  name='Questlines',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onestar', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines.onestar', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twostar', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines.twostar', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threestar', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines.threestar', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines.total', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32403,
  serialized_end=32497,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32499,
  serialized_end=32614,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32616,
  serialized_end=32680,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BATTLECUP = _descriptor.Descriptor(
  name='BattleCup',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.BattleCup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.BattleCup.wins', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.BattleCup.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32682,
  serialized_end=32722,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32724,
  serialized_end=32785,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32787,
  serialized_end=32829,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32831,
  serialized_end=32880,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32882,
  serialized_end=32941,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_Winter2017',
  full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='questlines', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.questlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battle_cup', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.battle_cup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.predictions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.bracket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.player_cards', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='dota.CMsgGCToClientBattlePassRollup_Winter2017.fantasy_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_QUESTLINES, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BATTLECUP, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34189,
  serialized_end=35449,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_QUESTLINES = _descriptor.Descriptor(
  name='Questlines',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onestar', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines.onestar', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twostar', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines.twostar', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threestar', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines.threestar', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Questlines.total', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32403,
  serialized_end=32497,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32499,
  serialized_end=32614,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32616,
  serialized_end=32680,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BATTLECUP = _descriptor.Descriptor(
  name='BattleCup',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.BattleCup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wins', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.BattleCup.wins', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.BattleCup.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32682,
  serialized_end=32722,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32724,
  serialized_end=32785,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32787,
  serialized_end=32829,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32831,
  serialized_end=32880,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32882,
  serialized_end=32941,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_TI7',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI7',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='questlines', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.questlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battle_cup', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.battle_cup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.predictions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.bracket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.player_cards', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='dota.CMsgGCToClientBattlePassRollup_TI7.fantasy_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_QUESTLINES, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BATTLECUP, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35452,
  serialized_end=36649,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_CAVERNCRAWL = _descriptor.Descriptor(
  name='CavernCrawl',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rooms_cleared', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl.rooms_cleared', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carry_completed', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl.carry_completed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='support_completed', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl.support_completed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='utility_completed', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl.utility_completed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37242,
  serialized_end=37357,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32499,
  serialized_end=32614,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32616,
  serialized_end=32680,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32724,
  serialized_end=32785,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32787,
  serialized_end=32829,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32831,
  serialized_end=32880,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32882,
  serialized_end=32941,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_TI8',
  full_name='dota.CMsgGCToClientBattlePassRollup_TI8',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cavern_crawl', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.cavern_crawl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.predictions', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.bracket', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.player_cards', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='dota.CMsgGCToClientBattlePassRollup_TI8.fantasy_challenge', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_CAVERNCRAWL, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36652,
  serialized_end=37759,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupRequest',
  full_name='dota.CMsgGCToClientBattlePassRollupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientBattlePassRollupRequest.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollupRequest.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37761,
  serialized_end=37838,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupResponse',
  full_name='dota.CMsgGCToClientBattlePassRollupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_ti6', full_name='dota.CMsgGCToClientBattlePassRollupResponse.event_ti6', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_fall2016', full_name='dota.CMsgGCToClientBattlePassRollupResponse.event_fall2016', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_winter2017', full_name='dota.CMsgGCToClientBattlePassRollupResponse.event_winter2017', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_ti7', full_name='dota.CMsgGCToClientBattlePassRollupResponse.event_ti7', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_ti8', full_name='dota.CMsgGCToClientBattlePassRollupResponse.event_ti8', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37841,
  serialized_end=38224,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupListRequest',
  full_name='dota.CMsgGCToClientBattlePassRollupListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientBattlePassRollupListRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38226,
  serialized_end=38289,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE_EVENTINFO = _descriptor.Descriptor(
  name='EventInfo',
  full_name='dota.CMsgGCToClientBattlePassRollupListResponse.EventInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientBattlePassRollupListResponse.EventInfo.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='dota.CMsgGCToClientBattlePassRollupListResponse.EventInfo.level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38418,
  serialized_end=38462,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupListResponse',
  full_name='dota.CMsgGCToClientBattlePassRollupListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_info', full_name='dota.CMsgGCToClientBattlePassRollupListResponse.event_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE_EVENTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38292,
  serialized_end=38462,
)


_CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTransferSeasonalMMRRequest',
  full_name='dota.CMsgClientToGCTransferSeasonalMMRRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_party', full_name='dota.CMsgClientToGCTransferSeasonalMMRRequest.is_party', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38464,
  serialized_end=38524,
)


_CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCTransferSeasonalMMRResponse',
  full_name='dota.CMsgClientToGCTransferSeasonalMMRResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgClientToGCTransferSeasonalMMRResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38526,
  serialized_end=38586,
)


_CMSGGCTOCLIENTPLAYTESTSTATUS = _descriptor.Descriptor(
  name='CMsgGCToClientPlaytestStatus',
  full_name='dota.CMsgGCToClientPlaytestStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='dota.CMsgGCToClientPlaytestStatus.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38588,
  serialized_end=38634,
)


_CMSGCLIENTTOGCJOINPLAYTEST = _descriptor.Descriptor(
  name='CMsgClientToGCJoinPlaytest',
  full_name='dota.CMsgClientToGCJoinPlaytest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgClientToGCJoinPlaytest.client_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38636,
  serialized_end=38688,
)


_CMSGCLIENTTOGCJOINPLAYTESTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCJoinPlaytestResponse',
  full_name='dota.CMsgClientToGCJoinPlaytestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='dota.CMsgClientToGCJoinPlaytestResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38690,
  serialized_end=38741,
)


_CMSGDOTASETFAVORITETEAM = _descriptor.Descriptor(
  name='CMsgDOTASetFavoriteTeam',
  full_name='dota.CMsgDOTASetFavoriteTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTASetFavoriteTeam.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDOTASetFavoriteTeam.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38743,
  serialized_end=38803,
)


_CMSGDOTATRIVIAQUESTION = _descriptor.Descriptor(
  name='CMsgDOTATriviaQuestion',
  full_name='dota.CMsgDOTATriviaQuestion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='question_id', full_name='dota.CMsgDOTATriviaQuestion.question_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='dota.CMsgDOTATriviaQuestion.category', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgDOTATriviaQuestion.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='question_value', full_name='dota.CMsgDOTATriviaQuestion.question_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_values', full_name='dota.CMsgDOTATriviaQuestion.answer_values', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='correct_answer_index', full_name='dota.CMsgDOTATriviaQuestion.correct_answer_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38806,
  serialized_end=39043,
)


_CMSGDOTATRIVIACURRENTQUESTIONS = _descriptor.Descriptor(
  name='CMsgDOTATriviaCurrentQuestions',
  full_name='dota.CMsgDOTATriviaCurrentQuestions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='questions', full_name='dota.CMsgDOTATriviaCurrentQuestions.questions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trivia_enabled', full_name='dota.CMsgDOTATriviaCurrentQuestions.trivia_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39045,
  serialized_end=39150,
)


_CMSGDOTATRIVIAQUESTIONANSWERSSUMMARY = _descriptor.Descriptor(
  name='CMsgDOTATriviaQuestionAnswersSummary',
  full_name='dota.CMsgDOTATriviaQuestionAnswersSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary_available', full_name='dota.CMsgDOTATriviaQuestionAnswersSummary.summary_available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='picked_count', full_name='dota.CMsgDOTATriviaQuestionAnswersSummary.picked_count', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39152,
  serialized_end=39239,
)


_CMSGDOTASUBMITTRIVIAQUESTIONANSWER = _descriptor.Descriptor(
  name='CMsgDOTASubmitTriviaQuestionAnswer',
  full_name='dota.CMsgDOTASubmitTriviaQuestionAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='question_id', full_name='dota.CMsgDOTASubmitTriviaQuestionAnswer.question_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_index', full_name='dota.CMsgDOTASubmitTriviaQuestionAnswer.answer_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39241,
  serialized_end=39320,
)


_CMSGDOTASUBMITTRIVIAQUESTIONANSWERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASubmitTriviaQuestionAnswerResponse',
  full_name='dota.CMsgDOTASubmitTriviaQuestionAnswerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTASubmitTriviaQuestionAnswerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39322,
  serialized_end=39448,
)


_CMSGDOTASTARTTRIVIASESSION = _descriptor.Descriptor(
  name='CMsgDOTAStartTriviaSession',
  full_name='dota.CMsgDOTAStartTriviaSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39450,
  serialized_end=39478,
)


_CMSGDOTASTARTTRIVIASESSIONRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAStartTriviaSessionResponse',
  full_name='dota.CMsgDOTAStartTriviaSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trivia_enabled', full_name='dota.CMsgDOTAStartTriviaSessionResponse.trivia_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_timestamp', full_name='dota.CMsgDOTAStartTriviaSessionResponse.current_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39480,
  serialized_end=39567,
)


_CMSGCLIENTTOGCGIVETIP = _descriptor.Descriptor(
  name='CMsgClientToGCGiveTip',
  full_name='dota.CMsgClientToGCGiveTip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient_account_id', full_name='dota.CMsgClientToGCGiveTip.recipient_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCGiveTip.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCGiveTip.event_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39569,
  serialized_end=39658,
)


_CMSGCLIENTTOGCGIVETIPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGiveTipResponse',
  full_name='dota.CMsgClientToGCGiveTipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCGiveTipResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCGIVETIPRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39661,
  serialized_end=39993,
)


_CMSGDOTAANCHORPHONENUMBERREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAAnchorPhoneNumberRequest',
  full_name='dota.CMsgDOTAAnchorPhoneNumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39995,
  serialized_end=40029,
)


_CMSGDOTAANCHORPHONENUMBERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAAnchorPhoneNumberResponse',
  full_name='dota.CMsgDOTAAnchorPhoneNumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAAnchorPhoneNumberResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAANCHORPHONENUMBERRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40032,
  serialized_end=40261,
)


_CMSGDOTAUNANCHORPHONENUMBERREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAUnanchorPhoneNumberRequest',
  full_name='dota.CMsgDOTAUnanchorPhoneNumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40263,
  serialized_end=40299,
)


_CMSGDOTAUNANCHORPHONENUMBERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAUnanchorPhoneNumberResponse',
  full_name='dota.CMsgDOTAUnanchorPhoneNumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAUnanchorPhoneNumberResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAUNANCHORPHONENUMBERRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40302,
  serialized_end=40456,
)


_CMSGGCTOCLIENTTIPNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCToClientTipNotification',
  full_name='dota.CMsgGCToClientTipNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tipper_account_id', full_name='dota.CMsgGCToClientTipNotification.tipper_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tipper_name', full_name='dota.CMsgGCToClientTipNotification.tipper_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recipient_account_id', full_name='dota.CMsgGCToClientTipNotification.recipient_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recipient_name', full_name='dota.CMsgGCToClientTipNotification.recipient_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientTipNotification.event_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40459,
  serialized_end=40610,
)


_CMSGGCTOCLIENTCOMMENDNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCToClientCommendNotification',
  full_name='dota.CMsgGCToClientCommendNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commender_account_id', full_name='dota.CMsgGCToClientCommendNotification.commender_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commender_name', full_name='dota.CMsgGCToClientCommendNotification.commender_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='dota.CMsgGCToClientCommendNotification.flags', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40612,
  serialized_end=40716,
)


_CMSGGCTOCLIENTALLSTARVOTESREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientAllStarVotesRequest',
  full_name='dota.CMsgGCToClientAllStarVotesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientAllStarVotesRequest.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40718,
  serialized_end=40771,
)


_CMSGGCTOCLIENTALLSTARVOTESREPLY = _descriptor.Descriptor(
  name='CMsgGCToClientAllStarVotesReply',
  full_name='dota.CMsgGCToClientAllStarVotesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_account_ids', full_name='dota.CMsgGCToClientAllStarVotesReply.player_account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40773,
  serialized_end=40834,
)


_CMSGGCTOCLIENTALLSTARVOTESSUBMIT = _descriptor.Descriptor(
  name='CMsgGCToClientAllStarVotesSubmit',
  full_name='dota.CMsgGCToClientAllStarVotesSubmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientAllStarVotesSubmit.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_account_ids', full_name='dota.CMsgGCToClientAllStarVotesSubmit.player_account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40836,
  serialized_end=40916,
)


_CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY = _descriptor.Descriptor(
  name='CMsgGCToClientAllStarVotesSubmitReply',
  full_name='dota.CMsgGCToClientAllStarVotesSubmitReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCToClientAllStarVotesSubmitReply.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40919,
  serialized_end=41166,
)


_CMSGDOTACLIENTTOGCQUICKSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAClientToGCQuickStatsRequest',
  full_name='dota.CMsgDOTAClientToGCQuickStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='dota.CMsgDOTAClientToGCQuickStatsRequest.player_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgDOTAClientToGCQuickStatsRequest.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgDOTAClientToGCQuickStatsRequest.item_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgDOTAClientToGCQuickStatsRequest.league_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41168,
  serialized_end=41285,
)


_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS = _descriptor.Descriptor(
  name='SimpleStats',
  full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='win_percent', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats.win_percent', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pick_percent', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats.pick_percent', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_count', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats.win_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pick_count', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats.pick_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41876,
  serialized_end=41971,
)

_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAClientToGCQuickStatsResponse',
  full_name='dota.CMsgDOTAClientToGCQuickStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_request', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.original_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.hero_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.item_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_hero_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.item_hero_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_player_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.item_player_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_player_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.hero_player_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_set_stats', full_name='dota.CMsgDOTAClientToGCQuickStatsResponse.full_set_stats', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41288,
  serialized_end=41971,
)


_CMSGDOTASELECTIONPRIORITYCHOICEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTASelectionPriorityChoiceRequest',
  full_name='dota.CMsgDOTASelectionPriorityChoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='dota.CMsgDOTASelectionPriorityChoiceRequest.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41974,
  serialized_end=42104,
)


_CMSGDOTASELECTIONPRIORITYCHOICERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASelectionPriorityChoiceResponse',
  full_name='dota.CMsgDOTASelectionPriorityChoiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTASelectionPriorityChoiceResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTASELECTIONPRIORITYCHOICERESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42107,
  serialized_end=42269,
)


_CMSGDOTAGAMEAUTOGRAPHREWARD = _descriptor.Descriptor(
  name='CMsgDOTAGameAutographReward',
  full_name='dota.CMsgDOTAGameAutographReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='badge_id', full_name='dota.CMsgDOTAGameAutographReward.badge_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42271,
  serialized_end=42318,
)


_CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGameAutographRewardResponse',
  full_name='dota.CMsgDOTAGameAutographRewardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTAGameAutographRewardResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42321,
  serialized_end=42475,
)


_CMSGDOTADESTROYLOBBYREQUEST = _descriptor.Descriptor(
  name='CMsgDOTADestroyLobbyRequest',
  full_name='dota.CMsgDOTADestroyLobbyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42477,
  serialized_end=42506,
)


_CMSGDOTADESTROYLOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTADestroyLobbyResponse',
  full_name='dota.CMsgDOTADestroyLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDOTADestroyLobbyResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTADESTROYLOBBYRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42509,
  serialized_end=42649,
)


_CMSGDOTAGETRECENTPLAYTIMEFRIENDSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGetRecentPlayTimeFriendsRequest',
  full_name='dota.CMsgDOTAGetRecentPlayTimeFriendsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42651,
  serialized_end=42692,
)


_CMSGDOTAGETRECENTPLAYTIMEFRIENDSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetRecentPlayTimeFriendsResponse',
  full_name='dota.CMsgDOTAGetRecentPlayTimeFriendsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgDOTAGetRecentPlayTimeFriendsResponse.account_ids', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42694,
  serialized_end=42757,
)


_CMSGPURCHASEITEMWITHEVENTPOINTS = _descriptor.Descriptor(
  name='CMsgPurchaseItemWithEventPoints',
  full_name='dota.CMsgPurchaseItemWithEventPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgPurchaseItemWithEventPoints.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CMsgPurchaseItemWithEventPoints.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgPurchaseItemWithEventPoints.event_id', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_premium_points', full_name='dota.CMsgPurchaseItemWithEventPoints.use_premium_points', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42760,
  serialized_end=42904,
)


_CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE = _descriptor.Descriptor(
  name='CMsgPurchaseItemWithEventPointsResponse',
  full_name='dota.CMsgPurchaseItemWithEventPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgPurchaseItemWithEventPointsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42907,
  serialized_end=43275,
)


_CMSGGCREQUESTITEMRECOMMENDATIONS = _descriptor.Descriptor(
  name='CMsgGCRequestItemRecommendations',
  full_name='dota.CMsgGCRequestItemRecommendations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mmr', full_name='dota.CMsgGCRequestItemRecommendations.mmr', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCRequestItemRecommendations.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allied_hero_ids', full_name='dota.CMsgGCRequestItemRecommendations.allied_hero_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enemy_hero_ids', full_name='dota.CMsgGCRequestItemRecommendations.enemy_hero_ids', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inventory_items', full_name='dota.CMsgGCRequestItemRecommendations.inventory_items', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='dota.CMsgGCRequestItemRecommendations.game_time', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gold', full_name='dota.CMsgGCRequestItemRecommendations.gold', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_worth', full_name='dota.CMsgGCRequestItemRecommendations.net_worth', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43278,
  serialized_end=43468,
)


_CMSGGCREQUESTITEMRECOMMENDATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestItemRecommendationsResponse',
  full_name='dota.CMsgGCRequestItemRecommendationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_item_ids', full_name='dota.CMsgGCRequestItemRecommendationsResponse.recommended_item_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43470,
  serialized_end=43542,
)


_CMSGGCREQUESTSKILLUPRECOMMENDATIONS = _descriptor.Descriptor(
  name='CMsgGCRequestSkillUpRecommendations',
  full_name='dota.CMsgGCRequestSkillUpRecommendations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mmr', full_name='dota.CMsgGCRequestSkillUpRecommendations.mmr', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgGCRequestSkillUpRecommendations.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allied_hero_ids', full_name='dota.CMsgGCRequestSkillUpRecommendations.allied_hero_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enemy_hero_ids', full_name='dota.CMsgGCRequestSkillUpRecommendations.enemy_hero_ids', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ability_ids', full_name='dota.CMsgGCRequestSkillUpRecommendations.ability_ids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43545,
  serialized_end=43682,
)


_CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE_ABILITYSELECTION = _descriptor.Descriptor(
  name='AbilitySelection',
  full_name='dota.CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ability_id', full_name='dota.CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection.ability_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='dota.CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection.weight', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43819,
  serialized_end=43873,
)

_CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestSkillUpRecommendationsResponse',
  full_name='dota.CMsgGCRequestSkillUpRecommendationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='abilities', full_name='dota.CMsgGCRequestSkillUpRecommendationsResponse.abilities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE_ABILITYSELECTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43685,
  serialized_end=43873,
)


_CMSGCLIENTTOGCRECYCLEHERORELIC = _descriptor.Descriptor(
  name='CMsgClientToGCRecycleHeroRelic',
  full_name='dota.CMsgClientToGCRecycleHeroRelic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='dota.CMsgClientToGCRecycleHeroRelic.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43875,
  serialized_end=43925,
)


_CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRecycleHeroRelicResponse',
  full_name='dota.CMsgClientToGCRecycleHeroRelicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRecycleHeroRelicResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dust_amount', full_name='dota.CMsgClientToGCRecycleHeroRelicResponse.dust_amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43928,
  serialized_end=44213,
)


_CMSGPURCHASEHERORELIC = _descriptor.Descriptor(
  name='CMsgPurchaseHeroRelic',
  full_name='dota.CMsgPurchaseHeroRelic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgPurchaseHeroRelic.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kill_eater_type', full_name='dota.CMsgPurchaseHeroRelic.kill_eater_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44215,
  serialized_end=44280,
)


_CMSGPURCHASEHERORELICRESPONSE = _descriptor.Descriptor(
  name='CMsgPurchaseHeroRelicResponse',
  full_name='dota.CMsgPurchaseHeroRelicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgPurchaseHeroRelicResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44282,
  serialized_end=44397,
)


_CMSGPURCHASEHERORANDOMRELIC = _descriptor.Descriptor(
  name='CMsgPurchaseHeroRandomRelic',
  full_name='dota.CMsgPurchaseHeroRandomRelic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgPurchaseHeroRandomRelic.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44399,
  serialized_end=44445,
)


_CMSGPURCHASEHERORANDOMRELICRESPONSE = _descriptor.Descriptor(
  name='CMsgPurchaseHeroRandomRelicResponse',
  full_name='dota.CMsgPurchaseHeroRandomRelicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgPurchaseHeroRandomRelicResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kill_eater_type', full_name='dota.CMsgPurchaseHeroRandomRelicResponse.kill_eater_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44448,
  serialized_end=44594,
)


_CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlusWeeklyChallengeResult',
  full_name='dota.CMsgClientToGCRequestPlusWeeklyChallengeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCRequestPlusWeeklyChallengeResult.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='week', full_name='dota.CMsgClientToGCRequestPlusWeeklyChallengeResult.week', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44596,
  serialized_end=44705,
)


_CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlusWeeklyChallengeResultResponse',
  full_name='dota.CMsgClientToGCRequestPlusWeeklyChallengeResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44707,
  serialized_end=44763,
)


_CMSGPROFILEREQUEST = _descriptor.Descriptor(
  name='CMsgProfileRequest',
  full_name='dota.CMsgProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgProfileRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44765,
  serialized_end=44805,
)


_CMSGPROFILERESPONSE_FEATUREDHERO = _descriptor.Descriptor(
  name='FeaturedHero',
  full_name='dota.CMsgProfileResponse.FeaturedHero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgProfileResponse.FeaturedHero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equipped_econ_items', full_name='dota.CMsgProfileResponse.FeaturedHero.equipped_econ_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manually_set', full_name='dota.CMsgProfileResponse.FeaturedHero.manually_set', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plus_hero_xp', full_name='dota.CMsgProfileResponse.FeaturedHero.plus_hero_xp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plus_hero_relics_item', full_name='dota.CMsgProfileResponse.FeaturedHero.plus_hero_relics_item', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45183,
  serialized_end=45356,
)

_CMSGPROFILERESPONSE_MATCHINFO = _descriptor.Descriptor(
  name='MatchInfo',
  full_name='dota.CMsgProfileResponse.MatchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgProfileResponse.MatchInfo.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_timestamp', full_name='dota.CMsgProfileResponse.MatchInfo.match_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance_rating', full_name='dota.CMsgProfileResponse.MatchInfo.performance_rating', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgProfileResponse.MatchInfo.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='won_match', full_name='dota.CMsgProfileResponse.MatchInfo.won_match', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45358,
  serialized_end=45476,
)

_CMSGPROFILERESPONSE = _descriptor.Descriptor(
  name='CMsgProfileResponse',
  full_name='dota.CMsgProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='background_item', full_name='dota.CMsgProfileResponse.background_item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featured_heroes', full_name='dota.CMsgProfileResponse.featured_heroes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recent_matches', full_name='dota.CMsgProfileResponse.recent_matches', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='successful_heroes', full_name='dota.CMsgProfileResponse.successful_heroes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recent_match_details', full_name='dota.CMsgProfileResponse.recent_match_details', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgProfileResponse.result', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPROFILERESPONSE_FEATUREDHERO, _CMSGPROFILERESPONSE_MATCHINFO, ],
  enum_types=[
    _CMSGPROFILERESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44808,
  serialized_end=45560,
)


_CMSGPROFILEUPDATE = _descriptor.Descriptor(
  name='CMsgProfileUpdate',
  full_name='dota.CMsgProfileUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='background_item_id', full_name='dota.CMsgProfileUpdate.background_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featured_hero_ids', full_name='dota.CMsgProfileUpdate.featured_hero_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45562,
  serialized_end=45636,
)


_CMSGPROFILEUPDATERESPONSE = _descriptor.Descriptor(
  name='CMsgProfileUpdateResponse',
  full_name='dota.CMsgProfileUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgProfileUpdateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGPROFILEUPDATERESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45639,
  serialized_end=45767,
)


_CMSGTALENTWINRATES = _descriptor.Descriptor(
  name='CMsgTalentWinRates',
  full_name='dota.CMsgTalentWinRates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_run', full_name='dota.CMsgTalentWinRates.last_run', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ability_id', full_name='dota.CMsgTalentWinRates.ability_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_count', full_name='dota.CMsgTalentWinRates.game_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_count', full_name='dota.CMsgTalentWinRates.win_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45769,
  serialized_end=45866,
)


_CMSGGLOBALHEROAVERAGES = _descriptor.Descriptor(
  name='CMsgGlobalHeroAverages',
  full_name='dota.CMsgGlobalHeroAverages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_run', full_name='dota.CMsgGlobalHeroAverages.last_run', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_gold_per_min', full_name='dota.CMsgGlobalHeroAverages.avg_gold_per_min', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_xp_per_min', full_name='dota.CMsgGlobalHeroAverages.avg_xp_per_min', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_kills', full_name='dota.CMsgGlobalHeroAverages.avg_kills', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_deaths', full_name='dota.CMsgGlobalHeroAverages.avg_deaths', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_assists', full_name='dota.CMsgGlobalHeroAverages.avg_assists', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_last_hits', full_name='dota.CMsgGlobalHeroAverages.avg_last_hits', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_denies', full_name='dota.CMsgGlobalHeroAverages.avg_denies', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_net_worth', full_name='dota.CMsgGlobalHeroAverages.avg_net_worth', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45869,
  serialized_end=46087,
)


_CMSGHEROGLOBALDATAREQUEST = _descriptor.Descriptor(
  name='CMsgHeroGlobalDataRequest',
  full_name='dota.CMsgHeroGlobalDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgHeroGlobalDataRequest.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46089,
  serialized_end=46133,
)


_CMSGHEROGLOBALDATARESPONSE_GRAPHDATA = _descriptor.Descriptor(
  name='GraphData',
  full_name='dota.CMsgHeroGlobalDataResponse.GraphData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='day', full_name='dota.CMsgHeroGlobalDataResponse.GraphData.day', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_percent', full_name='dota.CMsgHeroGlobalDataResponse.GraphData.win_percent', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pick_percent', full_name='dota.CMsgHeroGlobalDataResponse.GraphData.pick_percent', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ban_percent', full_name='dota.CMsgHeroGlobalDataResponse.GraphData.ban_percent', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46267,
  serialized_end=46355,
)

_CMSGHEROGLOBALDATARESPONSE_WEEKDATA = _descriptor.Descriptor(
  name='WeekData',
  full_name='dota.CMsgHeroGlobalDataResponse.WeekData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='week', full_name='dota.CMsgHeroGlobalDataResponse.WeekData.week', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_percent', full_name='dota.CMsgHeroGlobalDataResponse.WeekData.win_percent', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pick_percent', full_name='dota.CMsgHeroGlobalDataResponse.WeekData.pick_percent', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ban_percent', full_name='dota.CMsgHeroGlobalDataResponse.WeekData.ban_percent', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46357,
  serialized_end=46445,
)

_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK = _descriptor.Descriptor(
  name='HeroDataPerRankChunk',
  full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank_chunk', full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk.rank_chunk', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='talent_win_rates', full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk.talent_win_rates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_averages', full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk.hero_averages', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_data', full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk.graph_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='week_data', full_name='dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk.week_data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46448,
  serialized_end=46721,
)

_CMSGHEROGLOBALDATARESPONSE = _descriptor.Descriptor(
  name='CMsgHeroGlobalDataResponse',
  full_name='dota.CMsgHeroGlobalDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgHeroGlobalDataResponse.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_data_per_chunk', full_name='dota.CMsgHeroGlobalDataResponse.hero_data_per_chunk', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGHEROGLOBALDATARESPONSE_GRAPHDATA, _CMSGHEROGLOBALDATARESPONSE_WEEKDATA, _CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46136,
  serialized_end=46721,
)


_CMSGHEROGLOBALDATAALLHEROES = _descriptor.Descriptor(
  name='CMsgHeroGlobalDataAllHeroes',
  full_name='dota.CMsgHeroGlobalDataAllHeroes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heroes', full_name='dota.CMsgHeroGlobalDataAllHeroes.heroes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46723,
  serialized_end=46802,
)


_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_HERODATA = _descriptor.Descriptor(
  name='HeroData',
  full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_rate', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData.win_rate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_other_hero_id', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData.first_other_hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ally_win_rate', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData.ally_win_rate', index=3,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enemy_win_rate', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData.enemy_win_rate', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46938,
  serialized_end=47059,
)

_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA = _descriptor.Descriptor(
  name='RankedHeroData',
  full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData.rank', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_data', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData.hero_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47061,
  serialized_end=47167,
)

_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES = _descriptor.Descriptor(
  name='CMsgHeroGlobalDataHeroesAlliesAndEnemies',
  full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranked_hero_data', full_name='dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.ranked_hero_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_HERODATA, _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46805,
  serialized_end=47167,
)


_CMSGPRIVATEMETADATAKEYREQUEST = _descriptor.Descriptor(
  name='CMsgPrivateMetadataKeyRequest',
  full_name='dota.CMsgPrivateMetadataKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgPrivateMetadataKeyRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47169,
  serialized_end=47218,
)


_CMSGPRIVATEMETADATAKEYRESPONSE = _descriptor.Descriptor(
  name='CMsgPrivateMetadataKeyResponse',
  full_name='dota.CMsgPrivateMetadataKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_key', full_name='dota.CMsgPrivateMetadataKeyResponse.private_key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47220,
  serialized_end=47273,
)


_CMSGACTIVATEPLUSFREETRIALREQUEST = _descriptor.Descriptor(
  name='CMsgActivatePlusFreeTrialRequest',
  full_name='dota.CMsgActivatePlusFreeTrialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47275,
  serialized_end=47309,
)


_CMSGACTIVATEPLUSFREETRIALRESPONSE = _descriptor.Descriptor(
  name='CMsgActivatePlusFreeTrialResponse',
  full_name='dota.CMsgActivatePlusFreeTrialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgActivatePlusFreeTrialResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGACTIVATEPLUSFREETRIALRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47312,
  serialized_end=47558,
)


_CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED_COMPLETEDPATHINFO = _descriptor.Descriptor(
  name='CompletedPathInfo',
  full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_id_completed', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo.path_id_completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='received_ultra_rare_reward', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo.received_ultra_rare_reward', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='half_completed', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo.half_completed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47743,
  serialized_end=47849,
)

_CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED = _descriptor.Descriptor(
  name='CMsgGCToClientCavernCrawlMapPathCompleted',
  full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id_completed', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.hero_id_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_paths', full_name='dota.CMsgGCToClientCavernCrawlMapPathCompleted.completed_paths', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED_COMPLETEDPATHINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47561,
  serialized_end=47849,
)


_CMSGGCTOCLIENTCAVERNCRAWLMAPUPDATED = _descriptor.Descriptor(
  name='CMsgGCToClientCavernCrawlMapUpdated',
  full_name='dota.CMsgGCToClientCavernCrawlMapUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgGCToClientCavernCrawlMapUpdated.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47851,
  serialized_end=47906,
)


_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOM = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlClaimRoom',
  full_name='dota.CMsgClientToGCCavernCrawlClaimRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCavernCrawlClaimRoom.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='dota.CMsgClientToGCCavernCrawlClaimRoom.room_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47908,
  serialized_end=47979,
)


_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlClaimRoomResponse',
  full_name='dota.CMsgClientToGCCavernCrawlClaimRoomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCavernCrawlClaimRoomResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47982,
  serialized_end=48182,
)


_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOM = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlUseItemOnRoom',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoom.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoom.room_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_type', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoom.item_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48184,
  serialized_end=48278,
)


_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlUseItemOnRoomResponse',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnRoomResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48281,
  serialized_end=48489,
)


_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATH = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlUseItemOnPath',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPath.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_id', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPath.path_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_type', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPath.item_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48491,
  serialized_end=48585,
)


_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlUseItemOnPathResponse',
  full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPathResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCavernCrawlUseItemOnPathResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48588,
  serialized_end=48796,
)


_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlRequestMapState',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCavernCrawlRequestMapState.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48798,
  serialized_end=48858,
)


_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_SWAPPEDCHALLENGE = _descriptor.Descriptor(
  name='SwappedChallenge',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_id_1', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge.path_id_1', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_id_2', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge.path_id_2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49662,
  serialized_end=49718,
)

_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_INVENTORYITEM = _descriptor.Descriptor(
  name='InventoryItem',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_type', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem.item_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49720,
  serialized_end=49769,
)

_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_TREASUREMAP = _descriptor.Descriptor(
  name='TreasureMap',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_room_id', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap.map_room_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revealed_room_id', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap.revealed_room_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49771,
  serialized_end=49831,
)

_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlRequestMapStateResponse',
  full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='claimed_rooms_1', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.claimed_rooms_1', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='claimed_rooms_2', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.claimed_rooms_2', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revealed_rooms_1', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.revealed_rooms_1', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revealed_rooms_2', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.revealed_rooms_2', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_paths_1', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.completed_paths_1', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_paths_2', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.completed_paths_2', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_paths_3', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.completed_paths_3', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_paths_4', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.completed_paths_4', index=8,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='half_completed_paths_1', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.half_completed_paths_1', index=9,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='half_completed_paths_2', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.half_completed_paths_2', index=10,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='half_completed_paths_3', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.half_completed_paths_3', index=11,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='half_completed_paths_4', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.half_completed_paths_4', index=12,
      number=16, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swapped_challenge', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.swapped_challenge', index=13,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inventory_item', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.inventory_item', index=14,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ultra_rare_reward_room_number', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.ultra_rare_reward_room_number', index=15,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='treasure_map', full_name='dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.treasure_map', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_SWAPPEDCHALLENGE, _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_INVENTORYITEM, _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_TREASUREMAP, ],
  enum_types=[
    _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48861,
  serialized_end=49894,
)


_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNT = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlGetClaimedRoomCount',
  full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCount.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49896,
  serialized_end=49960,
)


_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse',
  full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49963,
  serialized_end=50187,
)


_CMSGDOTAMUTATIONLIST_MUTATION = _descriptor.Descriptor(
  name='Mutation',
  full_name='dota.CMsgDOTAMutationList.Mutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgDOTAMutationList.Mutation.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgDOTAMutationList.Mutation.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='dota.CMsgDOTAMutationList.Mutation.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50270,
  serialized_end=50327,
)

_CMSGDOTAMUTATIONLIST = _descriptor.Descriptor(
  name='CMsgDOTAMutationList',
  full_name='dota.CMsgDOTAMutationList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mutations', full_name='dota.CMsgDOTAMutationList.mutations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMUTATIONLIST_MUTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50190,
  serialized_end=50327,
)


_CMSGEVENTTIPSSUMMARYREQUEST = _descriptor.Descriptor(
  name='CMsgEventTipsSummaryRequest',
  full_name='dota.CMsgEventTipsSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgEventTipsSummaryRequest.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgEventTipsSummaryRequest.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50329,
  serialized_end=50425,
)


_CMSGEVENTTIPSSUMMARYRESPONSE_TIPPER = _descriptor.Descriptor(
  name='Tipper',
  full_name='dota.CMsgEventTipsSummaryResponse.Tipper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tipper_account_id', full_name='dota.CMsgEventTipsSummaryResponse.Tipper.tipper_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tip_count', full_name='dota.CMsgEventTipsSummaryResponse.Tipper.tip_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50542,
  serialized_end=50599,
)

_CMSGEVENTTIPSSUMMARYRESPONSE = _descriptor.Descriptor(
  name='CMsgEventTipsSummaryResponse',
  full_name='dota.CMsgEventTipsSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgEventTipsSummaryResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tips_received', full_name='dota.CMsgEventTipsSummaryResponse.tips_received', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGEVENTTIPSSUMMARYRESPONSE_TIPPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50428,
  serialized_end=50599,
)


_CMSGSOCIALFEEDREQUEST = _descriptor.Descriptor(
  name='CMsgSocialFeedRequest',
  full_name='dota.CMsgSocialFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgSocialFeedRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='self_only', full_name='dota.CMsgSocialFeedRequest.self_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50601,
  serialized_end=50663,
)


_CMSGSOCIALFEEDRESPONSE_FEEDEVENT = _descriptor.Descriptor(
  name='FeedEvent',
  full_name='dota.CMsgSocialFeedResponse.FeedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_event_id', full_name='dota.CMsgSocialFeedResponse.FeedEvent.feed_event_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgSocialFeedResponse.FeedEvent.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgSocialFeedResponse.FeedEvent.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_count', full_name='dota.CMsgSocialFeedResponse.FeedEvent.comment_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='dota.CMsgSocialFeedResponse.FeedEvent.event_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_sub_type', full_name='dota.CMsgSocialFeedResponse.FeedEvent.event_sub_type', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_big_int_1', full_name='dota.CMsgSocialFeedResponse.FeedEvent.param_big_int_1', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_int_1', full_name='dota.CMsgSocialFeedResponse.FeedEvent.param_int_1', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_int_2', full_name='dota.CMsgSocialFeedResponse.FeedEvent.param_int_2', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_int_3', full_name='dota.CMsgSocialFeedResponse.FeedEvent.param_int_3', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_string', full_name='dota.CMsgSocialFeedResponse.FeedEvent.param_string', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50816,
  serialized_end=51066,
)

_CMSGSOCIALFEEDRESPONSE = _descriptor.Descriptor(
  name='CMsgSocialFeedResponse',
  full_name='dota.CMsgSocialFeedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgSocialFeedResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_events', full_name='dota.CMsgSocialFeedResponse.feed_events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOCIALFEEDRESPONSE_FEEDEVENT, ],
  enum_types=[
    _CMSGSOCIALFEEDRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50666,
  serialized_end=51238,
)


_CMSGSOCIALFEEDCOMMENTSREQUEST = _descriptor.Descriptor(
  name='CMsgSocialFeedCommentsRequest',
  full_name='dota.CMsgSocialFeedCommentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_event_id', full_name='dota.CMsgSocialFeedCommentsRequest.feed_event_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51240,
  serialized_end=51294,
)


_CMSGSOCIALFEEDCOMMENTSRESPONSE_FEEDCOMMENT = _descriptor.Descriptor(
  name='FeedComment',
  full_name='dota.CMsgSocialFeedCommentsResponse.FeedComment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commenter_account_id', full_name='dota.CMsgSocialFeedCommentsResponse.FeedComment.commenter_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgSocialFeedCommentsResponse.FeedComment.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_text', full_name='dota.CMsgSocialFeedCommentsResponse.FeedComment.comment_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51474,
  serialized_end=51558,
)

_CMSGSOCIALFEEDCOMMENTSRESPONSE = _descriptor.Descriptor(
  name='CMsgSocialFeedCommentsResponse',
  full_name='dota.CMsgSocialFeedCommentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgSocialFeedCommentsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_comments', full_name='dota.CMsgSocialFeedCommentsResponse.feed_comments', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOCIALFEEDCOMMENTSRESPONSE_FEEDCOMMENT, ],
  enum_types=[
    _CMSGSOCIALFEEDCOMMENTSRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51297,
  serialized_end=51640,
)


_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASEREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCPlayerCardSpecificPurchaseRequest',
  full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseRequest.player_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseRequest.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='card_dust_item_id', full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseRequest.card_dust_item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51642,
  serialized_end=51763,
)


_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCPlayerCardSpecificPurchaseResponse',
  full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51766,
  serialized_end=52059,
)


_CMSGCLIENTTOGCREQUESTCONTESTVOTES = _descriptor.Descriptor(
  name='CMsgClientToGCRequestContestVotes',
  full_name='dota.CMsgClientToGCRequestContestVotes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='dota.CMsgClientToGCRequestContestVotes.contest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52061,
  serialized_end=52116,
)


_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ITEMVOTE = _descriptor.Descriptor(
  name='ItemVote',
  full_name='dota.CMsgClientToGCRequestContestVotesResponse.ItemVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_item_id', full_name='dota.CMsgClientToGCRequestContestVotesResponse.ItemVote.contest_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgClientToGCRequestContestVotesResponse.ItemVote.vote', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52330,
  serialized_end=52379,
)

_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestContestVotesResponse',
  full_name='dota.CMsgClientToGCRequestContestVotesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestContestVotesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='votes', full_name='dota.CMsgClientToGCRequestContestVotesResponse.votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ITEMVOTE, ],
  enum_types=[
    _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52119,
  serialized_end=52463,
)


_CMSGCLIENTTOGCRECORDCONTESTVOTE = _descriptor.Descriptor(
  name='CMsgClientToGCRecordContestVote',
  full_name='dota.CMsgClientToGCRecordContestVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='dota.CMsgClientToGCRecordContestVote.contest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contest_item_id', full_name='dota.CMsgClientToGCRecordContestVote.contest_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='dota.CMsgClientToGCRecordContestVote.vote', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52465,
  serialized_end=52557,
)


_CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientRecordContestVoteResponse',
  full_name='dota.CMsgGCToClientRecordContestVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgGCToClientRecordContestVoteResponse.eresult', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE_ERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52560,
  serialized_end=52844,
)


_CMSGDOTADPCFEED_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='dota.CMsgDOTADPCFeed.Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgDOTADPCFeed.Element.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgDOTADPCFeed.Element.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='dota.CMsgDOTADPCFeed.Element.series_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgDOTADPCFeed.Element.match_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgDOTADPCFeed.Element.team_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgDOTADPCFeed.Element.account_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CMsgDOTADPCFeed.Element.league_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='dota.CMsgDOTADPCFeed.Element.node_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='dota.CMsgDOTADPCFeed.Element.server_steam_id', index=8,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_1', full_name='dota.CMsgDOTADPCFeed.Element.data_1', index=9,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_2', full_name='dota.CMsgDOTADPCFeed.Element.data_2', index=10,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_3', full_name='dota.CMsgDOTADPCFeed.Element.data_3', index=11,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_4', full_name='dota.CMsgDOTADPCFeed.Element.data_4', index=12,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52916,
  serialized_end=53217,
)

_CMSGDOTADPCFEED = _descriptor.Descriptor(
  name='CMsgDOTADPCFeed',
  full_name='dota.CMsgDOTADPCFeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='dota.CMsgDOTADPCFeed.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTADPCFEED_ELEMENT, ],
  enum_types=[
    _CMSGDOTADPCFEED_EFEEDELEMENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52847,
  serialized_end=53615,
)


_CMSGDOTADPCUSERINFO = _descriptor.Descriptor(
  name='CMsgDOTADPCUserInfo',
  full_name='dota.CMsgDOTADPCUserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_plus_subscriber', full_name='dota.CMsgDOTADPCUserInfo.is_plus_subscriber', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53617,
  serialized_end=53666,
)


_CMSGDEVGRANTEVENTPOINTS = _descriptor.Descriptor(
  name='CMsgDevGrantEventPoints',
  full_name='dota.CMsgDevGrantEventPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDevGrantEventPoints.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='dota.CMsgDevGrantEventPoints.event_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='premium_points', full_name='dota.CMsgDevGrantEventPoints.premium_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53668,
  serialized_end=53786,
)


_CMSGDEVGRANTEVENTPOINTSRESPONSE = _descriptor.Descriptor(
  name='CMsgDevGrantEventPointsResponse',
  full_name='dota.CMsgDevGrantEventPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDevGrantEventPointsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53788,
  serialized_end=53901,
)


_CMSGDEVGRANTEVENTACTION = _descriptor.Descriptor(
  name='CMsgDevGrantEventAction',
  full_name='dota.CMsgDevGrantEventAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDevGrantEventAction.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='dota.CMsgDevGrantEventAction.action_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_score', full_name='dota.CMsgDevGrantEventAction.action_score', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53903,
  serialized_end=54016,
)


_CMSGDEVGRANTEVENTACTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgDevGrantEventActionResponse',
  full_name='dota.CMsgDevGrantEventActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDevGrantEventActionResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54018,
  serialized_end=54131,
)


_CMSGDEVRESETEVENTSTATE = _descriptor.Descriptor(
  name='CMsgDevResetEventState',
  full_name='dota.CMsgDevResetEventState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgDevResetEventState.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_audit', full_name='dota.CMsgDevResetEventState.remove_audit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54133,
  serialized_end=54226,
)


_CMSGDEVRESETEVENTSTATERESPONSE = _descriptor.Descriptor(
  name='CMsgDevResetEventStateResponse',
  full_name='dota.CMsgDevResetEventStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgDevResetEventStateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54228,
  serialized_end=54340,
)


_CMSGCONSUMEEVENTSUPPORTGRANTITEM = _descriptor.Descriptor(
  name='CMsgConsumeEventSupportGrantItem',
  full_name='dota.CMsgConsumeEventSupportGrantItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgConsumeEventSupportGrantItem.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54342,
  serialized_end=54393,
)


_CMSGCONSUMEEVENTSUPPORTGRANTITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgConsumeEventSupportGrantItemResponse',
  full_name='dota.CMsgConsumeEventSupportGrantItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgConsumeEventSupportGrantItemResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54396,
  serialized_end=54526,
)


_CMSGCLIENTTOGCGETFILTEREDPLAYERS = _descriptor.Descriptor(
  name='CMsgClientToGCGetFilteredPlayers',
  full_name='dota.CMsgClientToGCGetFilteredPlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54528,
  serialized_end=54562,
)


_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_CFILTERENTRY = _descriptor.Descriptor(
  name='CFilterEntry',
  full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry.account_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_added', full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry.time_added', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry.time_expires', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54776,
  serialized_end=54852,
)

_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientGetFilteredPlayersResponse',
  full_name='dota.CMsgGCToClientGetFilteredPlayersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filtered_players', full_name='dota.CMsgGCToClientGetFilteredPlayersResponse.filtered_players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_CFILTERENTRY, ],
  enum_types=[
    _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54565,
  serialized_end=54888,
)


_CMSGCLIENTTOGCREMOVEFILTEREDPLAYER = _descriptor.Descriptor(
  name='CMsgClientToGCRemoveFilteredPlayer',
  full_name='dota.CMsgClientToGCRemoveFilteredPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id_to_remove', full_name='dota.CMsgClientToGCRemoveFilteredPlayer.account_id_to_remove', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54890,
  serialized_end=54956,
)


_CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientRemoveFilteredPlayerResponse',
  full_name='dota.CMsgGCToClientRemoveFilteredPlayerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCToClientRemoveFilteredPlayerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54959,
  serialized_end=55121,
)


_CMSGPARTYSEARCHPLAYER = _descriptor.Descriptor(
  name='CMsgPartySearchPlayer',
  full_name='dota.CMsgPartySearchPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgPartySearchPlayer.account_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgPartySearchPlayer.match_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_time', full_name='dota.CMsgPartySearchPlayer.creation_time', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55123,
  serialized_end=55207,
)


_CMSGGCTOCLIENTPLAYERBEACONSTATE = _descriptor.Descriptor(
  name='CMsgGCToClientPlayerBeaconState',
  full_name='dota.CMsgGCToClientPlayerBeaconState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_active_beacons', full_name='dota.CMsgGCToClientPlayerBeaconState.num_active_beacons', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55209,
  serialized_end=55270,
)


_CMSGGCTOCLIENTPARTYBEACONUPDATE = _descriptor.Descriptor(
  name='CMsgGCToClientPartyBeaconUpdate',
  full_name='dota.CMsgGCToClientPartyBeaconUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_added', full_name='dota.CMsgGCToClientPartyBeaconUpdate.beacon_added', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beacon_type', full_name='dota.CMsgGCToClientPartyBeaconUpdate.beacon_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientPartyBeaconUpdate.account_id', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55272,
  serialized_end=55368,
)


_CMSGCLIENTTOGCUPDATEPARTYBEACON = _descriptor.Descriptor(
  name='CMsgClientToGCUpdatePartyBeacon',
  full_name='dota.CMsgClientToGCUpdatePartyBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='dota.CMsgClientToGCUpdatePartyBeacon.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCUPDATEPARTYBEACON_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55370,
  serialized_end=55496,
)


_CMSGCLIENTTOGCREQUESTACTIVEBEACONPARTIES = _descriptor.Descriptor(
  name='CMsgClientToGCRequestActiveBeaconParties',
  full_name='dota.CMsgClientToGCRequestActiveBeaconParties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55498,
  serialized_end=55540,
)


_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientRequestActiveBeaconPartiesResponse',
  full_name='dota.CMsgGCToClientRequestActiveBeaconPartiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgGCToClientRequestActiveBeaconPartiesResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_parties', full_name='dota.CMsgGCToClientRequestActiveBeaconPartiesResponse.active_parties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55543,
  serialized_end=55790,
)


_CMSGCLIENTTOGCJOINPARTYFROMBEACON = _descriptor.Descriptor(
  name='CMsgClientToGCJoinPartyFromBeacon',
  full_name='dota.CMsgClientToGCJoinPartyFromBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='dota.CMsgClientToGCJoinPartyFromBeacon.party_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCJoinPartyFromBeacon.account_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beacon_type', full_name='dota.CMsgClientToGCJoinPartyFromBeacon.beacon_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55792,
  serialized_end=55886,
)


_CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientJoinPartyFromBeaconResponse',
  full_name='dota.CMsgGCToClientJoinPartyFromBeaconResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgGCToClientJoinPartyFromBeaconResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55889,
  serialized_end=56083,
)


_CMSGCLIENTTOGCMANAGEFAVORITES = _descriptor.Descriptor(
  name='CMsgClientToGCManageFavorites',
  full_name='dota.CMsgClientToGCManageFavorites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='dota.CMsgClientToGCManageFavorites.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCManageFavorites.account_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='favorite_name', full_name='dota.CMsgClientToGCManageFavorites.favorite_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invite_response', full_name='dota.CMsgClientToGCManageFavorites.invite_response', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_friendlist', full_name='dota.CMsgClientToGCManageFavorites.from_friendlist', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgClientToGCManageFavorites.lobby_id', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCMANAGEFAVORITES_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56086,
  serialized_end=56324,
)


_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientManageFavoritesResponse',
  full_name='dota.CMsgGCToClientManageFavoritesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgGCToClientManageFavoritesResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='dota.CMsgGCToClientManageFavoritesResponse.debug_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player', full_name='dota.CMsgGCToClientManageFavoritesResponse.player', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56327,
  serialized_end=56618,
)


_CMSGCLIENTTOGCGETFAVORITEPLAYERS = _descriptor.Descriptor(
  name='CMsgClientToGCGetFavoritePlayers',
  full_name='dota.CMsgClientToGCGetFavoritePlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination_key', full_name='dota.CMsgClientToGCGetFavoritePlayers.pagination_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination_count', full_name='dota.CMsgClientToGCGetFavoritePlayers.pagination_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56620,
  serialized_end=56704,
)


_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientGetFavoritePlayersResponse',
  full_name='dota.CMsgGCToClientGetFavoritePlayersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgGCToClientGetFavoritePlayersResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='players', full_name='dota.CMsgGCToClientGetFavoritePlayersResponse.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_pagination_key', full_name='dota.CMsgGCToClientGetFavoritePlayersResponse.next_pagination_key', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56707,
  serialized_end=56948,
)


_CMSGGCTOCLIENTPARTYSEARCHINVITE = _descriptor.Descriptor(
  name='CMsgGCToClientPartySearchInvite',
  full_name='dota.CMsgGCToClientPartySearchInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToClientPartySearchInvite.account_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56950,
  serialized_end=57003,
)


_CMSGCLIENTTOGCVERIFYFAVORITEPLAYERS = _descriptor.Descriptor(
  name='CMsgClientToGCVerifyFavoritePlayers',
  full_name='dota.CMsgClientToGCVerifyFavoritePlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgClientToGCVerifyFavoritePlayers.account_ids', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57005,
  serialized_end=57063,
)


_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='dota.CMsgGCToClientVerifyFavoritePlayersResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player', full_name='dota.CMsgGCToClientVerifyFavoritePlayersResponse.Result.player', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_favorite', full_name='dota.CMsgGCToClientVerifyFavoritePlayersResponse.Result.is_favorite', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57188,
  serialized_end=57262,
)

_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientVerifyFavoritePlayersResponse',
  full_name='dota.CMsgGCToClientVerifyFavoritePlayersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='dota.CMsgGCToClientVerifyFavoritePlayersResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57066,
  serialized_end=57262,
)


_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTS = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerRecentAccomplishments',
  full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishments.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57264,
  serialized_end=57334,
)


_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse',
  full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_accomplishments', full_name='dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse.player_accomplishments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57337,
  serialized_end=57658,
)


_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTS = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerHeroRecentAccomplishments',
  full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishments.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishments.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57660,
  serialized_end=57751,
)


_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse',
  full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_accomplishments', full_name='dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse.hero_accomplishments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57754,
  serialized_end=58085,
)


_CMSGPLAYERCOACHMATCH = _descriptor.Descriptor(
  name='CMsgPlayerCoachMatch',
  full_name='dota.CMsgPlayerCoachMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgPlayerCoachMatch.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_outcome', full_name='dota.CMsgPlayerCoachMatch.match_outcome', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coached_team', full_name='dota.CMsgPlayerCoachMatch.coached_team', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='dota.CMsgPlayerCoachMatch.start_time', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dota.CMsgPlayerCoachMatch.duration', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teammate_ratings', full_name='dota.CMsgPlayerCoachMatch.teammate_ratings', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coach_flags', full_name='dota.CMsgPlayerCoachMatch.coach_flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58088,
  serialized_end=58332,
)


_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHES = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerCoachMatches',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58334,
  serialized_end=58375,
)


_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerCoachMatchesResponse',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestPlayerCoachMatchesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coach_matches', full_name='dota.CMsgClientToGCRequestPlayerCoachMatchesResponse.coach_matches', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58378,
  serialized_end=58661,
)


_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCH = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerCoachMatch',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCRequestPlayerCoachMatch.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58663,
  serialized_end=58720,
)


_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestPlayerCoachMatchResponse',
  full_name='dota.CMsgClientToGCRequestPlayerCoachMatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCRequestPlayerCoachMatchResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coach_match', full_name='dota.CMsgClientToGCRequestPlayerCoachMatchResponse.coach_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58723,
  serialized_end=59000,
)


_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATING = _descriptor.Descriptor(
  name='CMsgClientToGCSubmitCoachTeammateRating',
  full_name='dota.CMsgClientToGCSubmitCoachTeammateRating',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CMsgClientToGCSubmitCoachTeammateRating.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coach_account_id', full_name='dota.CMsgClientToGCSubmitCoachTeammateRating.coach_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rating', full_name='dota.CMsgClientToGCSubmitCoachTeammateRating.rating', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dota.CMsgClientToGCSubmitCoachTeammateRating.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59003,
  serialized_end=59177,
)


_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSubmitCoachTeammateRatingResponse',
  full_name='dota.CMsgClientToGCSubmitCoachTeammateRatingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCSubmitCoachTeammateRatingResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59180,
  serialized_end=59618,
)


_CMSGGCTOCLIENTCOACHTEAMMATERATINGSCHANGED = _descriptor.Descriptor(
  name='CMsgGCToClientCoachTeammateRatingsChanged',
  full_name='dota.CMsgGCToClientCoachTeammateRatingsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coach_match', full_name='dota.CMsgGCToClientCoachTeammateRatingsChanged.coach_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59620,
  serialized_end=59712,
)


_CMSGCLIENTTOGCGETTICKETCODESREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCGetTicketCodesRequest',
  full_name='dota.CMsgClientToGCGetTicketCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_pool_ids', full_name='dota.CMsgClientToGCGetTicketCodesRequest.ticket_pool_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59714,
  serialized_end=59776,
)


_CMSGCLIENTTOGCGETTICKETCODESRESPONSE_CODE = _descriptor.Descriptor(
  name='Code',
  full_name='dota.CMsgClientToGCGetTicketCodesResponse.Code',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_pool_id', full_name='dota.CMsgClientToGCGetTicketCodesResponse.Code.ticket_pool_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dota.CMsgClientToGCGetTicketCodesResponse.Code.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_disallowed', full_name='dota.CMsgClientToGCGetTicketCodesResponse.Code.account_disallowed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59883,
  serialized_end=59955,
)

_CMSGCLIENTTOGCGETTICKETCODESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetTicketCodesResponse',
  full_name='dota.CMsgClientToGCGetTicketCodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codes', full_name='dota.CMsgClientToGCGetTicketCodesResponse.codes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETTICKETCODESRESPONSE_CODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59779,
  serialized_end=59955,
)


_CMSGCLIENTTOGCGETUNDERLORDSCDKEYREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCGetUnderlordsCDKeyRequest',
  full_name='dota.CMsgClientToGCGetUnderlordsCDKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59957,
  serialized_end=59998,
)


_CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetUnderlordsCDKeyResponse',
  full_name='dota.CMsgClientToGCGetUnderlordsCDKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCGetUnderlordsCDKeyResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cd_keys', full_name='dota.CMsgClientToGCGetUnderlordsCDKeyResponse.cd_keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60001,
  serialized_end=60202,
)


_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYER = _descriptor.Descriptor(
  name='CMsgClientToGCSetFavoriteAllStarPlayer',
  full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayer.player_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayer.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60204,
  serialized_end=60281,
)


_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSetFavoriteAllStarPlayerResponse',
  full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_id', full_name='dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse.player_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60284,
  serialized_end=60627,
)


_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCGetFavoriteAllStarPlayerRequest',
  full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60629,
  serialized_end=60676,
)


_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetFavoriteAllStarPlayerResponse',
  full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_id', full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.player_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='picking_allowed_until', full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.picking_allowed_until', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='earned_battle_points', full_name='dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse.earned_battle_points', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60679,
  serialized_end=60965,
)


_CMSGCLIENTTOGCVERIFYINTEGRITY = _descriptor.Descriptor(
  name='CMsgClientToGCVerifyIntegrity',
  full_name='dota.CMsgClientToGCVerifyIntegrity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='dota.CMsgClientToGCVerifyIntegrity.currency', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_user_message', full_name='dota.CMsgClientToGCVerifyIntegrity.additional_user_message', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acked', full_name='dota.CMsgClientToGCVerifyIntegrity.acked', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60967,
  serialized_end=61064,
)

_CMSGDOTAREQUESTMATCHES.fields_by_name['skill'].enum_type = _CMSGDOTAREQUESTMATCHES_SKILLLEVEL
_CMSGDOTAREQUESTMATCHES_SKILLLEVEL.containing_type = _CMSGDOTAREQUESTMATCHES
_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES.containing_type = _CMSGDOTAREQUESTMATCHESRESPONSE
_CMSGDOTAREQUESTMATCHESRESPONSE.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAREQUESTMATCHESRESPONSE.fields_by_name['series'].message_type = _CMSGDOTAREQUESTMATCHESRESPONSE_SERIES
_CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO.fields_by_name['status'].enum_type = _CMSGDOTAGETDPCSTANDINGSRESPONSE_ESTATUS
_CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO.containing_type = _CMSGDOTAGETDPCSTANDINGSRESPONSE
_CMSGDOTAGETDPCSTANDINGSRESPONSE.fields_by_name['standings'].message_type = _CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO
_CMSGDOTAGETDPCSTANDINGSRESPONSE_ESTATUS.containing_type = _CMSGDOTAGETDPCSTANDINGSRESPONSE
_CMSGDOTAPOPUP.fields_by_name['id'].enum_type = _CMSGDOTAPOPUP_POPUPID
_CMSGDOTAPOPUP_POPUPID.containing_type = _CMSGDOTAPOPUP
_CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE.fields_by_name['match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CMSGDOTAREQUESTSAVEGAMESRESPONSE.fields_by_name['save_games'].message_type = dota__shared__enums__pb2._CDOTASAVEGAME
_CMSGGCMATCHDETAILSRESPONSE.fields_by_name['match'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGGCMATCHDETAILSRESPONSE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGGCTOSERVERMATCHDETAILSRESPONSE.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAPROFILETICKETS_LEAGUEPASS.containing_type = _CMSGDOTAPROFILETICKETS
_CMSGDOTAPROFILETICKETS.fields_by_name['league_passes'].message_type = _CMSGDOTAPROFILETICKETS_LEAGUEPASS
_CMSGGCTOCLIENTPARTYSEARCHINVITES.fields_by_name['invites'].message_type = _CMSGGCTOCLIENTPARTYSEARCHINVITE
_CMSGDOTAWELCOME_CEXTRAMSG.containing_type = _CMSGDOTAWELCOME
_CMSGDOTAWELCOME.fields_by_name['partner_account_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CMSGDOTAWELCOME.fields_by_name['extra_messages'].message_type = _CMSGDOTAWELCOME_CEXTRAMSG
_CMSGDOTAWELCOME.fields_by_name['active_event'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGDOTAWELCOME.fields_by_name['party_search_friend_invites'].message_type = _CMSGGCTOCLIENTPARTYSEARCHINVITES
_CMSGDOTAMATCHVOTES_PLAYERVOTE.containing_type = _CMSGDOTAMATCHVOTES
_CMSGDOTAMATCHVOTES.fields_by_name['votes'].message_type = _CMSGDOTAMATCHVOTES_PLAYERVOTE
_CMSGCASTMATCHVOTE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGMATCHVOTERESPONSE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGDOTAHALLOFFAME_FEATUREDPLAYER.containing_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOFFAME_FEATUREDFARMER.containing_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOFFAME.fields_by_name['featured_players'].message_type = _CMSGDOTAHALLOFFAME_FEATUREDPLAYER
_CMSGDOTAHALLOFFAME.fields_by_name['featured_farmer'].message_type = _CMSGDOTAHALLOFFAME_FEATUREDFARMER
_CMSGDOTAHALLOFFAMERESPONSE.fields_by_name['hall_of_fame'].message_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOWEENHIGHSCORERESPONSE.fields_by_name['match'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE.containing_type = _CMSGDOTASTOREPROMOPAGESRESPONSE
_CMSGDOTASTOREPROMOPAGESRESPONSE.fields_by_name['pages'].message_type = _CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE
_CMSGMATCHMAKINGMATCHGROUPINFO.fields_by_name['status'].enum_type = dota__shared__enums__pb2._EMATCHGROUPSERVERSTATUS
_CMSGDOTAMATCHMAKINGSTATSRESPONSE.fields_by_name['match_groups'].message_type = _CMSGMATCHMAKINGMATCHGROUPINFO
_CMSGDOTAUPDATEMATCHMAKINGSTATS.fields_by_name['stats'].message_type = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
_CMSGDOTAUPDATEMATCHMANAGEMENTSTATS.fields_by_name['stats'].message_type = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
_CMSGGCWATCHDOWNLOADEDREPLAY.fields_by_name['watch_type'].enum_type = _DOTA_WATCHREPLAYTYPE
_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS.containing_type = _CMSGDOTAFRIENDRECRUITSRESPONSE
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['recruits'].message_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['recruiters'].message_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS
_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT.containing_type = _CMSGDOTAFRIENDRECRUITSRESPONSE
_CMSGGCGETHEROSTANDINGSRESPONSE_HERO.containing_type = _CMSGGCGETHEROSTANDINGSRESPONSE
_CMSGGCGETHEROSTANDINGSRESPONSE.fields_by_name['standings'].message_type = _CMSGGCGETHEROSTANDINGSRESPONSE_HERO
_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER.fields_by_name['all_stats'].message_type = _CMATCHPLAYERTIMEDSTATAVERAGES
_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER.fields_by_name['winning_stats'].message_type = _CMATCHPLAYERTIMEDSTATAVERAGES
_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER.fields_by_name['losing_stats'].message_type = _CMATCHPLAYERTIMEDSTATAVERAGES
_CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER.containing_type = _CMSGGCGETHEROTIMEDSTATSRESPONSE
_CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS.fields_by_name['timed_stats'].message_type = _CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER
_CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS.containing_type = _CMSGGCGETHEROTIMEDSTATSRESPONSE
_CMSGGCGETHEROTIMEDSTATSRESPONSE.fields_by_name['rank_chunked_stats'].message_type = _CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS
_CMSGGCITEMEDITORRESERVATIONSRESPONSE.fields_by_name['reservations'].message_type = _CMSGGCITEMEDITORRESERVATION
_CMSGDOTACLAIMEVENTACTIONDATA_GRANTITEMGIFTDATA.containing_type = _CMSGDOTACLAIMEVENTACTIONDATA
_CMSGDOTACLAIMEVENTACTIONDATA.fields_by_name['grant_item_gift_data'].message_type = _CMSGDOTACLAIMEVENTACTIONDATA_GRANTITEMGIFTDATA
_CMSGDOTACLAIMEVENTACTION.fields_by_name['data'].message_type = _CMSGDOTACLAIMEVENTACTIONDATA
_CMSGDOTACLAIMEVENTACTIONRESPONSE_MYSTERYITEMREWARDDATA.containing_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGDOTACLAIMEVENTACTIONRESPONSE_LOOTLISTREWARDDATA.containing_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGDOTACLAIMEVENTACTIONRESPONSE_GRANTEDREWARDDATA.containing_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGDOTACLAIMEVENTACTIONRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE_RESULTCODE
_CMSGDOTACLAIMEVENTACTIONRESPONSE.fields_by_name['reward_results'].message_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE_GRANTEDREWARDDATA
_CMSGDOTACLAIMEVENTACTIONRESPONSE_RESULTCODE.containing_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEMRESPONSE.fields_by_name['action_results'].message_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGGCTOCLIENTCLAIMEVENTACTIONUSINGITEMCOMPLETED.fields_by_name['action_results'].message_type = _CMSGDOTACLAIMEVENTACTIONRESPONSE
_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION.containing_type = _CMSGDOTAGETEVENTPOINTSRESPONSE
_CMSGDOTAGETEVENTPOINTSRESPONSE.fields_by_name['completed_actions'].message_type = _CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION
_CMSGDOTAPERIODICRESOURCEUPDATED.fields_by_name['periodic_resource_key'].message_type = _CMSGDOTAGETPERIODICRESOURCE
_CMSGDOTAPERIODICRESOURCEUPDATED.fields_by_name['periodic_resource_value'].message_type = _CMSGDOTAGETPERIODICRESOURCERESPONSE
_CMSGDOTACOMPENDIUMDATA.fields_by_name['selections'].message_type = _CMSGDOTACOMPENDIUMSELECTION
_CMSGDOTACOMPENDIUMDATARESPONSE.fields_by_name['compendium_data'].message_type = _CMSGDOTACOMPENDIUMDATA
_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH.containing_type = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE
_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE.fields_by_name['matches'].message_type = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH
_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION.containing_type = _CMSGGCNOTIFICATIONSRESPONSE
_CMSGGCNOTIFICATIONSRESPONSE.fields_by_name['result'].enum_type = _CMSGGCNOTIFICATIONSRESPONSE_ERESULT
_CMSGGCNOTIFICATIONSRESPONSE.fields_by_name['notifications'].message_type = _CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION
_CMSGGCNOTIFICATIONSRESPONSE_ERESULT.containing_type = _CMSGGCNOTIFICATIONSRESPONSE
_CMSGGCPLAYERINFOREQUEST_PLAYERINFO.containing_type = _CMSGGCPLAYERINFOREQUEST
_CMSGGCPLAYERINFOREQUEST.fields_by_name['player_infos'].message_type = _CMSGGCPLAYERINFOREQUEST_PLAYERINFO
_CMSGGCPLAYERINFOSUBMITRESPONSE.fields_by_name['result'].enum_type = _CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT
_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT.containing_type = _CMSGGCPLAYERINFOSUBMITRESPONSE
_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE.containing_type = _CMSGCLIENTPROVIDESURVEYRESULT
_CMSGCLIENTPROVIDESURVEYRESULT.fields_by_name['responses'].message_type = _CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE
_CMSGGCTOCLIENTEMOTICONDATA.fields_by_name['emoticon_access'].message_type = _CMSGDOTAEMOTICONACCESSSDO
_CMSGCLIENTTOGCSETADDITIONALEQUIPS.fields_by_name['equips'].message_type = dota__gcmessages__common__pb2._CADDITIONALEQUIPSLOT
_CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE.fields_by_name['equips'].message_type = dota__gcmessages__common__pb2._CADDITIONALEQUIPSLOT
_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY.containing_type = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE
_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE.fields_by_name['trophies'].message_type = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY
_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT.fields_by_name['slot_type'].enum_type = dota__shared__enums__pb2._EPROFILECARDSLOTTYPE
_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT.containing_type = _CMSGCLIENTTOGCSETPROFILECARDSLOTS
_CMSGCLIENTTOGCSETPROFILECARDSLOTS.fields_by_name['slots'].message_type = _CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT
_CMSGGCTOCLIENTEVENTSTATUSCHANGED.fields_by_name['active_event'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME.containing_type = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE
_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE.fields_by_name['games'].message_type = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME
_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT.containing_type = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE
_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE.fields_by_name['comments'].message_type = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT
_CMSGDOTAPARTYRICHPRESENCE_MEMBER.containing_type = _CMSGDOTAPARTYRICHPRESENCE
_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY.fields_by_name['event'].enum_type = _EWEEKENDTOURNEYRICHPRESENCEEVENT
_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY.containing_type = _CMSGDOTAPARTYRICHPRESENCE
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['party_state'].enum_type = dota__gcmessages__common__match__management__pb2._CSODOTAPARTY_STATE
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['members'].message_type = _CMSGDOTAPARTYRICHPRESENCE_MEMBER
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['weekend_tourney'].message_type = _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY
_CMSGDOTALOBBYRICHPRESENCE.fields_by_name['lobby_state'].enum_type = dota__gcmessages__common__match__management__pb2._CSODOTALOBBY_STATE
_CMSGDOTALOBBYRICHPRESENCE.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE.containing_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST.fields_by_name['completed_challenges'].message_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST.containing_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE.fields_by_name['quests'].message_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST
_CMSGGCGETHEROSTATSHISTORYRESPONSE.fields_by_name['records'].message_type = dota__gcmessages__common__pb2._CMSGDOTASDOHEROSTATSHISTORY
_CMSGGCTOCLIENTWAGERINGUPDATE.fields_by_name['wagering_info'].message_type = _CMSGGCTOCLIENTWAGERINGRESPONSE
_CMSGGCTOCLIENTARCANAVOTESUPDATE.fields_by_name['arcana_votes'].message_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
_CMSGCLIENTTOGCGETEVENTGOALS.fields_by_name['event_ids'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGEVENTGOALS_EVENTGOAL.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGEVENTGOALS_EVENTGOAL.containing_type = _CMSGEVENTGOALS
_CMSGEVENTGOALS.fields_by_name['event_goals'].message_type = _CMSGEVENTGOALS_EVENTGOAL
_CMSGPREDICTIONRANKINGS_PREDICTIONLINE.containing_type = _CMSGPREDICTIONRANKINGS
_CMSGPREDICTIONRANKINGS_PREDICTION.fields_by_name['prediction_lines'].message_type = _CMSGPREDICTIONRANKINGS_PREDICTIONLINE
_CMSGPREDICTIONRANKINGS_PREDICTION.containing_type = _CMSGPREDICTIONRANKINGS
_CMSGPREDICTIONRANKINGS.fields_by_name['predictions'].message_type = _CMSGPREDICTIONRANKINGS_PREDICTION
_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN.containing_type = _CMSGPREDICTIONRESULTS
_CMSGPREDICTIONRESULTS_RESULT.fields_by_name['result_breakdown'].message_type = _CMSGPREDICTIONRESULTS_RESULTBREAKDOWN
_CMSGPREDICTIONRESULTS_RESULT.containing_type = _CMSGPREDICTIONRESULTS
_CMSGPREDICTIONRESULTS.fields_by_name['results'].message_type = _CMSGPREDICTIONRESULTS_RESULT
_CMSGMVPVOTESFORMATCH_PLAYER.containing_type = _CMSGMVPVOTESFORMATCH
_CMSGMVPVOTESFORMATCH.fields_by_name['players'].message_type = _CMSGMVPVOTESFORMATCH_PLAYER
_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT.containing_type = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE
_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE.fields_by_name['teammate_stats'].message_type = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT
_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE.containing_type = _CMSGCLIENTTOGCVOTEFORARCANA
_CMSGCLIENTTOGCVOTEFORARCANA.fields_by_name['matches'].message_type = _CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE
_CMSGCLIENTTOGCVOTEFORARCANARESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT
_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE
_CMSGARCANAVOTES_MATCH.containing_type = _CMSGARCANAVOTES
_CMSGARCANAVOTES.fields_by_name['matches'].message_type = _CMSGARCANAVOTES_MATCH
_CMSGARCANAVOTES_VOTINGSTATE.containing_type = _CMSGARCANAVOTES
_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE.containing_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE.fields_by_name['matches_previously_voted_for'].message_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2_LOGENTRY.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2.fields_by_name['log_entries'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2_LOGENTRY
_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGCLIENTTOGCREQUESTLINAGAMERESULT.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGCLIENTTOGCREQUESTSLARKGAMERESULT.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE.containing_type = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED
_CMSGGCTOCLIENTQUESTPROGRESSUPDATED.fields_by_name['completed_challenges'].message_type = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE
_CMSGDOTAREDEEMITEMRESPONSE.fields_by_name['response'].enum_type = _CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE
_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE.containing_type = _CMSGDOTAREDEEMITEMRESPONSE
_CMSGPERFECTWORLDUSERLOOKUPRESPONSE.fields_by_name['result_code'].enum_type = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE
_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE.containing_type = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE
_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING.containing_type = _CMSGREQUESTOFFERINGSRESPONSE
_CMSGREQUESTOFFERINGSRESPONSE.fields_by_name['offerings'].message_type = _CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING
_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT.containing_type = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS
_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS.fields_by_name['results'].message_type = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION.containing_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION.fields_by_name['predictions'].message_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT.containing_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE
_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT
_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE
_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT
_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE
_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT
_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['questlines'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['battle_cup'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_QUESTLINES.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BATTLECUP.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['questlines'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_QUESTLINES
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['battle_cup'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BATTLECUP
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_QUESTLINES.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BATTLECUP.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['questlines'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_QUESTLINES
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['battle_cup'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BATTLECUP
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_QUESTLINES.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BATTLECUP.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['questlines'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_QUESTLINES
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['battle_cup'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BATTLECUP
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_CAVERNCRAWL.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['cavern_crawl'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_CAVERNCRAWL
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_ti6'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_fall2016'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_winter2017'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_ti7'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_ti8'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE_EVENTINFO.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE
_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE.fields_by_name['event_info'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE_EVENTINFO
_CMSGDOTATRIVIAQUESTION.fields_by_name['category'].enum_type = _EDOTATRIVIAQUESTIONCATEGORY
_CMSGDOTATRIVIACURRENTQUESTIONS.fields_by_name['questions'].message_type = _CMSGDOTATRIVIAQUESTION
_CMSGDOTASUBMITTRIVIAQUESTIONANSWERRESPONSE.fields_by_name['result'].enum_type = _EDOTATRIVIAANSWERRESULT
_CMSGCLIENTTOGCGIVETIPRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCGIVETIPRESPONSE_RESULT
_CMSGCLIENTTOGCGIVETIPRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCGIVETIPRESPONSE
_CMSGDOTAANCHORPHONENUMBERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAANCHORPHONENUMBERRESPONSE_RESULT
_CMSGDOTAANCHORPHONENUMBERRESPONSE_RESULT.containing_type = _CMSGDOTAANCHORPHONENUMBERRESPONSE
_CMSGDOTAUNANCHORPHONENUMBERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAUNANCHORPHONENUMBERRESPONSE_RESULT
_CMSGDOTAUNANCHORPHONENUMBERRESPONSE_RESULT.containing_type = _CMSGDOTAUNANCHORPHONENUMBERRESPONSE
_CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY_RESULT
_CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY_RESULT.containing_type = _CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS.containing_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['original_request'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSREQUEST
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['hero_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['item_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['item_hero_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['item_player_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['hero_player_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE.fields_by_name['full_set_stats'].message_type = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS
_CMSGDOTASELECTIONPRIORITYCHOICEREQUEST.fields_by_name['choice'].enum_type = dota__shared__enums__pb2._DOTASELECTIONPRIORITYCHOICE
_CMSGDOTASELECTIONPRIORITYCHOICERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTASELECTIONPRIORITYCHOICERESPONSE_RESULT
_CMSGDOTASELECTIONPRIORITYCHOICERESPONSE_RESULT.containing_type = _CMSGDOTASELECTIONPRIORITYCHOICERESPONSE
_CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE_RESULT
_CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE_RESULT.containing_type = _CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE
_CMSGDOTADESTROYLOBBYRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTADESTROYLOBBYRESPONSE_RESULT
_CMSGDOTADESTROYLOBBYRESPONSE_RESULT.containing_type = _CMSGDOTADESTROYLOBBYRESPONSE
_CMSGPURCHASEITEMWITHEVENTPOINTS.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE.fields_by_name['result'].enum_type = _CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE_RESULT
_CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE_RESULT.containing_type = _CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE
_CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE_ABILITYSELECTION.containing_type = _CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE
_CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE.fields_by_name['abilities'].message_type = _CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE_ABILITYSELECTION
_CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE_RESULT
_CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE
_CMSGPURCHASEHERORELICRESPONSE.fields_by_name['result'].enum_type = _EPURCHASEHERORELICRESULT
_CMSGPURCHASEHERORANDOMRELICRESPONSE.fields_by_name['result'].enum_type = _EPURCHASEHERORELICRESULT
_CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULT.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGPROFILERESPONSE_FEATUREDHERO.fields_by_name['equipped_econ_items'].message_type = base__gcmessages__pb2._CSOECONITEM
_CMSGPROFILERESPONSE_FEATUREDHERO.fields_by_name['plus_hero_relics_item'].message_type = base__gcmessages__pb2._CSOECONITEM
_CMSGPROFILERESPONSE_FEATUREDHERO.containing_type = _CMSGPROFILERESPONSE
_CMSGPROFILERESPONSE_MATCHINFO.containing_type = _CMSGPROFILERESPONSE
_CMSGPROFILERESPONSE.fields_by_name['background_item'].message_type = base__gcmessages__pb2._CSOECONITEM
_CMSGPROFILERESPONSE.fields_by_name['featured_heroes'].message_type = _CMSGPROFILERESPONSE_FEATUREDHERO
_CMSGPROFILERESPONSE.fields_by_name['recent_matches'].message_type = _CMSGPROFILERESPONSE_MATCHINFO
_CMSGPROFILERESPONSE.fields_by_name['successful_heroes'].message_type = dota__gcmessages__common__pb2._CMSGSUCCESSFULHERO
_CMSGPROFILERESPONSE.fields_by_name['recent_match_details'].message_type = dota__gcmessages__common__pb2._CMSGRECENTMATCHINFO
_CMSGPROFILERESPONSE.fields_by_name['result'].enum_type = _CMSGPROFILERESPONSE_ERESPONSE
_CMSGPROFILERESPONSE_ERESPONSE.containing_type = _CMSGPROFILERESPONSE
_CMSGPROFILEUPDATERESPONSE.fields_by_name['result'].enum_type = _CMSGPROFILEUPDATERESPONSE_RESULT
_CMSGPROFILEUPDATERESPONSE_RESULT.containing_type = _CMSGPROFILEUPDATERESPONSE
_CMSGHEROGLOBALDATARESPONSE_GRAPHDATA.containing_type = _CMSGHEROGLOBALDATARESPONSE
_CMSGHEROGLOBALDATARESPONSE_WEEKDATA.containing_type = _CMSGHEROGLOBALDATARESPONSE
_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK.fields_by_name['talent_win_rates'].message_type = _CMSGTALENTWINRATES
_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK.fields_by_name['hero_averages'].message_type = _CMSGGLOBALHEROAVERAGES
_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK.fields_by_name['graph_data'].message_type = _CMSGHEROGLOBALDATARESPONSE_GRAPHDATA
_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK.fields_by_name['week_data'].message_type = _CMSGHEROGLOBALDATARESPONSE_WEEKDATA
_CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK.containing_type = _CMSGHEROGLOBALDATARESPONSE
_CMSGHEROGLOBALDATARESPONSE.fields_by_name['hero_data_per_chunk'].message_type = _CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK
_CMSGHEROGLOBALDATAALLHEROES.fields_by_name['heroes'].message_type = _CMSGHEROGLOBALDATARESPONSE
_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_HERODATA.containing_type = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES
_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA.fields_by_name['hero_data'].message_type = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_HERODATA
_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA.containing_type = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES
_CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES.fields_by_name['ranked_hero_data'].message_type = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA
_CMSGACTIVATEPLUSFREETRIALRESPONSE.fields_by_name['result'].enum_type = _CMSGACTIVATEPLUSFREETRIALRESPONSE_RESULT
_CMSGACTIVATEPLUSFREETRIALRESPONSE_RESULT.containing_type = _CMSGACTIVATEPLUSFREETRIALRESPONSE
_CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED_COMPLETEDPATHINFO.containing_type = _CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED
_CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED.fields_by_name['completed_paths'].message_type = _CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED_COMPLETEDPATHINFO
_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE_RESULT
_CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE_RESULT
_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE_RESULT
_CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_SWAPPEDCHALLENGE.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_INVENTORYITEM.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_TREASUREMAP.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_RESULT
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE.fields_by_name['swapped_challenge'].message_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_SWAPPEDCHALLENGE
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE.fields_by_name['inventory_item'].message_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_INVENTORYITEM
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE.fields_by_name['treasure_map'].message_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_TREASUREMAP
_CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE
_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE_RESULT
_CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE
_CMSGDOTAMUTATIONLIST_MUTATION.containing_type = _CMSGDOTAMUTATIONLIST
_CMSGDOTAMUTATIONLIST.fields_by_name['mutations'].message_type = _CMSGDOTAMUTATIONLIST_MUTATION
_CMSGEVENTTIPSSUMMARYREQUEST.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGEVENTTIPSSUMMARYRESPONSE_TIPPER.containing_type = _CMSGEVENTTIPSSUMMARYRESPONSE
_CMSGEVENTTIPSSUMMARYRESPONSE.fields_by_name['tips_received'].message_type = _CMSGEVENTTIPSSUMMARYRESPONSE_TIPPER
_CMSGSOCIALFEEDRESPONSE_FEEDEVENT.containing_type = _CMSGSOCIALFEEDRESPONSE
_CMSGSOCIALFEEDRESPONSE.fields_by_name['result'].enum_type = _CMSGSOCIALFEEDRESPONSE_RESULT
_CMSGSOCIALFEEDRESPONSE.fields_by_name['feed_events'].message_type = _CMSGSOCIALFEEDRESPONSE_FEEDEVENT
_CMSGSOCIALFEEDRESPONSE_RESULT.containing_type = _CMSGSOCIALFEEDRESPONSE
_CMSGSOCIALFEEDCOMMENTSRESPONSE_FEEDCOMMENT.containing_type = _CMSGSOCIALFEEDCOMMENTSRESPONSE
_CMSGSOCIALFEEDCOMMENTSRESPONSE.fields_by_name['result'].enum_type = _CMSGSOCIALFEEDCOMMENTSRESPONSE_RESULT
_CMSGSOCIALFEEDCOMMENTSRESPONSE.fields_by_name['feed_comments'].message_type = _CMSGSOCIALFEEDCOMMENTSRESPONSE_FEEDCOMMENT
_CMSGSOCIALFEEDCOMMENTSRESPONSE_RESULT.containing_type = _CMSGSOCIALFEEDCOMMENTSRESPONSE
_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE_RESULT
_CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE
_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ITEMVOTE.containing_type = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE
_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ERESPONSE
_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE.fields_by_name['votes'].message_type = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ITEMVOTE
_CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE
_CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE.fields_by_name['eresult'].enum_type = _CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE_ERESULT
_CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE_ERESULT.containing_type = _CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE
_CMSGDOTADPCFEED_ELEMENT.fields_by_name['type'].enum_type = _CMSGDOTADPCFEED_EFEEDELEMENTTYPE
_CMSGDOTADPCFEED_ELEMENT.containing_type = _CMSGDOTADPCFEED
_CMSGDOTADPCFEED.fields_by_name['elements'].message_type = _CMSGDOTADPCFEED_ELEMENT
_CMSGDOTADPCFEED_EFEEDELEMENTTYPE.containing_type = _CMSGDOTADPCFEED
_CMSGDEVGRANTEVENTPOINTS.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGDEVGRANTEVENTPOINTSRESPONSE.fields_by_name['result'].enum_type = _EDEVEVENTREQUESTRESULT
_CMSGDEVGRANTEVENTACTION.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGDEVGRANTEVENTACTIONRESPONSE.fields_by_name['result'].enum_type = _EDEVEVENTREQUESTRESULT
_CMSGDEVRESETEVENTSTATE.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGDEVRESETEVENTSTATERESPONSE.fields_by_name['result'].enum_type = _EDEVEVENTREQUESTRESULT
_CMSGCONSUMEEVENTSUPPORTGRANTITEMRESPONSE.fields_by_name['result'].enum_type = _ESUPPORTEVENTREQUESTRESULT
_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_CFILTERENTRY.containing_type = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE
_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_RESULT
_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE.fields_by_name['filtered_players'].message_type = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_CFILTERENTRY
_CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE
_CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE_RESULT
_CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE
_CMSGCLIENTTOGCUPDATEPARTYBEACON.fields_by_name['action'].enum_type = _CMSGCLIENTTOGCUPDATEPARTYBEACON_ACTION
_CMSGCLIENTTOGCUPDATEPARTYBEACON_ACTION.containing_type = _CMSGCLIENTTOGCUPDATEPARTYBEACON
_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE.fields_by_name['response'].enum_type = _CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE_ERESPONSE
_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE.fields_by_name['active_parties'].message_type = dota__gcmessages__common__pb2._CPARTYSEARCHCLIENTPARTY
_CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE_ERESPONSE.containing_type = _CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE
_CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE.fields_by_name['response'].enum_type = _CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE_ERESPONSE
_CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE_ERESPONSE.containing_type = _CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE
_CMSGCLIENTTOGCMANAGEFAVORITES.fields_by_name['action'].enum_type = _CMSGCLIENTTOGCMANAGEFAVORITES_ACTION
_CMSGCLIENTTOGCMANAGEFAVORITES_ACTION.containing_type = _CMSGCLIENTTOGCMANAGEFAVORITES
_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE.fields_by_name['response'].enum_type = _CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE_ERESPONSE
_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE.fields_by_name['player'].message_type = _CMSGPARTYSEARCHPLAYER
_CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE_ERESPONSE.containing_type = _CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE
_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE.fields_by_name['response'].enum_type = _CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE_ERESPONSE
_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE.fields_by_name['players'].message_type = _CMSGPARTYSEARCHPLAYER
_CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE_ERESPONSE.containing_type = _CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE
_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT.fields_by_name['player'].message_type = _CMSGPARTYSEARCHPLAYER
_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE
_CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE.fields_by_name['results'].message_type = _CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT
_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE_ERESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE.fields_by_name['player_accomplishments'].message_type = dota__gcmessages__common__pb2._CMSGPLAYERRECENTACCOMPLISHMENTS
_CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE_ERESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE.fields_by_name['hero_accomplishments'].message_type = dota__gcmessages__common__pb2._CMSGPLAYERHERORECENTACCOMPLISHMENTS
_CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE
_CMSGPLAYERCOACHMATCH.fields_by_name['match_outcome'].enum_type = dota__shared__enums__pb2._EMATCHOUTCOME
_CMSGPLAYERCOACHMATCH.fields_by_name['teammate_ratings'].enum_type = _ECOACHTEAMMATERATING
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE_ERESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE.fields_by_name['coach_matches'].message_type = _CMSGPLAYERCOACHMATCH
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE_ERESPONSE
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE.fields_by_name['coach_match'].message_type = _CMSGPLAYERCOACHMATCH
_CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE
_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATING.fields_by_name['rating'].enum_type = _ECOACHTEAMMATERATING
_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE_ERESPONSE
_CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE
_CMSGGCTOCLIENTCOACHTEAMMATERATINGSCHANGED.fields_by_name['coach_match'].message_type = _CMSGPLAYERCOACHMATCH
_CMSGCLIENTTOGCGETTICKETCODESRESPONSE_CODE.containing_type = _CMSGCLIENTTOGCGETTICKETCODESRESPONSE
_CMSGCLIENTTOGCGETTICKETCODESRESPONSE.fields_by_name['codes'].message_type = _CMSGCLIENTTOGCGETTICKETCODESRESPONSE_CODE
_CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE_ERESPONSE
_CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE
_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE
_CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE
_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE
_CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSuspended'] = _CMSGCLIENTSUSPENDED
DESCRIPTOR.message_types_by_name['CMsgBalancedShuffleLobby'] = _CMSGBALANCEDSHUFFLELOBBY
DESCRIPTOR.message_types_by_name['CMsgInitialQuestionnaireResponse'] = _CMSGINITIALQUESTIONNAIRERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPlayerMatchHistory'] = _CMSGDOTAPLAYERMATCHHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchHistoryFilter'] = _CMSGDOTAMATCHHISTORYFILTER
DESCRIPTOR.message_types_by_name['CMsgDOTARequestMatches'] = _CMSGDOTAREQUESTMATCHES
DESCRIPTOR.message_types_by_name['CMsgDOTARequestMatchesResponse'] = _CMSGDOTAREQUESTMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetDPCStandingsResponse'] = _CMSGDOTAGETDPCSTANDINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPopup'] = _CMSGDOTAPOPUP
DESCRIPTOR.message_types_by_name['CMsgDOTAReportsRemainingRequest'] = _CMSGDOTAREPORTSREMAININGREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAReportsRemainingResponse'] = _CMSGDOTAREPORTSREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitPlayerReport'] = _CMSGDOTASUBMITPLAYERREPORT
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitPlayerReportResponse'] = _CMSGDOTASUBMITPLAYERREPORTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAReportCountsRequest'] = _CMSGDOTAREPORTCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAReportCountsResponse'] = _CMSGDOTAREPORTCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitLobbyMVPVote'] = _CMSGDOTASUBMITLOBBYMVPVOTE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitLobbyMVPVoteResponse'] = _CMSGDOTASUBMITLOBBYMVPVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyMVPNotifyRecipient'] = _CMSGDOTALOBBYMVPNOTIFYRECIPIENT
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyMVPAwarded'] = _CMSGDOTALOBBYMVPAWARDED
DESCRIPTOR.message_types_by_name['CMsgDOTAKickedFromMatchmakingQueue'] = _CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE
DESCRIPTOR.message_types_by_name['CMsgDOTARequestSaveGames'] = _CMSGDOTAREQUESTSAVEGAMES
DESCRIPTOR.message_types_by_name['CMsgDOTARequestSaveGamesResponse'] = _CMSGDOTAREQUESTSAVEGAMESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCMatchDetailsRequest'] = _CMSGGCMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCMatchDetailsResponse'] = _CMSGGCMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgServerToGCMatchDetailsRequest'] = _CMSGSERVERTOGCMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToServerMatchDetailsResponse'] = _CMSGGCTOSERVERMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAProfileTickets'] = _CMSGDOTAPROFILETICKETS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileTickets'] = _CMSGCLIENTTOGCGETPROFILETICKETS
DESCRIPTOR.message_types_by_name['CMsgDOTAClearNotifySuccessfulReport'] = _CMSGDOTACLEARNOTIFYSUCCESSFULREPORT
DESCRIPTOR.message_types_by_name['CMsgGCToClientPartySearchInvites'] = _CMSGGCTOCLIENTPARTYSEARCHINVITES
DESCRIPTOR.message_types_by_name['CMsgDOTAWelcome'] = _CMSGDOTAWELCOME
DESCRIPTOR.message_types_by_name['CSODOTAGameHeroFavorites'] = _CSODOTAGAMEHEROFAVORITES
DESCRIPTOR.message_types_by_name['CMsgDOTAHeroFavoritesAdd'] = _CMSGDOTAHEROFAVORITESADD
DESCRIPTOR.message_types_by_name['CMsgDOTAHeroFavoritesRemove'] = _CMSGDOTAHEROFAVORITESREMOVE
DESCRIPTOR.message_types_by_name['CMsgDOTAFeaturedItems'] = _CMSGDOTAFEATUREDITEMS
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchVotes'] = _CMSGDOTAMATCHVOTES
DESCRIPTOR.message_types_by_name['CMsgCastMatchVote'] = _CMSGCASTMATCHVOTE
DESCRIPTOR.message_types_by_name['CMsgRetrieveMatchVote'] = _CMSGRETRIEVEMATCHVOTE
DESCRIPTOR.message_types_by_name['CMsgMatchVoteResponse'] = _CMSGMATCHVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFame'] = _CMSGDOTAHALLOFFAME
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFameRequest'] = _CMSGDOTAHALLOFFAMEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFameResponse'] = _CMSGDOTAHALLOFFAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAHalloweenHighScoreRequest'] = _CMSGDOTAHALLOWEENHIGHSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAHalloweenHighScoreResponse'] = _CMSGDOTAHALLOWEENHIGHSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAStorePromoPagesRequest'] = _CMSGDOTASTOREPROMOPAGESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAStorePromoPagesResponse'] = _CMSGDOTASTOREPROMOPAGESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgMatchmakingMatchGroupInfo'] = _CMSGMATCHMAKINGMATCHGROUPINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchmakingStatsRequest'] = _CMSGDOTAMATCHMAKINGSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchmakingStatsResponse'] = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAUpdateMatchmakingStats'] = _CMSGDOTAUPDATEMATCHMAKINGSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTAUpdateMatchManagementStats'] = _CMSGDOTAUPDATEMATCHMANAGEMENTSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTASetMatchHistoryAccess'] = _CMSGDOTASETMATCHHISTORYACCESS
DESCRIPTOR.message_types_by_name['CMsgDOTASetMatchHistoryAccessResponse'] = _CMSGDOTASETMATCHHISTORYACCESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTANotifyAccountFlagsChange'] = _CMSGDOTANOTIFYACCOUNTFLAGSCHANGE
DESCRIPTOR.message_types_by_name['CMsgDOTASetProfilePrivacy'] = _CMSGDOTASETPROFILEPRIVACY
DESCRIPTOR.message_types_by_name['CMsgDOTASetProfilePrivacyResponse'] = _CMSGDOTASETPROFILEPRIVACYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgUpgradeLeagueItem'] = _CMSGUPGRADELEAGUEITEM
DESCRIPTOR.message_types_by_name['CMsgUpgradeLeagueItemResponse'] = _CMSGUPGRADELEAGUEITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCWatchDownloadedReplay'] = _CMSGGCWATCHDOWNLOADEDREPLAY
DESCRIPTOR.message_types_by_name['CMsgSetMapLocationState'] = _CMSGSETMAPLOCATIONSTATE
DESCRIPTOR.message_types_by_name['CMsgSetMapLocationStateResponse'] = _CMSGSETMAPLOCATIONSTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgResetMapLocations'] = _CMSGRESETMAPLOCATIONS
DESCRIPTOR.message_types_by_name['CMsgResetMapLocationsResponse'] = _CMSGRESETMAPLOCATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgRefreshPartnerAccountLink'] = _CMSGREFRESHPARTNERACCOUNTLINK
DESCRIPTOR.message_types_by_name['CMsgClientsRejoinChatChannels'] = _CMSGCLIENTSREJOINCHATCHANNELS
DESCRIPTOR.message_types_by_name['CMsgDOTASendFriendRecruits'] = _CMSGDOTASENDFRIENDRECRUITS
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitsRequest'] = _CMSGDOTAFRIENDRECRUITSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitsResponse'] = _CMSGDOTAFRIENDRECRUITSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitInviteAcceptDecline'] = _CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE
DESCRIPTOR.message_types_by_name['CMsgRequestLeaguePrizePool'] = _CMSGREQUESTLEAGUEPRIZEPOOL
DESCRIPTOR.message_types_by_name['CMsgRequestLeaguePrizePoolResponse'] = _CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStandings'] = _CMSGGCGETHEROSTANDINGS
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStandingsResponse'] = _CMSGGCGETHEROSTANDINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroTimedStats'] = _CMSGGCGETHEROTIMEDSTATS
DESCRIPTOR.message_types_by_name['CMatchPlayerTimedStatAverages'] = _CMATCHPLAYERTIMEDSTATAVERAGES
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroTimedStatsResponse'] = _CMSGGCGETHEROTIMEDSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservationsRequest'] = _CMSGGCITEMEDITORRESERVATIONSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservation'] = _CMSGGCITEMEDITORRESERVATION
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservationsResponse'] = _CMSGGCITEMEDITORRESERVATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReserveItemDef'] = _CMSGGCITEMEDITORRESERVEITEMDEF
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReserveItemDefResponse'] = _CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReleaseReservation'] = _CMSGGCITEMEDITORRELEASERESERVATION
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReleaseReservationResponse'] = _CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTARewardTutorialPrizes'] = _CMSGDOTAREWARDTUTORIALPRIZES
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScorePost'] = _CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScoreRequest'] = _CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScoreResponse'] = _CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgFlipLobbyTeams'] = _CMSGFLIPLOBBYTEAMS
DESCRIPTOR.message_types_by_name['CMsgPresentedClientTerminateDlg'] = _CMSGPRESENTEDCLIENTTERMINATEDLG
DESCRIPTOR.message_types_by_name['CMsgGCLobbyUpdateBroadcastChannelInfo'] = _CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAClaimEventActionData'] = _CMSGDOTACLAIMEVENTACTIONDATA
DESCRIPTOR.message_types_by_name['CMsgDOTAClaimEventAction'] = _CMSGDOTACLAIMEVENTACTION
DESCRIPTOR.message_types_by_name['CMsgDOTAClaimEventActionResponse'] = _CMSGDOTACLAIMEVENTACTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCClaimEventActionUsingItem'] = _CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEM
DESCRIPTOR.message_types_by_name['CMsgClientToGCClaimEventActionUsingItemResponse'] = _CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientClaimEventActionUsingItemCompleted'] = _CMSGGCTOCLIENTCLAIMEVENTACTIONUSINGITEMCOMPLETED
DESCRIPTOR.message_types_by_name['CMsgDOTAGetEventPoints'] = _CMSGDOTAGETEVENTPOINTS
DESCRIPTOR.message_types_by_name['CMsgDOTAGetEventPointsResponse'] = _CMSGDOTAGETEVENTPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPeriodicResource'] = _CMSGDOTAGETPERIODICRESOURCE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPeriodicResourceResponse'] = _CMSGDOTAGETPERIODICRESOURCERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPeriodicResourceUpdated'] = _CMSGDOTAPERIODICRESOURCEUPDATED
DESCRIPTOR.message_types_by_name['CMsgDOTALiveLeagueGameUpdate'] = _CMSGDOTALIVELEAGUEGAMEUPDATE
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumSelection'] = _CMSGDOTACOMPENDIUMSELECTION
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumSelectionResponse'] = _CMSGDOTACOMPENDIUMSELECTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumData'] = _CMSGDOTACOMPENDIUMDATA
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumDataRequest'] = _CMSGDOTACOMPENDIUMDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumDataResponse'] = _CMSGDOTACOMPENDIUMDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPlayerMatchHistory'] = _CMSGDOTAGETPLAYERMATCHHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPlayerMatchHistoryResponse'] = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAStartDailyHeroChallenge'] = _CMSGDOTASTARTDAILYHEROCHALLENGE
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsRequest'] = _CMSGGCNOTIFICATIONSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsResponse'] = _CMSGGCNOTIFICATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsMarkReadRequest'] = _CMSGGCNOTIFICATIONSMARKREADREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCMarkNotificationListRead'] = _CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoRequest'] = _CMSGGCPLAYERINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoSubmit'] = _CMSGGCPLAYERINFOSUBMIT
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoSubmitResponse'] = _CMSGGCPLAYERINFOSUBMITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientProvideSurveyResult'] = _CMSGCLIENTPROVIDESURVEYRESULT
DESCRIPTOR.message_types_by_name['CMsgDOTAEmoticonAccessSDO'] = _CMSGDOTAEMOTICONACCESSSDO
DESCRIPTOR.message_types_by_name['CMsgClientToGCEmoticonDataRequest'] = _CMSGCLIENTTOGCEMOTICONDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientEmoticonData'] = _CMSGGCTOCLIENTEMOTICONDATA
DESCRIPTOR.message_types_by_name['CMsgClientToGCTrackDialogResult'] = _CMSGCLIENTTOGCTRACKDIALOGRESULT
DESCRIPTOR.message_types_by_name['CMsgGCToClientTournamentItemDrop'] = _CMSGGCTOCLIENTTOURNAMENTITEMDROP
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetAdditionalEquips'] = _CMSGCLIENTTOGCSETADDITIONALEQUIPS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetAdditionalEquipsResponse'] = _CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAdditionalEquips'] = _CMSGCLIENTTOGCGETADDITIONALEQUIPS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAdditionalEquipsResponse'] = _CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroOrder'] = _CMSGCLIENTTOGCGETALLHEROORDER
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroOrderResponse'] = _CMSGCLIENTTOGCGETALLHEROORDERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroProgress'] = _CMSGCLIENTTOGCGETALLHEROPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroProgressResponse'] = _CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTrophyList'] = _CMSGCLIENTTOGCGETTROPHYLIST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTrophyListResponse'] = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTrophyAwarded'] = _CMSGGCTOCLIENTTROPHYAWARDED
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileCard'] = _CMSGCLIENTTOGCGETPROFILECARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetProfileCardSlots'] = _CMSGCLIENTTOGCSETPROFILECARDSLOTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileCardStats'] = _CMSGCLIENTTOGCGETPROFILECARDSTATS
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreateHeroStatue'] = _CMSGCLIENTTOGCCREATEHEROSTATUE
DESCRIPTOR.message_types_by_name['CMsgGCToClientHeroStatueCreateResult'] = _CMSGGCTOCLIENTHEROSTATUECREATERESULT
DESCRIPTOR.message_types_by_name['CMsgGCToClientEventStatusChanged'] = _CMSGGCTOCLIENTEVENTSTATUSCHANGED
DESCRIPTOR.message_types_by_name['CMsgClientToGCPlayerStatsRequest'] = _CMSGCLIENTTOGCPLAYERSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientPlayerStatsResponse'] = _CMSGGCTOCLIENTPLAYERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCustomGamePlayerCountRequest'] = _CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientCustomGamePlayerCountResponse'] = _CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCustomGamesFriendsPlayedRequest'] = _CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientCustomGamesFriendsPlayedResponse'] = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialFeedPostCommentRequest'] = _CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialFeedPostCommentResponse'] = _CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialFeedPostMessageRequest'] = _CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialFeedPostMessageResponse'] = _CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCFriendsPlayedCustomGameRequest'] = _CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientFriendsPlayedCustomGameResponse'] = _CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialMatchPostCommentRequest'] = _CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialMatchPostCommentResponse'] = _CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialMatchDetailsRequest'] = _CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialMatchDetailsResponse'] = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPartyRichPresence'] = _CMSGDOTAPARTYRICHPRESENCE
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyRichPresence'] = _CMSGDOTALOBBYRICHPRESENCE
DESCRIPTOR.message_types_by_name['CMsgDOTACustomGameListenServerStartedLoading'] = _CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING
DESCRIPTOR.message_types_by_name['CMsgDOTACustomGameClientFinishedLoading'] = _CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING
DESCRIPTOR.message_types_by_name['CMsgClientToGCApplyGemCombiner'] = _CMSGCLIENTTOGCAPPLYGEMCOMBINER
DESCRIPTOR.message_types_by_name['CMsgClientToGCH264Unsupported'] = _CMSGCLIENTTOGCH264UNSUPPORTED
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestH264Support'] = _CMSGCLIENTTOGCREQUESTH264SUPPORT
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetQuestProgress'] = _CMSGCLIENTTOGCGETQUESTPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetQuestProgressResponse'] = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientMatchSignedOut'] = _CMSGGCTOCLIENTMATCHSIGNEDOUT
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStatsHistory'] = _CMSGGCGETHEROSTATSHISTORY
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStatsHistoryResponse'] = _CMSGGCGETHEROSTATSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPlayerConductScorecardRequest'] = _CMSGPLAYERCONDUCTSCORECARDREQUEST
DESCRIPTOR.message_types_by_name['CMsgPlayerConductScorecard'] = _CMSGPLAYERCONDUCTSCORECARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCWageringRequest'] = _CMSGCLIENTTOGCWAGERINGREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientWageringResponse'] = _CMSGGCTOCLIENTWAGERINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientWageringUpdate'] = _CMSGGCTOCLIENTWAGERINGUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCToClientArcanaVotesUpdate'] = _CMSGGCTOCLIENTARCANAVOTESUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetEventGoals'] = _CMSGCLIENTTOGCGETEVENTGOALS
DESCRIPTOR.message_types_by_name['CMsgEventGoals'] = _CMSGEVENTGOALS
DESCRIPTOR.message_types_by_name['CMsgGCToGCLeaguePredictions'] = _CMSGGCTOGCLEAGUEPREDICTIONS
DESCRIPTOR.message_types_by_name['CMsgPredictionRankings'] = _CMSGPREDICTIONRANKINGS
DESCRIPTOR.message_types_by_name['CMsgPredictionResults'] = _CMSGPREDICTIONRESULTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSuspiciousActivity'] = _CMSGCLIENTTOGCSUSPICIOUSACTIVITY
DESCRIPTOR.message_types_by_name['CMsgClientToGCHasPlayerVotedForMVP'] = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP
DESCRIPTOR.message_types_by_name['CMsgClientToGCHasPlayerVotedForMVPResponse'] = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForLeagueGameMVP'] = _CMSGCLIENTTOGCVOTEFORLEAGUEGAMEMVP
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForMVP'] = _CMSGCLIENTTOGCVOTEFORMVP
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForMVPResponse'] = _CMSGCLIENTTOGCVOTEFORMVPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCMVPVoteTimeout'] = _CMSGCLIENTTOGCMVPVOTETIMEOUT
DESCRIPTOR.message_types_by_name['CMsgClientToGCMVPVoteTimeoutResponse'] = _CMSGCLIENTTOGCMVPVOTETIMEOUTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgMVPVotesForMatch'] = _CMSGMVPVOTESFORMATCH
DESCRIPTOR.message_types_by_name['CMsgClientToGCTeammateStatsRequest'] = _CMSGCLIENTTOGCTEAMMATESTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTeammateStatsResponse'] = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForArcana'] = _CMSGCLIENTTOGCVOTEFORARCANA
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForArcanaResponse'] = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE
DESCRIPTOR.message_types_by_name['CMsgArcanaVotes'] = _CMSGARCANAVOTES
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestArcanaVotesRemaining'] = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestArcanaVotesRemainingResponse'] = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestEventPointLogV2'] = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGV2
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestEventPointLogResponseV2'] = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2
DESCRIPTOR.message_types_by_name['CMsgClientToGCPublishUserStat'] = _CMSGCLIENTTOGCPUBLISHUSERSTAT
DESCRIPTOR.message_types_by_name['CMsgClientToGCAddTI6TreeProgress'] = _CMSGCLIENTTOGCADDTI6TREEPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaPlaysRemaining'] = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaPlaysRemainingResponse'] = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaGameResult'] = _CMSGCLIENTTOGCREQUESTLINAGAMERESULT
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaGameResultResponse'] = _CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestSlarkGameResult'] = _CMSGCLIENTTOGCREQUESTSLARKGAMERESULT
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestSlarkGameResultResponse'] = _CMSGCLIENTTOGCREQUESTSLARKGAMERESULTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientQuestProgressUpdated'] = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemItem'] = _CMSGDOTAREDEEMITEM
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemItemResponse'] = _CMSGDOTAREDEEMITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPerfectWorldUserLookupRequest'] = _CMSGPERFECTWORLDUSERLOOKUPREQUEST
DESCRIPTOR.message_types_by_name['CMsgPerfectWorldUserLookupResponse'] = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgMakeOffering'] = _CMSGMAKEOFFERING
DESCRIPTOR.message_types_by_name['CMsgRequestOfferings'] = _CMSGREQUESTOFFERINGS
DESCRIPTOR.message_types_by_name['CMsgRequestOfferingsResponse'] = _CMSGREQUESTOFFERINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPCBangTimedReward'] = _CMSGDOTAPCBANGTIMEDREWARD
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumInGamePredictionResults'] = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSelectCompendiumInGamePrediction'] = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION
DESCRIPTOR.message_types_by_name['CMsgClientToGCSelectCompendiumInGamePredictionResponse'] = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCOpenPlayerCardPack'] = _CMSGCLIENTTOGCOPENPLAYERCARDPACK
DESCRIPTOR.message_types_by_name['CMsgClientToGCOpenPlayerCardPackResponse'] = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecyclePlayerCard'] = _CMSGCLIENTTOGCRECYCLEPLAYERCARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecyclePlayerCardResponse'] = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreatePlayerCardPack'] = _CMSGCLIENTTOGCCREATEPLAYERCARDPACK
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreatePlayerCardPackResponse'] = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_International2016'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_Fall2016'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_Winter2017'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_TI7'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_TI8'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupRequest'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupResponse'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupListRequest'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupListResponse'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCTransferSeasonalMMRRequest'] = _CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTransferSeasonalMMRResponse'] = _CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPlaytestStatus'] = _CMSGGCTOCLIENTPLAYTESTSTATUS
DESCRIPTOR.message_types_by_name['CMsgClientToGCJoinPlaytest'] = _CMSGCLIENTTOGCJOINPLAYTEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCJoinPlaytestResponse'] = _CMSGCLIENTTOGCJOINPLAYTESTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASetFavoriteTeam'] = _CMSGDOTASETFAVORITETEAM
DESCRIPTOR.message_types_by_name['CMsgDOTATriviaQuestion'] = _CMSGDOTATRIVIAQUESTION
DESCRIPTOR.message_types_by_name['CMsgDOTATriviaCurrentQuestions'] = _CMSGDOTATRIVIACURRENTQUESTIONS
DESCRIPTOR.message_types_by_name['CMsgDOTATriviaQuestionAnswersSummary'] = _CMSGDOTATRIVIAQUESTIONANSWERSSUMMARY
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitTriviaQuestionAnswer'] = _CMSGDOTASUBMITTRIVIAQUESTIONANSWER
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitTriviaQuestionAnswerResponse'] = _CMSGDOTASUBMITTRIVIAQUESTIONANSWERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAStartTriviaSession'] = _CMSGDOTASTARTTRIVIASESSION
DESCRIPTOR.message_types_by_name['CMsgDOTAStartTriviaSessionResponse'] = _CMSGDOTASTARTTRIVIASESSIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGiveTip'] = _CMSGCLIENTTOGCGIVETIP
DESCRIPTOR.message_types_by_name['CMsgClientToGCGiveTipResponse'] = _CMSGCLIENTTOGCGIVETIPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAAnchorPhoneNumberRequest'] = _CMSGDOTAANCHORPHONENUMBERREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAAnchorPhoneNumberResponse'] = _CMSGDOTAANCHORPHONENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAUnanchorPhoneNumberRequest'] = _CMSGDOTAUNANCHORPHONENUMBERREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAUnanchorPhoneNumberResponse'] = _CMSGDOTAUNANCHORPHONENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTipNotification'] = _CMSGGCTOCLIENTTIPNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCToClientCommendNotification'] = _CMSGGCTOCLIENTCOMMENDNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCToClientAllStarVotesRequest'] = _CMSGGCTOCLIENTALLSTARVOTESREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientAllStarVotesReply'] = _CMSGGCTOCLIENTALLSTARVOTESREPLY
DESCRIPTOR.message_types_by_name['CMsgGCToClientAllStarVotesSubmit'] = _CMSGGCTOCLIENTALLSTARVOTESSUBMIT
DESCRIPTOR.message_types_by_name['CMsgGCToClientAllStarVotesSubmitReply'] = _CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY
DESCRIPTOR.message_types_by_name['CMsgDOTAClientToGCQuickStatsRequest'] = _CMSGDOTACLIENTTOGCQUICKSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAClientToGCQuickStatsResponse'] = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASelectionPriorityChoiceRequest'] = _CMSGDOTASELECTIONPRIORITYCHOICEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTASelectionPriorityChoiceResponse'] = _CMSGDOTASELECTIONPRIORITYCHOICERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGameAutographReward'] = _CMSGDOTAGAMEAUTOGRAPHREWARD
DESCRIPTOR.message_types_by_name['CMsgDOTAGameAutographRewardResponse'] = _CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTADestroyLobbyRequest'] = _CMSGDOTADESTROYLOBBYREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTADestroyLobbyResponse'] = _CMSGDOTADESTROYLOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetRecentPlayTimeFriendsRequest'] = _CMSGDOTAGETRECENTPLAYTIMEFRIENDSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGetRecentPlayTimeFriendsResponse'] = _CMSGDOTAGETRECENTPLAYTIMEFRIENDSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPurchaseItemWithEventPoints'] = _CMSGPURCHASEITEMWITHEVENTPOINTS
DESCRIPTOR.message_types_by_name['CMsgPurchaseItemWithEventPointsResponse'] = _CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCRequestItemRecommendations'] = _CMSGGCREQUESTITEMRECOMMENDATIONS
DESCRIPTOR.message_types_by_name['CMsgGCRequestItemRecommendationsResponse'] = _CMSGGCREQUESTITEMRECOMMENDATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCRequestSkillUpRecommendations'] = _CMSGGCREQUESTSKILLUPRECOMMENDATIONS
DESCRIPTOR.message_types_by_name['CMsgGCRequestSkillUpRecommendationsResponse'] = _CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecycleHeroRelic'] = _CMSGCLIENTTOGCRECYCLEHERORELIC
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecycleHeroRelicResponse'] = _CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPurchaseHeroRelic'] = _CMSGPURCHASEHERORELIC
DESCRIPTOR.message_types_by_name['CMsgPurchaseHeroRelicResponse'] = _CMSGPURCHASEHERORELICRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPurchaseHeroRandomRelic'] = _CMSGPURCHASEHERORANDOMRELIC
DESCRIPTOR.message_types_by_name['CMsgPurchaseHeroRandomRelicResponse'] = _CMSGPURCHASEHERORANDOMRELICRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlusWeeklyChallengeResult'] = _CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULT
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlusWeeklyChallengeResultResponse'] = _CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgProfileRequest'] = _CMSGPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgProfileResponse'] = _CMSGPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgProfileUpdate'] = _CMSGPROFILEUPDATE
DESCRIPTOR.message_types_by_name['CMsgProfileUpdateResponse'] = _CMSGPROFILEUPDATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgTalentWinRates'] = _CMSGTALENTWINRATES
DESCRIPTOR.message_types_by_name['CMsgGlobalHeroAverages'] = _CMSGGLOBALHEROAVERAGES
DESCRIPTOR.message_types_by_name['CMsgHeroGlobalDataRequest'] = _CMSGHEROGLOBALDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgHeroGlobalDataResponse'] = _CMSGHEROGLOBALDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgHeroGlobalDataAllHeroes'] = _CMSGHEROGLOBALDATAALLHEROES
DESCRIPTOR.message_types_by_name['CMsgHeroGlobalDataHeroesAlliesAndEnemies'] = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES
DESCRIPTOR.message_types_by_name['CMsgPrivateMetadataKeyRequest'] = _CMSGPRIVATEMETADATAKEYREQUEST
DESCRIPTOR.message_types_by_name['CMsgPrivateMetadataKeyResponse'] = _CMSGPRIVATEMETADATAKEYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgActivatePlusFreeTrialRequest'] = _CMSGACTIVATEPLUSFREETRIALREQUEST
DESCRIPTOR.message_types_by_name['CMsgActivatePlusFreeTrialResponse'] = _CMSGACTIVATEPLUSFREETRIALRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientCavernCrawlMapPathCompleted'] = _CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED
DESCRIPTOR.message_types_by_name['CMsgGCToClientCavernCrawlMapUpdated'] = _CMSGGCTOCLIENTCAVERNCRAWLMAPUPDATED
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlClaimRoom'] = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOM
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlClaimRoomResponse'] = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlUseItemOnRoom'] = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOM
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlUseItemOnRoomResponse'] = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlUseItemOnPath'] = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATH
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlUseItemOnPathResponse'] = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlRequestMapState'] = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlRequestMapStateResponse'] = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlGetClaimedRoomCount'] = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNT
DESCRIPTOR.message_types_by_name['CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse'] = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAMutationList'] = _CMSGDOTAMUTATIONLIST
DESCRIPTOR.message_types_by_name['CMsgEventTipsSummaryRequest'] = _CMSGEVENTTIPSSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['CMsgEventTipsSummaryResponse'] = _CMSGEVENTTIPSSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSocialFeedRequest'] = _CMSGSOCIALFEEDREQUEST
DESCRIPTOR.message_types_by_name['CMsgSocialFeedResponse'] = _CMSGSOCIALFEEDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSocialFeedCommentsRequest'] = _CMSGSOCIALFEEDCOMMENTSREQUEST
DESCRIPTOR.message_types_by_name['CMsgSocialFeedCommentsResponse'] = _CMSGSOCIALFEEDCOMMENTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCPlayerCardSpecificPurchaseRequest'] = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCPlayerCardSpecificPurchaseResponse'] = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestContestVotes'] = _CMSGCLIENTTOGCREQUESTCONTESTVOTES
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestContestVotesResponse'] = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecordContestVote'] = _CMSGCLIENTTOGCRECORDCONTESTVOTE
DESCRIPTOR.message_types_by_name['CMsgGCToClientRecordContestVoteResponse'] = _CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTADPCFeed'] = _CMSGDOTADPCFEED
DESCRIPTOR.message_types_by_name['CMsgDOTADPCUserInfo'] = _CMSGDOTADPCUSERINFO
DESCRIPTOR.message_types_by_name['CMsgDevGrantEventPoints'] = _CMSGDEVGRANTEVENTPOINTS
DESCRIPTOR.message_types_by_name['CMsgDevGrantEventPointsResponse'] = _CMSGDEVGRANTEVENTPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDevGrantEventAction'] = _CMSGDEVGRANTEVENTACTION
DESCRIPTOR.message_types_by_name['CMsgDevGrantEventActionResponse'] = _CMSGDEVGRANTEVENTACTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDevResetEventState'] = _CMSGDEVRESETEVENTSTATE
DESCRIPTOR.message_types_by_name['CMsgDevResetEventStateResponse'] = _CMSGDEVRESETEVENTSTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgConsumeEventSupportGrantItem'] = _CMSGCONSUMEEVENTSUPPORTGRANTITEM
DESCRIPTOR.message_types_by_name['CMsgConsumeEventSupportGrantItemResponse'] = _CMSGCONSUMEEVENTSUPPORTGRANTITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetFilteredPlayers'] = _CMSGCLIENTTOGCGETFILTEREDPLAYERS
DESCRIPTOR.message_types_by_name['CMsgGCToClientGetFilteredPlayersResponse'] = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRemoveFilteredPlayer'] = _CMSGCLIENTTOGCREMOVEFILTEREDPLAYER
DESCRIPTOR.message_types_by_name['CMsgGCToClientRemoveFilteredPlayerResponse'] = _CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPartySearchPlayer'] = _CMSGPARTYSEARCHPLAYER
DESCRIPTOR.message_types_by_name['CMsgGCToClientPlayerBeaconState'] = _CMSGGCTOCLIENTPLAYERBEACONSTATE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPartyBeaconUpdate'] = _CMSGGCTOCLIENTPARTYBEACONUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUpdatePartyBeacon'] = _CMSGCLIENTTOGCUPDATEPARTYBEACON
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestActiveBeaconParties'] = _CMSGCLIENTTOGCREQUESTACTIVEBEACONPARTIES
DESCRIPTOR.message_types_by_name['CMsgGCToClientRequestActiveBeaconPartiesResponse'] = _CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCJoinPartyFromBeacon'] = _CMSGCLIENTTOGCJOINPARTYFROMBEACON
DESCRIPTOR.message_types_by_name['CMsgGCToClientJoinPartyFromBeaconResponse'] = _CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCManageFavorites'] = _CMSGCLIENTTOGCMANAGEFAVORITES
DESCRIPTOR.message_types_by_name['CMsgGCToClientManageFavoritesResponse'] = _CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetFavoritePlayers'] = _CMSGCLIENTTOGCGETFAVORITEPLAYERS
DESCRIPTOR.message_types_by_name['CMsgGCToClientGetFavoritePlayersResponse'] = _CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPartySearchInvite'] = _CMSGGCTOCLIENTPARTYSEARCHINVITE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVerifyFavoritePlayers'] = _CMSGCLIENTTOGCVERIFYFAVORITEPLAYERS
DESCRIPTOR.message_types_by_name['CMsgGCToClientVerifyFavoritePlayersResponse'] = _CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerRecentAccomplishments'] = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse'] = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerHeroRecentAccomplishments'] = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse'] = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPlayerCoachMatch'] = _CMSGPLAYERCOACHMATCH
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerCoachMatches'] = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHES
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerCoachMatchesResponse'] = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerCoachMatch'] = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCH
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestPlayerCoachMatchResponse'] = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSubmitCoachTeammateRating'] = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATING
DESCRIPTOR.message_types_by_name['CMsgClientToGCSubmitCoachTeammateRatingResponse'] = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientCoachTeammateRatingsChanged'] = _CMSGGCTOCLIENTCOACHTEAMMATERATINGSCHANGED
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTicketCodesRequest'] = _CMSGCLIENTTOGCGETTICKETCODESREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTicketCodesResponse'] = _CMSGCLIENTTOGCGETTICKETCODESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetUnderlordsCDKeyRequest'] = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetUnderlordsCDKeyResponse'] = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetFavoriteAllStarPlayer'] = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYER
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetFavoriteAllStarPlayerResponse'] = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetFavoriteAllStarPlayerRequest'] = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetFavoriteAllStarPlayerResponse'] = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVerifyIntegrity'] = _CMSGCLIENTTOGCVERIFYINTEGRITY
DESCRIPTOR.enum_types_by_name['DOTA_WatchReplayType'] = _DOTA_WATCHREPLAYTYPE
DESCRIPTOR.enum_types_by_name['EItemEditorReservationResult'] = _EITEMEDITORRESERVATIONRESULT
DESCRIPTOR.enum_types_by_name['EFeaturedHeroTextField'] = _EFEATUREDHEROTEXTFIELD
DESCRIPTOR.enum_types_by_name['EFeaturedHeroDataType'] = _EFEATUREDHERODATATYPE
DESCRIPTOR.enum_types_by_name['EWeekendTourneyRichPresenceEvent'] = _EWEEKENDTOURNEYRICHPRESENCEEVENT
DESCRIPTOR.enum_types_by_name['EDOTATriviaQuestionCategory'] = _EDOTATRIVIAQUESTIONCATEGORY
DESCRIPTOR.enum_types_by_name['EDOTATriviaAnswerResult'] = _EDOTATRIVIAANSWERRESULT
DESCRIPTOR.enum_types_by_name['EPurchaseHeroRelicResult'] = _EPURCHASEHERORELICRESULT
DESCRIPTOR.enum_types_by_name['EDevEventRequestResult'] = _EDEVEVENTREQUESTRESULT
DESCRIPTOR.enum_types_by_name['ESupportEventRequestResult'] = _ESUPPORTEVENTREQUESTRESULT
DESCRIPTOR.enum_types_by_name['ECoachTeammateRating'] = _ECOACHTEAMMATERATING
DESCRIPTOR.enum_types_by_name['EPlayerCoachMatchFlag'] = _EPLAYERCOACHMATCHFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientSuspended = _reflection.GeneratedProtocolMessageType('CMsgClientSuspended', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSUSPENDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientSuspended)
  ))
_sym_db.RegisterMessage(CMsgClientSuspended)

CMsgBalancedShuffleLobby = _reflection.GeneratedProtocolMessageType('CMsgBalancedShuffleLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGBALANCEDSHUFFLELOBBY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgBalancedShuffleLobby)
  ))
_sym_db.RegisterMessage(CMsgBalancedShuffleLobby)

CMsgInitialQuestionnaireResponse = _reflection.GeneratedProtocolMessageType('CMsgInitialQuestionnaireResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINITIALQUESTIONNAIRERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgInitialQuestionnaireResponse)
  ))
_sym_db.RegisterMessage(CMsgInitialQuestionnaireResponse)

CMsgDOTAPlayerMatchHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTAPlayerMatchHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPLAYERMATCHHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPlayerMatchHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTAPlayerMatchHistory)

CMsgDOTAMatchHistoryFilter = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchHistoryFilter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHHISTORYFILTER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMatchHistoryFilter)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchHistoryFilter)

CMsgDOTARequestMatches = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestMatches', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTMATCHES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARequestMatches)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestMatches)

CMsgDOTARequestMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestMatchesResponse', (_message.Message,), dict(

  Series = _reflection.GeneratedProtocolMessageType('Series', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREQUESTMATCHESRESPONSE_SERIES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTARequestMatchesResponse.Series)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAREQUESTMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARequestMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestMatchesResponse)
_sym_db.RegisterMessage(CMsgDOTARequestMatchesResponse.Series)

CMsgDOTAGetDPCStandingsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetDPCStandingsResponse', (_message.Message,), dict(

  TeamInfo = _reflection.GeneratedProtocolMessageType('TeamInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGETDPCSTANDINGSRESPONSE_TEAMINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetDPCStandingsResponse.TeamInfo)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGETDPCSTANDINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetDPCStandingsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetDPCStandingsResponse)
_sym_db.RegisterMessage(CMsgDOTAGetDPCStandingsResponse.TeamInfo)

CMsgDOTAPopup = _reflection.GeneratedProtocolMessageType('CMsgDOTAPopup', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPOPUP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPopup)
  ))
_sym_db.RegisterMessage(CMsgDOTAPopup)

CMsgDOTAReportsRemainingRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportsRemainingRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTSREMAININGREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAReportsRemainingRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportsRemainingRequest)

CMsgDOTAReportsRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportsRemainingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTSREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAReportsRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportsRemainingResponse)

CMsgDOTASubmitPlayerReport = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitPlayerReport', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITPLAYERREPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitPlayerReport)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitPlayerReport)

CMsgDOTASubmitPlayerReportResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitPlayerReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITPLAYERREPORTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitPlayerReportResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitPlayerReportResponse)

CMsgDOTAReportCountsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportCountsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTCOUNTSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAReportCountsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportCountsRequest)

CMsgDOTAReportCountsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportCountsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTCOUNTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAReportCountsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportCountsResponse)

CMsgDOTASubmitLobbyMVPVote = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitLobbyMVPVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITLOBBYMVPVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitLobbyMVPVote)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitLobbyMVPVote)

CMsgDOTASubmitLobbyMVPVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitLobbyMVPVoteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITLOBBYMVPVOTERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitLobbyMVPVoteResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitLobbyMVPVoteResponse)

CMsgDOTALobbyMVPNotifyRecipient = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyMVPNotifyRecipient', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYMVPNOTIFYRECIPIENT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALobbyMVPNotifyRecipient)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyMVPNotifyRecipient)

CMsgDOTALobbyMVPAwarded = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyMVPAwarded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYMVPAWARDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALobbyMVPAwarded)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyMVPAwarded)

CMsgDOTAKickedFromMatchmakingQueue = _reflection.GeneratedProtocolMessageType('CMsgDOTAKickedFromMatchmakingQueue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAKickedFromMatchmakingQueue)
  ))
_sym_db.RegisterMessage(CMsgDOTAKickedFromMatchmakingQueue)

CMsgDOTARequestSaveGames = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestSaveGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTSAVEGAMES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARequestSaveGames)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestSaveGames)

CMsgDOTARequestSaveGamesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestSaveGamesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTSAVEGAMESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARequestSaveGamesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestSaveGamesResponse)

CMsgGCMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCMatchDetailsRequest)

CMsgGCMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCMatchDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCMatchDetailsResponse)

CMsgServerToGCMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgServerToGCMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERTOGCMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgServerToGCMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgServerToGCMatchDetailsRequest)

CMsgGCToServerMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToServerMatchDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOSERVERMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToServerMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToServerMatchDetailsResponse)

CMsgDOTAProfileTickets = _reflection.GeneratedProtocolMessageType('CMsgDOTAProfileTickets', (_message.Message,), dict(

  LeaguePass = _reflection.GeneratedProtocolMessageType('LeaguePass', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILETICKETS_LEAGUEPASS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAProfileTickets.LeaguePass)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPROFILETICKETS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAProfileTickets)
  ))
_sym_db.RegisterMessage(CMsgDOTAProfileTickets)
_sym_db.RegisterMessage(CMsgDOTAProfileTickets.LeaguePass)

CMsgClientToGCGetProfileTickets = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileTickets', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILETICKETS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetProfileTickets)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileTickets)

CMsgDOTAClearNotifySuccessfulReport = _reflection.GeneratedProtocolMessageType('CMsgDOTAClearNotifySuccessfulReport', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLEARNOTIFYSUCCESSFULREPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClearNotifySuccessfulReport)
  ))
_sym_db.RegisterMessage(CMsgDOTAClearNotifySuccessfulReport)

CMsgGCToClientPartySearchInvites = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPartySearchInvites', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPARTYSEARCHINVITES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPartySearchInvites)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPartySearchInvites)

CMsgDOTAWelcome = _reflection.GeneratedProtocolMessageType('CMsgDOTAWelcome', (_message.Message,), dict(

  CExtraMsg = _reflection.GeneratedProtocolMessageType('CExtraMsg', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWELCOME_CEXTRAMSG,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAWelcome.CExtraMsg)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAWELCOME,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAWelcome)
  ))
_sym_db.RegisterMessage(CMsgDOTAWelcome)
_sym_db.RegisterMessage(CMsgDOTAWelcome.CExtraMsg)

CSODOTAGameHeroFavorites = _reflection.GeneratedProtocolMessageType('CSODOTAGameHeroFavorites', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAGAMEHEROFAVORITES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSODOTAGameHeroFavorites)
  ))
_sym_db.RegisterMessage(CSODOTAGameHeroFavorites)

CMsgDOTAHeroFavoritesAdd = _reflection.GeneratedProtocolMessageType('CMsgDOTAHeroFavoritesAdd', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHEROFAVORITESADD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHeroFavoritesAdd)
  ))
_sym_db.RegisterMessage(CMsgDOTAHeroFavoritesAdd)

CMsgDOTAHeroFavoritesRemove = _reflection.GeneratedProtocolMessageType('CMsgDOTAHeroFavoritesRemove', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHEROFAVORITESREMOVE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHeroFavoritesRemove)
  ))
_sym_db.RegisterMessage(CMsgDOTAHeroFavoritesRemove)

CMsgDOTAFeaturedItems = _reflection.GeneratedProtocolMessageType('CMsgDOTAFeaturedItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFEATUREDITEMS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAFeaturedItems)
  ))
_sym_db.RegisterMessage(CMsgDOTAFeaturedItems)

CMsgDOTAMatchVotes = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchVotes', (_message.Message,), dict(

  PlayerVote = _reflection.GeneratedProtocolMessageType('PlayerVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCHVOTES_PLAYERVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMatchVotes.PlayerVote)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAMATCHVOTES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMatchVotes)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchVotes)
_sym_db.RegisterMessage(CMsgDOTAMatchVotes.PlayerVote)

CMsgCastMatchVote = _reflection.GeneratedProtocolMessageType('CMsgCastMatchVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCASTMATCHVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgCastMatchVote)
  ))
_sym_db.RegisterMessage(CMsgCastMatchVote)

CMsgRetrieveMatchVote = _reflection.GeneratedProtocolMessageType('CMsgRetrieveMatchVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRETRIEVEMATCHVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRetrieveMatchVote)
  ))
_sym_db.RegisterMessage(CMsgRetrieveMatchVote)

CMsgMatchVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgMatchVoteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMATCHVOTERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgMatchVoteResponse)
  ))
_sym_db.RegisterMessage(CMsgMatchVoteResponse)

CMsgDOTAHallOfFame = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFame', (_message.Message,), dict(

  FeaturedPlayer = _reflection.GeneratedProtocolMessageType('FeaturedPlayer', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAHALLOFFAME_FEATUREDPLAYER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHallOfFame.FeaturedPlayer)
    ))
  ,

  FeaturedFarmer = _reflection.GeneratedProtocolMessageType('FeaturedFarmer', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAHALLOFFAME_FEATUREDFARMER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHallOfFame.FeaturedFarmer)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAHALLOFFAME,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHallOfFame)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFame)
_sym_db.RegisterMessage(CMsgDOTAHallOfFame.FeaturedPlayer)
_sym_db.RegisterMessage(CMsgDOTAHallOfFame.FeaturedFarmer)

CMsgDOTAHallOfFameRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOFFAMEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHallOfFameRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFameRequest)

CMsgDOTAHallOfFameResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOFFAMERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHallOfFameResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFameResponse)

CMsgDOTAHalloweenHighScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAHalloweenHighScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOWEENHIGHSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHalloweenHighScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAHalloweenHighScoreRequest)

CMsgDOTAHalloweenHighScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHalloweenHighScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOWEENHIGHSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAHalloweenHighScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHalloweenHighScoreResponse)

CMsgDOTAStorePromoPagesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAStorePromoPagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStorePromoPagesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesRequest)

CMsgDOTAStorePromoPagesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAStorePromoPagesResponse', (_message.Message,), dict(

  PromoPage = _reflection.GeneratedProtocolMessageType('PromoPage', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStorePromoPagesResponse.PromoPage)
    ))
  ,
  DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStorePromoPagesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesResponse)
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesResponse.PromoPage)

CMsgMatchmakingMatchGroupInfo = _reflection.GeneratedProtocolMessageType('CMsgMatchmakingMatchGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMATCHMAKINGMATCHGROUPINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgMatchmakingMatchGroupInfo)
  ))
_sym_db.RegisterMessage(CMsgMatchmakingMatchGroupInfo)

CMsgDOTAMatchmakingStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchmakingStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHMAKINGSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMatchmakingStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchmakingStatsRequest)

CMsgDOTAMatchmakingStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchmakingStatsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHMAKINGSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMatchmakingStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchmakingStatsResponse)

CMsgDOTAUpdateMatchmakingStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAUpdateMatchmakingStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUPDATEMATCHMAKINGSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAUpdateMatchmakingStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAUpdateMatchmakingStats)

CMsgDOTAUpdateMatchManagementStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAUpdateMatchManagementStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUPDATEMATCHMANAGEMENTSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAUpdateMatchManagementStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAUpdateMatchManagementStats)

CMsgDOTASetMatchHistoryAccess = _reflection.GeneratedProtocolMessageType('CMsgDOTASetMatchHistoryAccess', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETMATCHHISTORYACCESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASetMatchHistoryAccess)
  ))
_sym_db.RegisterMessage(CMsgDOTASetMatchHistoryAccess)

CMsgDOTASetMatchHistoryAccessResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASetMatchHistoryAccessResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETMATCHHISTORYACCESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASetMatchHistoryAccessResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASetMatchHistoryAccessResponse)

CMsgDOTANotifyAccountFlagsChange = _reflection.GeneratedProtocolMessageType('CMsgDOTANotifyAccountFlagsChange', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTANOTIFYACCOUNTFLAGSCHANGE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTANotifyAccountFlagsChange)
  ))
_sym_db.RegisterMessage(CMsgDOTANotifyAccountFlagsChange)

CMsgDOTASetProfilePrivacy = _reflection.GeneratedProtocolMessageType('CMsgDOTASetProfilePrivacy', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETPROFILEPRIVACY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASetProfilePrivacy)
  ))
_sym_db.RegisterMessage(CMsgDOTASetProfilePrivacy)

CMsgDOTASetProfilePrivacyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASetProfilePrivacyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETPROFILEPRIVACYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASetProfilePrivacyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASetProfilePrivacyResponse)

CMsgUpgradeLeagueItem = _reflection.GeneratedProtocolMessageType('CMsgUpgradeLeagueItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPGRADELEAGUEITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgUpgradeLeagueItem)
  ))
_sym_db.RegisterMessage(CMsgUpgradeLeagueItem)

CMsgUpgradeLeagueItemResponse = _reflection.GeneratedProtocolMessageType('CMsgUpgradeLeagueItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPGRADELEAGUEITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgUpgradeLeagueItemResponse)
  ))
_sym_db.RegisterMessage(CMsgUpgradeLeagueItemResponse)

CMsgGCWatchDownloadedReplay = _reflection.GeneratedProtocolMessageType('CMsgGCWatchDownloadedReplay', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCWATCHDOWNLOADEDREPLAY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCWatchDownloadedReplay)
  ))
_sym_db.RegisterMessage(CMsgGCWatchDownloadedReplay)

CMsgSetMapLocationState = _reflection.GeneratedProtocolMessageType('CMsgSetMapLocationState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETMAPLOCATIONSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSetMapLocationState)
  ))
_sym_db.RegisterMessage(CMsgSetMapLocationState)

CMsgSetMapLocationStateResponse = _reflection.GeneratedProtocolMessageType('CMsgSetMapLocationStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETMAPLOCATIONSTATERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSetMapLocationStateResponse)
  ))
_sym_db.RegisterMessage(CMsgSetMapLocationStateResponse)

CMsgResetMapLocations = _reflection.GeneratedProtocolMessageType('CMsgResetMapLocations', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETMAPLOCATIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgResetMapLocations)
  ))
_sym_db.RegisterMessage(CMsgResetMapLocations)

CMsgResetMapLocationsResponse = _reflection.GeneratedProtocolMessageType('CMsgResetMapLocationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETMAPLOCATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgResetMapLocationsResponse)
  ))
_sym_db.RegisterMessage(CMsgResetMapLocationsResponse)

CMsgRefreshPartnerAccountLink = _reflection.GeneratedProtocolMessageType('CMsgRefreshPartnerAccountLink', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREFRESHPARTNERACCOUNTLINK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRefreshPartnerAccountLink)
  ))
_sym_db.RegisterMessage(CMsgRefreshPartnerAccountLink)

CMsgClientsRejoinChatChannels = _reflection.GeneratedProtocolMessageType('CMsgClientsRejoinChatChannels', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSREJOINCHATCHANNELS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientsRejoinChatChannels)
  ))
_sym_db.RegisterMessage(CMsgClientsRejoinChatChannels)

CMsgDOTASendFriendRecruits = _reflection.GeneratedProtocolMessageType('CMsgDOTASendFriendRecruits', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASENDFRIENDRECRUITS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASendFriendRecruits)
  ))
_sym_db.RegisterMessage(CMsgDOTASendFriendRecruits)

CMsgDOTAFriendRecruitsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAFriendRecruitsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsRequest)

CMsgDOTAFriendRecruitsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitsResponse', (_message.Message,), dict(

  FriendRecruitStatus = _reflection.GeneratedProtocolMessageType('FriendRecruitStatus', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAFriendRecruitsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsResponse)
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus)

CMsgDOTAFriendRecruitInviteAcceptDecline = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitInviteAcceptDecline', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAFriendRecruitInviteAcceptDecline)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitInviteAcceptDecline)

CMsgRequestLeaguePrizePool = _reflection.GeneratedProtocolMessageType('CMsgRequestLeaguePrizePool', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTLEAGUEPRIZEPOOL,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRequestLeaguePrizePool)
  ))
_sym_db.RegisterMessage(CMsgRequestLeaguePrizePool)

CMsgRequestLeaguePrizePoolResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestLeaguePrizePoolResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRequestLeaguePrizePoolResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestLeaguePrizePoolResponse)

CMsgGCGetHeroStandings = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStandings', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTANDINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroStandings)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStandings)

CMsgGCGetHeroStandingsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStandingsResponse', (_message.Message,), dict(

  Hero = _reflection.GeneratedProtocolMessageType('Hero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCGETHEROSTANDINGSRESPONSE_HERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroStandingsResponse.Hero)
    ))
  ,
  DESCRIPTOR = _CMSGGCGETHEROSTANDINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroStandingsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStandingsResponse)
_sym_db.RegisterMessage(CMsgGCGetHeroStandingsResponse.Hero)

CMsgGCGetHeroTimedStats = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroTimedStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROTIMEDSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroTimedStats)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroTimedStats)

CMatchPlayerTimedStatAverages = _reflection.GeneratedProtocolMessageType('CMatchPlayerTimedStatAverages', (_message.Message,), dict(
  DESCRIPTOR = _CMATCHPLAYERTIMEDSTATAVERAGES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMatchPlayerTimedStatAverages)
  ))
_sym_db.RegisterMessage(CMatchPlayerTimedStatAverages)

CMsgGCGetHeroTimedStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroTimedStatsResponse', (_message.Message,), dict(

  TimedStatsContainer = _reflection.GeneratedProtocolMessageType('TimedStatsContainer', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCGETHEROTIMEDSTATSRESPONSE_TIMEDSTATSCONTAINER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer)
    ))
  ,

  RankChunkedStats = _reflection.GeneratedProtocolMessageType('RankChunkedStats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCGETHEROTIMEDSTATSRESPONSE_RANKCHUNKEDSTATS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroTimedStatsResponse.RankChunkedStats)
    ))
  ,
  DESCRIPTOR = _CMSGGCGETHEROTIMEDSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroTimedStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroTimedStatsResponse)
_sym_db.RegisterMessage(CMsgGCGetHeroTimedStatsResponse.TimedStatsContainer)
_sym_db.RegisterMessage(CMsgGCGetHeroTimedStatsResponse.RankChunkedStats)

CMsgGCItemEditorReservationsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATIONSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReservationsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservationsRequest)

CMsgGCItemEditorReservation = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservation', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReservation)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservation)

CMsgGCItemEditorReservationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReservationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservationsResponse)

CMsgGCItemEditorReserveItemDef = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReserveItemDef', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVEITEMDEF,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReserveItemDef)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReserveItemDef)

CMsgGCItemEditorReserveItemDefResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReserveItemDefResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReserveItemDefResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReserveItemDefResponse)

CMsgGCItemEditorReleaseReservation = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReleaseReservation', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRELEASERESERVATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReleaseReservation)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReleaseReservation)

CMsgGCItemEditorReleaseReservationResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReleaseReservationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCItemEditorReleaseReservationResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReleaseReservationResponse)

CMsgDOTARewardTutorialPrizes = _reflection.GeneratedProtocolMessageType('CMsgDOTARewardTutorialPrizes', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREWARDTUTORIALPRIZES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARewardTutorialPrizes)
  ))
_sym_db.RegisterMessage(CMsgDOTARewardTutorialPrizes)

CMsgDOTALastHitChallengeHighScorePost = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScorePost', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALastHitChallengeHighScorePost)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScorePost)

CMsgDOTALastHitChallengeHighScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALastHitChallengeHighScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScoreRequest)

CMsgDOTALastHitChallengeHighScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALastHitChallengeHighScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScoreResponse)

CMsgFlipLobbyTeams = _reflection.GeneratedProtocolMessageType('CMsgFlipLobbyTeams', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFLIPLOBBYTEAMS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgFlipLobbyTeams)
  ))
_sym_db.RegisterMessage(CMsgFlipLobbyTeams)

CMsgPresentedClientTerminateDlg = _reflection.GeneratedProtocolMessageType('CMsgPresentedClientTerminateDlg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRESENTEDCLIENTTERMINATEDLG,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPresentedClientTerminateDlg)
  ))
_sym_db.RegisterMessage(CMsgPresentedClientTerminateDlg)

CMsgGCLobbyUpdateBroadcastChannelInfo = _reflection.GeneratedProtocolMessageType('CMsgGCLobbyUpdateBroadcastChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCLobbyUpdateBroadcastChannelInfo)
  ))
_sym_db.RegisterMessage(CMsgGCLobbyUpdateBroadcastChannelInfo)

CMsgDOTAClaimEventActionData = _reflection.GeneratedProtocolMessageType('CMsgDOTAClaimEventActionData', (_message.Message,), dict(

  GrantItemGiftData = _reflection.GeneratedProtocolMessageType('GrantItemGiftData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONDATA_GRANTITEMGIFTDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionData.GrantItemGiftData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionData)
  ))
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionData)
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionData.GrantItemGiftData)

CMsgDOTAClaimEventAction = _reflection.GeneratedProtocolMessageType('CMsgDOTAClaimEventAction', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLAIMEVENTACTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventAction)
  ))
_sym_db.RegisterMessage(CMsgDOTAClaimEventAction)

CMsgDOTAClaimEventActionResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAClaimEventActionResponse', (_message.Message,), dict(

  MysteryItemRewardData = _reflection.GeneratedProtocolMessageType('MysteryItemRewardData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONRESPONSE_MYSTERYITEMREWARDDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionResponse.MysteryItemRewardData)
    ))
  ,

  LootListRewardData = _reflection.GeneratedProtocolMessageType('LootListRewardData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONRESPONSE_LOOTLISTREWARDDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionResponse.LootListRewardData)
    ))
  ,

  GrantedRewardData = _reflection.GeneratedProtocolMessageType('GrantedRewardData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONRESPONSE_GRANTEDREWARDDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionResponse.GrantedRewardData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACLAIMEVENTACTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClaimEventActionResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionResponse)
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionResponse.MysteryItemRewardData)
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionResponse.LootListRewardData)
_sym_db.RegisterMessage(CMsgDOTAClaimEventActionResponse.GrantedRewardData)

CMsgClientToGCClaimEventActionUsingItem = _reflection.GeneratedProtocolMessageType('CMsgClientToGCClaimEventActionUsingItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCClaimEventActionUsingItem)
  ))
_sym_db.RegisterMessage(CMsgClientToGCClaimEventActionUsingItem)

CMsgClientToGCClaimEventActionUsingItemResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCClaimEventActionUsingItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCLAIMEVENTACTIONUSINGITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCClaimEventActionUsingItemResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCClaimEventActionUsingItemResponse)

CMsgGCToClientClaimEventActionUsingItemCompleted = _reflection.GeneratedProtocolMessageType('CMsgGCToClientClaimEventActionUsingItemCompleted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCLAIMEVENTACTIONUSINGITEMCOMPLETED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientClaimEventActionUsingItemCompleted)
  ))
_sym_db.RegisterMessage(CMsgGCToClientClaimEventActionUsingItemCompleted)

CMsgDOTAGetEventPoints = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetEventPoints', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETEVENTPOINTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetEventPoints)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetEventPoints)

CMsgDOTAGetEventPointsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetEventPointsResponse', (_message.Message,), dict(

  Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetEventPointsResponse.Action)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGETEVENTPOINTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetEventPointsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetEventPointsResponse)
_sym_db.RegisterMessage(CMsgDOTAGetEventPointsResponse.Action)

CMsgDOTAGetPeriodicResource = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPeriodicResource', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETPERIODICRESOURCE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetPeriodicResource)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPeriodicResource)

CMsgDOTAGetPeriodicResourceResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPeriodicResourceResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETPERIODICRESOURCERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetPeriodicResourceResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPeriodicResourceResponse)

CMsgDOTAPeriodicResourceUpdated = _reflection.GeneratedProtocolMessageType('CMsgDOTAPeriodicResourceUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPERIODICRESOURCEUPDATED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPeriodicResourceUpdated)
  ))
_sym_db.RegisterMessage(CMsgDOTAPeriodicResourceUpdated)

CMsgDOTALiveLeagueGameUpdate = _reflection.GeneratedProtocolMessageType('CMsgDOTALiveLeagueGameUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALIVELEAGUEGAMEUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALiveLeagueGameUpdate)
  ))
_sym_db.RegisterMessage(CMsgDOTALiveLeagueGameUpdate)

CMsgDOTACompendiumSelection = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumSelection', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMSELECTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumSelection)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumSelection)

CMsgDOTACompendiumSelectionResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumSelectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMSELECTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumSelectionResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumSelectionResponse)

CMsgDOTACompendiumData = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumData)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumData)

CMsgDOTACompendiumDataRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATAREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumDataRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumDataRequest)

CMsgDOTACompendiumDataResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATARESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumDataResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumDataResponse)

CMsgDOTAGetPlayerMatchHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPlayerMatchHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetPlayerMatchHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistory)

CMsgDOTAGetPlayerMatchHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPlayerMatchHistoryResponse', (_message.Message,), dict(

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetPlayerMatchHistoryResponse.Match)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetPlayerMatchHistoryResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistoryResponse)
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistoryResponse.Match)

CMsgDOTAStartDailyHeroChallenge = _reflection.GeneratedProtocolMessageType('CMsgDOTAStartDailyHeroChallenge', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTARTDAILYHEROCHALLENGE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStartDailyHeroChallenge)
  ))
_sym_db.RegisterMessage(CMsgDOTAStartDailyHeroChallenge)

CMsgGCNotificationsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNOTIFICATIONSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCNotificationsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsRequest)

CMsgGCNotificationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsResponse', (_message.Message,), dict(

  Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCNotificationsResponse.Notification)
    ))
  ,
  DESCRIPTOR = _CMSGGCNOTIFICATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCNotificationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsResponse)
_sym_db.RegisterMessage(CMsgGCNotificationsResponse.Notification)

CMsgGCNotificationsMarkReadRequest = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsMarkReadRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNOTIFICATIONSMARKREADREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCNotificationsMarkReadRequest)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsMarkReadRequest)

CMsgClientToGCMarkNotificationListRead = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMarkNotificationListRead', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCMarkNotificationListRead)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMarkNotificationListRead)

CMsgGCPlayerInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoRequest', (_message.Message,), dict(

  PlayerInfo = _reflection.GeneratedProtocolMessageType('PlayerInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCPLAYERINFOREQUEST_PLAYERINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCPlayerInfoRequest.PlayerInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCPLAYERINFOREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCPlayerInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoRequest)
_sym_db.RegisterMessage(CMsgGCPlayerInfoRequest.PlayerInfo)

CMsgGCPlayerInfoSubmit = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoSubmit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPLAYERINFOSUBMIT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCPlayerInfoSubmit)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoSubmit)

CMsgGCPlayerInfoSubmitResponse = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoSubmitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPLAYERINFOSUBMITRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCPlayerInfoSubmitResponse)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoSubmitResponse)

CMsgClientProvideSurveyResult = _reflection.GeneratedProtocolMessageType('CMsgClientProvideSurveyResult', (_message.Message,), dict(

  Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientProvideSurveyResult.Response)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPROVIDESURVEYRESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientProvideSurveyResult)
  ))
_sym_db.RegisterMessage(CMsgClientProvideSurveyResult)
_sym_db.RegisterMessage(CMsgClientProvideSurveyResult.Response)

CMsgDOTAEmoticonAccessSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTAEmoticonAccessSDO', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEMOTICONACCESSSDO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAEmoticonAccessSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTAEmoticonAccessSDO)

CMsgClientToGCEmoticonDataRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCEmoticonDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCEMOTICONDATAREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCEmoticonDataRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCEmoticonDataRequest)

CMsgGCToClientEmoticonData = _reflection.GeneratedProtocolMessageType('CMsgGCToClientEmoticonData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTEMOTICONDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientEmoticonData)
  ))
_sym_db.RegisterMessage(CMsgGCToClientEmoticonData)

CMsgClientToGCTrackDialogResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTrackDialogResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRACKDIALOGRESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTrackDialogResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTrackDialogResult)

CMsgGCToClientTournamentItemDrop = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTournamentItemDrop', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTOURNAMENTITEMDROP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientTournamentItemDrop)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTournamentItemDrop)

CMsgClientToGCSetAdditionalEquips = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetAdditionalEquips', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETADDITIONALEQUIPS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetAdditionalEquips)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetAdditionalEquips)

CMsgClientToGCSetAdditionalEquipsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetAdditionalEquipsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetAdditionalEquipsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetAdditionalEquipsResponse)

CMsgClientToGCGetAdditionalEquips = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAdditionalEquips', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETADDITIONALEQUIPS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAdditionalEquips)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAdditionalEquips)

CMsgClientToGCGetAdditionalEquipsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAdditionalEquipsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAdditionalEquipsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAdditionalEquipsResponse)

CMsgClientToGCGetAllHeroOrder = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroOrder', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROORDER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAllHeroOrder)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroOrder)

CMsgClientToGCGetAllHeroOrderResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroOrderResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROORDERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAllHeroOrderResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroOrderResponse)

CMsgClientToGCGetAllHeroProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAllHeroProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroProgress)

CMsgClientToGCGetAllHeroProgressResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroProgressResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetAllHeroProgressResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroProgressResponse)

CMsgClientToGCGetTrophyList = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTrophyList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLIST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTrophyList)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyList)

CMsgClientToGCGetTrophyListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTrophyListResponse', (_message.Message,), dict(

  Trophy = _reflection.GeneratedProtocolMessageType('Trophy', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTrophyListResponse.Trophy)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTrophyListResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyListResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyListResponse.Trophy)

CMsgGCToClientTrophyAwarded = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTrophyAwarded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTROPHYAWARDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientTrophyAwarded)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTrophyAwarded)

CMsgClientToGCGetProfileCard = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileCard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILECARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetProfileCard)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileCard)

CMsgClientToGCSetProfileCardSlots = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetProfileCardSlots', (_message.Message,), dict(

  CardSlot = _reflection.GeneratedProtocolMessageType('CardSlot', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetProfileCardSlots.CardSlot)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCSETPROFILECARDSLOTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetProfileCardSlots)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetProfileCardSlots)
_sym_db.RegisterMessage(CMsgClientToGCSetProfileCardSlots.CardSlot)

CMsgClientToGCGetProfileCardStats = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileCardStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILECARDSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetProfileCardStats)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileCardStats)

CMsgClientToGCCreateHeroStatue = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreateHeroStatue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEHEROSTATUE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCreateHeroStatue)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreateHeroStatue)

CMsgGCToClientHeroStatueCreateResult = _reflection.GeneratedProtocolMessageType('CMsgGCToClientHeroStatueCreateResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTHEROSTATUECREATERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientHeroStatueCreateResult)
  ))
_sym_db.RegisterMessage(CMsgGCToClientHeroStatueCreateResult)

CMsgGCToClientEventStatusChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToClientEventStatusChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTEVENTSTATUSCHANGED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientEventStatusChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToClientEventStatusChanged)

CMsgClientToGCPlayerStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPlayerStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPLAYERSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCPlayerStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPlayerStatsRequest)

CMsgGCToClientPlayerStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPlayerStatsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPLAYERSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPlayerStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPlayerStatsResponse)

CMsgClientToGCCustomGamePlayerCountRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCustomGamePlayerCountRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCustomGamePlayerCountRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCustomGamePlayerCountRequest)

CMsgGCToClientCustomGamePlayerCountResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCustomGamePlayerCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCustomGamePlayerCountResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCustomGamePlayerCountResponse)

CMsgClientToGCCustomGamesFriendsPlayedRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCustomGamesFriendsPlayedRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCustomGamesFriendsPlayedRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCustomGamesFriendsPlayedRequest)

CMsgGCToClientCustomGamesFriendsPlayedResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCustomGamesFriendsPlayedResponse', (_message.Message,), dict(

  CustomGame = _reflection.GeneratedProtocolMessageType('CustomGame', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCustomGamesFriendsPlayedResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCustomGamesFriendsPlayedResponse)
_sym_db.RegisterMessage(CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame)

CMsgClientToGCSocialFeedPostCommentRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialFeedPostCommentRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSocialFeedPostCommentRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialFeedPostCommentRequest)

CMsgGCToClientSocialFeedPostCommentResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialFeedPostCommentResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientSocialFeedPostCommentResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialFeedPostCommentResponse)

CMsgClientToGCSocialFeedPostMessageRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialFeedPostMessageRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSocialFeedPostMessageRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialFeedPostMessageRequest)

CMsgGCToClientSocialFeedPostMessageResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialFeedPostMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientSocialFeedPostMessageResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialFeedPostMessageResponse)

CMsgClientToGCFriendsPlayedCustomGameRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCFriendsPlayedCustomGameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCFriendsPlayedCustomGameRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCFriendsPlayedCustomGameRequest)

CMsgGCToClientFriendsPlayedCustomGameResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientFriendsPlayedCustomGameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientFriendsPlayedCustomGameResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientFriendsPlayedCustomGameResponse)

CMsgClientToGCSocialMatchPostCommentRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialMatchPostCommentRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSocialMatchPostCommentRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialMatchPostCommentRequest)

CMsgGCToClientSocialMatchPostCommentResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialMatchPostCommentResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientSocialMatchPostCommentResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchPostCommentResponse)

CMsgClientToGCSocialMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSocialMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialMatchDetailsRequest)

CMsgGCToClientSocialMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialMatchDetailsResponse', (_message.Message,), dict(

  Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientSocialMatchDetailsResponse.Comment)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientSocialMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchDetailsResponse)
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchDetailsResponse.Comment)

CMsgDOTAPartyRichPresence = _reflection.GeneratedProtocolMessageType('CMsgDOTAPartyRichPresence', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE_MEMBER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPartyRichPresence.Member)
    ))
  ,

  WeekendTourney = _reflection.GeneratedProtocolMessageType('WeekendTourney', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPartyRichPresence.WeekendTourney)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPartyRichPresence)
  ))
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence)
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence.Member)
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence.WeekendTourney)

CMsgDOTALobbyRichPresence = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyRichPresence', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYRICHPRESENCE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTALobbyRichPresence)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyRichPresence)

CMsgDOTACustomGameListenServerStartedLoading = _reflection.GeneratedProtocolMessageType('CMsgDOTACustomGameListenServerStartedLoading', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACustomGameListenServerStartedLoading)
  ))
_sym_db.RegisterMessage(CMsgDOTACustomGameListenServerStartedLoading)

CMsgDOTACustomGameClientFinishedLoading = _reflection.GeneratedProtocolMessageType('CMsgDOTACustomGameClientFinishedLoading', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACustomGameClientFinishedLoading)
  ))
_sym_db.RegisterMessage(CMsgDOTACustomGameClientFinishedLoading)

CMsgClientToGCApplyGemCombiner = _reflection.GeneratedProtocolMessageType('CMsgClientToGCApplyGemCombiner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCAPPLYGEMCOMBINER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCApplyGemCombiner)
  ))
_sym_db.RegisterMessage(CMsgClientToGCApplyGemCombiner)

CMsgClientToGCH264Unsupported = _reflection.GeneratedProtocolMessageType('CMsgClientToGCH264Unsupported', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCH264UNSUPPORTED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCH264Unsupported)
  ))
_sym_db.RegisterMessage(CMsgClientToGCH264Unsupported)

CMsgClientToGCRequestH264Support = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestH264Support', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTH264SUPPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestH264Support)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestH264Support)

CMsgClientToGCGetQuestProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetQuestProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetQuestProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgress)

CMsgClientToGCGetQuestProgressResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetQuestProgressResponse', (_message.Message,), dict(

  Challenge = _reflection.GeneratedProtocolMessageType('Challenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetQuestProgressResponse.Challenge)
    ))
  ,

  Quest = _reflection.GeneratedProtocolMessageType('Quest', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetQuestProgressResponse.Quest)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetQuestProgressResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse.Challenge)
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse.Quest)

CMsgGCToClientMatchSignedOut = _reflection.GeneratedProtocolMessageType('CMsgGCToClientMatchSignedOut', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTMATCHSIGNEDOUT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientMatchSignedOut)
  ))
_sym_db.RegisterMessage(CMsgGCToClientMatchSignedOut)

CMsgGCGetHeroStatsHistory = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStatsHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTATSHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroStatsHistory)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStatsHistory)

CMsgGCGetHeroStatsHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStatsHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTATSHISTORYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCGetHeroStatsHistoryResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStatsHistoryResponse)

CMsgPlayerConductScorecardRequest = _reflection.GeneratedProtocolMessageType('CMsgPlayerConductScorecardRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPLAYERCONDUCTSCORECARDREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPlayerConductScorecardRequest)
  ))
_sym_db.RegisterMessage(CMsgPlayerConductScorecardRequest)

CMsgPlayerConductScorecard = _reflection.GeneratedProtocolMessageType('CMsgPlayerConductScorecard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPLAYERCONDUCTSCORECARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPlayerConductScorecard)
  ))
_sym_db.RegisterMessage(CMsgPlayerConductScorecard)

CMsgClientToGCWageringRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCWageringRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCWAGERINGREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCWageringRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCWageringRequest)

CMsgGCToClientWageringResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientWageringResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTWAGERINGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientWageringResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientWageringResponse)

CMsgGCToClientWageringUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCToClientWageringUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTWAGERINGUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientWageringUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCToClientWageringUpdate)

CMsgGCToClientArcanaVotesUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCToClientArcanaVotesUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTARCANAVOTESUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientArcanaVotesUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCToClientArcanaVotesUpdate)

CMsgClientToGCGetEventGoals = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetEventGoals', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETEVENTGOALS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetEventGoals)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetEventGoals)

CMsgEventGoals = _reflection.GeneratedProtocolMessageType('CMsgEventGoals', (_message.Message,), dict(

  EventGoal = _reflection.GeneratedProtocolMessageType('EventGoal', (_message.Message,), dict(
    DESCRIPTOR = _CMSGEVENTGOALS_EVENTGOAL,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgEventGoals.EventGoal)
    ))
  ,
  DESCRIPTOR = _CMSGEVENTGOALS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgEventGoals)
  ))
_sym_db.RegisterMessage(CMsgEventGoals)
_sym_db.RegisterMessage(CMsgEventGoals.EventGoal)

CMsgGCToGCLeaguePredictions = _reflection.GeneratedProtocolMessageType('CMsgGCToGCLeaguePredictions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCLEAGUEPREDICTIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCLeaguePredictions)
  ))
_sym_db.RegisterMessage(CMsgGCToGCLeaguePredictions)

CMsgPredictionRankings = _reflection.GeneratedProtocolMessageType('CMsgPredictionRankings', (_message.Message,), dict(

  PredictionLine = _reflection.GeneratedProtocolMessageType('PredictionLine', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRANKINGS_PREDICTIONLINE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgPredictionRankings.PredictionLine)
    ))
  ,

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRANKINGS_PREDICTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgPredictionRankings.Prediction)
    ))
  ,
  DESCRIPTOR = _CMSGPREDICTIONRANKINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPredictionRankings)
  ))
_sym_db.RegisterMessage(CMsgPredictionRankings)
_sym_db.RegisterMessage(CMsgPredictionRankings.PredictionLine)
_sym_db.RegisterMessage(CMsgPredictionRankings.Prediction)

CMsgPredictionResults = _reflection.GeneratedProtocolMessageType('CMsgPredictionResults', (_message.Message,), dict(

  ResultBreakdown = _reflection.GeneratedProtocolMessageType('ResultBreakdown', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRESULTS_RESULTBREAKDOWN,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgPredictionResults.ResultBreakdown)
    ))
  ,

  Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRESULTS_RESULT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgPredictionResults.Result)
    ))
  ,
  DESCRIPTOR = _CMSGPREDICTIONRESULTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPredictionResults)
  ))
_sym_db.RegisterMessage(CMsgPredictionResults)
_sym_db.RegisterMessage(CMsgPredictionResults.ResultBreakdown)
_sym_db.RegisterMessage(CMsgPredictionResults.Result)

CMsgClientToGCSuspiciousActivity = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSuspiciousActivity', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSUSPICIOUSACTIVITY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSuspiciousActivity)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSuspiciousActivity)

CMsgClientToGCHasPlayerVotedForMVP = _reflection.GeneratedProtocolMessageType('CMsgClientToGCHasPlayerVotedForMVP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCHasPlayerVotedForMVP)
  ))
_sym_db.RegisterMessage(CMsgClientToGCHasPlayerVotedForMVP)

CMsgClientToGCHasPlayerVotedForMVPResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCHasPlayerVotedForMVPResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCHasPlayerVotedForMVPResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCHasPlayerVotedForMVPResponse)

CMsgClientToGCVoteForLeagueGameMVP = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForLeagueGameMVP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORLEAGUEGAMEMVP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForLeagueGameMVP)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForLeagueGameMVP)

CMsgClientToGCVoteForMVP = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForMVP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORMVP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForMVP)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForMVP)

CMsgClientToGCVoteForMVPResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForMVPResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORMVPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForMVPResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForMVPResponse)

CMsgClientToGCMVPVoteTimeout = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMVPVoteTimeout', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMVPVOTETIMEOUT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCMVPVoteTimeout)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMVPVoteTimeout)

CMsgClientToGCMVPVoteTimeoutResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMVPVoteTimeoutResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMVPVOTETIMEOUTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCMVPVoteTimeoutResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMVPVoteTimeoutResponse)

CMsgMVPVotesForMatch = _reflection.GeneratedProtocolMessageType('CMsgMVPVotesForMatch', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CMSGMVPVOTESFORMATCH_PLAYER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgMVPVotesForMatch.Player)
    ))
  ,
  DESCRIPTOR = _CMSGMVPVOTESFORMATCH,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgMVPVotesForMatch)
  ))
_sym_db.RegisterMessage(CMsgMVPVotesForMatch)
_sym_db.RegisterMessage(CMsgMVPVotesForMatch.Player)

CMsgClientToGCTeammateStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTeammateStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTeammateStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsRequest)

CMsgClientToGCTeammateStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTeammateStatsResponse', (_message.Message,), dict(

  TeammateStat = _reflection.GeneratedProtocolMessageType('TeammateStat', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTeammateStatsResponse.TeammateStat)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTeammateStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsResponse)
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsResponse.TeammateStat)

CMsgClientToGCVoteForArcana = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForArcana', (_message.Message,), dict(

  MatchVote = _reflection.GeneratedProtocolMessageType('MatchVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForArcana.MatchVote)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForArcana)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcana)
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcana.MatchVote)

CMsgClientToGCVoteForArcanaResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForArcanaResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVoteForArcanaResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcanaResponse)

CMsgArcanaVotes = _reflection.GeneratedProtocolMessageType('CMsgArcanaVotes', (_message.Message,), dict(

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(
    DESCRIPTOR = _CMSGARCANAVOTES_MATCH,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgArcanaVotes.Match)
    ))
  ,
  DESCRIPTOR = _CMSGARCANAVOTES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgArcanaVotes)
  ))
_sym_db.RegisterMessage(CMsgArcanaVotes)
_sym_db.RegisterMessage(CMsgArcanaVotes.Match)

CMsgClientToGCRequestArcanaVotesRemaining = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestArcanaVotesRemaining', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestArcanaVotesRemaining)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemaining)

CMsgClientToGCRequestArcanaVotesRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestArcanaVotesRemainingResponse', (_message.Message,), dict(

  MatchVote = _reflection.GeneratedProtocolMessageType('MatchVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestArcanaVotesRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemainingResponse)
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote)

CMsgClientToGCRequestEventPointLogV2 = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestEventPointLogV2', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGV2,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestEventPointLogV2)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogV2)

CMsgClientToGCRequestEventPointLogResponseV2 = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestEventPointLogResponseV2', (_message.Message,), dict(

  LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2_LOGENTRY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestEventPointLogResponseV2.LogEntry)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSEV2,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestEventPointLogResponseV2)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponseV2)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponseV2.LogEntry)

CMsgClientToGCPublishUserStat = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPublishUserStat', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPUBLISHUSERSTAT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCPublishUserStat)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPublishUserStat)

CMsgClientToGCAddTI6TreeProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCAddTI6TreeProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCADDTI6TREEPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCAddTI6TreeProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCAddTI6TreeProgress)

CMsgClientToGCRequestLinaPlaysRemaining = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaPlaysRemaining', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestLinaPlaysRemaining)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaPlaysRemaining)

CMsgClientToGCRequestLinaPlaysRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaPlaysRemainingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestLinaPlaysRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaPlaysRemainingResponse)

CMsgClientToGCRequestLinaGameResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaGameResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAGAMERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestLinaGameResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaGameResult)

CMsgClientToGCRequestLinaGameResultResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaGameResultResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestLinaGameResultResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaGameResultResponse)

CMsgClientToGCRequestSlarkGameResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestSlarkGameResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTSLARKGAMERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestSlarkGameResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestSlarkGameResult)

CMsgClientToGCRequestSlarkGameResultResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestSlarkGameResultResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTSLARKGAMERESULTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestSlarkGameResultResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestSlarkGameResultResponse)

CMsgGCToClientQuestProgressUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToClientQuestProgressUpdated', (_message.Message,), dict(

  Challenge = _reflection.GeneratedProtocolMessageType('Challenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientQuestProgressUpdated.Challenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientQuestProgressUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToClientQuestProgressUpdated)
_sym_db.RegisterMessage(CMsgGCToClientQuestProgressUpdated.Challenge)

CMsgDOTARedeemItem = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARedeemItem)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemItem)

CMsgDOTARedeemItemResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTARedeemItemResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemItemResponse)

CMsgPerfectWorldUserLookupRequest = _reflection.GeneratedProtocolMessageType('CMsgPerfectWorldUserLookupRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPERFECTWORLDUSERLOOKUPREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPerfectWorldUserLookupRequest)
  ))
_sym_db.RegisterMessage(CMsgPerfectWorldUserLookupRequest)

CMsgPerfectWorldUserLookupResponse = _reflection.GeneratedProtocolMessageType('CMsgPerfectWorldUserLookupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPerfectWorldUserLookupResponse)
  ))
_sym_db.RegisterMessage(CMsgPerfectWorldUserLookupResponse)

CMsgMakeOffering = _reflection.GeneratedProtocolMessageType('CMsgMakeOffering', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMAKEOFFERING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgMakeOffering)
  ))
_sym_db.RegisterMessage(CMsgMakeOffering)

CMsgRequestOfferings = _reflection.GeneratedProtocolMessageType('CMsgRequestOfferings', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTOFFERINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRequestOfferings)
  ))
_sym_db.RegisterMessage(CMsgRequestOfferings)

CMsgRequestOfferingsResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestOfferingsResponse', (_message.Message,), dict(

  NewYearsOffering = _reflection.GeneratedProtocolMessageType('NewYearsOffering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgRequestOfferingsResponse.NewYearsOffering)
    ))
  ,
  DESCRIPTOR = _CMSGREQUESTOFFERINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRequestOfferingsResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestOfferingsResponse)
_sym_db.RegisterMessage(CMsgRequestOfferingsResponse.NewYearsOffering)

CMsgDOTAPCBangTimedReward = _reflection.GeneratedProtocolMessageType('CMsgDOTAPCBangTimedReward', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPCBANGTIMEDREWARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAPCBangTimedReward)
  ))
_sym_db.RegisterMessage(CMsgDOTAPCBangTimedReward)

CMsgDOTACompendiumInGamePredictionResults = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumInGamePredictionResults', (_message.Message,), dict(

  PredictionResult = _reflection.GeneratedProtocolMessageType('PredictionResult', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumInGamePredictionResults.PredictionResult)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACompendiumInGamePredictionResults)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumInGamePredictionResults)
_sym_db.RegisterMessage(CMsgDOTACompendiumInGamePredictionResults.PredictionResult)

CMsgClientToGCSelectCompendiumInGamePrediction = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSelectCompendiumInGamePrediction', (_message.Message,), dict(

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSelectCompendiumInGamePrediction)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePrediction)
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePrediction.Prediction)

CMsgClientToGCSelectCompendiumInGamePredictionResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSelectCompendiumInGamePredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSelectCompendiumInGamePredictionResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePredictionResponse)

CMsgClientToGCOpenPlayerCardPack = _reflection.GeneratedProtocolMessageType('CMsgClientToGCOpenPlayerCardPack', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCOPENPLAYERCARDPACK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCOpenPlayerCardPack)
  ))
_sym_db.RegisterMessage(CMsgClientToGCOpenPlayerCardPack)

CMsgClientToGCOpenPlayerCardPackResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCOpenPlayerCardPackResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCOpenPlayerCardPackResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCOpenPlayerCardPackResponse)

CMsgClientToGCRecyclePlayerCard = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecyclePlayerCard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEPLAYERCARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRecyclePlayerCard)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecyclePlayerCard)

CMsgClientToGCRecyclePlayerCardResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecyclePlayerCardResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRecyclePlayerCardResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecyclePlayerCardResponse)

CMsgClientToGCCreatePlayerCardPack = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreatePlayerCardPack', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEPLAYERCARDPACK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCreatePlayerCardPack)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreatePlayerCardPack)

CMsgClientToGCCreatePlayerCardPackResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreatePlayerCardPackResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCreatePlayerCardPackResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreatePlayerCardPackResponse)

CMsgGCToClientBattlePassRollup_International2016 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_International2016', (_message.Message,), dict(

  Questlines = _reflection.GeneratedProtocolMessageType('Questlines', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.Questlines)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.Achievements)
    ))
  ,

  BattleCup = _reflection.GeneratedProtocolMessageType('BattleCup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.BattleCup)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_International2016)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Questlines)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.BattleCup)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge)

CMsgGCToClientBattlePassRollup_Fall2016 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_Fall2016', (_message.Message,), dict(

  Questlines = _reflection.GeneratedProtocolMessageType('Questlines', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_QUESTLINES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.Questlines)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.Achievements)
    ))
  ,

  BattleCup = _reflection.GeneratedProtocolMessageType('BattleCup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BATTLECUP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.BattleCup)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_FALL2016,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Fall2016)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.Questlines)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.BattleCup)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Fall2016.FantasyChallenge)

CMsgGCToClientBattlePassRollup_Winter2017 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_Winter2017', (_message.Message,), dict(

  Questlines = _reflection.GeneratedProtocolMessageType('Questlines', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_QUESTLINES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.Questlines)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.Achievements)
    ))
  ,

  BattleCup = _reflection.GeneratedProtocolMessageType('BattleCup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BATTLECUP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.BattleCup)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_WINTER2017,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_Winter2017)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.Questlines)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.BattleCup)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_Winter2017.FantasyChallenge)

CMsgGCToClientBattlePassRollup_TI7 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_TI7', (_message.Message,), dict(

  Questlines = _reflection.GeneratedProtocolMessageType('Questlines', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_QUESTLINES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.Questlines)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.Achievements)
    ))
  ,

  BattleCup = _reflection.GeneratedProtocolMessageType('BattleCup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BATTLECUP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.BattleCup)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI7,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI7)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.Questlines)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.BattleCup)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI7.FantasyChallenge)

CMsgGCToClientBattlePassRollup_TI8 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_TI8', (_message.Message,), dict(

  CavernCrawl = _reflection.GeneratedProtocolMessageType('CavernCrawl', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_CAVERNCRAWL,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.CavernCrawl)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.Achievements)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_TI8,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollup_TI8)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.CavernCrawl)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_TI8.FantasyChallenge)

CMsgGCToClientBattlePassRollupRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollupRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupRequest)

CMsgGCToClientBattlePassRollupResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollupResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupResponse)

CMsgGCToClientBattlePassRollupListRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollupListRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupListRequest)

CMsgGCToClientBattlePassRollupListResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupListResponse', (_message.Message,), dict(

  EventInfo = _reflection.GeneratedProtocolMessageType('EventInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE_EVENTINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollupListResponse.EventInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientBattlePassRollupListResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupListResponse)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupListResponse.EventInfo)

CMsgClientToGCTransferSeasonalMMRRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTransferSeasonalMMRRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTransferSeasonalMMRRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTransferSeasonalMMRRequest)

CMsgClientToGCTransferSeasonalMMRResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTransferSeasonalMMRResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCTransferSeasonalMMRResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTransferSeasonalMMRResponse)

CMsgGCToClientPlaytestStatus = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPlaytestStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPLAYTESTSTATUS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPlaytestStatus)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPlaytestStatus)

CMsgClientToGCJoinPlaytest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCJoinPlaytest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCJOINPLAYTEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCJoinPlaytest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCJoinPlaytest)

CMsgClientToGCJoinPlaytestResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCJoinPlaytestResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCJOINPLAYTESTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCJoinPlaytestResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCJoinPlaytestResponse)

CMsgDOTASetFavoriteTeam = _reflection.GeneratedProtocolMessageType('CMsgDOTASetFavoriteTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETFAVORITETEAM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASetFavoriteTeam)
  ))
_sym_db.RegisterMessage(CMsgDOTASetFavoriteTeam)

CMsgDOTATriviaQuestion = _reflection.GeneratedProtocolMessageType('CMsgDOTATriviaQuestion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATRIVIAQUESTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTATriviaQuestion)
  ))
_sym_db.RegisterMessage(CMsgDOTATriviaQuestion)

CMsgDOTATriviaCurrentQuestions = _reflection.GeneratedProtocolMessageType('CMsgDOTATriviaCurrentQuestions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATRIVIACURRENTQUESTIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTATriviaCurrentQuestions)
  ))
_sym_db.RegisterMessage(CMsgDOTATriviaCurrentQuestions)

CMsgDOTATriviaQuestionAnswersSummary = _reflection.GeneratedProtocolMessageType('CMsgDOTATriviaQuestionAnswersSummary', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATRIVIAQUESTIONANSWERSSUMMARY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTATriviaQuestionAnswersSummary)
  ))
_sym_db.RegisterMessage(CMsgDOTATriviaQuestionAnswersSummary)

CMsgDOTASubmitTriviaQuestionAnswer = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitTriviaQuestionAnswer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITTRIVIAQUESTIONANSWER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitTriviaQuestionAnswer)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitTriviaQuestionAnswer)

CMsgDOTASubmitTriviaQuestionAnswerResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitTriviaQuestionAnswerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITTRIVIAQUESTIONANSWERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASubmitTriviaQuestionAnswerResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitTriviaQuestionAnswerResponse)

CMsgDOTAStartTriviaSession = _reflection.GeneratedProtocolMessageType('CMsgDOTAStartTriviaSession', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTARTTRIVIASESSION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStartTriviaSession)
  ))
_sym_db.RegisterMessage(CMsgDOTAStartTriviaSession)

CMsgDOTAStartTriviaSessionResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAStartTriviaSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTARTTRIVIASESSIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAStartTriviaSessionResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAStartTriviaSessionResponse)

CMsgClientToGCGiveTip = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGiveTip', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGIVETIP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGiveTip)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGiveTip)

CMsgClientToGCGiveTipResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGiveTipResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGIVETIPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGiveTipResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGiveTipResponse)

CMsgDOTAAnchorPhoneNumberRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAAnchorPhoneNumberRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAANCHORPHONENUMBERREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAAnchorPhoneNumberRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAAnchorPhoneNumberRequest)

CMsgDOTAAnchorPhoneNumberResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAAnchorPhoneNumberResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAANCHORPHONENUMBERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAAnchorPhoneNumberResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAAnchorPhoneNumberResponse)

CMsgDOTAUnanchorPhoneNumberRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAUnanchorPhoneNumberRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUNANCHORPHONENUMBERREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAUnanchorPhoneNumberRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAUnanchorPhoneNumberRequest)

CMsgDOTAUnanchorPhoneNumberResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAUnanchorPhoneNumberResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUNANCHORPHONENUMBERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAUnanchorPhoneNumberResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAUnanchorPhoneNumberResponse)

CMsgGCToClientTipNotification = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTipNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTIPNOTIFICATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientTipNotification)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTipNotification)

CMsgGCToClientCommendNotification = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCommendNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCOMMENDNOTIFICATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCommendNotification)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCommendNotification)

CMsgGCToClientAllStarVotesRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientAllStarVotesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTALLSTARVOTESREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientAllStarVotesRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientAllStarVotesRequest)

CMsgGCToClientAllStarVotesReply = _reflection.GeneratedProtocolMessageType('CMsgGCToClientAllStarVotesReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTALLSTARVOTESREPLY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientAllStarVotesReply)
  ))
_sym_db.RegisterMessage(CMsgGCToClientAllStarVotesReply)

CMsgGCToClientAllStarVotesSubmit = _reflection.GeneratedProtocolMessageType('CMsgGCToClientAllStarVotesSubmit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTALLSTARVOTESSUBMIT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientAllStarVotesSubmit)
  ))
_sym_db.RegisterMessage(CMsgGCToClientAllStarVotesSubmit)

CMsgGCToClientAllStarVotesSubmitReply = _reflection.GeneratedProtocolMessageType('CMsgGCToClientAllStarVotesSubmitReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTALLSTARVOTESSUBMITREPLY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientAllStarVotesSubmitReply)
  ))
_sym_db.RegisterMessage(CMsgGCToClientAllStarVotesSubmitReply)

CMsgDOTAClientToGCQuickStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAClientToGCQuickStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLIENTTOGCQUICKSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClientToGCQuickStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAClientToGCQuickStatsRequest)

CMsgDOTAClientToGCQuickStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAClientToGCQuickStatsResponse', (_message.Message,), dict(

  SimpleStats = _reflection.GeneratedProtocolMessageType('SimpleStats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE_SIMPLESTATS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClientToGCQuickStatsResponse.SimpleStats)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACLIENTTOGCQUICKSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAClientToGCQuickStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAClientToGCQuickStatsResponse)
_sym_db.RegisterMessage(CMsgDOTAClientToGCQuickStatsResponse.SimpleStats)

CMsgDOTASelectionPriorityChoiceRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTASelectionPriorityChoiceRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASELECTIONPRIORITYCHOICEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASelectionPriorityChoiceRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTASelectionPriorityChoiceRequest)

CMsgDOTASelectionPriorityChoiceResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASelectionPriorityChoiceResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASELECTIONPRIORITYCHOICERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTASelectionPriorityChoiceResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASelectionPriorityChoiceResponse)

CMsgDOTAGameAutographReward = _reflection.GeneratedProtocolMessageType('CMsgDOTAGameAutographReward', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGAMEAUTOGRAPHREWARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGameAutographReward)
  ))
_sym_db.RegisterMessage(CMsgDOTAGameAutographReward)

CMsgDOTAGameAutographRewardResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGameAutographRewardResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGAMEAUTOGRAPHREWARDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGameAutographRewardResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGameAutographRewardResponse)

CMsgDOTADestroyLobbyRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTADestroyLobbyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTADESTROYLOBBYREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTADestroyLobbyRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTADestroyLobbyRequest)

CMsgDOTADestroyLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTADestroyLobbyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTADESTROYLOBBYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTADestroyLobbyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTADestroyLobbyResponse)

CMsgDOTAGetRecentPlayTimeFriendsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetRecentPlayTimeFriendsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETRECENTPLAYTIMEFRIENDSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetRecentPlayTimeFriendsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetRecentPlayTimeFriendsRequest)

CMsgDOTAGetRecentPlayTimeFriendsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetRecentPlayTimeFriendsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETRECENTPLAYTIMEFRIENDSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAGetRecentPlayTimeFriendsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetRecentPlayTimeFriendsResponse)

CMsgPurchaseItemWithEventPoints = _reflection.GeneratedProtocolMessageType('CMsgPurchaseItemWithEventPoints', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEITEMWITHEVENTPOINTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseItemWithEventPoints)
  ))
_sym_db.RegisterMessage(CMsgPurchaseItemWithEventPoints)

CMsgPurchaseItemWithEventPointsResponse = _reflection.GeneratedProtocolMessageType('CMsgPurchaseItemWithEventPointsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEITEMWITHEVENTPOINTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseItemWithEventPointsResponse)
  ))
_sym_db.RegisterMessage(CMsgPurchaseItemWithEventPointsResponse)

CMsgGCRequestItemRecommendations = _reflection.GeneratedProtocolMessageType('CMsgGCRequestItemRecommendations', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTITEMRECOMMENDATIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestItemRecommendations)
  ))
_sym_db.RegisterMessage(CMsgGCRequestItemRecommendations)

CMsgGCRequestItemRecommendationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestItemRecommendationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTITEMRECOMMENDATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestItemRecommendationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestItemRecommendationsResponse)

CMsgGCRequestSkillUpRecommendations = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSkillUpRecommendations', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSKILLUPRECOMMENDATIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestSkillUpRecommendations)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSkillUpRecommendations)

CMsgGCRequestSkillUpRecommendationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSkillUpRecommendationsResponse', (_message.Message,), dict(

  AbilitySelection = _reflection.GeneratedProtocolMessageType('AbilitySelection', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE_ABILITYSELECTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection)
    ))
  ,
  DESCRIPTOR = _CMSGGCREQUESTSKILLUPRECOMMENDATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestSkillUpRecommendationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSkillUpRecommendationsResponse)
_sym_db.RegisterMessage(CMsgGCRequestSkillUpRecommendationsResponse.AbilitySelection)

CMsgClientToGCRecycleHeroRelic = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecycleHeroRelic', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEHERORELIC,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRecycleHeroRelic)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecycleHeroRelic)

CMsgClientToGCRecycleHeroRelicResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecycleHeroRelicResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEHERORELICRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRecycleHeroRelicResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecycleHeroRelicResponse)

CMsgPurchaseHeroRelic = _reflection.GeneratedProtocolMessageType('CMsgPurchaseHeroRelic', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEHERORELIC,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseHeroRelic)
  ))
_sym_db.RegisterMessage(CMsgPurchaseHeroRelic)

CMsgPurchaseHeroRelicResponse = _reflection.GeneratedProtocolMessageType('CMsgPurchaseHeroRelicResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEHERORELICRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseHeroRelicResponse)
  ))
_sym_db.RegisterMessage(CMsgPurchaseHeroRelicResponse)

CMsgPurchaseHeroRandomRelic = _reflection.GeneratedProtocolMessageType('CMsgPurchaseHeroRandomRelic', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEHERORANDOMRELIC,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseHeroRandomRelic)
  ))
_sym_db.RegisterMessage(CMsgPurchaseHeroRandomRelic)

CMsgPurchaseHeroRandomRelicResponse = _reflection.GeneratedProtocolMessageType('CMsgPurchaseHeroRandomRelicResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPURCHASEHERORANDOMRELICRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPurchaseHeroRandomRelicResponse)
  ))
_sym_db.RegisterMessage(CMsgPurchaseHeroRandomRelicResponse)

CMsgClientToGCRequestPlusWeeklyChallengeResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlusWeeklyChallengeResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlusWeeklyChallengeResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlusWeeklyChallengeResult)

CMsgClientToGCRequestPlusWeeklyChallengeResultResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlusWeeklyChallengeResultResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLUSWEEKLYCHALLENGERESULTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlusWeeklyChallengeResultResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlusWeeklyChallengeResultResponse)

CMsgProfileRequest = _reflection.GeneratedProtocolMessageType('CMsgProfileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPROFILEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgProfileRequest)
  ))
_sym_db.RegisterMessage(CMsgProfileRequest)

CMsgProfileResponse = _reflection.GeneratedProtocolMessageType('CMsgProfileResponse', (_message.Message,), dict(

  FeaturedHero = _reflection.GeneratedProtocolMessageType('FeaturedHero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPROFILERESPONSE_FEATUREDHERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgProfileResponse.FeaturedHero)
    ))
  ,

  MatchInfo = _reflection.GeneratedProtocolMessageType('MatchInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPROFILERESPONSE_MATCHINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgProfileResponse.MatchInfo)
    ))
  ,
  DESCRIPTOR = _CMSGPROFILERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgProfileResponse)
  ))
_sym_db.RegisterMessage(CMsgProfileResponse)
_sym_db.RegisterMessage(CMsgProfileResponse.FeaturedHero)
_sym_db.RegisterMessage(CMsgProfileResponse.MatchInfo)

CMsgProfileUpdate = _reflection.GeneratedProtocolMessageType('CMsgProfileUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPROFILEUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgProfileUpdate)
  ))
_sym_db.RegisterMessage(CMsgProfileUpdate)

CMsgProfileUpdateResponse = _reflection.GeneratedProtocolMessageType('CMsgProfileUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPROFILEUPDATERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgProfileUpdateResponse)
  ))
_sym_db.RegisterMessage(CMsgProfileUpdateResponse)

CMsgTalentWinRates = _reflection.GeneratedProtocolMessageType('CMsgTalentWinRates', (_message.Message,), dict(
  DESCRIPTOR = _CMSGTALENTWINRATES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgTalentWinRates)
  ))
_sym_db.RegisterMessage(CMsgTalentWinRates)

CMsgGlobalHeroAverages = _reflection.GeneratedProtocolMessageType('CMsgGlobalHeroAverages', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGLOBALHEROAVERAGES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGlobalHeroAverages)
  ))
_sym_db.RegisterMessage(CMsgGlobalHeroAverages)

CMsgHeroGlobalDataRequest = _reflection.GeneratedProtocolMessageType('CMsgHeroGlobalDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGHEROGLOBALDATAREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataRequest)
  ))
_sym_db.RegisterMessage(CMsgHeroGlobalDataRequest)

CMsgHeroGlobalDataResponse = _reflection.GeneratedProtocolMessageType('CMsgHeroGlobalDataResponse', (_message.Message,), dict(

  GraphData = _reflection.GeneratedProtocolMessageType('GraphData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGHEROGLOBALDATARESPONSE_GRAPHDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataResponse.GraphData)
    ))
  ,

  WeekData = _reflection.GeneratedProtocolMessageType('WeekData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGHEROGLOBALDATARESPONSE_WEEKDATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataResponse.WeekData)
    ))
  ,

  HeroDataPerRankChunk = _reflection.GeneratedProtocolMessageType('HeroDataPerRankChunk', (_message.Message,), dict(
    DESCRIPTOR = _CMSGHEROGLOBALDATARESPONSE_HERODATAPERRANKCHUNK,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataResponse.HeroDataPerRankChunk)
    ))
  ,
  DESCRIPTOR = _CMSGHEROGLOBALDATARESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataResponse)
  ))
_sym_db.RegisterMessage(CMsgHeroGlobalDataResponse)
_sym_db.RegisterMessage(CMsgHeroGlobalDataResponse.GraphData)
_sym_db.RegisterMessage(CMsgHeroGlobalDataResponse.WeekData)
_sym_db.RegisterMessage(CMsgHeroGlobalDataResponse.HeroDataPerRankChunk)

CMsgHeroGlobalDataAllHeroes = _reflection.GeneratedProtocolMessageType('CMsgHeroGlobalDataAllHeroes', (_message.Message,), dict(
  DESCRIPTOR = _CMSGHEROGLOBALDATAALLHEROES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataAllHeroes)
  ))
_sym_db.RegisterMessage(CMsgHeroGlobalDataAllHeroes)

CMsgHeroGlobalDataHeroesAlliesAndEnemies = _reflection.GeneratedProtocolMessageType('CMsgHeroGlobalDataHeroesAlliesAndEnemies', (_message.Message,), dict(

  HeroData = _reflection.GeneratedProtocolMessageType('HeroData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_HERODATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData)
    ))
  ,

  RankedHeroData = _reflection.GeneratedProtocolMessageType('RankedHeroData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES_RANKEDHERODATA,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData)
    ))
  ,
  DESCRIPTOR = _CMSGHEROGLOBALDATAHEROESALLIESANDENEMIES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgHeroGlobalDataHeroesAlliesAndEnemies)
  ))
_sym_db.RegisterMessage(CMsgHeroGlobalDataHeroesAlliesAndEnemies)
_sym_db.RegisterMessage(CMsgHeroGlobalDataHeroesAlliesAndEnemies.HeroData)
_sym_db.RegisterMessage(CMsgHeroGlobalDataHeroesAlliesAndEnemies.RankedHeroData)

CMsgPrivateMetadataKeyRequest = _reflection.GeneratedProtocolMessageType('CMsgPrivateMetadataKeyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRIVATEMETADATAKEYREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPrivateMetadataKeyRequest)
  ))
_sym_db.RegisterMessage(CMsgPrivateMetadataKeyRequest)

CMsgPrivateMetadataKeyResponse = _reflection.GeneratedProtocolMessageType('CMsgPrivateMetadataKeyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRIVATEMETADATAKEYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPrivateMetadataKeyResponse)
  ))
_sym_db.RegisterMessage(CMsgPrivateMetadataKeyResponse)

CMsgActivatePlusFreeTrialRequest = _reflection.GeneratedProtocolMessageType('CMsgActivatePlusFreeTrialRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGACTIVATEPLUSFREETRIALREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgActivatePlusFreeTrialRequest)
  ))
_sym_db.RegisterMessage(CMsgActivatePlusFreeTrialRequest)

CMsgActivatePlusFreeTrialResponse = _reflection.GeneratedProtocolMessageType('CMsgActivatePlusFreeTrialResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGACTIVATEPLUSFREETRIALRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgActivatePlusFreeTrialResponse)
  ))
_sym_db.RegisterMessage(CMsgActivatePlusFreeTrialResponse)

CMsgGCToClientCavernCrawlMapPathCompleted = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCavernCrawlMapPathCompleted', (_message.Message,), dict(

  CompletedPathInfo = _reflection.GeneratedProtocolMessageType('CompletedPathInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED_COMPLETEDPATHINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTCAVERNCRAWLMAPPATHCOMPLETED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCavernCrawlMapPathCompleted)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCavernCrawlMapPathCompleted)
_sym_db.RegisterMessage(CMsgGCToClientCavernCrawlMapPathCompleted.CompletedPathInfo)

CMsgGCToClientCavernCrawlMapUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCavernCrawlMapUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCAVERNCRAWLMAPUPDATED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCavernCrawlMapUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCavernCrawlMapUpdated)

CMsgClientToGCCavernCrawlClaimRoom = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlClaimRoom', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlClaimRoom)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlClaimRoom)

CMsgClientToGCCavernCrawlClaimRoomResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlClaimRoomResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLCLAIMROOMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlClaimRoomResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlClaimRoomResponse)

CMsgClientToGCCavernCrawlUseItemOnRoom = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlUseItemOnRoom', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlUseItemOnRoom)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlUseItemOnRoom)

CMsgClientToGCCavernCrawlUseItemOnRoomResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlUseItemOnRoomResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONROOMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlUseItemOnRoomResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlUseItemOnRoomResponse)

CMsgClientToGCCavernCrawlUseItemOnPath = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlUseItemOnPath', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATH,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlUseItemOnPath)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlUseItemOnPath)

CMsgClientToGCCavernCrawlUseItemOnPathResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlUseItemOnPathResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLUSEITEMONPATHRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlUseItemOnPathResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlUseItemOnPathResponse)

CMsgClientToGCCavernCrawlRequestMapState = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlRequestMapState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlRequestMapState)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlRequestMapState)

CMsgClientToGCCavernCrawlRequestMapStateResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlRequestMapStateResponse', (_message.Message,), dict(

  SwappedChallenge = _reflection.GeneratedProtocolMessageType('SwappedChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_SWAPPEDCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge)
    ))
  ,

  InventoryItem = _reflection.GeneratedProtocolMessageType('InventoryItem', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_INVENTORYITEM,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem)
    ))
  ,

  TreasureMap = _reflection.GeneratedProtocolMessageType('TreasureMap', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE_TREASUREMAP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLREQUESTMAPSTATERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlRequestMapStateResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlRequestMapStateResponse)
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlRequestMapStateResponse.SwappedChallenge)
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlRequestMapStateResponse.InventoryItem)
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlRequestMapStateResponse.TreasureMap)

CMsgClientToGCCavernCrawlGetClaimedRoomCount = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlGetClaimedRoomCount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlGetClaimedRoomCount)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlGetClaimedRoomCount)

CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCAVERNCRAWLGETCLAIMEDROOMCOUNTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCavernCrawlGetClaimedRoomCountResponse)

CMsgDOTAMutationList = _reflection.GeneratedProtocolMessageType('CMsgDOTAMutationList', (_message.Message,), dict(

  Mutation = _reflection.GeneratedProtocolMessageType('Mutation', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMUTATIONLIST_MUTATION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMutationList.Mutation)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAMUTATIONLIST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTAMutationList)
  ))
_sym_db.RegisterMessage(CMsgDOTAMutationList)
_sym_db.RegisterMessage(CMsgDOTAMutationList.Mutation)

CMsgEventTipsSummaryRequest = _reflection.GeneratedProtocolMessageType('CMsgEventTipsSummaryRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEVENTTIPSSUMMARYREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgEventTipsSummaryRequest)
  ))
_sym_db.RegisterMessage(CMsgEventTipsSummaryRequest)

CMsgEventTipsSummaryResponse = _reflection.GeneratedProtocolMessageType('CMsgEventTipsSummaryResponse', (_message.Message,), dict(

  Tipper = _reflection.GeneratedProtocolMessageType('Tipper', (_message.Message,), dict(
    DESCRIPTOR = _CMSGEVENTTIPSSUMMARYRESPONSE_TIPPER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgEventTipsSummaryResponse.Tipper)
    ))
  ,
  DESCRIPTOR = _CMSGEVENTTIPSSUMMARYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgEventTipsSummaryResponse)
  ))
_sym_db.RegisterMessage(CMsgEventTipsSummaryResponse)
_sym_db.RegisterMessage(CMsgEventTipsSummaryResponse.Tipper)

CMsgSocialFeedRequest = _reflection.GeneratedProtocolMessageType('CMsgSocialFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCIALFEEDREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedRequest)
  ))
_sym_db.RegisterMessage(CMsgSocialFeedRequest)

CMsgSocialFeedResponse = _reflection.GeneratedProtocolMessageType('CMsgSocialFeedResponse', (_message.Message,), dict(

  FeedEvent = _reflection.GeneratedProtocolMessageType('FeedEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOCIALFEEDRESPONSE_FEEDEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedResponse.FeedEvent)
    ))
  ,
  DESCRIPTOR = _CMSGSOCIALFEEDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedResponse)
  ))
_sym_db.RegisterMessage(CMsgSocialFeedResponse)
_sym_db.RegisterMessage(CMsgSocialFeedResponse.FeedEvent)

CMsgSocialFeedCommentsRequest = _reflection.GeneratedProtocolMessageType('CMsgSocialFeedCommentsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCIALFEEDCOMMENTSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedCommentsRequest)
  ))
_sym_db.RegisterMessage(CMsgSocialFeedCommentsRequest)

CMsgSocialFeedCommentsResponse = _reflection.GeneratedProtocolMessageType('CMsgSocialFeedCommentsResponse', (_message.Message,), dict(

  FeedComment = _reflection.GeneratedProtocolMessageType('FeedComment', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOCIALFEEDCOMMENTSRESPONSE_FEEDCOMMENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedCommentsResponse.FeedComment)
    ))
  ,
  DESCRIPTOR = _CMSGSOCIALFEEDCOMMENTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSocialFeedCommentsResponse)
  ))
_sym_db.RegisterMessage(CMsgSocialFeedCommentsResponse)
_sym_db.RegisterMessage(CMsgSocialFeedCommentsResponse.FeedComment)

CMsgClientToGCPlayerCardSpecificPurchaseRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPlayerCardSpecificPurchaseRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCPlayerCardSpecificPurchaseRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPlayerCardSpecificPurchaseRequest)

CMsgClientToGCPlayerCardSpecificPurchaseResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPlayerCardSpecificPurchaseResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPLAYERCARDSPECIFICPURCHASERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCPlayerCardSpecificPurchaseResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPlayerCardSpecificPurchaseResponse)

CMsgClientToGCRequestContestVotes = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestContestVotes', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTCONTESTVOTES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestContestVotes)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestContestVotes)

CMsgClientToGCRequestContestVotesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestContestVotesResponse', (_message.Message,), dict(

  ItemVote = _reflection.GeneratedProtocolMessageType('ItemVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE_ITEMVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestContestVotesResponse.ItemVote)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTCONTESTVOTESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestContestVotesResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestContestVotesResponse)
_sym_db.RegisterMessage(CMsgClientToGCRequestContestVotesResponse.ItemVote)

CMsgClientToGCRecordContestVote = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecordContestVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECORDCONTESTVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRecordContestVote)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecordContestVote)

CMsgGCToClientRecordContestVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientRecordContestVoteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTRECORDCONTESTVOTERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientRecordContestVoteResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientRecordContestVoteResponse)

CMsgDOTADPCFeed = _reflection.GeneratedProtocolMessageType('CMsgDOTADPCFeed', (_message.Message,), dict(

  Element = _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTADPCFEED_ELEMENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgDOTADPCFeed.Element)
    ))
  ,
  DESCRIPTOR = _CMSGDOTADPCFEED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTADPCFeed)
  ))
_sym_db.RegisterMessage(CMsgDOTADPCFeed)
_sym_db.RegisterMessage(CMsgDOTADPCFeed.Element)

CMsgDOTADPCUserInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTADPCUserInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTADPCUSERINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTADPCUserInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTADPCUserInfo)

CMsgDevGrantEventPoints = _reflection.GeneratedProtocolMessageType('CMsgDevGrantEventPoints', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVGRANTEVENTPOINTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevGrantEventPoints)
  ))
_sym_db.RegisterMessage(CMsgDevGrantEventPoints)

CMsgDevGrantEventPointsResponse = _reflection.GeneratedProtocolMessageType('CMsgDevGrantEventPointsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVGRANTEVENTPOINTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevGrantEventPointsResponse)
  ))
_sym_db.RegisterMessage(CMsgDevGrantEventPointsResponse)

CMsgDevGrantEventAction = _reflection.GeneratedProtocolMessageType('CMsgDevGrantEventAction', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVGRANTEVENTACTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevGrantEventAction)
  ))
_sym_db.RegisterMessage(CMsgDevGrantEventAction)

CMsgDevGrantEventActionResponse = _reflection.GeneratedProtocolMessageType('CMsgDevGrantEventActionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVGRANTEVENTACTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevGrantEventActionResponse)
  ))
_sym_db.RegisterMessage(CMsgDevGrantEventActionResponse)

CMsgDevResetEventState = _reflection.GeneratedProtocolMessageType('CMsgDevResetEventState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVRESETEVENTSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevResetEventState)
  ))
_sym_db.RegisterMessage(CMsgDevResetEventState)

CMsgDevResetEventStateResponse = _reflection.GeneratedProtocolMessageType('CMsgDevResetEventStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVRESETEVENTSTATERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDevResetEventStateResponse)
  ))
_sym_db.RegisterMessage(CMsgDevResetEventStateResponse)

CMsgConsumeEventSupportGrantItem = _reflection.GeneratedProtocolMessageType('CMsgConsumeEventSupportGrantItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONSUMEEVENTSUPPORTGRANTITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgConsumeEventSupportGrantItem)
  ))
_sym_db.RegisterMessage(CMsgConsumeEventSupportGrantItem)

CMsgConsumeEventSupportGrantItemResponse = _reflection.GeneratedProtocolMessageType('CMsgConsumeEventSupportGrantItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONSUMEEVENTSUPPORTGRANTITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgConsumeEventSupportGrantItemResponse)
  ))
_sym_db.RegisterMessage(CMsgConsumeEventSupportGrantItemResponse)

CMsgClientToGCGetFilteredPlayers = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetFilteredPlayers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETFILTEREDPLAYERS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetFilteredPlayers)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetFilteredPlayers)

CMsgGCToClientGetFilteredPlayersResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientGetFilteredPlayersResponse', (_message.Message,), dict(

  CFilterEntry = _reflection.GeneratedProtocolMessageType('CFilterEntry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE_CFILTERENTRY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTGETFILTEREDPLAYERSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientGetFilteredPlayersResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientGetFilteredPlayersResponse)
_sym_db.RegisterMessage(CMsgGCToClientGetFilteredPlayersResponse.CFilterEntry)

CMsgClientToGCRemoveFilteredPlayer = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRemoveFilteredPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREMOVEFILTEREDPLAYER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRemoveFilteredPlayer)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRemoveFilteredPlayer)

CMsgGCToClientRemoveFilteredPlayerResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientRemoveFilteredPlayerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTREMOVEFILTEREDPLAYERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientRemoveFilteredPlayerResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientRemoveFilteredPlayerResponse)

CMsgPartySearchPlayer = _reflection.GeneratedProtocolMessageType('CMsgPartySearchPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYSEARCHPLAYER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPartySearchPlayer)
  ))
_sym_db.RegisterMessage(CMsgPartySearchPlayer)

CMsgGCToClientPlayerBeaconState = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPlayerBeaconState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPLAYERBEACONSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPlayerBeaconState)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPlayerBeaconState)

CMsgGCToClientPartyBeaconUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPartyBeaconUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPARTYBEACONUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPartyBeaconUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPartyBeaconUpdate)

CMsgClientToGCUpdatePartyBeacon = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUpdatePartyBeacon', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUPDATEPARTYBEACON,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCUpdatePartyBeacon)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUpdatePartyBeacon)

CMsgClientToGCRequestActiveBeaconParties = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestActiveBeaconParties', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTACTIVEBEACONPARTIES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestActiveBeaconParties)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestActiveBeaconParties)

CMsgGCToClientRequestActiveBeaconPartiesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientRequestActiveBeaconPartiesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTREQUESTACTIVEBEACONPARTIESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientRequestActiveBeaconPartiesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientRequestActiveBeaconPartiesResponse)

CMsgClientToGCJoinPartyFromBeacon = _reflection.GeneratedProtocolMessageType('CMsgClientToGCJoinPartyFromBeacon', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCJOINPARTYFROMBEACON,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCJoinPartyFromBeacon)
  ))
_sym_db.RegisterMessage(CMsgClientToGCJoinPartyFromBeacon)

CMsgGCToClientJoinPartyFromBeaconResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientJoinPartyFromBeaconResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTJOINPARTYFROMBEACONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientJoinPartyFromBeaconResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientJoinPartyFromBeaconResponse)

CMsgClientToGCManageFavorites = _reflection.GeneratedProtocolMessageType('CMsgClientToGCManageFavorites', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMANAGEFAVORITES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCManageFavorites)
  ))
_sym_db.RegisterMessage(CMsgClientToGCManageFavorites)

CMsgGCToClientManageFavoritesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientManageFavoritesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTMANAGEFAVORITESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientManageFavoritesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientManageFavoritesResponse)

CMsgClientToGCGetFavoritePlayers = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetFavoritePlayers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETFAVORITEPLAYERS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetFavoritePlayers)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetFavoritePlayers)

CMsgGCToClientGetFavoritePlayersResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientGetFavoritePlayersResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTGETFAVORITEPLAYERSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientGetFavoritePlayersResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientGetFavoritePlayersResponse)

CMsgGCToClientPartySearchInvite = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPartySearchInvite', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPARTYSEARCHINVITE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPartySearchInvite)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPartySearchInvite)

CMsgClientToGCVerifyFavoritePlayers = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVerifyFavoritePlayers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVERIFYFAVORITEPLAYERS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVerifyFavoritePlayers)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVerifyFavoritePlayers)

CMsgGCToClientVerifyFavoritePlayersResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientVerifyFavoritePlayersResponse', (_message.Message,), dict(

  Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE_RESULT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientVerifyFavoritePlayersResponse.Result)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTVERIFYFAVORITEPLAYERSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientVerifyFavoritePlayersResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientVerifyFavoritePlayersResponse)
_sym_db.RegisterMessage(CMsgGCToClientVerifyFavoritePlayersResponse.Result)

CMsgClientToGCRequestPlayerRecentAccomplishments = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerRecentAccomplishments', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerRecentAccomplishments)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerRecentAccomplishments)

CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERRECENTACCOMPLISHMENTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerRecentAccomplishmentsResponse)

CMsgClientToGCRequestPlayerHeroRecentAccomplishments = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerHeroRecentAccomplishments', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishments)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerHeroRecentAccomplishments)

CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERHERORECENTACCOMPLISHMENTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerHeroRecentAccomplishmentsResponse)

CMsgPlayerCoachMatch = _reflection.GeneratedProtocolMessageType('CMsgPlayerCoachMatch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPLAYERCOACHMATCH,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPlayerCoachMatch)
  ))
_sym_db.RegisterMessage(CMsgPlayerCoachMatch)

CMsgClientToGCRequestPlayerCoachMatches = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerCoachMatches', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerCoachMatches)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerCoachMatches)

CMsgClientToGCRequestPlayerCoachMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerCoachMatchesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerCoachMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerCoachMatchesResponse)

CMsgClientToGCRequestPlayerCoachMatch = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerCoachMatch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCH,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerCoachMatch)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerCoachMatch)

CMsgClientToGCRequestPlayerCoachMatchResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestPlayerCoachMatchResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTPLAYERCOACHMATCHRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCRequestPlayerCoachMatchResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestPlayerCoachMatchResponse)

CMsgClientToGCSubmitCoachTeammateRating = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSubmitCoachTeammateRating', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSubmitCoachTeammateRating)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSubmitCoachTeammateRating)

CMsgClientToGCSubmitCoachTeammateRatingResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSubmitCoachTeammateRatingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSUBMITCOACHTEAMMATERATINGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSubmitCoachTeammateRatingResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSubmitCoachTeammateRatingResponse)

CMsgGCToClientCoachTeammateRatingsChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCoachTeammateRatingsChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCOACHTEAMMATERATINGSCHANGED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientCoachTeammateRatingsChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCoachTeammateRatingsChanged)

CMsgClientToGCGetTicketCodesRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTicketCodesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETTICKETCODESREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTicketCodesRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTicketCodesRequest)

CMsgClientToGCGetTicketCodesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTicketCodesResponse', (_message.Message,), dict(

  Code = _reflection.GeneratedProtocolMessageType('Code', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETTICKETCODESRESPONSE_CODE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTicketCodesResponse.Code)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETTICKETCODESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetTicketCodesResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTicketCodesResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetTicketCodesResponse.Code)

CMsgClientToGCGetUnderlordsCDKeyRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetUnderlordsCDKeyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetUnderlordsCDKeyRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetUnderlordsCDKeyRequest)

CMsgClientToGCGetUnderlordsCDKeyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetUnderlordsCDKeyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETUNDERLORDSCDKEYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetUnderlordsCDKeyResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetUnderlordsCDKeyResponse)

CMsgClientToGCSetFavoriteAllStarPlayer = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetFavoriteAllStarPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetFavoriteAllStarPlayer)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetFavoriteAllStarPlayer)

CMsgClientToGCSetFavoriteAllStarPlayerResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetFavoriteAllStarPlayerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETFAVORITEALLSTARPLAYERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCSetFavoriteAllStarPlayerResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetFavoriteAllStarPlayerResponse)

CMsgClientToGCGetFavoriteAllStarPlayerRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetFavoriteAllStarPlayerRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetFavoriteAllStarPlayerRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetFavoriteAllStarPlayerRequest)

CMsgClientToGCGetFavoriteAllStarPlayerResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetFavoriteAllStarPlayerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETFAVORITEALLSTARPLAYERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCGetFavoriteAllStarPlayerResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetFavoriteAllStarPlayerResponse)

CMsgClientToGCVerifyIntegrity = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVerifyIntegrity', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVERIFYINTEGRITY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientToGCVerifyIntegrity)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVerifyIntegrity)


DESCRIPTOR._options = None
_CSODOTAGAMEHEROFAVORITES.fields_by_name['account_id']._options = None
_CSODOTAGAMEHEROFAVORITES.fields_by_name['hero_id']._options = None
# @@protoc_insertion_point(module_scope)
